function centerFrequencies = CalculateCenterFrequencies(nrOfFilters, ...
    minimumFrequency, maximumFrequency)

% CalculateCenterFrequencies calculates the center frequencies between
% "minimumFrequency" and "maximumFrequency" equidistant on an ERB-rate 
% scale. If the minimum frequency is lower than 75 Hz, it is set to 
% 75 Hz, in order to prevent errors in the calculation of the filter 
% coefficients. 

% Prevent errors for very low frequencies
if minimumFrequency < 75
    minimumFrequency = 75;
    warning('Minimum frequency set to 75 Hz.')
end

% Calculate center frequencies
minimumZ = Hz2ERB(minimumFrequency);
maximumZ = Hz2ERB(maximumFrequency);
z = linspace(minimumZ, maximumZ, nrOfFilters);
centerFrequencies = ERB2Hz(z);
