function d = DissonanceMeasure(f, amp)
%
% Given a set of partials in f, with amplitudes in amp,
% this routine calculates the dissonance.
%
% This routine is "DissMeasure.m" copied from:
%
% William A. Sethares (1999),
% "Tuning, timbre, spectrum, scale",
% Springer Verlag, Berlin, p. 301.

if ~exist('firstpass', 'var')
    Dstar = 0.24;
    S1 = 0.0207;
    S2 = 18.96;
    C1 = 5;
    C2 = -5;
    A1 = -3.51;
    A2 = -5.75;
    firstpass = 1; %#ok<NASGU>
end
N = length(f);
D = 0;
[f, ind] = sort(f);
ams = amp(ind);
for i = 2:N
    Fmin = f(1:N-i+1);
    S = Dstar./(S1*Fmin+S2);
    Fdif = f(i:N)-f(1:N-i+1);
    a = ams(i:N).*ams(1:N-i+1);
    Dnew = a.*(C1*exp(A1*S.*Fdif) + C2*exp(A2*S.*Fdif));
    D = D+Dnew*ones(size(Dnew))';
end
d = D;
  