function I_out = MiddleEarFilter(f, I_in)
% This software was written by Preeti Rao at the 
% Institute for Perception Research (IPO) in 1999, and 
% adapted by Dik Hermes, Human-Technology Interaction group,
% Eindhoven University of Technology in 2009.
% 
% The function MiddleEarFilter applies the effective attenuation by 
% the middle ear.  The arrays f and I_in give the frequencies and 
% intensities of the input components, respectively. 
% The data represent Figure 3 of: 
% Moore B.C.J., Glasberg B.R. & Baer T. (1997), 
% A model for the prediction of thresholds, loudness, 
% and partial loudness. 
% J. Audio Eng. Soc. 45(4), 224-240.
% (This figure 3 is reproduced by the commands at the bottom
% of this script.)

flt = [20.0 39.15
       25.0 31.4
       31.5 25.4
       40.0 20.9
       50.0 18.0
       63.0 16.1
       80.0 14.2
      100.0 12.5
      125.0 11.13
      160.0  9.71
      200.0  8.42
      250.0  7.20
      315.0  6.1
      400.0  4.7
      500.0  3.7
      630.0  3.0
      750.0  2.7
      800.0  2.6
     1000.0  2.6
     1250.0  2.7
     1500.0  3.7
     1600.0  4.6
     2000.0  8.5
     2500.0 10.8
     3000.0  7.3
     3150.0  6.7
     4000.0  5.7
     5000.0  5.7
     6000.0  7.6
     6300.0  8.4
     8000.0 11.9  %11.3
     9000.0 10.6
    10000.0  9.9
    11200.0 11.9
    12500.0 13.9
    14000.0 16.0
    15000.0 17.3
    16000.0 17.8];

a = interp1(flt(:, 1), flt(:, 2), f, 'linear');
I_out = I_in./(10.^(a/10));

% semilogx(flt(:, 1), flt(:, 2))
% axis([20 20000 0 40])
