function I_out = OuterEarFilter(f, I_in)
% This software was written by Preeti Rao at the 
% Institute for Perception Research (IPO) in 1999, and 
% adapted by Dik Hermes, Human-Technology Interaction group,
% Eindhoven University of Technology in 2009.
%
% The function OuterEarFilter applies the transfer from free field 
% to ear drum.  The arrays f and I_in give the frequencies and 
% intensities of the input components, respectively. 
% The data represent Figure 2 of: 
% Moore B.C.J., Glasberg B.R. & Baer T. (1997), 
% A model for the prediction of thresholds, loudness, 
% and partial loudness. 
% J. Audio Eng. Soc. 45(4), 224-240.
% (This figure 2 is reproduced by the commands at the bottom
% of this script.)

flt = [20.0   0.0
       25.0   0.0
       31.5   0.0
       40.0   0.0
       50.0   0.0
       63.0   0.0
       80.0   0.0
      100.0   0.0
      125.0   0.1
      160.0   0.3
      200.0   0.5
      250.0   0.9
      315.0   1.4
      400.0   1.6
      500.0   1.7
      630.0   2.5
      750.0   2.7
      800.0   2.6
     1000.0   2.6
     1250.0   3.2
     1500.0   5.2
     1600.0   6.6
     2000.0  12.0
     2500.0  16.8
     3000.0  15.3
     3150.0  15.2
     4000.0  14.2
     5000.0  10.7
     6000.0   7.1
     6300.0   6.4
     8000.0   1.8
     9000.0  -1.0 %-0.9
    10000.0  -1.6
    11200.0   1.9
    12500.0   4.9
    14000.0   2.0
    15000.0  -2.0
    16000.0   2.5];

I_dB = interp1(flt(:, 1), flt(:, 2), f, 'linear'); 
I_out = I_in.*10.^(I_dB/10);

% semilogx(flt(:, 1), flt(:, 2))
% axis([20 20000 -5 20])
