function toneSequence = SynthToneSequence(schemTime, schemFreq, ...
    sampleFrequency, envelope)
% SynthTones calculates a ssequence of n tonal sounds based on 
% the information in schemTime, a 2 x n matrix with the start and end 
% times of the partials in the colums, schemFreq, a 2 x n matrix with 
% the begin and end frequencies of the partials in the columns,
% sampleFrequency, the sample frequency of the sound, and
% envelope, containing the envelope of the tones.

durationTones = max(schemTime(2,:));
dt = 1/sampleFrequency;
toneSequence = zeros(size(dt:dt:durationTones));
for k = 1:size(schemTime, 2)
    t1 = schemTime(1, k);
    t2 = schemTime(2, k);
    f1 = schemFreq(1, k);
    f2 = schemFreq(2, k);
    t = t1+dt:dt:t2;
    instFreq = (t2-t)/(t2-t1)*f1 + (t-t1)/(t2-t1)*f2;
    tone = sin(2*pi*cumsum(instFreq)*dt);
    tone = tone.*envelope;
    tp = 1+floor(t1/dt);
    toneSequence(tp:tp+length(tone)-1) = ...
        toneSequence(tp:tp+length(tone)-1) + tone;
end