clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define the stimulus
sampleFrequency = 44100; % Hz
dt = 1/sampleFrequency;
durationTone = 0.12; % sec
durationInterval = 0.03; % sec
interval = zeros(size(dt:dt:durationInterval));
durationPause = 1; % sec
pause = zeros(size(dt:dt:durationPause));
t = dt:dt:durationTone;
fade = 0.02; % sec
nrOfOctaves = 3;
fLow = 440; % Hz
fHgh = fLow*2^nrOfOctaves;
freq = logspace(log10(fLow), log10(fHgh), 12*nrOfOctaves+1);
melody = [1 3 5 6 8 10 12 13 12 10 8 6 5 3 1];
n = 12;
nDisp = 7;
mixture = zeros(n, 2*length(melody));
for k = 1:n
    for j = 1:length(melody)
        mixture(k,2*j-1:2*j) = [floor(n*rand)+1 k-1+melody(j)];
    end
end
amp = 0.5;

% Calculate the schematic time-frequency distribution and the stimulus
stimulus = [];
envelope = amp*FadeInOut(ones(size(t)), sampleFrequency, fade, fade);
t0 = 0;
for k = 1:n
    for j = 1:length(mixture(k,:))
        f0 = freq(mixture(k,j));
        if k == nDisp
            schemTime(1:2, j) = [t0 t0+durationTone]; %#ok<SAGROW>
            schemFreq(1:2, j) = [f0 f0]; %#ok<SAGROW>
        end
        tone = amp*sin(2*pi*f0*t);
        tone = tone.*envelope;
        stimulus = [stimulus tone interval];  %#ok<AGROW>
        t0 = t0+durationTone+durationInterval;
    end
    stimulus = [stimulus pause];  %#ok<AGROW>
    t0 = t0+durationPause;
end

% Play and save the stimulus
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position of figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = 150; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 90; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the schematic time-frequency representation of the nDisp-th
% melody
panel = 1;
axes('Position', pos(panel,:))
dXTick = 0.5; % sec
durationStimulus = length(stimulus)*dt; % sec
xTick = 0:dXTick:durationStimulus+dXTick/4;
yTick = log2([fLow 2*fLow 4*fLow]);
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
    'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', xTick, 'XTickLabel', xTick, ...
    'YTick', yTick, 'YTickLabel', 2.^yTick)
schemFreq = log2(schemFreq);
for j = 1:size(schemTime, 2)
    plot([schemTime(1, j) schemTime(2, j)], ...
        [schemFreq(1, j) schemFreq(1, j)], ...
        'LineWidth', 2, 'Color', blueGreen)
end

t1 = (nDisp-1)*(2*length(melody)*(durationTone+durationInterval)+durationPause);
tAxis = [t1-dXTick/4 t1+2*length(melody)*(durationTone+durationInterval)+dXTick/4];
fAxis = log2([fLow/1.2 4*fLow*1.2]);
axis([tAxis fAxis])
xlabel('time (s)')
ylabel('frequency (Hz)', 'FontWeight', 'bold')


