clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define and synthesize the stimulus
sampleFrequency = 44100; % Hz
dt = 1/sampleFrequency;
durationTone = 0.1; % sec
t = dt:dt:durationTone;
durationInterval = 0.025; % sec
interval = zeros(size(dt:dt:durationInterval));
nrOfRepetitions = 8;
fade = 0.005; % sec
f0 = 440; % Hz
partials = ...
    f0*[1 3 5 7 9 11
        1 3 5 0 0 0
        1 3 5 7 9 11
        0 0 0 7 9 11
        1 3 5 7 9 11];
amp = 0.9/size(partials, 2);
envelopeTone = ...
    FadeInOut(ones(size(t)), sampleFrequency, fade, fade);

stimulus = [];
t0 = 0;
nrOfTones = 1;
for k = 1:size(partials, 1)
    for i = 1:nrOfRepetitions
        tone = zeros(size(t));
        for j = 1:size(partials, 2)
            f = partials(k, j);
            if f>0
                tone = tone + amp*sin(2*pi*f*t);
                schemTime(1:2, nrOfTones) = [t0 t0+durationTone]; %#ok<*SAGROW>
                schemFreq(1:2, nrOfTones) = [f f];
                nrOfTones = nrOfTones+1;
            end
        end
        tone = tone.*envelopeTone;
        stimulus =  [stimulus tone interval];  %#ok<*AGROW>
        t0 = t0+durationTone+durationInterval;
    end
end

% Save and play the sound segment
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position of figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = 240; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 80; % pixels
xMargin = 20; % pixels
yMargin = 20; % pixels
% Set the current figure handle and return the width and
% height of the figure.
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of the panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

dXTick = 1; % sec
dYTick = 1000; % kHz
maxYAxis = 6000; % Hz
durationStimulus = length(stimulus)*dt; % sec
tAxis = [-dXTick/4 durationStimulus+dXTick/4];
fAxis = [0 maxYAxis];

axes('Position', pos(1,:))
xTick = 0:dXTick:durationStimulus;
yTick = 0:dYTick:sampleFrequency/2;
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
    'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', xTick, ...
    'YTick', yTick, 'YTickLabel', yTick/1000)
for m = 1:size(schemTime, 2)
    plot([schemTime(1, m) schemTime(2, m)], ...
        [schemFreq(1,m) schemFreq(2,m)], ...
        'LineWidth', 2, 'Color', blueGreen)
end
xlabel('time (s)')
ylabel('frequency (kHz)')
axis([tAxis fAxis])

