clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define the stimulus
sampleFrequency = 10000; % Hz
durationTone = 0.18; % sec
durationInterval = 0.02; % sec
interOnsetInterval = durationTone+durationInterval;
nrOfRepetitions = 25;
fLow = 440; % hertz
fHgh = 880; % hertz
durationDelay = [0 0.03]; % delay in sec. of low tones rel. to high tones
% Calculated the modulation in frequency (fm) in octaves per sec. to make 
% the delayed low tone collinear with the following high tone.
fm = log2(fHgh/fLow)/(durationTone+durationInterval-durationDelay(2));
amp = 0.45;

% Synthesize the stimulus
dt = 1/sampleFrequency;
t = dt:dt:durationTone;
interval = zeros(size(dt:dt:durationInterval));
envelopeTone = exp(-t/(durationTone/4));

fInst = fHgh*2.^(fm*t);
toneHgh = amp*sin(2*pi*cumsum(fInst)*dt);
toneHgh = toneHgh.*envelopeTone;
fInst = fLow*2.^(fm*t);
toneLow = amp*sin(2*pi*cumsum(fInst)*dt);
toneLow = toneLow.*envelopeTone;
for k = 1:length(durationDelay)
    delay = zeros(size(dt:dt:durationDelay(k)));
    sHgh = [];
    t0 = 0;
    nrOfTones = 1;
    % Synthesize sequence of high tones
    for i = 1:2*nrOfRepetitions
        schemTime(k, 1:2, nrOfTones) = [t0 t0+durationTone]; %#ok<*SAGROW>
        schemFreq(k, 1:2, nrOfTones) = fHgh*[1 2^(fm*durationTone)];
        nrOfTones = nrOfTones+1;
        sHgh =  [sHgh toneHgh interval];  %#ok<*AGROW>
        t0 = t0+interOnsetInterval;
    end
    sHgh = [sHgh delay];
    % Synthesize sequence of low tones with a delay
    sLow = delay;
    t0 = durationDelay(k);
    for i = 1:2:2*nrOfRepetitions
        sLow = [sLow zeros(size(t)) interval];  %#ok<*AGROW>
        t0 = t0+interOnsetInterval;
        schemTime(k, 1:2, nrOfTones) = [t0 t0+durationTone]; %#ok<*SAGROW>
        schemFreq(k, 1:2, nrOfTones) = fLow*[1 2^(fm*durationTone)];
        nrOfTones = nrOfTones+1;
        sLow = [sLow toneLow interval];  %#ok<*AGROW>
        t0 = t0+interOnsetInterval;
    end
    s(k,1:length(sHgh)) = sHgh+sLow;
end
stimulus = [s(1,:) repmat(interval, 1, 20) s(2,:)];
durationStimulus = size(stimulus,2)*dt; % sec
% Save and play the sound segment
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position of figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = [120 120]; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 90; % pixels
xMargin = 20; % pixels
yMargin = 20; % pixels
% Set the current figure handle and return the width and
% height of the figure.
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of the panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

dXTick = 0.5; % sec
dYTick = 1000; % kHz
a = 440;
tAxis = [-dXTick/4 2+dXTick/4];
fAxis = [300 2100];
xTick = 0:dXTick:durationStimulus;
yTick = -1:log2(sampleFrequency/a);
for k = 1:length(durationDelay)
    % Plot the figure
    axes('Position', pos(k,:))
    set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
        'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
        'FontWeight', 'bold', 'TickDir', 'out', ...
        'XTick', xTick, ...
        'YTick', yTick, 'YTickLabel', (a*2.^yTick))
    lfAxis = log2(fAxis/a);
    sT(:,:) = schemTime(length(durationDelay)-k+1,:,:);
    sF(:,:) = schemFreq(length(durationDelay)-k+1,:,:);
    PlotSTlFR(stimulus, sampleFrequency, ...
        sT, sF, envelopeTone, ...
        tAxis, dXTick, ...
        fAxis, 0.03, blueGreen)
    plot([interOnsetInterval interOnsetInterval], ...
        lfAxis, ':', 'LineWidth', 1, 'Color' , blueGreen)
    set(gca, 'Color', lightYellowGreen)
    if k==1
        set(gca, 'XTick', 0:dXTick:durationStimulus, ...
            'XTickLabel', 0:dXTick:durationStimulus)
        xlabel('time (s)')
    end
    ylabel('freq. (Hz)')
    axis([tAxis lfAxis])
end
