clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define and synthesize the stimulus
sampleFrequency = 10000; % Hz
dt = 1/sampleFrequency;
interOnsetInterval = 0.125;
durationSilence = 0.025; % sec 
durationNoise = interOnsetInterval - durationSilence; % sec
t = dt:dt:durationNoise;
fade = 0.005; % sec 
% Continuous noise when durationSilence == -durationFade and
% consecutive noise bursts overlap by duration of fade
amp = 0.2;
cutOffMin = 100;
cutOffMid = 2500;
cutOffMax = 4900;
nrOfRepetitions = 8;
w = [2*cutOffMin/sampleFrequency 2*cutOffMax/sampleFrequency];
[bWide, aWide] = butter(4, w);
w = [2*cutOffMin/sampleFrequency 2*cutOffMid/sampleFrequency];
[bLow, aLow] = butter(4, w);
w = [2*cutOffMid/sampleFrequency 2*cutOffMax/sampleFrequency];
[bHgh, aHgh] = butter(4, w);
% Overlap and add
lt = length(t);
ls = round(durationSilence/dt);
stimulus = zeros(1, 5*nrOfRepetitions*(lt+ls-1)-ls+1);
envelope = FadeInOut(ones(size(t)), sampleFrequency, fade, fade);
i = 0;
for k = 1:nrOfRepetitions
    noise = amp*randn(size(t));
    noise = filtfilt(bWide, aWide, noise);
    noise = noise.*envelope;
    stimulus(i+(1:lt)) = stimulus(i+(1:lt))+noise;
    i = i+lt+ls-1;
end
for k = 1:nrOfRepetitions
    noise = amp*randn(size(t));
    noise = filtfilt(bLow, aLow, noise);
    noise = noise.*envelope;
    stimulus(i+(1:lt)) = stimulus(i+(1:lt))+noise;
    i = i+lt+ls-1;
end
for k = 1:nrOfRepetitions
    noise = amp*randn(size(t));
    noise = filtfilt(bWide, aWide, noise);
    noise = noise.*envelope;
    stimulus(i+(1:lt)) = stimulus(i+(1:lt))+noise;
    i = i+lt+ls-1;
end
for k = 1:nrOfRepetitions
    noise = amp*randn(size(t));
    noise = filtfilt(bHgh, aHgh, noise);
    noise = noise.*envelope;
    stimulus(i+(1:lt)) = stimulus(i+(1:lt))+noise;
    i = i+lt+ls-1;
end
for k = 1:nrOfRepetitions
    noise = amp*randn(size(t));
    noise = filtfilt(bWide, aWide, noise);
    noise = noise.*envelope;
    stimulus(i+(1:lt)) = stimulus(i+(1:lt))+noise;
    i = i+lt+ls-1;
end

% Save and play the sound segment
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = 240; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 80; % pixels
xMargin = 20; % pixels
yMargin = 20; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the spectrogram
dXTick = 1; % sec
dYTick = 1; % kHz
maxYAxis = 6000; % Hz
durationStimulus = length(stimulus)*dt; % sec
xTick = -dXTick:dXTick:durationStimulus+dXTick;
tAxis = [-0.2*dXTick durationStimulus+0.2*dXTick];
fAxis = [-20 maxYAxis];
nFft = 1024; % Number of samples in fft window
nWindow = 128;
nOverlap = nWindow-4;
durationPadding = 0.025; % sec
padding = zeros(size(dt:dt:durationPadding));
[~, f, ts, p] = spectrogram([padding stimulus padding], ...
    nWindow, nOverlap, nFft, sampleFrequency);
p = 10*log10(abs(p));
ts = ts-durationPadding;
PlotSpectrogram(stimulus, sampleFrequency, ...
    f, ts, p, tAxis, dXTick, fAxis, dYTick, 40, ...
    frameColor)
set(gca, 'XTick', xTick, 'XTickLabel', xTick, ...
    'Color', lightYellowGreen)
text(0.99*tAxis(1)+0.01*tAxis(2), fAxis(1)+0.925*(fAxis(2)-fAxis(1)), ...
    'spectrogram', 'FontSize', 14, 'FontWeight', 'bold')
xlabel('time (s)')


