clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define the stimulus
sampleFrequency = 10000; % Hz
dt = 1/sampleFrequency;
durationTone = 0.1; % sec
tTone = dt:dt:durationTone;
durationInterval = 0.025; % sec
tInterval = dt:dt:durationInterval;
interval = zeros(size(tInterval));
durationFade = [1.0 0.7 0.4 0.2]*durationInterval; % sec
amp = 0.9;
fLow = 440;
fHigh = 660;
nrOfTriplets = 20;

% Synthesize the stimulus
% Calculate the instantaneous frequency
instFreqLow = fLow*ones(1, length(tTone));
instFreqHigh = fHigh*ones(1, length(tTone));
glide = tInterval/durationInterval;
instFreqLowHigh = (1-glide)*fLow+glide*fHigh;
instFreqHighLow = fliplr(instFreqLowHigh);
tripletFreq = [fLow*ones(1, length(instFreqLowHigh)) instFreqLow ...
    instFreqLowHigh instFreqHigh instFreqHighLow instFreqLow ...
    fLow*ones(1, length(instFreqLowHigh)+length(instFreqHigh))];
instFreq = repmat(tripletFreq, 1, nrOfTriplets);
phi = 2*pi*cumsum(instFreq)*dt;
carrier = sin(phi);
% Calculate the instantaneous amplitude
instAmp = zeros(length(durationFade), ...
    2*nrOfTriplets*(2*length(tTone)+2*length(tInterval)));
stimulus = [];
for k = 1:length(durationFade)
    tFade = dt:dt:durationFade(k);
    leftFade = zeros(size(tInterval));
    leftFade(1:length(tFade)) = 1-tFade/durationFade(k);
    rightFade = fliplr(leftFade);
    fade = leftFade+rightFade;
    periodAmp = [rightFade ones(size(tTone)) fade ones(size(tTone)) ...
        fade ones(size(tTone)) leftFade zeros(size(tTone))];
    instAmp(k,:) = repmat(periodAmp, 1, nrOfTriplets);
    stimulus = [stimulus amp*instAmp(k,:).*carrier ...
        repmat(zeros(size(tTone)), 1, 10)]; %#ok<AGROW>
end

% Save and play the sound
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Specify the figure parameters
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = ones(1, length(durationFade))*120; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 90; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels

% Calculate the position of the figure on the screen
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the schematic spectrotemporal representation
dXTick = 0.5; % sec
dYTick = 200; % kHz
xTick = 0:dXTick:length(instFreq)*dt;
tAxis = [0 1.42];
fAxis = [200 900];
for k = 1:length(durationFade)
    panel = length(durationFade)-k+1;
    axes('Position', pos(panel,:))
    if k == length(durationFade)
        xTickLabel = xTick;
    else
        xTickLabel = [];
    end
    set(gca, 'LineWidth', 2, 'FontSize', 14, ...
        'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
        'FontWeight', 'bold', 'TickDir', 'out', ...
        'XTick', xTick, ...
        'XTickLabel', xTickLabel, ...
        'YTick', 0:dYTick:sampleFrequency/2)
    % Calculate the plot parameters
    durationStimulus = (length(instAmp)-1)*dt; % sec
    tStimulus = dt:dt:durationStimulus;
    for i = 1:10:length(tStimulus)
        plot([tStimulus(i) tStimulus(i)], ...
            [instFreq(i)-30*instAmp(k,i) instFreq(i)+30*instAmp(k,i)], ...
            'LineWidth', 0.5, 'Color', blueGreen)
    end
    axis([tAxis fAxis])
    if k == length(durationFade)
        xlabel('time (s)')
    end
    ylabel('freq. (Hz)')
end

