clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define the stimulus
sampleFrequency = 10000; % Hz
dt = 1/sampleFrequency;
durationTone = 0.08; % sec
tTone = dt:dt:durationTone;
durationInterval = 0.045; % sec
tInterval = dt:dt:durationInterval;
interval = zeros(size(tInterval));
durationFade = 0.5*durationInterval; % sec
amp = 0.9;
fLow = 440;
fHigh = 660;
nrOfTriplets = 20;

% Synthesize the stimulus
% Calculate the instantaneous amplitude
tFade = dt:dt:durationFade;
leftFade = zeros(size(tInterval));
leftFade(1:length(tFade)) = 1-tFade/durationFade;
rightFade = fliplr(leftFade);
fade = leftFade+rightFade;
periodAmp = [rightFade ones(size(tTone)) fade ones(size(tTone)) ...
    fade ones(size(tTone)) leftFade zeros(size(tTone))];
instAmp = repmat(periodAmp, 1, nrOfTriplets);

% Calculate the instantaneous frequency in the no glide condition
instFreqLow = fLow*ones(1, length(tTone));
instFreqHigh = fHigh*ones(1, length(tTone));
r = round(length(tInterval)/2);
instFreqLowHigh(1:r) = fLow;
instFreqLowHigh((r+1):length(tInterval)) = fHigh;
instFreqHighLow = fliplr(instFreqLowHigh);
tripletFreq = [fLow*ones(1, length(instFreqLowHigh)) instFreqLow ...
    instFreqLowHigh instFreqHigh instFreqHighLow instFreqLow ...
    fLow*ones(1, length(instFreqLowHigh)+length(instFreqHigh))];
instFreqNoGlide = repmat(tripletFreq, 1, nrOfTriplets);
phi = 2*pi*cumsum(instFreqNoGlide)*dt;
carrier = sin(phi);
stimulus = [amp*instAmp.*carrier ...
    repmat(zeros(size(tTone)), 1, 10)];

% Calculate the instantaneous frequency in the glide condition
glide = tInterval/durationInterval;
instFreqLowHigh = (1-glide)*fLow+glide*fHigh;
instFreqHighLow = fliplr(instFreqLowHigh);
tripletFreq = [fLow*ones(1, length(instFreqLowHigh)) instFreqLow ...
    instFreqLowHigh instFreqHigh instFreqHighLow instFreqLow ...
    fLow*ones(1, length(instFreqLowHigh)+length(instFreqHigh))];
instFreqGlide = repmat(tripletFreq, 1, nrOfTriplets);
phi = 2*pi*cumsum(instFreqGlide)*dt;
carrier = sin(phi);
% Calculate the instantaneous amplitude
stimulus = [stimulus amp*instAmp.*carrier];

% Save and play the sound
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Specify the figure parameters
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = [120 120]; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 90; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels

% Calculate the position of the figure on the screen
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the schematic spectrotemporal representation for the glide
% condition
dXTick = 0.5; % sec
dYTick = 200; % kHz
xTick = 0:dXTick:length(instFreqGlide)*dt;
axes('Position', pos(1,:))
set(gca, 'LineWidth', 2, 'FontSize', 14, ...
    'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', xTick, 'YTick', 0:dYTick:sampleFrequency/2)
durationStimulus = (length(instAmp)-1)*dt; % sec
tStimulus = dt:dt:durationStimulus;
for i = 1:10:length(tStimulus)
    plot([tStimulus(i) tStimulus(i)], ...
        [instFreqGlide(i)-30*instAmp(i) ...
        instFreqGlide(i)+30*instAmp(i)], ...
        'LineWidth', 0.5, 'Color', blueGreen)
end
tAxis = [0 1.42];
fAxis = [200 900];
axis([tAxis fAxis])
xlabel('time (s)')
ylabel('freq. (Hz)')

% Plot the schematic spectrotemporal representation for the no-glide
% condition
axes('Position', pos(2,:))
xTickLabel = xTick;
set(gca, 'LineWidth', 2, 'FontSize', 14, ...
    'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', xTick, 'XTickLabel', [], ...
    'YTick', 0:dYTick:sampleFrequency/2)
for i = 1:10:length(tStimulus)
    plot([tStimulus(i) tStimulus(i)], ...
        [instFreqNoGlide(i)-30*instAmp(i) instFreqNoGlide(i)+30*instAmp(i)], ...
        'LineWidth', 0.5, 'Color', blueGreen)
end
axis([tAxis fAxis])
ylabel('freq. (Hz)')

