clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

fprintf('%s\n\n', 'Stimuli according to Carlyon et al. 2004.')

% Specify the stimulus
sampleFrequency = 10000; % Hz
durationTone = 1; % sec
f0 = 1000; % Hz
fm = 5; % Hz
md = 0.1;
mi = md*f0/fm;
ampTone = 0.02;
durationInterval = 1; % sec
% Specify the noise bursts
bandWidth = 1; % octaves
cutOffMin = f0*2^(-bandWidth/2);
cutOffMax = f0*2^(bandWidth/2);
ampNoise = 0.6;
periodEnvelope = 3/fm;
p = 1/3; % proportion of period of envelope occupied by noise
durationBurst = p*periodEnvelope; % sec
durationGap = durationBurst; % sec
fade = 0.005; % sec

% Calculate the continuous tone
dt = 1/sampleFrequency;
t = dt:dt:durationTone;
fInst = f0-mi*fm*square(pi*t/periodEnvelope+pi*p/2) .* ...
    sin(2*pi*fm*(t+durationGap/2));
tone = ampTone*sin(2*pi*cumsum(fInst)*dt);
tone = FadeInOut(tone, sampleFrequency, fade, fade);
durationStimulus = length(tone)*dt; % sec

% Calculate the continuous noise
w = [2*cutOffMin/sampleFrequency 2*cutOffMax/sampleFrequency];
[b, a] = butter(4, w);
noise = ampNoise*filtfilt(b, a, randn(size(tone)));

% Calculate the envelope of the noise and the tone
tInterval  = dt:dt:periodEnvelope;
% Calculate the envelope of the noise
envelopeNoise = zeros(size(dt:dt:periodEnvelope));
tNoise = dt:dt:durationBurst;
envBurst = FadeInOut(ones(size(tNoise)), sampleFrequency, fade, fade);
i1 = length(tInterval)-length(tNoise);
i2 = i1+length(tNoise)-1;
envelopeNoise(i1:i2) = envBurst;
% Calculate the envelope of the tone
envelopeTone = zeros(size(dt:dt:periodEnvelope));
tGap = dt:dt:durationGap;
envGap = FadeInOut(ones(size(tGap)), sampleFrequency, fade, fade);
i1 = length(tInterval)-length(tGap);
i2 = i1+length(tGap)-1;
envelopeTone(i1:i2) = envGap;

% Generate the interrupted tones, the noise bursts and the combination
nrOfRepetitions = ceil(durationStimulus/periodEnvelope);
envelopeNoise = repmat(envelopeNoise, 1, nrOfRepetitions);
envelopeTone = 1-repmat(envelopeTone, 1, nrOfRepetitions);
noiseBursts = noise.*envelopeNoise(1:length(tone));
interruptedTone = tone.*envelopeTone(1:length(tone));
stimContIll = interruptedTone + noiseBursts;
interval = zeros(size(dt:dt:durationInterval));
stimulus = [tone interval interruptedTone interval stimContIll];

% Save and play the stimulus
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = [150 150 150]; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 70; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the spectrograms

% number of samples in one fft window and
nFft = 1024; % Number of samples in fft window
nWindow = 128;
nOverlap = nWindow-32;

% Plot the spectrogram of the sum of the bursts and the interrupted tones
tAxis = [-0.1 durationTone+0.1];
maxYAxis = 2000; % Hz
fAxis = [0 maxYAxis];
dXTick = 0.2; % sec
dYTick = 1; % kHz
panel = 1;
axes('Position', pos(panel,:))
[~, f, ts, spgr] = spectrogram(stimContIll, ...
    nWindow, nOverlap, nFft, sampleFrequency);
spgr = 10*log10(abs(spgr));
PlotSpectrogram(stimulus, sampleFrequency, ...
    f, ts, spgr, tAxis, dXTick, fAxis, dYTick, 25, ...
    frameColor)
set(gca, 'XTick', 0:dXTick:durationStimulus, ...
    'XTickLabel', 0:dXTick:durationStimulus, ...
    'Color', lightYellowGreen)
xlabel('time (s)')
ylabel('freq. (kHz)')
caxis([-75 -40])

% Plot the spectrogram of the sum of the uninterrupted tones
panel = panel+1;
axes('Position', pos(panel,:))
[~, f, ts, spgr] = spectrogram(interruptedTone, ...
    nWindow, nOverlap, nFft, sampleFrequency);
spgr = 10*log10(abs(spgr));
PlotSpectrogram(stimulus, sampleFrequency, ...
    f, ts, spgr, tAxis, dXTick, fAxis, dYTick, 25, ...
    frameColor)
set(gca, 'Color', lightYellowGreen)
ylabel('freq. (kHz)')
caxis([-75 -40])

% Plot the spectrogram of the sum of the uninterrupted tones
panel = panel+1;
axes('Position', pos(panel,:))
[~, f, ts, spgr] = spectrogram(tone, ...
    nWindow, nOverlap, nFft, sampleFrequency);
spgr = 10*log10(abs(spgr));
PlotSpectrogram(stimulus, sampleFrequency, ...
    f, ts, spgr, tAxis, dXTick, fAxis, dYTick, 25, ...
    frameColor)
set(gca, 'Color', lightYellowGreen)
ylabel('freq. (kHz)')
caxis([-75 -40])

