clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Specify the stimulus
sampleFrequency = 5000; % Hz
durationTone = 3; % sec
f0 = 880; % Hz
ampTone = 0.04;
% Specify the noise bursts
bandWidth = 1; % octaves
cutOffMin = f0*2^(-bandWidth);
cutOffMax = f0*2^(bandWidth);
ampNoise = 0.2;
periodEnvelope = 0.2; % sec
durationBurst = 0.1; % sec
durationGap = 0.1; % sec
fade = 0.02; % sec

% Calculate the continuous tone
dt = 1/sampleFrequency;
t = dt:dt:durationTone;
fm = 0.5/periodEnvelope;
mi = f0/fm;
instFreq = f0+mi*sawtooth(2*pi*fm*t+pi/4, 0.5);
tone = ampTone*sin(2*pi*cumsum(instFreq)*dt);
tone = FadeInOut(tone, sampleFrequency, fade, fade);
durationStimulus = length(tone)*dt; % sec

% Calculate the continuous noise
w = [2*cutOffMin/sampleFrequency 2*cutOffMax/sampleFrequency];
[b, a] = butter(4, w);
noise = ampNoise*filtfilt(b, a, randn(size(tone)));

% Calculate the envelope of the noise and the tone
fade = 0.01; % sec
tInterval  = dt:dt:periodEnvelope;
% Calculate the envelope of the noise
envelopeNoise = zeros(size(dt:dt:periodEnvelope));
tNoise = dt:dt:durationBurst;
envBurst = FadeInOut(ones(size(tNoise)), sampleFrequency, fade, fade);
i1 = length(tInterval)-length(tNoise);
i2 = i1+length(tNoise)-1;
envelopeNoise(i1:i2) = envBurst;
% Calculate the envelope of the tone
envelopeTone = zeros(size(dt:dt:periodEnvelope));
tGap = dt:dt:durationGap;
envGap = FadeInOut(ones(size(tGap)), sampleFrequency, fade, fade);
i1 = length(tInterval)-length(tGap);
i2 = i1+length(tGap)-1;
envelopeTone(i1:i2) = envGap;

% Generate the interrupted tones, the noise bursts and the combination
nrOfRepetitions = ceil(durationStimulus/periodEnvelope);
envelopeNoise = repmat(envelopeNoise, 1, nrOfRepetitions);
envelopeTone = 1-repmat(envelopeTone, 1, nrOfRepetitions);
noiseBursts = noise.*envelopeNoise(1:length(tone));
interruptedTone = tone.*envelopeTone(1:length(tone));
stimContIll = interruptedTone + noiseBursts;
stimulus = stimContIll;

% Save and play the stimulus
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Specify the figure parameters
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = 150; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 70; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
nrOfPanels = length(panelHeights);
% Calculate the position of the figure on the screen
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the spectrogram of the sum of the bursts and the interrupted tones
nFft = 256; % Number of samples in fft window
nWindow = 64;
nOverlap = nWindow-32;
tAxis = [-0.1 durationTone+0.1];
maxYAxis = sampleFrequency/2; % Hz
fAxis = [0 maxYAxis];
dXTick = 0.5; % sec
dYTick = 1; % kHz
panel = 1;
axes('Position', pos(panel,:))
[~, f, ts, spgr] = spectrogram(stimContIll, ...
    nWindow, nOverlap, nFft, sampleFrequency);
spgr = 10*log10(abs(spgr));
PlotSpectrogram(stimulus, sampleFrequency, ...
    f, ts, spgr, tAxis, dXTick, fAxis, dYTick, 25, ...
    frameColor)
set(gca, 'XTick', 0:dXTick:durationStimulus, ...
    'XTickLabel', 0:dXTick:durationStimulus, ...
    'Color', lightYellowGreen)
xlabel('time (s)')
ylabel('freq. (kHz)')

