clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

fprintf('\n%s\n\n', 'Sounds as used by Haywood, Chang, & Ciocca, 2011')

% Specify the stimulus
sampleFrequency = 5000; % Hz
durationTone = 12; % sec
f0 = 880; % Hz
ampTone = 0.02;
durationInterval = 1; % sec

% Specify the noise bursts
bandWidth = 1; % octaves
cutOffMin = f0*2^(-bandWidth/2);
cutOffMax = f0*2^(bandWidth/2);
ampNoise = 0.4;
periodEnvelope = 1.0; % sec
durationGap = [0.48 0.36 0]; % sec
durationBurst = 0.36; % sec
durationGapInBurst = 0.06; % sec
fade = 0.01; % sec

% Calculate the continuous tone
dt = 1/sampleFrequency;
t = dt:dt:durationTone;
tone = ampTone*sin(2*pi*f0*t);
tone = FadeInOut(tone, sampleFrequency, fade, fade);
durationStim = length(tone)*dt; % sec

% Calculate the continuous noise
w = [2*cutOffMin/sampleFrequency 2*cutOffMax/sampleFrequency];
[b, a] = butter(4, w);
noise = ampNoise*filtfilt(b, a, randn(size(tone)));

% Calculate the envelope of the noise and the tone
fade = 0.01; % sec
tInterval  = dt:dt:periodEnvelope;
% Calculate the envelope of the noise
envelopeNoise = zeros(size(dt:dt:periodEnvelope));
tNoise = dt:dt:durationBurst;
envBurst = FadeInOut(ones(size(tNoise)), sampleFrequency, fade, fade);
i1 = round((length(tInterval)-length(tNoise))/2);
i2 = i1+length(tNoise)-1;
envelopeNoise(i1:i2) = envBurst;
tGapInBurst = dt:dt:durationGapInBurst;
gapInBurst = ...
    FadeInOut(ones(size(tGapInBurst)), sampleFrequency, fade, fade);
i1 = round((length(tInterval)-length(tGapInBurst))/2);
i2 = i1+length(tGapInBurst)-1;
envelopeNoise(i1:i2) = 1-gapInBurst;
stim = zeros(length(durationGap), length(t));
interval = zeros(size(dt:dt:durationInterval));
stimulus = [];
for k = 1:length(durationGap)
    % Calculate the envelope of the tone
    envelopeTone = zeros(size(dt:dt:periodEnvelope));
    tGap = dt:dt:durationGap(k);
    envGap = FadeInOut(ones(size(tGap)), sampleFrequency, fade, fade);
    i1 = round((length(tInterval)-length(tGap))/2);
    i2 = i1+length(tGap)-1;
    envelopeTone(i1:i2) = envGap;
    
    % Generate the interrupted tones, the noise bursts and the combination
    nrOfRepetitions = ceil(durationStim/periodEnvelope);
    envelopeNoise = repmat(envelopeNoise, 1, nrOfRepetitions);
    envelopeTone = 1-repmat(envelopeTone, 1, nrOfRepetitions);
    noiseBursts = noise.*envelopeNoise(1:length(tone));
    interruptedTone = tone.*envelopeTone(1:length(tone));
    stim(k,:) = interruptedTone + noiseBursts;
    stimulus = [stimulus stim(k,:) interval]; %#ok<AGROW>
end
% Save and play the stimulus
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = [150 150 150]; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 70; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the spectrograms
nFft = 256; % number of samples in one fft, including padded zeros
nWindow = 64; % length of analysis window
nOverlap = nWindow-32;
tAxis = [-0.1 durationTone+0.1];
maxYAxis = sampleFrequency/2; % Hz
fAxis = [0 maxYAxis];
dXTick = 2; % sec
dYTick = 1; % kHz
for k = 1:length(durationGap)
    axes('Position', pos(length(durationGap)-k+1,:))
    [~, f, ts, spgr] = spectrogram(stim(k,:), ...
        nWindow, nOverlap, nFft, sampleFrequency);
    spgr = 10*log10(abs(spgr));
    PlotSpectrogram(stim, sampleFrequency, ...
        f, ts, spgr, tAxis, dXTick, fAxis, dYTick, 40, ...
        frameColor)
    set(gca, 'Color', lightYellowGreen)
    if k == length(durationGap)
        set(gca, 'XTick', 0:dXTick:durationStim, ...
            'XTickLabel', 0:dXTick:durationStim)
        xlabel('time (s)')
    end
    ylabel('freq. (kHz)')
end

