clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Specify the stimulus
sampleFrequency = 5000; % Hz
dt = 1/sampleFrequency;
durationTexture = 14; % sec
tTexture = dt:dt:durationTexture;
f0 = 880; % Hz
durationInterval = 2; % sec
% Specify the noise bursts
ampNoise = 0.15;
periodEnvelope = 4; % sec
durationGap = 2; % sec
durationBurst = 2; % sec
fade = 0.01; % sec

% Calculate the textures
texture = zeros(size(tTexture));
fCentr = 200; % Hz
df = fCentr/2;
fMod = 5; % Hz
ampTexture = 0.2;
md = 0.3;
fInst = fCentr+df*sin(2*pi*fMod*tTexture);
sinusoid = ampTexture*sin(2*pi*cumsum(fInst)*dt);
jitter = 1/fCentr/dt;
for i=2:length(sinusoid)
    if sinusoid(i-1)<0 && sinusoid(i)>=0
        j = i+round(jitter*(0.5*randn-0.5));
        if j>0 && j<=length(tTexture)
            texture(j) = ampTexture;
        end
    end
end
durationTexture = length(texture)*dt; % sec

% Calculate the white noise
noise = ampNoise*randn(size(texture));

% Calculate the envelope of the noise and the tone
tInterval  = dt:dt:periodEnvelope;
% Calculate the envelope of the noise
envelopeNoise = zeros(size(dt:dt:periodEnvelope));
tNoise = dt:dt:durationBurst;
envBurst = FadeInOut(ones(size(tNoise)), sampleFrequency, fade, fade);
i1 = length(tInterval)-length(tNoise);
i2 = i1+length(tNoise)-1;
envelopeNoise(i1:i2) = envBurst;
% Calculate the envelope of the tone
envelopeTexture = zeros(size(dt:dt:periodEnvelope));
tGap = dt:dt:durationGap;
envGap = FadeInOut(ones(size(tGap)), sampleFrequency, fade, fade);
i1 = length(tInterval)-length(tGap);
i2 = i1+length(tGap)-1;
envelopeTexture(i1:i2) = envGap;

% Generate the interrupted texture, the noise bursts and the combination
nrOfRepetitions = ceil(durationTexture/periodEnvelope);
envelopeNoise = repmat(envelopeNoise, 1, nrOfRepetitions);
envelopeTexture = 1-repmat(envelopeTexture, 1, nrOfRepetitions);
noiseBursts = noise.*envelopeNoise(1:length(texture));
interruptedTexture = texture.*envelopeTexture(1:length(texture));
stimContIll = interruptedTexture + noiseBursts;
interval = zeros(size(dt:dt:durationInterval));
stimulus = [interruptedTexture interval noiseBursts interval stimContIll];

% Low-pass filter the stimulus
cutOffLow = 2000; % Hz
[b, a] = butter(4, 2*cutOffLow/sampleFrequency, 'low');
stimulus = filter(b, a, stimulus);

% Save and play the stimulus
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the figure parameters
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = [150 150 150]; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 70; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
% Calculate the position of the figure on the screen
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the spectrogram of the sum of the bursts and the interrupted tones
durationStimulus = length(stimulus)*dt; % sec
tAxis = [-0.5 durationTexture+0.5]+2*(durationTexture+durationInterval);
fAxis = [0 sampleFrequency/2];
dXTick = 2; % sec
xTick = 0:dXTick:durationStimulus;
XTickLabel = xTick-round(2*(durationTexture+durationInterval));
dYTick = 1; % kHz
dBRange = 40;
panel = 1;
axes('Position', pos(panel,:))
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
    'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', xTick, 'XTickLabel', XTickLabel, ...
    'YTick', 0:1000*dYTick:sampleFrequency/2, ...
    'YTickLabel', 0:dYTick:sampleFrequency/2000)
% Calculate and plot the spectrograms
nFft = 256; % Number of samples in fft window
nWindow = 64;
nOverlap = nWindow-32;
[~, f, ts, spgr] = spectrogram(stimulus, ...
    nWindow, nOverlap, nFft, sampleFrequency);
spgr = 10*log10(abs(spgr));
PlotSpectrogram(stimulus, sampleFrequency, ...
    f, ts, spgr, tAxis, dXTick, fAxis, dYTick, ...
    dBRange, lightYellowGreen)
set(gca, 'XTickLabel', XTickLabel)
xlabel('time (s)')
ylabel('freq. (kHz)', 'FontWeight', 'bold')

% Plot the spectrogram of the interrupted tones
panel = panel+1;
axes('Position', pos(panel,:))
tAxis = [-0.5 durationTexture+0.5]+durationTexture+durationInterval;
PlotSpectrogram(stimulus, sampleFrequency, ...
    f, ts, spgr, tAxis, dXTick, fAxis, dYTick, ...
    dBRange, lightYellowGreen)
ylabel('freq. (kHz)', 'FontWeight', 'bold')

% Plot the spectrogram of the sum of the interrupted texture and the noise
panel = panel+1;
axes('Position', pos(panel,:))
tAxis = [-0.5 durationTexture+0.5];
PlotSpectrogram(stimulus, sampleFrequency, ...
    f, ts, spgr, tAxis, dXTick, fAxis, dYTick, ...
    dBRange, lightYellowGreen)
ylabel('freq. (kHz)', 'FontWeight', 'bold')

