clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Specify the stimulus
sampleFrequency = 8000; % Hz
durationTone = 0.2; % sec
nrOfRepetitions = 25;
fLow = 440;
fHgh = 880;
amp = 0.2;
% Specify the noise bursts
cutOffMin = 100;
cutOffMax = 2000;
durationInterval = 0.47; % sec
durationBurst = 0.18; % sec
fade = 0.01; % sec

% Calculate the stimulus
dt = 1/sampleFrequency;
t = dt:dt:durationTone;
envelopeTone = ...
    exp(-t/(durationTone/6));
toneHgh = amp*sin(2*pi*fHgh*t).*envelopeTone;
toneLow = amp*sin(2*pi*fLow*t).*envelopeTone;
sHgh = repmat(toneHgh, 1, 2*nrOfRepetitions);
sLow = repmat([zeros(size(t)) toneLow], 1, nrOfRepetitions);
tones = sHgh+sLow;
durationStimulus = length(tones)*dt; % sec
tInterval  = dt:dt:durationInterval;
interval = zeros(size(tInterval));
tNoise = dt:dt:durationBurst;
% Generate the envelope
env = FadeInOut(ones(size(tNoise)), sampleFrequency, fade, fade);
nrOfBursts = ceil(durationStimulus/(durationInterval+durationBurst));
envelope = repmat([interval env], 1, nrOfBursts);
% Generate the noise
w = [2*cutOffMin/sampleFrequency 2*cutOffMax/sampleFrequency];
[b, a] = butter(4, w);
noise = 0.2*filtfilt(b, a, randn(size(tones)));
% Generate the interrupted tones, the noise bursts and the combination
noiseBursts = noise.*envelope(1:length(tones));
interruptedTones = tones.*(1-envelope(1:length(tones)));
stimContIll = interruptedTones + noiseBursts;
stimulus = [tones interval interruptedTones interval stimContIll];

% Save and play the stimulus
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = [90 150 150 150]; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 70; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the speech signal
panel = 1;
axes('Position', pos(panel,:))
tAxis = [-0.1 3.1];
fAxis = [0 1.5*cutOffMax];
dXTick = 0.5; % sec
dYTick = 1; % kHz
PlotSignal(stimContIll, sampleFrequency, ...
    tAxis, dXTick, blueGreen, 'time (s)')
set(gca, 'XTick', 0:dXTick:durationStimulus, ...
    'XTickLabel', 0:dXTick:durationStimulus, ...
    'Color', lightYellowGreen)

% Plot the spectrogram of the sum of the bursts and the interrupted tones
panel = panel+1;
axes('Position', pos(panel,:))
nFft = 256; % Number of samples in fft window
nWindow = 64;
nOverlap = nWindow-32;
[~, f, ts, spgr] = spectrogram(stimContIll, ...
    nWindow, nOverlap, nFft, sampleFrequency);
spgr = 10*log10(abs(spgr));
PlotSpectrogram(stimulus, sampleFrequency, ...
    f, ts, spgr, tAxis, dXTick, fAxis, dYTick, 40, ...
    frameColor)
set(gca, 'Color', lightYellowGreen)
ylabel('freq. (kHz)')

% Plot the spectrogram of the interrupted tones
panel = panel+1;
axes('Position', pos(panel,:))
[~, f, ts, spgr] = spectrogram(interruptedTones, ...
    nWindow, nOverlap, nFft, sampleFrequency);
spgr = 10*log10(abs(spgr));
PlotSpectrogram(stimulus, sampleFrequency, ...
    f, ts, spgr, tAxis, dXTick, fAxis, dYTick, 40, ...
    frameColor)
set(gca, 'Color', lightYellowGreen)
ylabel('freq. (kHz)')

% Plot the spectrogram of the sum of the uninterrupted tones
panel = panel+1;
axes('Position', pos(panel,:))
[~, f, ts, spgr] = spectrogram(tones, ...
    nWindow, nOverlap, nFft, sampleFrequency);
spgr = 10*log10(abs(spgr));
PlotSpectrogram(stimulus, sampleFrequency, ...
    f, ts, spgr, tAxis, dXTick, fAxis, dYTick, 40, ...
    frameColor)
set(gca, 'Color', lightYellowGreen)
ylabel('freq. (kHz)')

