clear
close all
InitializePSS()

% Define the stimulus
sampleFrequency = 44100; % Hz
dt = 1/sampleFrequency;
durationTone = 0.10; % sec
t = dt:dt:durationTone;
durationInterval = 0.02; % sec
interval = zeros(size(dt:dt:durationInterval));
ioi = durationTone+durationInterval;
silenceDuration = 4; % sec
silence = repmat([0 0 0 0], 1, round(silenceDuration/(4*ioi)));
fade = 0.02; % sec
fLow = 440; % Hz
fHgh = 880; % Hz
freq = [fLow fHgh 0];
triplet = [1 2 1 0];
nrOfRepetitions = [1 2 4 8 16 32];
melody = [];
for k = 1:length(nrOfRepetitions)
    triplets = repmat(triplet, 1, nrOfRepetitions(k));
    if k<length(nrOfRepetitions)
        melody = [melody triplets silence]; %#ok<AGROW>
    else
        melody = [melody triplets]; %#ok<AGROW>
    end
end
amp = 0.9;

% Calculate the schematic time-frequency distribution
t0 = durationInterval;
for k = 1:length(melody)
    if melody(k) == 0
        f = 0;
    else
        f = freq(melody(k));
    end
    schemTime(1:2, k) = [t0 t0+durationTone]; %#ok<SAGROW>
    schemFreq(1:2, k) = [f f]; %#ok<SAGROW>
    t0 = t0+durationTone+durationInterval;
end
envelopeTone = ...
    amp*FadeInOut(ones(size(t)), sampleFrequency, fade, fade);
% Calculate the stimulus
stimulus = SynthToneSequence(schemTime, schemFreq, sampleFrequency, ...
    envelopeTone);

% Play and save the stimulus
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position of figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = 90; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 90; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the schematic time-frequency representation
% on a logarithmic frequency axis
axes('Position', pos)
dXTick = 5; % sec
stimulusDuration = length(stimulus)*dt;
xTick = 0:dXTick:stimulusDuration;
yTick = [fLow fHgh];
fc = mean(yTick);
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
    'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', xTick, 'XTickLabel', xTick, ...
    'YTick', log2(yTick/fc), 'YTickLabel', yTick)
schemFreq = log2(schemFreq/fc);
for m = 1:size(schemTime, 2)
    plot([schemTime(1, m) schemTime(2, m)], ...
        [schemFreq(1,m) schemFreq(1,m)], ...
        'LineWidth', 2, 'Color', blueGreen)
end
tAxis = [-dXTick/2 stimulusDuration+dXTick/2];
fAxis = [250 1720];
axis([tAxis log2(fAxis/fc)])
xlabel('time (s)')
ylabel('freq. (Hz)', 'FontWeight', 'bold')


