clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Synthesize the stimulus
sampleFrequency = 44100; % Hz
dt = 1/sampleFrequency;
duration = 24; % sec
t = dt:dt:duration;
fade = 0.02; % sec
nrOfOctaves = 2;
fBegin = 440; % Hz
fEnd = fBegin*2^nrOfOctaves; % Hz
nrOfHarmonics = 6;
amp = 0.4/nrOfHarmonics;
fLow = fBegin*ones(size(t));
fHigh = fBegin*(fEnd/fBegin).^(t/duration);
stimulus = zeros(size(t));
for k = 1:nrOfHarmonics
    stimulus = stimulus + ...
        (amp/k)*(sin(2*pi*cumsum(k*fHigh)*dt)+sin(2*pi*k*fLow.*t));
end
% Prevent audible clicks at onset and offset
stimulus = FadeInOut(stimulus, sampleFrequency, fade, fade);
durationStimulus = length(stimulus)*dt; % sec

% Save and play the sound
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the dissonance curve
dissonance = zeros(1, length(fLow));
for i = 1:length(fLow)
    freq = [fLow(i)*(1:nrOfHarmonics) fHigh(i)*(1:nrOfHarmonics)];
    dissonance(i) = ...
        DissonanceMeasure(freq, ones(size(freq)));
end

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position of figure in pixels from bottom
panelWidth = 900; % pixels
panelHeights = [180 180]; % pixels
xLabelHeight = [80 60]; % pixels
yLabelWidth = 90; % pixels
xMargin = 30; % pixels
yMargin = 20; % pixels
% Set the current figure handle and return the width and 
% height of the figure. 
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the figure
panel = 2;
axes('Position', pos(panel,:))
xTick = 0:4:duration;
yTick = [50 100 200 500 1000 2000 5000 10000];
logYTick = log10(yTick);
xAxis = [0 durationStimulus];
yAxis = [log10(fBegin/1.5) log10(nrOfHarmonics*fEnd*1.2)];
set(gca, 'LineWidth', 2, 'FontSize', 14, ...
    'Box', 'on', 'Color', lightYellowGreen, 'NextPlot', 'add', ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'Xtick', xTick, 'XTickLabel', xTick, ...
    'Ytick', logYTick, 'YtickLabel', yTick/1000)
for k = 1:nrOfHarmonics
    plot(t, log10(k*fLow), ':', 'LineWidth', 2, 'Color', blueGreen)
    plot(t, log10(k*fHigh), 'Color', red)
end
for i = log2([6/5 5/4 4/3 3/2 5/3 2 5/2 3 4])
    x = (i/nrOfOctaves)*duration;
    plot([x x], yAxis, ':k' , 'LineWidth', 1)
end
xlabel('time (s)')
ylabel('frequency (kHz)')
axis([xAxis yAxis])

panel = panel-1;
axes('Position', pos(panel,:))
xAxis = [0 duration];
yAxis = [0 1.2*max(dissonance)];
xTick = ((0:3/12:nrOfOctaves)/nrOfOctaves)*duration;
xTickLabel = 12*xTick*nrOfOctaves/duration;
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
    'Box', 'on', 'Color', lightYellowGreen, 'NextPlot', 'add', ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'Xtick', xTick, 'XTickLabel', xTickLabel, 'Ytick', 0:10)
plot(t(1:end), dissonance, 'LineWidth', 2, 'Color', blueGreen)
for i = 1/12:1/12:nrOfOctaves
    x = (i/nrOfOctaves)*duration;
    plot([x x], [0 (yAxis(2)-yAxis(1))/20], 'k' , 'LineWidth', 2)
end
for i = log2([6/5 5/4 4/3 3/2 5/3 2 5/2 3 4])
    x = (i/nrOfOctaves)*duration;
    plot([x x], yAxis, ':k' , 'LineWidth', 1)
end
xlabel('interval (semitones)')
ylabel('dissonance')
axis([xAxis yAxis])

