clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define the stimulus
sampleFrequency = 44100; % Hz
dt = 1/sampleFrequency;
toneDuration = 2;
durationInterval = 1; % sec
interval = zeros(size(dt:dt:durationInterval));
t = dt:dt:toneDuration;
fade = 0.05; % sec
nrOfOctaves = 1;
nrOfTonesPerOctave = 12;
fBegin = 440;
f = fBegin*[6/5 2^(3/12) 5/4 2^(4/12) 4/3 2^(5/12) ...
    3/2 2^(7/12) 8/5 2^(8/12)];
melody = 1:length(f);
nrOfHarmonics = 8;
amp = 0.4/nrOfHarmonics;

% Calculate the stimulus and the schematic 
% time-frequency representation
envelopeTone = FadeInOut(ones(size(t)), sampleFrequency, fade, fade);
stimulus = [];
t0 = 0;
nrOfTones = 1;
for k = 1:length(melody)
    tone = zeros(size(t));
    for i = 1:nrOfHarmonics
        fr = i*fBegin;
        s = amp*sin(2*pi*fr*t);
        tone = tone + s;
        schemTime(1:2, nrOfTones) = [t0 t0+toneDuration]; %#ok<SAGROW>
        schemFreq(1:2, nrOfTones) = [fr fr]; %#ok<SAGROW>
        nrOfTones = nrOfTones+1;
    end
    for i = 1:nrOfHarmonics
        fr = i*f(melody(k));
        s = amp*sin(2*pi*fr*t);
        tone = tone + s;
        schemTime(1:2, nrOfTones) = [t0 t0+toneDuration]; 
        schemFreq(1:2, nrOfTones) = [fr fr];
        nrOfTones = nrOfTones+1;
    end
    tone = tone.*envelopeTone;
    if mod(k, 2) == 1
        stimulus =  [stimulus tone];  %#ok<AGROW>
        t0 = t0+toneDuration;
    else
        stimulus =  [stimulus tone interval];  %#ok<AGROW>
        t0 = t0+toneDuration+durationInterval;
    end
end
durationStimulus = length(stimulus)*dt; % sec

% Save and play the sound
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 900; % pixels
panelHeights = 180; % pixels
xLabelHeight = 80; % pixels
yLabelWidth = 90; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the schematic time-logfrequency representation
dXTick = 5; % sec
xTick = 0:dXTick:durationStimulus;
yTick = [50 100 200 500 1000 2000 5000 10000];
logYTick = log10(yTick);
xAxis = [0 durationStimulus];
yAxis = [log10(fBegin/1.5) log10(nrOfHarmonics*f(end)*1.2)];
set(gca, 'LineWidth', 2, 'FontSize', 14, ...
    'Box', 'on', 'Color', lightYellowGreen, 'NextPlot', 'add', ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'Xtick', xTick, 'XTickLabel', xTick, ...
    'Ytick', logYTick, 'YtickLabel', yTick/1000)
logSchemFreq = log10(schemFreq);
for k = 1:size(schemTime, 2)
    if mod(floor((k-1)/nrOfHarmonics), 2) == 0
        plot([schemTime(1, k)+fade schemTime(2, k)]-fade, ...
            [logSchemFreq(1, k) logSchemFreq(1, k)], ':', ...
            'LineWidth', 2, 'Color', blueGreen)
    else
        plot([schemTime(1, k)+fade schemTime(2, k)]-fade, ...
            [logSchemFreq(1, k) logSchemFreq(1, k)], 'Color', red)
    end
end
yTxt = log10(370);
for j = 1:length(melody)
    m = 2*(j-1)*nrOfHarmonics+1;
    tTxt = 0.5*(schemTime(2, m)+schemTime(1, m));
    switch j
        case 1
            text(tTxt, yTxt, 'm3 J', 'HorizontalAlignment', 'center')
        case 2
            text(tTxt, yTxt, 'm3 E', 'HorizontalAlignment', 'center')
        case 3
            text(tTxt, yTxt, 'M3 J', 'HorizontalAlignment', 'center')
        case 4
            text(tTxt, yTxt, 'M3 E', 'HorizontalAlignment', 'center')
        case 5
            text(tTxt, yTxt, '4 J', 'HorizontalAlignment', 'center')
        case 6
            text(tTxt, yTxt, '4 E', 'HorizontalAlignment', 'center')
        case 7
            text(tTxt, yTxt, '5 J', 'HorizontalAlignment', 'center')
        case 8
            text(tTxt, yTxt, '5 E', 'HorizontalAlignment', 'center')
        case 9
            text(tTxt, yTxt, 'm6 J', 'HorizontalAlignment', 'center')
        case 10
            text(tTxt, yTxt, 'm6 E', 'HorizontalAlignment', 'center')
        case 11
            text(tTxt, yTxt, 'M6 J', 'HorizontalAlignment', 'center')
        case 12
            text(tTxt, yTxt, 'M6 E', 'HorizontalAlignment', 'center')
    end
end
axis([xAxis yAxis])
xlabel('time (s)')
ylabel('frequency (kHz)')


