clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define the stimulus
sampleFrequency = 44100; % Hz
dt = 1/sampleFrequency;
toneDuration = 2; 
t = dt:dt:toneDuration;
fade = 0.05; % sec
nrOfOctaves = 1;
nrOfTonesPerOctave = 12;
fBegin = 440;
% Ratios for just temperament from Sethares (2005, p. 101) 
f = fBegin*[1 16/15 9/8 6/5 5/4 4/3 45/32 3/2 8/5 5/3 16/9 15/8 2];
melody = 1:length(f);
nrOfHarmonics = 6;
amp = 0.4/nrOfHarmonics;

% Calculate the stimulus and the schematic 
% time-frequency representation
envelopeTone = FadeInOut(ones(size(t)), sampleFrequency, fade, fade);
stimulus = [];
t0 = 0;
nrOfTones = 1;
for k = 1:length(melody)
    tone = zeros(size(t));
    for i = 1:nrOfHarmonics
        fr = i*fBegin;
        s = amp*sin(2*pi*fr*t);
        tone = tone + s;
        schemTime(1:2, nrOfTones) = [t0 t0+toneDuration]; %#ok<SAGROW>
        schemFreq(1:2, nrOfTones) = [fr fr]; %#ok<SAGROW>
        nrOfTones = nrOfTones+1;
    end
    for i = 1:nrOfHarmonics
        fr = i*f(melody(k));
        s = amp*sin(2*pi*fr*t);
        tone = tone + s;
        schemTime(1:2, nrOfTones) = [t0 t0+toneDuration]; 
        schemFreq(1:2, nrOfTones) = [fr fr];
        nrOfTones = nrOfTones+1;
    end
    tone = tone.*envelopeTone;
    stimulus =  [stimulus tone];  %#ok<AGROW>
    t0 = t0+toneDuration;
end
durationStimulus = length(stimulus)*dt; % sec

% Save and play the sound
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 900; % pixels
panelHeights = 180; % pixels
xLabelHeight = 80; % pixels
yLabelWidth = 90; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the schematic time-logfrequency representation
xTick = 0:4:durationStimulus;
dXTick = 1; % sec
dYTick = 2; % one octave
yTick = [50 100 200 500 1000 2000 5000 10000];
logYTick = log10(yTick);
xAxis = [0 durationStimulus];
yAxis = [log10(fBegin/1.5) log10(nrOfHarmonics*f(end)*1.2)];
set(gca, 'LineWidth', 2, 'FontSize', 14, ...
    'Box', 'on', 'Color', lightYellowGreen, 'NextPlot', 'add', ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'Xtick', xTick, 'XTickLabel', xTick, ...
    'Ytick', logYTick, 'YtickLabel', yTick/1000)
logSchemFreq = log10(schemFreq);
for k = 1:size(schemTime, 2)
    if mod(floor((k-1)/nrOfHarmonics), 2) == 0
    plot([schemTime(1, k)+fade schemTime(2, k)]-fade, ...
        [logSchemFreq(1, k) logSchemFreq(1, k)], ...
        'LineWidth', 1.5, 'Color', blueGreen)
    else
    plot([schemTime(1, k)+fade schemTime(2, k)]-fade, ...
        [logSchemFreq(1, k) logSchemFreq(1, k)], ...
        'Color', red)
    end
end
for i = (nrOfTonesPerOctave/12)*[0 3 4 5 7 9 12 16 19] 
    % consonant intervals in semitones
    x = ((i+0.5)/length(f))*durationStimulus;
    plot([x x], yAxis, ':k' , 'LineWidth', 1)
end
axis([xAxis yAxis])
xlabel('time (s)')
ylabel('frequency (kHz)')


