clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Synthesize the stimulus
sampleFrequency = 44100; % Hz
dt = 1/sampleFrequency;
duration = 20; % sec
t = dt:dt:duration;
fade = 0.02; % sec
amp = 0.4;
fConst = 440; % Hz
fDiffStart = 2; % Hz
nrOfOctaves = 3;
fDiffEnd = fConst*2^nrOfOctaves-fConst;
fDiff = fDiffStart*(fDiffEnd/fDiffStart).^(t/duration);
fLow = fConst*ones(size(t));
fHigh = fLow + fDiff;
stimulus = amp*(sin(2*pi*cumsum(fLow)*dt)+sin(2*pi*cumsum(fHigh)*dt));
% Prevent audible clicks at onset and offset
stimulus = FadeInOut(stimulus, sampleFrequency, fade, fade);

% Save and play the sound
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the dissonance curve
dissonance = zeros(1, length(fLow));
for i = 1:length(fLow)
    dissonance(i) = DissonanceMeasure([fLow(i) fHigh(i)], [1 1]);
end

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position of figure in pixels from bottom
panelWidth = 900; % pixels
panelHeights = [200 200]; % pixels
xLabelHeight = [80 60]; % pixels
yLabelWidth = 90; % pixels
xMargin = 30; % pixels
yMargin = 20; % pixels
% Set the current figure handle and return the width and 
% height of the figure. 
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the figure
panel = 2;
axes('Position', pos(panel,:))
yTick = [50 100 200 500 1000 2000 5000 10000];
logFTick = log10(yTick);
xTickLabel = [2 5 10 20 50 100 200 500 1000 2000 5000];
xTick = log10(xTickLabel);
xAxis = [log10(fHigh(1)-fLow(1)) log10(fHigh(end)-fLow(end))];
yAxis = [log10(160) log10(5100)];
yTxt = 0.15*yAxis(end)+0.85*yAxis(1);
set(gca, 'LineWidth', 2, 'FontSize', 14, ...
    'Box', 'on', 'Color', lightYellowGreen, 'NextPlot', 'add', ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'Ytick', logFTick, 'YtickLabel', yTick/1000, ...
    'Xtick', xTick, 'XTickLabel', xTickLabel)
plot(log10(fHigh-fLow), log10(fLow), ':', 'LineWidth', 2, ...
    'Color', blueGreen)
plot(log10(fHigh-fLow), log10(fHigh), 'Color', red, 'LineWidth', 1.5)
text(log10(5), yTxt, 'beats', 'FontWeight', 'bold', 'FontSize', 14, ...
    'HorizontalAlignment', 'center')
text(log10(50), yTxt, 'roughness', ...
    'FontWeight', 'bold', 'FontSize', 14, ...
    'HorizontalAlignment', 'center')
text(log10(700), yTxt, 'consonance', ...
    'FontWeight', 'bold', 'FontSize', 14, ...
    'HorizontalAlignment', 'center')
xlabel('difference frequency ({\itf}_2-{\itf}_1) (Hz)')
ylabel('{\itf}_{inst} (kHz)')
axis([xAxis yAxis])

panel = panel-1;
axes('Position', pos(panel,:))
xAxis = [0 duration];
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
    'Box', 'on', 'Color', lightYellowGreen, 'NextPlot', 'add', ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'Ytick', 0:0.2:1, ...
    'Xtick', 0:4:duration)
plot(t, dissonance, ...
    'LineWidth', 1.5, 'LineWidth', 1.5, 'Color', blueGreen)
xlabel('time (s)')
ylabel('dissonance')
axis([xAxis 0 1])


