clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Calculate the dissonance curves
nrOfOctaves = 2; % octave
inc = 1/1200; % octave
int = 0:inc:nrOfOctaves;
f0 = 440; % Hz
nrOfHarms = 6;
dissonanceCurves = zeros(nrOfHarms, length(int));
% Calculate the dissonance curves
for k = 1:nrOfHarms
    freq = (1:k)*f0;
    amp = 2*ones(size(freq));
    for i = 1:length(int)
        dissonanceCurves(k, i) = ...
            DissonanceMeasure([freq 2^int(i)*freq], [amp amp]);
    end
end

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 900; % pixels
panelHeights = 120*ones(1, nrOfHarms); % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 70; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the dissonance curves
panel = nrOfHarms;
xTick = 0:1/12:nrOfOctaves;
mx = max(dissonanceCurves(:));
yAxis = [0 1.1*mx];
for k = 1:nrOfHarms
    axes('Position', pos(panel,:))
    if k == nrOfHarms
        xTickLabel = 12*xTick;
        xlabel('interval (semitones)')
        ylabel('dissonance')
    else
        xTickLabel = [];
    end
    set(gca, 'LineWidth', 2, 'FontSize', 12, ...
        'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
        'FontWeight', 'bold', 'TickDir', 'out', ...
        'XTickLabelRotation', 0, ...
        'XTick', xTick, 'XTickLabel', xTickLabel, ...
        'YTick', 0:5:mx)
    plot(int, dissonanceCurves(k,:), 'LineWidth', 2, 'Color', blueGreen)    
    if k == nrOfHarms
        for i = log2([6/5 5/4 4/3 3/2 5/3 2 5/2 3 4])
            plot([i i], yAxis, ':k' , 'LineWidth', 1)
        end
    else
        xTickLabel = [];
    end
    axis([0 nrOfOctaves yAxis])
    text(nrOfOctaves-0.1, 0.75*yAxis(2), sprintf('nr of harmonics:  %d', k), ... 
        'FontSize', 14, 'FontWeight', 'bold', ...
        'HorizontalAlignment', 'Right')
    panel = panel-1;
end


