clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% The data presented were obtained by enlarging Figure 2.7 
% of Van Noorden (1975) and measuring the position of the
% datapoints.
iOI = 0.060:0.010:0.150; % inter-onset interval in ms
scF = 5.0/5.3; % scale factor from paper copy of Figure 2.7
fB_st  = scF*[2.7 3.0 3.1 2.8 3.9 3.4 4.0  3.0  3.1  3.7]; % semitones
tCB_st = scF*[4.2 4.2 4.7 5.2 6.4 7.5 8.6 10.2 11.4 13.1]; % semitones
freqIntervals = [1 6 12]; % value2 taken from asa_FromFusionToFission

fc = 1000; % Hz % reference frequency used by Van Noorden (1975)
fB_ERB = Hz2ERB(fc*2.^(fB_st/12))-Hz2ERB(fc);
tCB_ERB = Hz2ERB(fc*2.^(tCB_st/12))-Hz2ERB(fc);
% values [1 6 12] taken from asa_FromFusionToFission
freqIntervals_ERB = Hz2ERB(fc*2.^([1 6 12]/12))-Hz2ERB(fc);

% Define the stimulus
sampleFrequency = 44100; % Hz
dt = 1/sampleFrequency;
durationTone = 0.125; % sec
t = dt:dt:durationTone;
durationInterval = 0; % sec
interval = zeros(size(dt:dt:durationInterval));
fade = 0.02; % sec
freq = logspace(log10(220), log10(880), 25);
freq = [freq 0];
mel = [13 19 13 0];
nrOfRepetitions = 100;
melody = repmat(mel, 1, nrOfRepetitions);
amp = 0.9;

% Calculate the stimulus
stimulus = interval;
t0 = durationInterval;
envelopeTone = ...
    amp*FadeInOut(ones(size(t)), sampleFrequency, fade, fade);
for k = 1:length(melody)
    if melody(k) == 0
        f = 0; % Hz
        tone = zeros(size(t));
    else
        f = freq(melody(k));
        tone = amp*sin(2*pi*f*t);
    end
    tone = tone.*envelopeTone;
    stimulus = [stimulus tone interval];  %#ok<AGROW>
    t0 = t0+durationTone+durationInterval;
end
durationStimulus = length(stimulus)*dt; % sec

% Play and save the stimulus
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position of figure in pixels from bottom
panelWidth = 600; % pixels
panelHeights = 300; % pixels
xLabelHeight = 80; % pixels
yLabelWidth = 90; % pixels
xMargin = 30; % pixels
yMargin = 30; % pixels
% Set the current figure handle and return the width and
% height of the figure.
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the figure
axes('Position', pos)
XTick = 0:0.050:0.200;
YTick = 0:2:15;
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
    'Box', 'on', 'Color', lightYellowGreen, 'NextPlot', 'add', ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', XTick, 'XTickLabel',1000*XTick, ...
    'Ytick', YTick)
plot(iOI, fB_ERB, 's', 'Color', 'k', 'LineWidth', 2, 'MarkerSize', 14)
plot(iOI, fB_ERB, 'LineWidth', 2, 'Color', 'k')
plot(iOI, tCB_ERB, 'o', 'Color', 'k', 'LineWidth', 2, 'MarkerSize', 14)
plot(iOI, tCB_ERB, 'LineWidth', 2, 'Color', 'k')
plot(durationTone, freqIntervals_ERB(1), 'x', ...
    'Color', red, 'LineWidth', 1, 'MarkerSize', 12)
plot(durationTone, freqIntervals_ERB(2), 'x', ...
    'Color', red, 'LineWidth', 2, 'MarkerSize', 16)
plot(durationTone, freqIntervals_ERB(3), 'x', ...
    'Color', red, 'LineWidth', 1, 'MarkerSize', 12)
text(0.080, 4.5, 'fission', 'FontSize', 16, 'FontWeight', 'bold')
text(0.130, 3.6, 'bistability: ', 'FontSize', 18, 'FontWeight', 'bold')
text(0.132, 3.0, 'temporal coherence', ...
    'FontSize', 16, 'FontWeight', 'bold')
text(0.132, 2.4, 'or fission', 'FontSize', 16, 'FontWeight', 'bold')
text(0.070, 0.6, 'temporal coherence', ...
    'FontSize', 16, 'FontWeight', 'bold')
text(0.155, 6, 'TCB', 'FontSize', 18, 'FontWeight', 'bold')
text(0.155, 1.6, 'FB', 'FontSize', 18, 'FontWeight', 'bold')
xlabel('inter-onset interval (ms)')
ylabel('frequency difference (Cam)')
axis([0.040 0.180 0 7])


