clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define the stimulus
sampleFrequency = 44100; % Hz
dt = 1/sampleFrequency;
durationTone = 0.125; % sec
t = dt:dt:durationTone;
durationInterval = 0; % sec
interval = zeros(size(dt:dt:durationInterval));
ioi = durationTone+durationInterval;
fade = 0.02; % sec
fLow = 220;
nrOfOctaves = 2;
nrOfNotesPerOctave = 12;
fHgh = fLow*2^nrOfOctaves;
fCntr = sqrt(fLow*fHgh);
freq = logspace(log10(fLow), log10(fHgh), ...
    nrOfNotesPerOctave*nrOfOctaves+1);
freq = [freq 0];
mel = [13 14 13 0];
nrOfRepetitions = 10;
melody = repmat(mel, 1, nrOfRepetitions);
mel = [13 19 13 0];
nrOfRepetitions = 30;
melody = [melody repmat(mel, 1, nrOfRepetitions)];
mel = [13 25 13 0];
nrOfRepetitions = 10;
melody = [melody repmat(mel, 1, nrOfRepetitions)];
amp = 0.9;

% Calculate the schematic time-frequency distribution
t0 = durationInterval;
for k = 1:length(melody)
    if melody(k) == 0
        f = 0; % Hz
    else
        f = freq(melody(k));
    end
    schemTime(1:2, k) = [t0 t0+durationTone]; %#ok<SAGROW>
    schemFreq(1:2, k) = [f f]; %#ok<SAGROW>
    t0 = t0+durationTone+durationInterval;
end
envelopeTone = ...
    amp*FadeInOut(ones(size(t)), sampleFrequency, fade, fade);
% Calculate the stimulus
stimulus = SynthToneSequence(schemTime, schemFreq, sampleFrequency, ...
    envelopeTone);

% Play and save the stimulus
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position of figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = 180; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 90; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the schematic time-frequency representation
% on a logarithmic frequency axis
axes('Position', pos)
fc = 660; % Hz
dXTick = 2; % sec
durationStimulus = length(stimulus)*dt; % sec
xTick = 0:dXTick:durationStimulus+dXTick/4;
yTick = [330 440 660 880 1320];
% yTick = -1:0.5:log2(sampleFrequency/fc);
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
    'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', xTick, 'XTickLabel', xTick, ...
    'YTick', log2(yTick/fc), 'YTickLabel', yTick)
schemFreq = log2(schemFreq/fc);
for m = 1:size(schemTime, 2)
    plot([schemTime(1, m) schemTime(2, m)], ...
        [schemFreq(1,m) schemFreq(1,m)], ...
        'LineWidth', 2, 'Color', blueGreen)
end
tAxis = [-dXTick/4 durationStimulus+dXTick/4];
fAxis = [300 1500];
axis([tAxis log2(fAxis/fc)])
xlabel('time (s)')
ylabel('frequency (Hz)', 'FontWeight', 'bold')


