 clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define the stimulus
sampleFrequency = 10000; % Hz
durationLongTone = 2.5; % sec
durationShortTone = 0.5; % sec
durationInterval = 0.2; % sec
fade = 0.005; % sec
f0 = 880; % Hz
fmLong = 0.8; % octaves per second
fmShort = -0.5; % octaves per second
amp = 0.45;
durationGap = 0.1; % sec

% Calculate the real stimulus parameters and store them in 
% schemTimeIll and schemFreqIll
d1 = 0;
d2 = durationLongTone;
f1 = f0*2^(-fmLong*durationLongTone/2);
f2 = f0*2^(fmLong*durationLongTone/2);
d3 = (durationLongTone-durationShortTone)/2;
d4 = (durationLongTone-durationGap)/2;
f3 = f0*2^(-fmShort*durationShortTone/2);
f4 = f3*2^(fmShort*(d4-d3));
d5 = (durationLongTone+durationGap)/2;
d6 = (durationLongTone+durationShortTone)/2;
f5 = f3*2^(fmShort*(d5-d3));
f6 = f3*2^(fmShort*(d6-d3));
schemTime = [d1 d3 d5; d2 d4 d6];
schemFreq = [f1 f3 f5; f2 f4 f6];

% Calculate the illusory stimulus parameters and store them in 
% schemTime and schemFreq
d1 = 0;
d2 = (durationLongTone-durationGap)/2;
f1 = f0*2^(-fmLong*durationLongTone/2);
f2 = f1*2^(fmLong*(d2-d1));
d3 = (durationLongTone+durationGap)/2;
d4 = durationLongTone;
f3 = f1*2^(fmLong*(d3-d1));
f4 = f1*2^(fmLong*(d4-d1));
d5 = (durationLongTone-durationShortTone)/2;
d6 = d5+durationShortTone;
f5 = f0*2^(-fmShort*durationShortTone/2);
f6 = f5*2^(fmShort*(d6-d5));
schemTimeIll = [d1 d3 d5; d2 d4 d6];
schemFreqIll = [f1 f3 f5; f2 f4 f6];

% Synthesize the illusory stimulus
dt = 1/sampleFrequency;
tLong = dt:dt:durationLongTone;
stimIll = zeros(size(tLong));
% Synthesize the two long tones
for k=1:size(schemTime, 2)
    t = schemTime(:, k);
    f = schemFreq(:, k);
    tTone = t(1)+dt:dt:t(2);
    fm = log2(f(2)/f(1))/(t(2)-t(1));
    fInst = f(1)*2.^(fm*(tTone-t(1)));
    tone = amp*sin(2*pi*cumsum(fInst)*dt);
    tone = FadeInOut(tone, sampleFrequency, fade, fade);
    i1 = round(t(1)/dt)+1;
    i2 = i1+length(tone)-1;
    stimIll(i1:i2) = stimIll(i1:i2) + tone;
end

% Synthesize the real stimulus
dt = 1/sampleFrequency;
tLong = dt:dt:durationLongTone;
stimReal = zeros(size(tLong));
% Synthesize the two long tones
for k=1:size(schemTimeIll, 2)
    t = schemTimeIll(:, k);
    f = schemFreqIll(:, k);
    tTone = t(1)+dt:dt:t(2); 
    fm = log2(f(2)/f(1))/(t(2)-t(1));
    fInst = f(1)*2.^(fm*(tTone-t(1)));
    tone = amp*sin(2*pi*cumsum(fInst)*dt);
    tone = FadeInOut(tone, sampleFrequency, fade, fade);
    i1 = round(t(1)/dt)+1;
    i2 = i1+length(tone)-1;
    stimReal(i1:i2) = stimReal(i1:i2) + tone;
end
stimulus = [stimIll zeros(size(dt:dt:durationInterval)) stimReal];
durationStimulus = length(stimulus)*dt; % sec

% Save and play the sound segment
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position of figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = [240 240]; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 90; % pixels
xMargin = 20; % pixels
yMargin = 20; % pixels
% Set the current figure handle and return the width and
% height of the figure.
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of the panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the spectrogram of the stimulus
dXTick = 0.5; % sec
a440 = 440;
tAxis = [-dXTick/4 durationLongTone+dXTick/4];
fAxis = [360 2100];
xTick = 0:dXTick:durationLongTone;
lfAxis = log2(fAxis/a440);
yTick = -1:log2(sampleFrequency/a440);
panel = 1;
axes('Position', pos(panel,:))
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
    'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontWeight', 'bold', 'TickDir', 'out')
nFft = 1024; % Number of samples in one fft window
nWindow = 256; % Number of samples in one analysis window
nOverlap = nWindow-16;
[~, f, ts, spgr] = spectrogram(stimReal, ...
    nWindow, nOverlap, nFft, sampleFrequency);
spgr = 10*log10(abs(spgr));
% Transform the linear frequency axis to a logarithmic frequency axis
freqLogScale = logspace(log10(fAxis(1)), log10(fAxis(2)), 1000);
spgrLog = zeros(length(freqLogScale), size(spgr,2));
for k = 1:size(spgr, 2)
    spgrLog(:,k) = spline(f, spgr(:,k), freqLogScale);    
end
PlotSpectrogram(stimulus, sampleFrequency, ...
    log2(freqLogScale/a440), ts, spgrLog, tAxis, dXTick, lfAxis, ...
    1, 10, frameColor)
cm = max(spgrLog(:));
caxis([cm-10 cm])
set(gca, 'XTick', xTick, 'XTickLabel', xTick, ...
    'YTick', yTick, 'YTickLabel', (a440*2.^yTick), ...
    'Color', lightYellowGreen)
xlabel('time (s)')
ylabel('frequency (Hz)')

% Plot the spectrogram of the stimulus
panel = panel+1;
axes('Position', pos(panel,:))
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
    'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontWeight', 'bold', 'TickDir', 'out')
[~, f, ts, spgr] = spectrogram(stimIll, ...
    nWindow, nOverlap, nFft, sampleFrequency);
spgr = 10*log10(abs(spgr));
% Transform the linear frequency axis to a logarithmic frequency axis
freqLogScale = logspace(log10(fAxis(1)), log10(fAxis(2)), 1000);
spgrLog = zeros(length(freqLogScale), size(spgr,2));
for k = 1:size(spgr, 2)
    spgrLog(:,k) = spline(f, spgr(:,k), freqLogScale);    
end
PlotSpectrogram(stimulus, sampleFrequency, ...
    log2(freqLogScale/a440), ts, spgrLog, tAxis, dXTick, lfAxis, ...
    1, 10, frameColor)
caxis([cm-10 cm])
set(gca, 'XTick', xTick, 'XTickLabel', [], ...
    'YTick', yTick, 'YTickLabel', (a440*2.^yTick), ...
    'Color', lightYellowGreen)
ylabel('frequency (Hz)')





