clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define the stimulus
sampleFrequency = 44100; % Hz
dt = 1/sampleFrequency;
durationTone = 0.05; % sec
t = dt:dt:durationTone;
durationInterval = 0.0; % sec
interval = zeros(size(dt:dt:durationInterval));
fade = 0.02; % sec
fLow = 440;
nrOfOctaves = 1;
nrOfNotesPerOctave = 12;
fHgh = fLow*2^nrOfOctaves;
freq = logspace(log10(fLow), log10(fHgh), ...
    nrOfNotesPerOctave*nrOfOctaves+1);
freq = [freq 0];
amp = 0.9;
nrOfRepetitions = 6;
mel = [2 0 1 0 2 0 0 0 0 0];
melody = repmat(mel, 1, nrOfRepetitions);
mel = [2 1 0 0 2 0 0 0 0 0];
melody = [melody repmat(mel, 1, nrOfRepetitions)];
mel = [2 0 0 1 2 0 0 0 0 0];
melody = [melody repmat(mel, 1, nrOfRepetitions)];
mel = zeros(1,20);
melody = [melody repmat(mel, 1, 1)];
mel = [13 0 1 0 13 0 0 0 0 0];
melody = [melody repmat(mel, 1, nrOfRepetitions)];
mel = [13 1 0 0 13 0 0 0 0 0];
melody = [melody repmat(mel, 1, nrOfRepetitions)];
mel = [13 0 0 1 13 0 0 0 0 0];
melody = [melody repmat(mel, 1, nrOfRepetitions)];

% Calculate the schematic time-frequency distribution
t0 = durationInterval;
for k = 1:length(melody)
    if melody(k) == 0
        f = 0; % Hz
    else
        f = freq(melody(k));
    end
    schemTime(1:2, k) = [t0 t0+durationTone]; %#ok<SAGROW>
    schemFreq(1:2, k) = [f f]; %#ok<SAGROW>
    t0 = t0+durationTone+durationInterval;
end
envelopeTone = ...
    amp*FadeInOut(ones(size(t)), sampleFrequency, fade, fade);
% Calculate the stimulus
stimulus = SynthToneSequence(schemTime, schemFreq, sampleFrequency, ...
    envelopeTone);

% Play and save the stimulus
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position of figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = [90 90]; % pixels
xLabelHeight = [70 70]; % pixels
yLabelWidth = 80; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the schematic time-frequency representation
% on a logarithmic frequency axis
axes('Position', pos(2,:))
fc = 660; % Hz
dXTick = 1; % sec
durationStimulus = length(stimulus)*dt; % sec
xTick = 0:dXTick:durationStimulus+dXTick/4;
yTick = [440 880];
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
    'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', xTick, 'XTickLabel', xTick, ...
    'YTick', log2(yTick/fc), 'YTickLabel', yTick)
schemFreq = log2(schemFreq/fc);
for m = 1:size(schemTime, 2)/2
    plot([schemTime(1, m) schemTime(2, m)], ...
        [schemFreq(1,m) schemFreq(1,m)], ...
        'LineWidth', 2, 'Color', blueGreen)
end
tAxis = [-dXTick/3 durationStimulus/2];
fAxis = [330 1500];
axis([tAxis log2(fAxis/fc)])
xlabel('time (s)')
ylabel('freq. (Hz)', 'FontWeight', 'bold')

% Plot the schematic time-frequency representation
% on a logarithmic frequency axis
axes('Position', pos(1,:))
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
    'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', xTick, 'XTickLabel', xTick, ...
    'YTick', log2(yTick/fc), 'YTickLabel', yTick)
for m = size(schemTime, 2)/2+1:size(schemTime, 2)
    plot([schemTime(1, m) schemTime(2, m)], ...
        [schemFreq(1,m) schemFreq(1,m)], ...
        'LineWidth', 2, 'Color', blueGreen)
end
tAxis = [durationStimulus/2-dXTick/3 durationStimulus];
axis([tAxis log2(fAxis/fc)])
xlabel('time (s)')
ylabel('freq. (Hz)', 'FontWeight', 'bold')


