clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define the stimulus
sampleFrequency = 20000; % Hz
dt = 1/sampleFrequency;
durationTone = 0.25; % sec 
t = dt:dt:durationTone;
durationInterval = 0.00; % sec
interval = zeros(size(dt:dt:durationInterval));
fade = 0.01; % sec
nrOfOctaves = 3;
f = logspace(log10(440), log10((2^nrOfOctaves)*440), ...
    12*nrOfOctaves+1);
f = [f 0];
melody = ...
    [1 1 5 8 1 1 5 8 1 length(f) 8 length(f)];
nrOfHarmonics = 3;
amp = 0.5/nrOfHarmonics;
tau = durationTone/3; % sec

% Calculate the stimulus and the schematic 
% time-frequency representation
t0 = durationInterval;
nrOfTones = 1;
for k = 1:length(melody)
    for i = 1:nrOfHarmonics
        fr = i*f(melody(k));
        schemTime(1:2, nrOfTones) = [t0 t0+durationTone]; %#ok<SAGROW>
        schemFreq(1:2, nrOfTones) = [fr fr]; %#ok<SAGROW>
        nrOfTones = nrOfTones+1;
    end
    t0 = t0+durationTone+durationInterval;
end
envelopeTone = amp*FadeInOut(ones(size(t)), sampleFrequency, fade, fade);
% Calculate the stimulus
stimulus = SynthToneSequence(schemTime, schemFreq, sampleFrequency, ...
    envelopeTone);

% Save and play the sound
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = 240; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 90; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the schematic time-logfrequency representation
dXTick = 1; % sec
dYTick = 2; % one octave
durationStimulus = length(stimulus)*dt; % sec
tAxis = [-dXTick/4 durationStimulus+dXTick/4];
axes('Position', pos)
fAxis = [330 2700];
PlotSTlFR(stimulus, sampleFrequency, ...
    schemTime, schemFreq, envelopeTone, ...
    tAxis, dXTick, fAxis, 0.3*amp, blueGreen)
set(gca, 'XTick', 0:dXTick:durationStimulus, ...
    'XTickLabel', 0:dXTick:durationStimulus, ...
    'Color', lightYellowGreen)
t1 = -0.3*durationTone;
t2 = durationStimulus+0.3*durationTone;
f1 = log2(f(1)/440)-0.16;
f2 = log2(f(8)/440)+0.16;
plot([t1 t2 t2 t1 t1], [f1 f1 f2 f2 f1], ...
    'Color', darkRed, 'LineWidth', 2)
xlabel('time (s)')

% Plot the dotted rectangles
t1 = 3*(durationTone+durationInterval)-0.1*durationTone;
t2 = 6*(durationTone+durationInterval)+0.1*durationTone;
f11 = log2(f(20)/440)-0.1;
f12 = log2(f(20)/440)-0.1;
f21 = log2(f(20)/440)+0.1;
f22 = log2(f(20)/440)+0.1;
plot([t1 t2 t2 t1 t1], [f11 f12 f21 f22 f11], ...
    ':', 'Color', darkRed, 'LineWidth', 2)

% Plot the large rectangle
t1 = 7*(durationTone+durationInterval)-0.1*durationTone;
t2 = 9*(durationTone+durationInterval)+0.1*durationTone;
f11 = log2(f(20)/440)-0.1;
f12 = log2(f(20)/440)-0.1;
f21 = log2(f(20)/440)+0.1;
f22 = log2(f(20)/440)+0.1;
plot([t1 t2 t2 t1 t1], [f11 f12 f21 f22 f11], ...
    ':', 'Color', darkRed, 'LineWidth', 2)


