clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Synthesizes stimuli similar to those used by Bey & McAdams (2002).

% Define the stimulus
sampleFrequency = 44100; % Hz
dt = 1/sampleFrequency;
durationTone = 0.111; % sec
t = dt:dt:durationTone;
durationInterval = 0.056; % sec
interval = zeros(size(dt:dt:durationInterval));
ioi = durationTone+durationInterval;
fade = 0.02; % sec
fCntr = 880;
fLow = fCntr/2;
fHgh = fCntr*2;
nrOfOctaves = log2(fHgh/fLow);
nrOfTonesPerOctave = 12;
freq = logspace(log10(fLow), log10(fHgh), ...
    nrOfTonesPerOctave*nrOfOctaves+1);
freq = [freq 0];
nrOfTones = 6;
maxRange = 11; % maximum frequency range of melody is 11 semitones
nrOfTrials = 6;
melody = [];
shiftFreq = 7; % semitones
for m = 1:nrOfTrials
    r = randperm(maxRange);
    trgt = nrOfTonesPerOctave/2+r(1:nrOfTones);
    dstr = zeros(size(trgt));
    for k = 1:nrOfTones-1
        if mod(k,2) == 1
            r = max([trgt(k) trgt(k+1)])+1;
            dstr(k) = ...
                randi([r length(freq)-shiftFreq-1]); % freq(end) == 0!
        else
            r = min([trgt(k) trgt(k+1)])-1;
            dstr(k) = randi([1 r]);
        end
    end
    dstr(nrOfTones) = randi([1 trgt(k)-1]);
    mixture(1:2:2*nrOfTones) = trgt;
    mixture(2:2:2*nrOfTones) = dstr+shiftFreq;
    target = zeros(1, 2*nrOfTones);
    if mod(m, 2) == 0
        trgt = trgt([1 4 3 2 5:end]);
    end
    target(1:2:2*nrOfTones) = trgt;
    melody = [melody target zeros(size(target)) ...
        mixture zeros(size(target))]; %#ok<AGROW>
end
amp = 0.9;

% Calculate the stimulus
stimulus = interval;
t0 = durationInterval;
envelopeTone = ...
    amp*FadeInOut(ones(size(t)), sampleFrequency, fade, fade);
for k = 1:length(melody)
    if melody(k) == 0
        f = 0; % Hz
        tone = zeros(size(t));
    else
        f = freq(melody(k));
        tone = amp*sin(2*pi*f*t);
    end
    schemTime(1:2, k) = [t0 t0+durationTone]; %#ok<SAGROW>
    schemFreq(1:2, k) = [f f]; %#ok<SAGROW>
    tone = tone.*envelopeTone;
    stimulus = [stimulus tone interval];  %#ok<AGROW>
    t0 = t0+durationTone+durationInterval;
end
durationStimulus = length(stimulus)*dt; % sec
trialDuration = durationStimulus/nrOfTrials;

% Play and save the stimulus
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position of figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = 180; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 90; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the schematic time-frequency representation
% on a logarithmic frequency axis
axes('Position', pos)
fc = 660; % Hz
dXTick = 1; % sec
xTick = 0:dXTick:trialDuration+dXTick/4;
yTick = [440 880 1760];
% yTick = -1:0.5:log2(sampleFrequency/fc);
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
    'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', xTick, 'XTickLabel', xTick, ...
    'YTick', log2(yTick/fc), 'YTickLabel', yTick)
schemFreq = log2(schemFreq/fc);
for r = 1:size(schemTime, 2)
    plot([schemTime(1, r) schemTime(2, r)], ...
        [schemFreq(1,r) schemFreq(1,r)], ...
        'LineWidth', 2, 'Color', blueGreen)
    if mod(r,2) == 0
        mT = mean(schemTime(:, r));
        plot(mT, schemFreq(1,r), 'xk', 'Color', blueGreen, ...
            'LineWidth', 1, 'MarkerSize', 6)
    end
end
tAxis = [-dXTick/2 0.75*trialDuration+dXTick];
fAxis = [0.8*fLow 1.25*fHgh];
axis([tAxis log2(fAxis/fc)])
xlabel('time (s)')
ylabel('frequency (Hz)', 'FontWeight', 'bold')

