clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define the stimulus
sampleFrequency = 44100; % Hz
dt = 1/sampleFrequency;
durationTone = 0.2; % sec
t = dt:dt:durationTone;
durationInterval = 0; % sec
interval = zeros(size(dt:dt:durationInterval));
fade = 0.005; % sec
fLow = 440;
fHgh = 880;
freq = [fLow fLow*2^(0.5) fHgh];
midf = ceil((length(freq))/2);
nrOfRepetitions = 100;
melody = repmat(freq, 1, nrOfRepetitions);
fCntr = 440;
amp = 0.9;

% Calculate the schematic time-frequency distribution
t0 = durationInterval;
for k = 1:length(melody)
    f = melody(k);
    schemTime(1:2, k) = [t0 t0+durationTone]; %#ok<SAGROW>
    schemFreq(1:2, k) = [f f]; %#ok<SAGROW>
    t0 = t0+durationTone+durationInterval;
end
envelopeTone = ...
    amp*FadeInOut(ones(size(t)), sampleFrequency, fade, fade);
% Calculate the stimulus
stimulus = SynthToneSequence(schemTime, schemFreq, sampleFrequency, ...
    envelopeTone);

% Play and save the stimulus
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position of figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = [150 150]; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 90; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the schematic time-frequency representation
panel = 1;
axes('Position', pos(panel,:))
dXTick =1; % sec
durationStimulus = length(stimulus)*dt; % sec
xTick = 0:dXTick:durationStimulus+dXTick/4;
yTick = log2(freq);
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
    'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', xTick, 'XTickLabel', xTick, ...
    'YTick', yTick, 'YTickLabel', round(2.^yTick))
schemFreq = log2(schemFreq);
for m = 1:size(schemTime, 2)
    plot([schemTime(1, m) schemTime(2, m)], ...
        [schemFreq(1, m) schemFreq(1, m)], ...
        'LineWidth', 2, 'Color', blueGreen)
end
for m = 1:3:size(schemTime, 2)
    p1 = 0.5*(schemTime(1, m)+schemTime(2, m));
    p2 = 0.5*(schemTime(1, m+1)+schemTime(2, m+1));
    p3 = 0.5*(schemTime(1, m+2)+schemTime(2, m+2));
    plot([p1 p2], ...
        [schemFreq(1, m) schemFreq(1, m+1)], '--', 'Color', red)
    plot([p2 p3], ...
        [schemFreq(1, m+1) schemFreq(1, m+2)], '--', 'Color', red)
    if m<size(schemTime, 2)-3
        p4 = 0.5*(schemTime(1, m+3)+schemTime(2, m+3));
        plot([p3 p4], ...
            [schemFreq(1, m+2) schemFreq(1, m+3)], '--', 'Color', red)
    end
end

tAxis = [2-dXTick/4 6+dXTick/4];
fAxis = log2([fLow/1.2 fHgh*1.2]);
axis([tAxis fAxis])
xlabel('time (s)')
ylabel('frequency (Hz)', 'FontWeight', 'bold')

% Plot the schematic time-frequency representation
panel = panel+1;
axes('Position', pos(panel,:))
dXTick = 1; % sec
xTick = 0:dXTick:durationStimulus+dXTick/4;
yTick = log2(freq);
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
    'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', xTick, 'XTickLabel', [], ...
    'YTick', yTick, 'YTickLabel', round(2.^yTick))
for m = 1:size(schemTime, 2)
    plot([schemTime(1, m) schemTime(2, m)], ...
        [schemFreq(1, m) schemFreq(1, m)], ...
        'LineWidth', 2, 'Color', blueGreen)
end
for m = 1:3:size(schemTime, 2)
    p2 = 0.5*(schemTime(1, m+1)+schemTime(2, m+1));
    p3 = 0.5*(schemTime(1, m+2)+schemTime(2, m+2));
    plot([p2 p3], ...
        [schemFreq(1, m+1) schemFreq(1, m+2)], '--', 'Color', red)
    if m<size(schemTime, 2)-3
        p5 = 0.5*(schemTime(1, m+4)+schemTime(2, m+4));
        plot([schemTime(2, m) schemTime(1, m+3)], ...
            [schemFreq(1, m) schemFreq(1, m+3)], '--', 'Color', red)
        plot([p3 p5], ...
            [schemFreq(1, m+2) schemFreq(1, m+4)], '--', 'Color', red)
    end
end
axis([tAxis fAxis])
ylabel('frequency (Hz)', 'FontWeight', 'bold')


