clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define the stimulus
sampleFrequency = 44100; % Hz
dt = 1/sampleFrequency;
durationTone = 0.10; % sec
t = dt:dt:durationTone;
durationInterval = 0.0; % sec
interval = zeros(size(dt:dt:durationInterval));
fade = 0.02; % sec
freq = [440 880];
melLeft = [2 1];
melRight = [1 2];
nrOfRepetitions = 20;
melodyLeft = repmat(melLeft, 1, nrOfRepetitions);
melodyRight = repmat(melRight, 1, nrOfRepetitions);
amp = 0.9;

% Calculate the stimulus
stimulusLeft = interval;
stimulusRight = interval;
envelopeTone = ...
    amp*FadeInOut(ones(size(t)), sampleFrequency, fade, fade);
t0 = durationInterval;
for k = 1:length(melodyLeft)
    f = freq(melodyLeft(k));
    tone = amp*sin(2*pi*f*t);
    schemTimeLeft(1:2, k) = [t0 t0+durationTone]; %#ok<SAGROW>
    schemFreqLeft(1:2, k) = [f f]; %#ok<SAGROW>
    tone = tone.*envelopeTone;
    stimulusLeft = [stimulusLeft tone];  %#ok<AGROW>
    t0 = t0+durationTone+durationInterval;
end
t0 = durationInterval;
for k = 1:length(melodyRight)
    f = freq(melodyRight(k));
    tone = amp*sin(2*pi*f*t);
    schemTimeRight(1:2, k) = [t0 t0+durationTone]; %#ok<SAGROW>
    schemFreqRight(1:2, k) = [f f]; %#ok<SAGROW>
    tone = tone.*envelopeTone;
    stimulusRight = [stimulusRight tone];  %#ok<AGROW>
    t0 = t0+durationTone+durationInterval;
end
durationStimulus = length(stimulusRight)*dt; % sec
stimulus = [stimulusLeft' stimulusRight'];

% Save and play the stimulus
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position of figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = [90 90 90]; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 90; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the schematic time-frequency representation 
% on a logarithmic frequency axis of the sound 
% as it is perceived
panel = 1;
axes('Position', pos(panel, :))
dXTick = 1; % sec
xTick = 0:dXTick:durationStimulus+dXTick/4;
yTick = -1:log2(sampleFrequency/freq(1));
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
    'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', xTick, 'XTickLabel', xTick, ...
    'YTick', yTick, 'YTickLabel', freq(1)*2.^yTick)
schemFreqLeft = log2(schemFreqLeft/freq(1));
for m = 1:size(schemTimeLeft, 2)
    plot([schemTimeLeft(1, m) schemTimeLeft(2, m)], ...
        [schemFreqLeft(1,m) schemFreqLeft(1,m)], ...
        'LineWidth', 2, 'Color', red)
end
tAxis = [-dXTick/4 durationStimulus/2+dXTick/4];
fAxis = [freq(1)/2^(2/3) freq(end)*2^(2/3)];
axis([tAxis log2(fAxis/freq(1))])
xlabel('time (s)')
ylabel('freq. (Hz)', 'FontWeight', 'bold')
text(-dXTick/8, 1/3+log2(freq(end)/freq(1)), 'perceived at right ear', ...
    'FontSize', 12)
text(-dXTick/8, 1/3, 'perceived at left ear', ...
    'FontSize', 12)

% Plot the schematic time-frequency representation 
% on a logarithmic frequency axis of the sound presented
% at the left ear
panel = panel+1;
axes('Position', pos(panel, :))
dXTick = 1; % sec
xTick = 0:dXTick:durationStimulus+dXTick/4;
yTick = -1:log2(sampleFrequency/freq(1));
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
    'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', xTick, 'XTickLabel', [], ...
    'YTick', yTick, 'YTickLabel', freq(1)*2.^yTick)
schemFreqRight = log2(schemFreqRight/freq(1));
for m = 1:size(schemTimeRight, 2)
    plot([schemTimeRight(1, m) schemTimeRight(2, m)], ...
        [schemFreqRight(1,m) schemFreqRight(1,m)], ...
        'LineWidth', 2, 'Color', blueGreen)
end
axis([tAxis log2(fAxis/freq(1))])
ylabel('freq. (Hz)', 'FontWeight', 'bold')
text(-dXTick/8, log2(freq(end)*2^(1/3)/freq(1)), ...
    'presented at left ear', 'FontSize', 12)

% Plot the schematic time-frequency representation 
% on a logarithmic frequency axis of the sound presented
% at the right ear
panel = panel+1;
axes('Position', pos(panel, :))
dXTick = 1; % sec
xTick = 0:dXTick:durationStimulus+dXTick/4;
yTick = -1:log2(sampleFrequency/freq(1));
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
    'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', xTick, 'XTickLabel', [], ...
    'YTick', yTick, 'YTickLabel', freq(1)*2.^yTick)
schemFreqRight = log2(schemFreqRight/freq(1));
for m = 1:size(schemTimeRight, 2)
    plot([schemTimeLeft(1, m) schemTimeLeft(2, m)], ...
        [schemFreqLeft(1,m) schemFreqLeft(1,m)], ...
        'LineWidth', 2, 'Color', blueGreen)
end
axis([tAxis log2(fAxis/freq(1))])
ylabel('freq. (Hz)', 'FontWeight', 'bold')
text(-dXTick/8, log2(freq(end)*2^(1/3)/freq(1)), ...
    'presented at right ear', 'FontSize', 12)


