clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define the stimulus
sampleFrequency = 44100; % Hz
dt = 1/sampleFrequency;
durationTone = 0.1; % sec
t = dt:dt:durationTone-dt;
durationInterval = 0; % sec
interval = zeros(size(dt:dt:durationInterval));
ioi = durationTone+durationInterval;
fade = 0.02; % sec
fCntr = 440;
nrOfOctaves = 2;
nrOfNotesPerOctave = 24;
f0Low = fCntr*2^(-nrOfOctaves/2);
f0Hgh = fCntr*2^(nrOfOctaves/2);
freq = logspace(log10(f0Low), log10(f0Hgh), ...
    nrOfNotesPerOctave*nrOfOctaves+1);
frLow = 6000;
frHgh = 12000;
midk = round(nrOfOctaves*nrOfNotesPerOctave/2+1);
melody = [];
for k = [1:length(freq) length(freq):-1:1] 
    melody = [melody k midk k 0]; %#ok<AGROW>
end

% Calculate the stimulus
stimulus = interval;
t0 = durationInterval;
envelopeTone = ...
    FadeInOut(ones(size(t)), sampleFrequency, fade, fade);
for k = 1:length(melody)
    f0 = 0; % Hz
    tone = zeros(size(t));
    if melody(k) > 0
        f0 = freq(melody(k));
        hLow = ceil(frLow/f0);
        hHgh = floor(frHgh/f0);
        amp = 1/(hHgh-hLow+1);
        for h = hLow:hHgh
            tone = tone+amp*sin(2*pi*h*f0*t);
        end
    end
    schemTime(1:2, k) = [t0 t0+durationTone]; %#ok<SAGROW>
    schemFreq(1:2, k) = [f0 f0]; %#ok<SAGROW>
    tone = tone.*envelopeTone;
    stimulus = [stimulus tone interval];  %#ok<AGROW>
    t0 = t0+ioi;
end

% Save and play wav file
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position of figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = [180 180]; % pixels
xLabelHeight = [70 30]; % pixels
yLabelWidth = 90; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the schematic time frequency-representation
panel = 2;
axes('Position', pos(panel,:))
dXTick = 5; % sec
durationStimulus = length(stimulus)*dt; % sec
tAxis = [-dXTick/8 durationStimulus+dXTick/8];
fAxis = [f0Low/1.2 f0Hgh*1.2];
xTick = 0:dXTick:durationStimulus+dXTick/4;
yTick = round(fCntr*2.^(-3:3));
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
    'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', xTick, 'XTickLabel', xTick, ...
    'YTick', log2(yTick/fCntr), 'YTickLabel', yTick)
schemFreq = log2(schemFreq/fCntr);
for m = 1:size(schemTime, 2)
    plot([schemTime(1, m) schemTime(2, m)], ...
        [schemFreq(1, m) schemFreq(1, m)], ...
        'LineWidth', 1, 'Color', blueGreen)
end
text(0, 0.5/12, 'B tones', 'VerticalAlignment', 'bottom')
text(0.2, -11.5/12, 'A tones', 'VerticalAlignment', 'bottom', ...
    'Rotation', 23)
axis([tAxis log2(fAxis/fCntr)])
ylabel('{\it{F}}_{0} (Hz)', 'FontWeight', 'bold')

% Plot a red rectangles around the integrated tones
fissionBoundary = 2.75/12; % 2.75 semitones to octaves
nrOfNotesInFissionBoundary = floor(nrOfNotesPerOctave*fissionBoundary);
tCntr = (4*(midk-1)+1.5)*ioi;
t1 = tCntr-(4*nrOfNotesInFissionBoundary+2)*ioi;
t2 = tCntr+(4*nrOfNotesInFissionBoundary+2)*ioi;

% Plot the insert of the schematic time-frequency representation
panel = panel-1;
axes('Position', pos(panel,:))
dXTick = 1; % sec
xTick = 0:dXTick:durationStimulus+dXTick/4;
yTick = round(fCntr*2.^((-6:2:6)/12));
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
    'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', xTick, 'XTickLabel', xTick, ...
    'YTick', log2(yTick/fCntr), 'YTickLabel', yTick)
for m = 1:size(schemTime, 2)
    plot([schemTime(1, m) schemTime(2, m)], ...
        [schemFreq(1, m) schemFreq(1, m)], ...
        'LineWidth', 2, 'Color', blueGreen)
end
for m = 1:4:size(schemTime, 2)
    p1 = 0.5*(schemTime(1, m)+schemTime(2, m));
    p2 = 0.5*(schemTime(1, m+1)+schemTime(2, m+1));
    p3 = 0.5*(schemTime(1, m+2)+schemTime(2, m+2));
    if m+4<size(schemTime, 2)
        plot([schemTime(2, m+2) schemTime(1, m+4)], ...
            [schemFreq(2, m) schemFreq(1, m+4)], ...
            'LineWidth', 1, 'Color', red)
    end
        plot([p1 p2], ...
            [schemFreq(1, m) schemFreq(1, m+1)], 'Color', red)
        plot([p2 p3], ...
            [schemFreq(1, m+1) schemFreq(1, m+2)], 'Color', red)
end
axis([t1-4*nrOfNotesInFissionBoundary*ioi ...
    t2+4*nrOfNotesInFissionBoundary*ioi ...
    -2*fissionBoundary 2*fissionBoundary])
text(5.8, 0.4/12, 'B tones', 'VerticalAlignment', 'bottom', ...
    'FontSize', 16)
text(7, -5.3/12, 'A tones', 'VerticalAlignment', 'bottom', ...
    'FontSize', 16, 'Rotation', 12)
xlabel('time (s)')
ylabel('{\it{F}}_{0} (Hz)', 'FontWeight', 'bold')

