clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Specify the stimuli
I_ref = 1.0e-12;
zMin = Hz2ERB(50);
zMax = Hz2ERB(20000);
dz = 0.01;
z = zMin:dz:zMax;
I_dB = 50;
fLow = 6000; % Hertz
fHgh = 12000; % Hertz
f0 = [220 440 880]; % Hertz

% Calculate the specific-loudness contours
specificLoudness = zeros(length(f0), length(z));
loudness = zeros(length(f0));
I = I_ref*10.^(I_dB/10);
f = zeros(length(f0), ceil(fHgh/min(f0)));
for k = 1:length(f0)
    rnk = ceil(fLow/f0(k)):floor(fHgh/f0(k));
    f(k,rnk) = f0(k)*rnk;
    [~, specificLoudness(k,:)] = ...
        CalcLoudnessFunctions(f(k,rnk), I, z, 1, 1);
    loudness(k) = dz*sum(specificLoudness(k,:));
end

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = 120*ones(size(f0)); % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 70; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the specific-loudness contours
zRange = [zMin 40];
rangeYAxis = [0 1.1]; % dB
for k = 1:length(f0)
    axes('Position', pos(k,:))
    set(gca, 'Box', 'on', 'LineWidth', 2, ...
        'NextPlot', 'add', 'Color', lightYellowGreen, ...
        'YTick', 0:0.5:2, 'YTickLabel', 0:0.5:2, ...
        'TickDir', 'out', ...
        'FontSize', 14, 'Fontweight', 'bold')
    plot(z, specificLoudness(k,:), 'Color', blueGreen, ...
        'LineWidth', 2)
    plot([Hz2ERB(f0(k)) Hz2ERB(f0(k))], [0 0.2], ...
        ':', 'Color', darkRed, 'LineWidth', 1.5)
    rnk = ceil(fLow/f0(k)):floor(fHgh/f0(k));
    f(k,rnk) = f0(k)*rnk;
    for i = rnk(1):rnk(end)
        plot(Hz2ERB([i*f0(k) i*f0(k)]), [0 0.05], 'Color', ...
            red, 'LineWidth', 1.5)
    end
    axis([zRange rangeYAxis])
    if k == 1
        set(gca, 'XTick', 5:5:40, 'XTickLabel', 5:5:40)
        xlabel('Cam')
    else
        set(gca, 'XTick', 5:5:40, 'XTickLabel', [])
    end
    ylabel('spec. loudness', 'FontSize', 12, 'Fontweight', 'bold')
    txt = sprintf('F_0 = %3.0f Hz', f0(k));
    text(Hz2ERB(f0(k)), 0.27, txt, ...
        'FontSize', 12, 'Fontweight', 'bold', ...
        'HorizontalAlignment', 'center')
    txt = sprintf('loudness = %5.2f sone', ...
        loudness(k));
    text(zRange(1)+1, 0.8*rangeYAxis(2), txt, ...
        'FontSize', 12, 'Fontweight', 'bold')
end


