clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define the stimulus
sampleFrequency = 44100; % Hz
durationTone = 0.10; % sec 
durationInterval = 0.025; % sec 
tau = durationTone/2.5; % sec
fc = 440; % Hz
df = 110; % Hz
delay = [-0.03 0 0 0]; % sec
nrOfNotes = 4;
nrOfSidebands = [1 1 0 0];
nrOfRepetitions = 30;
amp = 0.3;

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position of figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = 150*ones(1, length(delay)); % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 90; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

dt = 1/sampleFrequency;
t = dt:dt:durationTone;
pause = zeros(size(dt:dt:durationInterval));
samplesInDelay = round(delay/dt)+1;
envelopeTone = exp(-t/tau);
panel = 0;
stim = zeros(length(delay), nrOfRepetitions*nrOfNotes * ...
    (length(t)+length(pause))+max(samplesInDelay));
for h = 1:length(delay)
    rng(2)
    % Calculate the schematic time-frequency representation
    t0 = 0;
    k = 1;
    clear [schemTime schemFreq];
    for j = 1:nrOfRepetitions
        f = fc;
        schemTime(1:2, k) = [t0 t0+durationTone]; %#ok<SAGROW>
        schemFreq(1:2, k) = [f f]; %#ok<SAGROW>
        k = k+1;
        t0 = t0+durationTone+durationInterval;
        if h < length(delay) %
            for m = 2:nrOfNotes
                if randi(2) == 1
                    f = fc;
                    schemTime(1:2, k) = [t0 t0+durationTone];
                    schemFreq(1:2, k) = [f f];
                    k = k+1;
                    tone = zeros(size(t));
                    for i = 1:nrOfSidebands(h)
                        f = fc-i*df;
                        schemTime(1:2, k) = [t0 t0+durationTone]+delay(h);
                        schemFreq(1:2, k) = [f f];
                        k = k+1;
                        f = fc+i*df;
                        schemTime(1:2, k) = [t0 t0+durationTone]+delay(h);
                        schemFreq(1:2, k) = [f f];
                        k = k+1;
                    end
                end
                t0 = t0+durationTone+durationInterval;
            end
        else
            t0 = t0+(nrOfNotes-1)*(durationTone+durationInterval);
        end
    end
    % Calculate the stimulus
    for j = 1:k-1
        f = schemFreq(1, j);
        tone = amp*sin(2*pi*f*t);
        tone = tone.*envelopeTone;
        s = round(schemTime(1, j)/dt)+(1:length(tone));
        stim(h, s) = stim(h, s)+tone;
    end
    durationStimulus = size(stim,2)*dt; % sec
    
    % Plot the schematic time-frequency representation
    % on a logarithmic frequency axis
    panel = panel+1;
    axes('Position', pos(panel,:))
    dXTick = 0.5; % sec
    xTick = 0:dXTick:durationStimulus+dXTick/4;
    yTick = 0:fc/2:sampleFrequency;
    tAxis = [-dXTick/4 2.5];
    fAxis = [180 700];
    set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
        'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
        'FontWeight', 'bold', 'TickDir', 'out', ...
        'YTick', yTick, 'XTick', xTick, 'XTickLabel', [])
    if h == 1
        set(gca, 'XTick', xTick, 'XTickLabel', xTick)
        xlabel('time (s)')
    end
    ylabel('freq. (Hz)', 'FontWeight', 'bold')
    axis([tAxis fAxis])
    text(-0.15*dXTick, 625, char(double('a')+length(delay)-h), ...
        'FontSize', 14, 'FontWeight', 'bold')
    % schemLogFreq = log2(schemFreq/fc);
    for m = 1:size(schemTime, 2)
        t0 = schemTime(1, m);
        for n = 1:400:length(envelopeTone)
            d = 10*envelopeTone(n);
            plot([t0+n*dt t0+n*dt], ...
                [schemFreq(1, m)-d schemFreq(1, m)+d], ...
                'LineWidth', 2, 'Color', blueGreen)
        end
        r = mod(schemTime(1, m), durationTone+durationInterval);
        if m<size(schemTime, 2)-2 && ...
                (schemTime(1, m) == schemTime(1, m+1)) > 0
            plot([schemTime(1, m) schemTime(1, m)], fAxis, ':', ...
                'Color', 'k')
        end
    end
end

% Append the demos
pauseDuration = 1; % sec
pause = zeros(size(dt:dt:pauseDuration));
stimulus = [];
for h = size(stim,1):-1:1
    stimulus = [stimulus stim(h,:) pause]; %#ok<AGROW>
end
% Play and save the stimulus
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)


