clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define the stimulus
sampleFrequency = 44100; % Hz
dt = 1/sampleFrequency;
durationIOI = 0.200; % sec
ioi = zeros(size(dt:dt:durationIOI));
fade = 0.005; % sec
long = 0.120;
shrt = 0.040;
hgh = 1;
low = 0.25;
freq = 880*2.^((0:5)/12);
melody = repmat([1 2 3 2], 1, 16);
amp = 0.9;
ampls = amp*repmat([hgh low low], 1, ceil(length(melody)/3));
dur = repmat([shrt shrt shrt shrt long long long long], 1, 8);

% Calculate the stimulus
stimulus = zeros(1, length(ioi)*(length(melody)+1));
t0 = durationIOI;
for k = 1:length(melody)
    f = freq(melody(k));
    t = dt:dt:dur(k);
    tone = ampls(k)*sin(2*pi*f*t);
    envelopeTone = ...
        FadeInOut(ones(size(t)), sampleFrequency, fade, fade);
    tone = tone.*envelopeTone;
    schemTime(1:2, k) = [t0 t0+dur(k)]; %#ok<SAGROW>
    schemFreq(1:2, k) = [f f]; %#ok<SAGROW>
    ti = round(t0/dt);
    stimulus(ti+1:ti+length(tone)) = tone;
    t0 = t0+durationIOI;
end
durationStimulus = length(stimulus)*dt; % sec

% Save and play wav file
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position of figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = 120; % pixels
xLabelHeight = [70 30]; % pixels
yLabelWidth = 90; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the schematic time-frequency representation
panel = 1;
axes('Position', pos(panel,:))
dXTick = 1; % sec
xTick = 0:dXTick:durationStimulus+dXTick/4;
yTick = log2(freq(1)*2.^((-1:3)/12));
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
    'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', xTick, 'XTickLabel', xTick, ...
    'YTick', yTick, 'YTickLabel', -1:3)
logSchemFreq = log2(schemFreq);
for m = 1:size(schemTime, 2)
    if ampls(m) == amp*low
        plot([schemTime(1, m) schemTime(2, m)], ...
            [logSchemFreq(1, m) logSchemFreq(1, m)], ...
            'LineWidth', 1, 'Color', blueGreen)
    else
        plot([schemTime(1, m) schemTime(2, m)], ...
            [logSchemFreq(1, m) logSchemFreq(1, m)], ...
            'LineWidth', 8, 'Color', blueGreen)
    end
end
yAxis = log2([freq(1)*2^(-1/24) freq(3)*2^(1/24)]);
axis([0 durationStimulus/2 yAxis])
xlabel('time (s)')
ylabel('sts re 880 Hz', 'FontWeight', 'bold')

