clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define the stimulus
sampleFrequency = 10000; % Hz
durationTone = 1.4; % sec
fade = 0.05; % sec
fStart = 440;
fm = 1.5; % octaves per second
amp = 0.45;
delay = 1.0;

% Calculate the stimulus parameters and store them in 
% schemTime and SchemFreq
dt = 1/sampleFrequency;
tTone = dt:dt:durationTone;
schemTime(1:2, 1) = [0 durationTone]; 
schemFreq(1:2, 1) = fStart*[1 2^(fm*durationTone)];
schemTime(1:2, 2) = delay+[0 durationTone]; 
schemFreq(1:2, 2) = 2*schemFreq(1:2, 1);

% Synthesize the stimulus
stimulus = zeros(1, length(dt:dt:(durationTone+delay)));
% Synthesize the two long tones
for k=1:size(schemTime, 2)
    t = schemTime(:, k);
    f = schemFreq(:, k);
    tTone = t(1)+dt:dt:t(2);
    fInst = f(1)*2.^(fm*(tTone-t(1)));
    tone = amp*sin(2*pi*cumsum(fInst)*dt);
    tone = FadeInOut(tone, sampleFrequency, fade, fade);
    i1 = round(t(1)/dt)+1;
    i2 = i1+length(tTone)-1;
    stimulus(i1:i2) = stimulus(i1:i2) + tone;
end
durationStimulus = length(stimulus)*dt; % sec

% Save and play the sound segment
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position of figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = 240; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 90; % pixels
xMargin = 20; % pixels
yMargin = 20; % pixels
% Set the current figure handle and return the width and
% height of the figure.
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of the panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the spectrogram of the two tones
a440 = 440;
dXTick = 0.5; % sec
tAxis = [-dXTick/2 durationStimulus+dXTick/2];
fAxis = [0.8*schemFreq(1,1) min([1.25*schemFreq(2,2) sampleFrequency/2])];
xTick = 0:dXTick:1.2*durationStimulus;
lfAxis = log2(fAxis/a440);
yTick = -1:log2(sampleFrequency/a440);
axes('Position', pos)
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
    'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', xTick, 'XTickLabel', xTick, ...
    'YTick', yTick, 'YTickLabel', (a440*2.^yTick))
% Calculate the spectrogram
nFft = 1024; % Number of samples in one fft window
nWindow = 256; % Number of samples in analysis window
nOverlap = nWindow-16;
[~, f, ts, spgr] = spectrogram(stimulus, ...
    nWindow, nOverlap, nFft, sampleFrequency);
spgr = 10*log10(abs(spgr));
% Transform the linear frequency axis to a logarithmic frequency axis
freqLogScale = logspace(log10(fAxis(1)), log10(fAxis(2)), 1000);
spgrLog = zeros(length(freqLogScale), size(spgr,2));
for k = 1:size(spgr, 2)
    spgrLog(:,k) = spline(f, spgr(:,k), freqLogScale);    
end
PlotSpectrogram(stimulus, sampleFrequency, ...
    log2(freqLogScale/a440), ts, spgrLog, tAxis, dXTick, fAxis, 1, 20, ...
    frameColor)
plot([tAxis(1) tAxis(2) tAxis(2) tAxis(1) tAxis(1)], ...
    log2([fAxis(1) fAxis(1) fAxis(2) fAxis(2) fAxis(1)]/a440), ...
    'LineWidth', 2, 'Color', 'k')
set(gca, 'XTick', xTick, 'XTickLabel', xTick, ...
    'YTick', yTick, 'YTickLabel', (a440*2.^yTick), ...
    'Color', lightYellowGreen)
xlabel('time (s)')
ylabel('frequency (Hz)')
axis([tAxis lfAxis])

