clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define the stimulus
sampleFrequency = 44100; % Hz
dt = 1/sampleFrequency;
durationTone = 0.10; % sec
t = dt:dt:durationTone;
durationInterval = 0; % sec
interval = zeros(size(dt:dt:durationInterval));
fade = 0.02; % sec
freq = logspace(log10(220), log10(880), 25);
freq = [freq 0];
mel = [21 25 5 1];
nrOfRepetitions = 20;
melody = repmat(mel, 1, nrOfRepetitions);
fc = 440; % Hz
amp = 0.9;

% Calculate the stimulus
t0 = durationInterval;
for k = 1:length(melody)
    f = freq(melody(k));
    schemTime(1:2, k) = [t0 t0+durationTone]; %#ok<SAGROW>
    schemFreq(1:2, k) = [f f]; %#ok<SAGROW>
    t0 = t0+durationTone+durationInterval;
end
envelopeTone = ...
    amp*FadeInOut(ones(size(t)), sampleFrequency, fade, fade);
% Calculate the stimulus
stimulus = SynthToneSequence(schemTime, schemFreq, sampleFrequency, ...
    envelopeTone);

% Save and play the stimulus
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position of figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = 180; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 90; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the schematic time-frequency representation 
% on a logarithmic frequency axis
axes('Position', pos)
durationStimulus = length(stimulus)*dt; % sec
dXTick = 1; % sec
xTick = 0:dXTick:durationStimulus+dXTick/4;
yTick = -1:log2(sampleFrequency/fc);
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
    'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', xTick, 'XTickLabel', xTick, ...
    'YTick', yTick, 'YTickLabel', fc*2.^yTick)
schemFreq = log2(schemFreq/fc);
for m = 1:size(schemTime, 2)
    plot([schemTime(1, m) schemTime(2, m)], ...
        [schemFreq(1,m) schemFreq(1,m)], ...
        'LineWidth', 2, 'Color', blueGreen)
end
tAxis = [-dXTick/4 durationStimulus+dXTick/4];
fAxis = [150 1200];
axis([tAxis log2(fAxis/fc)])
xlabel('time (s)')
ylabel('frequency (Hz)', 'FontWeight', 'bold')


