clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define the stimuli
sampleFrequency = 10000; % Hz
dt = 1/sampleFrequency;
f0 = [2 4 6 8 10 12 15 20];
period = 1./f0;
durationTrain = 3*ones(size(f0)); % sec
durationInterval = 1; % sec
amp = 0.99;
fade = 0; % sec

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 720; % pixels
panelHeight = 60*ones(size(f0)); % pixels
xLabelHeight = 70;
yLabelWidth = 70; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeight, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeight, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Calculate and plot the sum of the two tones
t = dt:dt:durationTrain(length(f0));
p = zeros(length(f0), length(t));
stimulus = [];
for k = 1:length(f0)
    
    % Calculate the stimuli
    tp = rand/f0(k);
    while tp<=durationTrain(k)
        p(k, floor(tp*sampleFrequency)+1) = 1;
        tp = tp+1/f0(k);
    end
    interval =  zeros(size(dt:dt:durationInterval));
    savedSamples = sampleFrequency*durationTrain(k);
    stimulus = [stimulus p(k,1:savedSamples) interval]; %#ok<AGROW>

    % Calculate the plot parameters
    tAxis = ...
        [-0.05*durationTrain(k) durationTrain(k)+0.05*durationTrain(k)];
    yAxis = [-0.2 1.3];
    
    % Plot the signals
    axes('Position', pos(length(f0)+1-k,:))
    if k < length(f0)
        set(gca, 'XTicklabel', '')
    end
    set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
        'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
        'FontWeight', 'bold', 'TickDir', 'out', ...
        'YTick', -1:1)
    if k == length(f0)
        xlabel('time (s)', 'FontWeight', 'bold')
        ylabel('signal')
    end
    plot(t, p(k,:), 'Color', blueGreen, 'LineWidth', 1.5);
    plot(tAxis, [0 0], 'Color', blueGreen, 'Linewidth', 1.5)
    axis([tAxis yAxis])
end

% Save and play the stimulus
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)



