clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define the stimulus
% This generates the stimulus used by Large et al. (2015).
sampleFrequency = 44100; % Hz
dt = 1/sampleFrequency;
durationTone = 0.05; % sec
t = dt:dt:durationTone;
interOnsetInterval = 0.25;
durationInterval = interOnsetInterval-durationTone; % sec
interval = zeros(size(dt:dt:durationInterval));
fade = 0.005; % sec
fc = 262; % Hz
pattern = [1 0 1 0 0 1 0 1 1 0 0 1 0 1 1 0];
% last pattern from Figure 6 of Large et al. (2015), page 9.
nrOfRepetitions = 6;
amp = 0.9;

% Calculate the stimulus
stim = [];
tone = amp*sin(2*pi*fc*t);
tone = amp*FadeInOut(tone, sampleFrequency, fade, fade);
tone0 = zeros(size(tone));
t0 = 0;
for k = 1:length(pattern)
    sT(1:2, k) = [t0 t0+durationTone]; %#ok<SAGROW>
    sF(1:2, k) = pattern(k)*[fc fc]; %#ok<SAGROW>
    stim = [stim pattern(k)*tone interval];  %#ok<AGROW>
    t0 = t0+durationTone+durationInterval;
end
stimDuration = length(stim)*dt;
stimulus = stim;
schemTime = sT;
schemFreq = sF;
for k = 1:nrOfRepetitions-1
    stimulus = [stimulus stim];  %#ok<AGROW>
    schemFreq = [schemFreq sF];  %#ok<AGROW>
    schemTime = [schemTime sT+k*stimDuration];  %#ok<AGROW>
end
durationStimulus = length(stimulus)*dt; % sec

% Save and play the stimulus
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position of figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = 120; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 90; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the schematic time-frequency representation
% on a logarithmic frequency axis
axes('Position', pos)
dXTick = 1; % sec
xTick = 0:dXTick:durationStimulus+dXTick/4;
yTick = 0:10:2*fc;
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
    'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', xTick, 'YTick', yTick)
for m = 1:size(schemTime, 2)
    text(schemTime(1, m), schemFreq(1,m), 'o', ...        
        'LineWidth', 12, 'Color', blueGreen, ...
        'FontSize', 16, 'FontWeight', 'bold', ...
        'HorizontalAlignment', 'left')
    if mod(m,2) == 1
        plot([schemTime(1, m) schemTime(1, m)], ...
            [0 sampleFrequency/2], 'Color', blueGreen)
    else
        plot([schemTime(1, m) schemTime(1, m)], ...
            [0 sampleFrequency/2], '--', 'Color', blueGreen)
    end
end
tAxis = [-0.25*dXTick stimDuration+0.25*dXTick];
fAxis = [250 280];
axis([tAxis fAxis])
xlabel('time (s)')
ylabel('frequency (Hz)', 'FontWeight', 'bold')


