clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define the stimulus
sampleFrequency = 44100; % Hz
durationTone = 0.02; % sec 
fade = 0.002; % sec
fc = 880; % Hz
ioi2 = 0.30; % sec
delay = [0.19:-0.01:0.15 0 0.11:0.01:0.15]; % sec
nrOfTones = 3;
amp = 0.7;

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position of figure in pixels from bottom
panelWidth = 600; % pixels
panelHeights = 50*ones(1, length(delay)); % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 90; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

dt = 1/sampleFrequency;
t = dt:dt:durationTone;
samplesInDelay = round(delay/dt)+1;
envelopeTone = FadeInOut(ones(size(t)), sampleFrequency, fade, fade);
tone = amp*sin(2*pi*fc*t).*envelopeTone;
panel = 0;
stim = zeros(length(delay), round(ioi2/dt)+length(t));
for h = 1:length(delay)
    % Calculate the stimulus
    if delay(h)>0
        t0 = 0;
        s = round(t0/dt)+(1:length(tone));
        stim(h, s) = stim(h, s)+tone;
        t0 = delay(h);
        s = round(t0/dt)+(1:length(tone));
        stim(h, s) = stim(h, s)+tone;
        t0 = ioi2;
        s = round(t0/dt)+(1:length(tone));
        stim(h, s) = stim(h, s)+tone;
    end
    durationStimulus = size(stim,2)*dt; % sec
    % Plot the schematic time-frequency representation
    % on a logarithmic frequency axis
    panel = panel+1;
    axes('Position', pos(panel,:))
    dXTick = 0.1; % sec
    xTick = 0:dXTick:durationStimulus+dXTick/2;
    yTick = [-1 0 1];
    tAxis = [-dXTick/2 durationStimulus+dXTick/2];
    yAxis = [-1.2 1.2];
    set(gca, 'LineWidth', 1.5, 'FontSize', 12, ...
        'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
        'FontWeight', 'bold', 'TickDir', 'out', ...
        'YTick', yTick, 'XTick', xTick, 'XTickLabel', [])
    if h == 1
        set(gca, 'XTick', xTick, 'XTickLabel', xTick)
        xlabel('time (s)')
    end
    if h == round(length(delay)/2)
        ylabel('freq. (Hz)', 'FontWeight', 'bold')
    end
    axis([tAxis yAxis])
    text(-0.3*dXTick, 0.6, char(double('a')+length(delay)-h), ...
        'FontSize', 14, 'FontWeight', 'bold')
    plot(tAxis, [0 0], 'Color', blueGreen)
    if delay(h)>0
        plot((1:size(stim,2))*dt, stim(h,:), 'Color', blueGreen)
    end
end

% Append the demos
pauseDuration = 1; % sec
pause = zeros(size(dt:dt:pauseDuration));
stimulus = [];
for h = size(stim,1):-1:1
    stimulus = [stimulus stim(h,:) pause]; %#ok<AGROW>
end
% Play and save the stimulus
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)


