clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define the stimulus
sampleFrequency = 44100; % Hz
dt = 1/sampleFrequency;
durationTone = 0.1; % sec
t = dt:dt:durationTone;
durationInterval = 0; % sec
interval = zeros(size(dt:dt:durationInterval));
fade = 0.02; % sec
freq = logspace(log10(220), log10(440), 13);
freq = [freq 0];
mel = [1 2];
nrOfRepetitions = 10;
melody = repmat(mel, 1, nrOfRepetitions);
mel = [1 13];
melody = [melody repmat(mel, 1, nrOfRepetitions)];
mel = [1 2];
melody = [melody repmat(mel, 1, nrOfRepetitions)];
mel = [1 13];
melody = [melody repmat(mel, 1, nrOfRepetitions)];
amp = 0.9;

% Calculate the schematic time-frequency representation
% stimulus = interval;
t0 = durationInterval;
for k = 1:length(melody)
    if melody(k) == 0
        f = 0; % Hz
        tone = zeros(size(t));
    else
        f = freq(melody(k));
        tone = amp*sin(2*pi*f*t);
    end
    schemTime(1:2, k) = [t0 t0+durationTone]; %#ok<SAGROW>
    schemFreq(1:2, k) = [f f]; %#ok<SAGROW>
    t0 = t0+durationTone+durationInterval;
end
envelopeTone = ...
    amp*FadeInOut(ones(size(t)), sampleFrequency, fade, fade);

% Calculate the stimulus
stimulus = SynthToneSequence(schemTime, schemFreq, sampleFrequency, ...
    envelopeTone);

% Save and play the stimulus
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position of figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = 120; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 90; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the schematic time-frequency representation
% on a logarithmic frequency axis
axes('Position', pos)
fc = 440; % Hz
dXTick = 2; % sec
durationStimulus = length(stimulus)*dt; % sec
xTick = 0:dXTick:durationStimulus+dXTick/4;
yTick = [220 440 660];
tAxis = [-dXTick/4 durationStimulus+dXTick/4];
fAxis = [180 560];
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
    'Box', 'on', 'NextPlot', 'add', ...
    'FontWeight', 'bold', 'TickDir', 'out')
PlotSTlFR(stimulus, sampleFrequency, ...
    schemTime, schemFreq, envelopeTone, ...
    tAxis, dXTick, fAxis, 0.01*amp, blueGreen)
set(gca, 'XTick', xTick, 'XTickLabel', xTick, ...
    'YTick', log2(yTick/fc), 'YTickLabel', yTick, ...
    'Color', lightYellowGreen) 
xlabel('time (s)')
ylabel('freq. (Hz)', 'FontWeight', 'bold')


