clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Read the speech signal
[speech, sampleFrequency] = audioread('pleaseTurn.wav');
stimulus = speech';
dt = 1/sampleFrequency;
segment = [0.03 0.28];
ti = round(segment*sampleFrequency);
stimulus = stimulus(ti(1):ti(2));
durationStimulus = length(stimulus)*dt; % sec
nrOfRepetitions = 50;
stimulus = repmat(stimulus, 1, nrOfRepetitions);

% Save and play the sound segment
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Figure parameters
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = 120; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 70; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels

% Calculate the position of the figure on the screen
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the speech signal
panel = 1;
axes('Position', pos(panel,:))
set(gca, 'XTick', 0:0.25:durationStimulus, ...
    'XTickLabel', 0:0.25:durationStimulus)
tAxis = [0 5*durationStimulus-0.01];
dXTick = 0.25; % sec
dYTick = 1; % kHz
PlotSignal(stimulus, sampleFrequency, ...
    tAxis, dXTick, blueGreen, 'time (ms)')
set(gca, 'Color', lightYellowGreen)


