clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define the stimulus
sampleFrequency = 44100; % Hz
dt = 1/sampleFrequency;
durationTone = 0.2; % sec
t = dt:dt:durationTone;
fade = 0.005; % sec
fLow = 440;
fHgh = 880;
freq = [fLow fLow*2^(0.5) fHgh];
nrOfRepetitions = 20;
melody = repmat(freq, 1, nrOfRepetitions);
amp = 0.9;
ampTone = 0.3;

% Calculate the schematic time-frequency distribution and the stimulus
envelope = amp*FadeInOut(ones(size(t)), sampleFrequency, fade, fade);
stimulus = [];
t0 = 0;
for k = 1:length(melody)
    f0 = melody(k);
    schemTime(1:2, k) = [t0 t0+durationTone]; %#ok<SAGROW>
    schemFreq(1:2, k) = [f0 f0]; %#ok<SAGROW>
    if round(k/2) == k/2
        tone = ampTone*sin(2*pi*f0*t);
        tone = tone.*envelope;
        stimulus = [stimulus tone];  %#ok<AGROW>
    else
        pulses = zeros(1, length(t));
        pulses(1:round(sampleFrequency/f0):length(t)) = 1;
        pulses = pulses.*envelope;
        stimulus = [stimulus pulses];  %#ok<AGROW>
    end
    t0 = t0+durationTone;
end

% Save and play the stimulus
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position of figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = 150; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 90; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the schematic time-frequency representation
% on a logarithmic frequency axis
panel = 1;
axes('Position', pos(panel,:))
dXTick =1; % sec
durationStimulus = length(stimulus)*dt; % sec
xTick = 0:dXTick:durationStimulus+dXTick/4;
yTick = log2(freq);
tAxis = [2-dXTick/4 6+dXTick/4];
fAxis = log2([fLow/1.2 fHgh*1.2]);
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
    'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', xTick, 'XTickLabel', xTick, ...
    'YTick', yTick, 'YTickLabel', round(2.^yTick))
schemFreq = log2(schemFreq);
for m = 1:size(schemTime, 2)
    if round(m/2) ~= m/2
        plot([schemTime(1, m) schemTime(2, m)], ...
            [schemFreq(1, m) schemFreq(1, m)], ...
            'LineWidth', 3, 'Color', blueGreen)
    else
        plot([schemTime(1, m) schemTime(2, m)], ...
            [schemFreq(1, m) schemFreq(1, m)], ':', ...
            'LineWidth', 3, 'Color', blueGreen)
    end
end
p = zeros(1,3);
for m = 1:size(schemTime, 2)-3
    for i = [1 3]
        p(i) = 0.5*(schemTime(1, m+i-1)+schemTime(2, m+i-1));
    end
    if round(m/2) == m/2
        plot([p(1) p(3)], ...
            [schemFreq(1, m) schemFreq(1, m+2)], '--', 'Color', blueGreen)
    else
        plot([p(1) p(3)], ...
            [schemFreq(1, m) schemFreq(1, m+2)], 'Color', blueGreen)
    end
end
axis([tAxis fAxis])
xlabel('time (s)')
ylabel('frequency (Hz)', 'FontWeight', 'bold')


