clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define the stimulus
sampleFrequency = 10000; % Hz
durationBurst = 0.5; % sec 
durationPadding = 0.1; % sec 
nrOfRepetitions = 40;
fade = 0.02; % sec 
amp = 0.09;

% Synthesize the stimulus
dt = 1/sampleFrequency;
t = dt:dt:durationBurst;
padding = zeros(size(dt:dt:durationPadding));
fr = 0.1:0.1:sampleFrequency/2;
n = length(fr);
s = zeros(size(t));
for i = 1:n
    s = s + (amp/sqrt(i))*sin(2*pi*(fr(i)*t + rand));
end
s = repmat(s, 1, nrOfRepetitions);
s = FadeInOut(s, sampleFrequency, fade, fade);
stimulus = [padding s padding];
if max(abs(stimulus)) > 1
    fprintf('Noise scaled by a factor: %4.2f\n', max(abs(stimulus)));
    stimulus = stimulus/max(abs(stimulus));
end

% Save and play the stimulus
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position of figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = [80 180]; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 70; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the signal
panel = 1;
axes('Position', pos(panel,:))
dXTick = 2.5; % sec
dYTick = 1; % kHz
maxYAxis = 5000; % Hz
durationStimulus = length(stimulus)*dt; % sec
tAxis = [5 15];
fAxis = [-20 maxYAxis+20];
PlotSignal(stimulus, sampleFrequency, ...
    tAxis, dXTick, blueGreen, '')
set(gca, 'Color', lightYellowGreen)
text(0.98*tAxis(1)+0.02*tAxis(2), 0.85, ...
    'waveform', 'FontSize', 14, 'FontWeight', 'bold')
xlabel('time (s)')

% Calculate and lot the narrow-band spectrogram
dBRange = 60;
panel = panel+1;
axes('Position', pos(panel,:))
nFft = 2048; % Number of samples in fft window
nWindow = 512;
nOverlap = nWindow-32;
[~, f, ts, spcgr] = spectrogram(stimulus, ...
    nWindow, nOverlap, nFft, sampleFrequency);
spcgr = 10*log10(abs(spcgr));
PlotSpectrogram(stimulus, sampleFrequency, ...
    f, ts, spcgr, tAxis, dXTick, fAxis, dYTick, dBRange, ...
    frameColor)
set(gca, 'Color', lightYellowGreen)
text(0.98*tAxis(1)+0.02*tAxis(2), fAxis(1)+0.9*(fAxis(2)-fAxis(1)), ...
    'narrow-band spectrogram', 'FontSize', 14, 'FontWeight', 'bold')

