clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define the stimulus
sampleFrequency = 44100; % Hz
dt = 1/sampleFrequency;
toneDuration = 15;
t = dt:dt:toneDuration;
fade = 0.005; % sec
f0 = 400; % Hz
mF = 4;
md = 0.9;
amp = 0.5;

% Calculate the stimulus
tone = amp*sin(2*pi*f0*t);
tone = FadeInOut(tone, sampleFrequency, fade, fade);
instAmpl = 1+md*sin(2*pi*mF*t);
stimulus = tone.*instAmpl;

% Save and play the stimulus
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Specify the figure parameters
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = 180; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 80; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels

% Calculate the plot parameters
dXTick = 2; % sec
dYTick = 200; % kHz
maxYAxis = 1.5*f0; % Hz
tAxis = [-0.1*dXTick toneDuration+0.1*dXTick];
fAxis = [0 maxYAxis];
widthAmp = 0.05;

% Calculate the position of the figure on the screen
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the schematic time-frequency representation
axes('Position', pos)
set(gca, 'LineWidth', 2, 'FontSize', 14, ...
    'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', 0:dXTick:toneDuration, ...
    'YTick', 0:dYTick:maxYAxis)
mod = widthAmp*maxYAxis*instAmpl;
for r = 0:0.1:1
    plot(t, f0+r*mod, 'LineWidth', 1.5, 'Color', blueGreen)
    plot(t, f0-r*mod, 'LineWidth', 1.5, 'Color', blueGreen)
end
xlabel('time (s)', 'FontWeight', 'bold')
ylabel('inst. frequency (Hz)')
axis([tAxis fAxis])

