clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define the stimulus
sampleFrequency = 44100; % Hz
dt = 1/sampleFrequency;
nrOfHarmonics = 10;
rankOfCancelledHarmonic = 3;
amp = 1/nrOfHarmonics;
durationCancelledHarmonic = 1; % sec
t = dt:dt:durationCancelledHarmonic;
durationInterval = 1; % sec
nrOfRepetitions = 5;
interval = zeros(size(dt:dt:durationInterval));
fade = 0.02; % sec
f0 = 440; % Hz

% Calculate the interrupted harmonic
f = rankOfCancelledHarmonic*f0;
envelopeTone = ...
    FadeInOut(ones(size(t)), sampleFrequency, fade, fade);
tone = amp*sin(2*pi*f*t).*envelopeTone;
stimulus = [];
t0 = 0;
nrOfTones = 1;
for k = 1:nrOfRepetitions
    schemTime(1:2, nrOfTones) = [t0 t0+durationCancelledHarmonic]; %#ok<*SAGROW>
    schemFreq(1:2, nrOfTones) = [f f];
    nrOfTones = nrOfTones+1;
    stimulus =  [stimulus tone interval];  %#ok<*AGROW>
    t0 = t0+durationCancelledHarmonic+durationInterval;
end
durationStimulus = length(stimulus)*dt; % sec
t = dt:dt:durationStimulus;

% Calculate the other harmonics
envelopeTone = ...
    FadeInOut(ones(size(t)), sampleFrequency, fade, fade);
tone = zeros(size(t));
for k = 1:nrOfHarmonics
    if k ~=  rankOfCancelledHarmonic
        f = k*f0;
        s = amp*sin(2*pi*f*t);
        tone = tone + s;
        schemTime(1:2, nrOfTones) = [dt durationStimulus]; %#ok<*SAGROW>
        schemFreq(1:2, nrOfTones) = [f f];
        nrOfTones = nrOfTones+1;
    end
end
tone = tone.*envelopeTone;
stimulus = stimulus+tone;

% Save and play the stimulus
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position of figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = 180; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 80; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the schematic time-frequency representation
dXTick = 1; % sec
dYTick = 2; % kHz
maxYAxis = 5000; % Hz
axes('Position', pos(1,:))
tAxis = ...
    [-dXTick/2 durationStimulus+dXTick/2];
fAxis = [0 maxYAxis];
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
    'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', 0:dXTick:durationStimulus, 'XTickLabel', [], ...
    'YTick', 1000*(0:dYTick:sampleFrequency/2), ...
    'YTickLabel', 0:dYTick:sampleFrequency/2)
for m = 1:size(schemTime, 2)
    plot([schemTime(1, m) schemTime(2, m)], ...
        [schemFreq(1,m) schemFreq(1,m)], ...
        'LineWidth', 3, 'Color', blueGreen)
end
axis([tAxis fAxis])
ylabel('frequency (kHz)', 'FontWeight', 'bold')

% Plot a red rectangle around the separate stream
t1 = 1.75*durationCancelledHarmonic;
t2 = durationStimulus-0.75*durationCancelledHarmonic;
f1 = (rankOfCancelledHarmonic-0.5)*f0;
f2 = (rankOfCancelledHarmonic+0.5)*f0;
plot([t1 t2 t2 t1 t1 ], [f1 f1 f2 f2 f1], 'Color', red)
fAxis = [0 maxYAxis];
set(gca, 'XTick', 0:dXTick:durationStimulus, ...
    'XTickLabel', ...
    0:dXTick:durationStimulus)
xlabel('time (s)')


