clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define the stimulus
sampleFrequency = 44100; % Hz
dt = 1/sampleFrequency;
durationTone = 5; % sec
t = dt:dt:durationTone;
durationConstantPart = 1; % sec
fade = 0.02; % sec
f0 = 440; % Hz
mf = 4; % Hz
md = 0.9;
nrOfHarmonics = 10;
amp = 0.5/nrOfHarmonics;
% deviant harmonics
deviantHarmonics = 1:2:nrOfHarmonics;

% Calculate the stimulus
instAmpl = zeros(nrOfHarmonics, length(t));
s = round(durationConstantPart*sampleFrequency);
modulation = md*sin(2*pi*mf*t(s+1:end-s+1));
for k = 1:nrOfHarmonics
    instAmpl(k,:) = FadeInOut(ones(size(t)), sampleFrequency, fade, fade);
    if ~isempty(find(deviantHarmonics == k, 1))
        instAmpl(k,s+1:end-s+1) = ...
            instAmpl(k,s+1:end-s+1)+modulation;
    end
end
stimulus = zeros(size(t));
for k = 1:nrOfHarmonics
    tone = amp*sin(2*pi*k*f0*t);
    stimulus = stimulus + instAmpl(k,:).*tone;
end
durationStimulus = durationTone; % sec

% Save and play the stimulus
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position of figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = 300; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 70; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the instantaneous amplitude of the harmonics
axes('Position', pos)
tLabel = 'time (ms)';
dXTick = 1; % sec
dYTick = 1000; % kHz
maxYAxis = 5000; % kHz
tAxis = [-dXTick/4 durationStimulus+dXTick/4];
fAxis = [0 maxYAxis];
yTick = 0:dYTick:sampleFrequency/2;
xTick = 0:dXTick:durationStimulus;
widthAmp = 0.007;
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
    'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', xTick, 'YTick', yTick, 'YTickLabel', yTick/1000)
mod = zeros(size(t));
for k = 1:nrOfHarmonics
    mod = widthAmp*maxYAxis*instAmpl(k,:);
    for r = -1:0.2:1
        plot(t, k*f0+r*mod, 'LineWidth', 1.5, 'Color', blueGreen)
    end
end
xlabel('time (s)')
ylabel('frequency (kHz)')
axis([tAxis fAxis])


