clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define the stimulus
sampleFrequency = 44100; % Hz
dt = 1/sampleFrequency;
durationTone = 5; % sec
t = dt:dt:durationTone;
durationConstantPart = 1; % sec
fade = 0.02; % sec
f0 = 440; % Hz
mf = 4; % Hz
mi = 50;
nrOfHarmonics = 10;
amp = 0.9/nrOfHarmonics;
% deviant harmonics
deviantHarmonics = 1:2:nrOfHarmonics;

% Calculate the stimulus
instFreq = zeros(nrOfHarmonics, length(t));
s = round(durationConstantPart*sampleFrequency);
modulation = mi*mf*sin(2*pi*mf*t(s+1:end-s+1));
for k = 1:nrOfHarmonics
    instFreq(k,:) = k*f0*ones(size(t));
    if ~isempty(find(deviantHarmonics == k, 1))
        instFreq(k,s+1:end-s+1) = ...
            instFreq(k,s+1:end-s+1)+modulation;
    end
end
stimulus = zeros(size(t));
for k = 1:nrOfHarmonics
    phi = cumsum(2*pi*instFreq(k,:)*dt);
    stimulus = stimulus + amp*sin(phi);
end
stimulus = FadeInOut(stimulus, sampleFrequency, fade, fade);

% Save and play wav file
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position of figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = 300; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 70; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the instantaneous frequencies of the harmonics
axes('Position', pos)
dXTick = 1; % sec
dYTick = 1000; % kHz
maxYAxis = 5000; % kHz
durationStimulus = length(stimulus)*dt;
xAxis = [-dXTick/4 durationStimulus+dXTick/4];
yAxis = [0 maxYAxis];
yTick = 0:dYTick:sampleFrequency/2;
xTick = 0:dXTick:durationStimulus;
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
    'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', xTick, ...
    'YTick', yTick, 'YTickLabel', yTick/1000)
for k = 1:nrOfHarmonics
    plot(t, instFreq(k,:), 'LineWidth', 1.5, 'Color', blueGreen)
end
xlabel('time (s)')
ylabel('frequency (kHz)')
axis([xAxis yAxis])

