clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Calculate the stimulus
sampleFrequency = 44100; % Hz
dt = 1/sampleFrequency;
% I_ref is the intensity in W/m2 corresponding to 0 db SIL
I_ref = 1.0e-12; 
% Calculate the envelope of the series of tones
I_dB_min = 50; % minimum of ramp at start in dB
I_dB_max = 60; % maximum of ramp at thee end in dB
toneDuration = 0.2;
toneInterval = 0.2;
f = 1000; % Hz % frequency of tone in Hz
tTone = dt:dt:toneDuration;
tInterval = dt:dt:toneInterval;
fade = 0.02; % sec
toneEnvelope = FadeInOut(ones(size(tTone)), ...
    sampleFrequency, fade, fade);
interval = zeros(size(tInterval));
nrOfTones = 20;
I_tones = interval;
for k = 1:nrOfTones
    I_tones = ...
        [I_tones toneEnvelope interval]; %#ok<AGROW>
end
I_tones = I_ref*I_tones*(10^6);
duration = dt*length(I_tones); % sec

% Calculate the envelope of the ramp
% turning points tp of envelope in time
t_turningPoints = [0 0.1 0.9 1]*duration;
% intensity of envelope Ip_dB in dB at time tp
I_turningPoints_dB = [I_dB_min I_dB_min I_dB_max I_dB_max];
t = dt:dt:duration;
I_ramp_dB = zeros(size(I_tones));
ti1 = 1;
for k = 2:length(t_turningPoints)
    ti2 = floor(t_turningPoints(k)/dt);
    dI_dB = I_turningPoints_dB(k)-I_turningPoints_dB(k-1);
    ds = t_turningPoints(k)-t_turningPoints(k-1);
    for i = ti1:ti2
        I_ramp_dB(i) = ...
            (dI_dB/ds)*(t(i)-t_turningPoints(k-1)) + ...
            I_turningPoints_dB(k-1);
    end
    I_ramp(ti1:ti2) = I_ref*10.^(I_ramp_dB(ti1:ti2)/10);
    ti1 = ti2+1;
end
while length(I_ramp) < length(I_tones)
    I_ramp(end+1) = I_tones(end); %#ok<*SAGROW>
end
I_stimulus = max(I_tones, I_ramp);
% Calculate the pure tone and multiply it with the envelope
stimulus = sqrt(I_stimulus/max(I_stimulus)).*sin(2*pi*f*t);
stimulus = FadeInOut(stimulus, sampleFrequency, fade, fade);

wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, 0.2*stimulus, sampleFrequency)
sound(0.2*stimulus, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position of figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = 120; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 80; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

panel = 1;
axes('Position', pos(panel,:))
yt = 0:5:100; % Y ticks in dB
set(gca, 'Box', 'on', 'LineWidth', 2, ...
    'NextPlot', 'add', 'Color', lightYellowGreen,'TickDir', 'out', ...
    'XTick', 0:2:duration, 'XtickLabel', 0:2:duration, ...
    'YTick', yt, 'YtickLabel', yt, ...
    'FontSize', 14, 'Fontweight', 'bold')
plot(t, 10*log10(I_stimulus/I_ref), ...
    'LineWidth', 2, 'Color', blueGreen)
plot(t, 10*log10(I_ramp/I_ref), ':', 'LineWidth', 2, 'Color', red)
axis([0 duration I_dB_min-2.2 I_dB_max+5]);
xlabel('time (sec)')
ylabel('dB')
text(0.1, 63, 'intensity level of stimulus', ...
    'FontSize', 12, 'Fontweight', 'bold')


