clear
close all
InitializePSS()
rng(2) % set random number generator
fprintf('%s\n', mfilename);

% Define the stimulus
sampleFrequency = 44100; % Hz
dt = 1/sampleFrequency;
durationTone = 0.7; % sec
t = dt:dt:durationTone;
durationInterval = 0.3; % sec
interval = zeros(size(dt:dt:durationInterval));
fade = 0.02; % sec
f0 = 440; % Hz
harmonics = 1:10;
amp = 0.9/length(harmonics);
% deviation from onset of other harmonics in sec.
deviationFromOffset = [-0.3 -0.1 -0.03 0.0 0.03 0.1 0.3];

% Calculate the stimulus
t0 = -deviationFromOffset(1);
nrOfTones = 1;
for k = 1:length(deviationFromOffset)
    tone = zeros(size(t));
    a = harmonics(1)-0.5;
    b = harmonics(end)+0.5;
    deviantHarmonic = round(a+(b-a)*rand);
    for i = harmonics(1:end)
        if i == deviantHarmonic
            dF0 = deviationFromOffset(k);
        else
            dF0 = 0;
        end
        f = i*f0;
        schemTime(1:2, nrOfTones) = [t0 t0+dF0+durationTone]; %#ok<*SAGROW>
        schemFreq(1:2, nrOfTones) = [f f];
        nrOfTones = nrOfTones+1;
    end
    t0 = t0+durationTone+durationInterval;
end
nrOfTones = nrOfTones-1;
durationStimulus = max(schemTime(:)); % sec
t = dt:dt:durationStimulus;
stimulus = zeros(size(t));
for nOT = 1:nrOfTones
    toneDuration = schemTime(2, nOT)-schemTime(1, nOT);
    tTone = dt:dt:toneDuration;
    if schemFreq(1, nOT) == schemFreq(2, nOT)
        tone = amp*sin(2*pi*schemFreq(1, nOT)*tTone);
        tone = FadeInOut(tone, sampleFrequency, fade, fade);
    end
    sI = floor(schemTime(1, nOT)*sampleFrequency+1);
    stimulus(sI:sI+length(tone)-1) = stimulus(sI:sI+length(tone)-1) + tone;
end

% Save and play wav file
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position of figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = [90 180]; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 70; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the sound signal
panel = 1;
axes('Position', pos(panel,:))
tLabel = 'time (ms)';
dXTick = 1; % sec
dYTick = 2; % kHz
tAxis = ...
    [-dXTick/4 durationStimulus+dXTick/4];
fAxis = [0 5000];
PlotSignal(stimulus, sampleFrequency, ...
    tAxis, dXTick, blueGreen, 'time (s)')
set(gca, 'XTick', 0:dXTick:durationStimulus, ...
    'XTickLabel', 0:dXTick:durationStimulus, ...
    'Color', lightYellowGreen)

% Plot the schematic time frequency representation
panel = panel+1;
axes('Position', pos(panel,:))
yTick = 0:1000:sampleFrequency/2;
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
    'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', 0:dXTick:durationStimulus, 'XTickLabel', [], ...
    'YTick', yTick, 'YTickLabel', yTick/1000)
for m = 1:size(schemTime, 2)
    plot([schemTime(1, m) schemTime(2, m)], ...
        [schemFreq(1,m) schemFreq(1,m)], ...
        'LineWidth', 3, 'Color', blueGreen)
end
set(gca, 'Color', lightYellowGreen)
ylabel('frequency (kHz)')
axis([tAxis fAxis])


