clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define the stimulus
sampleFrequency = 44100; % Hz
dt = 1/sampleFrequency;
durationTone = 0.8; % sec
t = dt:dt:durationTone;
durationInterval = 0.2; % sec
interval = zeros(size(dt:dt:durationInterval));
fade = 0.02; % sec
f0 = 440; % Hz
df = f0*(sqrt(5)-1)/2;
harmonics = 1:10;
amp = 1/length(harmonics);
deviantHarmonic = harmonics(1)+2;
deviationFromHarmonicity = ...
    [0 0.01 0.03 0.1 0.3 0.5 0.3 0.1 0.03 0.01 0]; % proportion of f0

% Calculate the stimulus
t0 = 0;
nrOfTones = 1;
for k = 1:length(deviationFromHarmonicity)
    for i = harmonics(1:end)
        f = i*f0+df;
        if i == deviantHarmonic
            f = f+deviationFromHarmonicity(k)*f0;
        end
        schemTime(1:2, nrOfTones) = [t0 t0+durationTone]; %#ok<*SAGROW>
        schemFreq(1:2, nrOfTones) = [f f];
        nrOfTones = nrOfTones+1;
    end
    t0 = t0+durationTone+durationInterval;
end
envelopeTone = ...
    amp*FadeInOut(ones(size(t)), sampleFrequency, fade, fade);
stimulus = SynthToneSequence(schemTime, schemFreq, sampleFrequency, ...
    envelopeTone);

% Save and play the stimulus
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position of figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = [90 180]; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 70; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the sound signal
panel = 1;
axes('Position', pos(panel,:))
tLabel = 'time (ms)';
dXTick = 1; % sec
dYTick = 2; % kHz
durationStimulus = length(stimulus)*dt; % sec
tAxis = [-dXTick/4 durationStimulus+dXTick/4];
fAxis = [0 5000];
PlotSignal(stimulus, sampleFrequency, ...
    tAxis, dXTick, blueGreen, 'time (s)')
set(gca, 'XTick', 0:dXTick:durationStimulus, ...
    'XTickLabel', 0:dXTick:durationStimulus, ...
    'Color', lightYellowGreen)

% Plot the schematic time frequency representation
panel = panel+1;
axes('Position', pos(panel,:))
yTick = 0:1000:sampleFrequency/2;
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
    'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', 0:dXTick:durationStimulus, 'XTickLabel', [], ...
    'YTick', yTick, 'YTickLabel', yTick/1000)
for m = 1:size(schemTime, 2)
    plot([schemTime(1, m) schemTime(2, m)], ...
        [schemFreq(1,m) schemFreq(1,m)], ...
        'LineWidth', 3, 'Color', blueGreen)
end
ylabel('frequency (kHz)')
axis([tAxis fAxis])

% Plot a red rectangle around the deviant partials
t1 = 2*(durationTone + durationInterval)-0.5*durationInterval;
t2 = 9*(durationTone + durationInterval)-0.5*durationInterval;
f1 = (deviantHarmonic-0.25)*f0+df;
f2 = (deviantHarmonic+0.75)*f0+df;
plot([t1 t2 t2 t1 t1], [f1 f1 f2 f2 f1], 'Color', darkRed)


