clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define the stimulus
sampleFrequency = 44100; % Hz
dt = 1/sampleFrequency;
durationTone = 0.8; % sec
t = dt:dt:durationTone;
durationInterval = 0.2; % sec
interval = zeros(size(dt:dt:durationInterval));
fade = 0.02; % sec
f0 = 440; % Hz
nrOfPartials = 10;
amp = 1/nrOfPartials;
shiftFromHarmonicity = ...
    [0 0.01 0.03 0.1 0.3 0.5 0.3 0.1 0.03 0.01 0];

% Calculate the stimulus
t0 = 0;
nrOfTones = 1;
for k = 1:length(shiftFromHarmonicity)
    for i = 1:nrOfPartials
        f = i*f0+shiftFromHarmonicity(k)*f0;
        schemTime(1:2, nrOfTones) = [t0 t0+durationTone]; %#ok<*SAGROW>
        schemFreq(1:2, nrOfTones) = [f f];
        nrOfTones = nrOfTones+1;
    end
    t0 = t0+durationTone+durationInterval;
end
envelopeTone = ...
    amp*FadeInOut(ones(size(t)), sampleFrequency, fade, fade);
stimulus = SynthToneSequence(schemTime, schemFreq, sampleFrequency, ...
    envelopeTone);

% Save and play wav file
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position of figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = [80 180]; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 70; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the signal
panel = 1;
axes('Position', pos(panel,:))
dXTick = 1;
dFTick = 1000; % sec
fTick = 0:dFTick:sampleFrequency/2;
maxYAxis = 5000; % Hz
durationStimulus = length(stimulus)*dt; % sec
tTick = 0:dXTick:durationStimulus;
tAxis = [-dXTick/4 durationStimulus+dXTick/4];
fAxis = [0 maxYAxis];
PlotSignal(stimulus, sampleFrequency, ...
    tAxis, dXTick, blueGreen, 'time (ms)')
set(gca, 'XTick', tTick, 'XTickLabel', tTick, ...
    'Color', lightYellowGreen)
xlabel('time (s)')

% Plot the schematic time frequency representation
panel = panel+1;
axes('Position', pos(panel,:))
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
    'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', tTick, 'XTickLabel', [], ...
    'YTick', fTick, 'YTickLabel', fTick/1000)
for m = 1:size(schemTime, 2)
    plot([schemTime(1, m) schemTime(2, m)], ...
        [schemFreq(1,m) schemFreq(1,m)], ...
        'LineWidth', 2, 'Color', blueGreen)
end
axis([tAxis 0 maxYAxis])
ylabel('frequency (kHz)', 'FontWeight', 'bold')


