clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define and synthesize the stimulus
sampleFrequency = 10000; % Hz
dt = 1/sampleFrequency;
durationNoise = 0.8; % sec
durationTone = 0.2; % sec
durationInterval = 1; % sec
tNoise = dt:dt:durationNoise;
tTone = dt:dt:durationTone;
ampNoise = 0.29;
ampTone = 0.08;
interval = zeros(size(dt:dt:durationInterval));
fade = 0.005; % sec
cutOffMin = 1000;
f0 = 2500; % Hz
cutOffMax = 4000;
w = (2/sampleFrequency)*[cutOffMin cutOffMax];
[b, a] = butter(4, w);
noise = ampNoise*randn(size(tNoise));
noise = filtfilt(b, a, noise);
noise = FadeInOut(noise, sampleFrequency, fade, fade);
tone = ampTone*sin(2*pi*f0*tTone);
tone = FadeInOut(tone, sampleFrequency, fade, fade);
stimulus= [noise tone interval tone];

% Save and play the sound segment
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = 240; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 80; % pixels
xMargin = 20; % pixels
yMargin = 20; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the spectrogram
dXTick = 0.5; % sec
dYTick = 1; % kHz
maxYAxis = 6000; % Hz
durationStimulus = length(stimulus)*dt;
xTick = -dXTick:dXTick:durationStimulus+dXTick;
tAxis = [-0.2*dXTick 2.5+0.2*dXTick];
fAxis = [-20 maxYAxis];
nFft = 1024; % Number of samples in fft window
nWindow = 128;
nOverlap = nWindow-16;
durationPadding = 0.025; % sec
padding = zeros(size(dt:dt:durationPadding));
[~, f, ts, p] = spectrogram([padding stimulus padding], ...
    nWindow, nOverlap, nFft, sampleFrequency);
p = 10*log10(abs(p));
ts = ts-durationPadding;
PlotSpectrogram(stimulus, sampleFrequency, ...
    f, ts, p, tAxis, dXTick, fAxis, dYTick, 40, ...
    lightYellowGreen)
set(gca, 'XTick', xTick, 'XTickLabel', xTick)
text(0.99*tAxis(1)+0.01*tAxis(2), fAxis(1)+0.925*(fAxis(2)-fAxis(1)), ...
    'spectrogram', 'FontSize', 14, 'FontWeight', 'bold')
xlabel('time (s)')


