clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Read the speech signal and define the segment
[speech, sampleFrequency] =  audioread('sap.wav');
pCenter = [0.0 0.2 0.4]; %sec
syllable = speech';
dt = 1/sampleFrequency;
syllable = ...
    5*syllable(round(0.05*sampleFrequency):round(0.6*sampleFrequency));
durationInterval = 0.5; % sec
interval = zeros(1, round(sampleFrequency*durationInterval));
clickDuration = 0.0003; % sec
click = 0.9*ones(1, round(sampleFrequency*clickDuration));
stimulus = repmat(interval, length(pCenter), 2*length(pCenter)+1);
durationStimulus = length(stimulus)*dt; % sec
t = (1:length(stimulus))*dt;
lc = length(click);
li = length(interval);
for k = 1:length(pCenter)
    for i = [1 3 5]
        stimulus(k, i*li+(1:lc)) = stimulus(k, i*li+(1:lc)) + click;
    end
    for i = [2 4]
        k1 = i*li-round(pCenter(k)*sampleFrequency);
        k2 = k1+length(syllable);
        stimulus(k, k1+1:k2) = stimulus(k, k1+1:k2) + syllable;
    end
end

% Play and save the stimulus
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
s = [stimulus(1,:) stimulus(2,:) stimulus(3,:)];
audiowrite(wavFileName, s, sampleFrequency)
sound(s, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = 120*ones(size(pCenter)); % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 60; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the stimuli
dXTick = 0.5; % sec
xTick = 0:dXTick:t(end);
tAxis = [0 6*durationInterval];
yAxis = [-0.8 1.4];
panel = 1;
axes('Position', pos(panel,:))
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
    'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', xTick, 'XTickLabel', xTick, 'YTick', -1:1)
q = length(pCenter)-panel+1;
plot((1:size(stimulus, 2))/sampleFrequency, stimulus(q,:), ...
    'Color', blueGreen, 'LineWidth', 1.5);
axis([tAxis yAxis])
xlabel('time (s)', 'FontWeight', 'bold')
ylabel('signal', 'FontWeight', 'bold')
text(0.99*tAxis(1)+0.01*tAxis(2), 1.2, 'syllable too early', ...
    'FontSize', 10, 'FontWeight', 'bold', 'Color', blueGreen)

panel = panel+1;
axes('Position', pos(panel,:))
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
    'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', xTick, 'XTickLabel', [], 'YTick', -1:1)
q = 3-panel+1;
plot((1:size(stimulus, 2))/sampleFrequency, stimulus(q,:), ...
    'Color', blueGreen, 'LineWidth', 1.5);
axis([tAxis yAxis])
ylabel('signal', 'FontWeight', 'bold')
text(0.99*tAxis(1)+0.01*tAxis(2), 1.2, 'syllable on the beat', ...
    'FontSize', 10, 'FontWeight', 'bold', 'Color', blueGreen)

panel = panel+1;
axes('Position', pos(panel,:))
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
    'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', xTick, 'XTickLabel', [], 'YTick', -1:1)
q = 3-panel+1;
plot((1:size(stimulus, 2))/sampleFrequency, stimulus(q,:), ...
    'Color', blueGreen, 'LineWidth', 1.5);
axis([tAxis yAxis])
ylabel('signal', 'FontWeight', 'bold')
text(0.99*tAxis(1)+0.01*tAxis(2), 1.2, 'syllable too late', ...
    'FontSize', 10, 'FontWeight', 'bold', 'Color', blueGreen)

