clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Read the speech signal
[speech, sampleFrequency] = audioread('pleaseInsert.wav');
stimulus = 0.9*speech';
dt = 1/sampleFrequency;
segment = [0.027 0.31];
ti = round(segment*sampleFrequency);
stimulus = stimulus(ti(1):ti(2));
durationStimulus = length(stimulus)*dt; % sec
t = (0:length(stimulus))*dt;

% Save and play the sound segment
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = [120 240]; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 70; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the speech signal
panel = 1;
axes('Position', pos(panel,:))
set(gca, 'XTick', 0:0.25:durationStimulus, ...
    'XTickLabel', 0:0.25:durationStimulus)
tAxis = [t(1) t(end)-0.02];
dXTick = 0.05; % sec
dYTick = 1; % kHz
PlotSignal(stimulus, sampleFrequency, ...
    tAxis, dXTick, blueGreen, 'time (s)')
set(gca, 'Color', lightYellowGreen)
onsets = [0.037 0.09 0.118]-segment(1);
for i = 1:length(onsets)
    plot([onsets(i) onsets(i)], [-2 2], 'LineWidth', 1, ...
    'Color', blueGreen); 
end
text(onsets(1)+0.005, -0.7, '/p/', 'FontSize', 14)
text(onsets(2)+0.005, -0.7, '/l/', 'FontSize', 14)
text(onsets(3)+0.005, -0.7, '/i/', 'FontSize', 14)

% Calculate and plot the spectrogram
panel = panel+1;
axes('Position', pos(panel,:))
maxYAxis = sampleFrequency/2; % Hz
fAxis = [0 maxYAxis];
nFft = 2048; % Number of samples in fft window
nWindow = 64;
nOverlap = nWindow-2;
[~, f, ts, spgr] = spectrogram(stimulus, ...
    nWindow, nOverlap, nFft, sampleFrequency);
spgr = 10*log10(abs(spgr));

PlotSpectrogram(speech, sampleFrequency, ...
    f, ts, spgr, tAxis, dXTick, fAxis, dYTick, 50, ...
    lightYellowGreen)
text(t(end)-0.05, 0.9*(fAxis(2)-fAxis(1)), ...
    'wide-band spectrogram', ...
    'FontSize', 14, 'FontWeight', 'bold', ...
    'HorizontalAlignment', 'right')


