clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define the stimulus
sampleFrequency = 44100; % Hz
dt = 1/sampleFrequency;
durationTone = 0.125; % sec
t = dt:dt:durationTone;
tau = durationTone/3; % sec
shift = -tau*log(0.16); % Based on Schutte (1978a)
durationInterval = 0.125; % sec
durationIntervalLong = durationInterval+shift; % sec
durationIntervalShort = durationInterval-shift; % sec
interval = zeros(size(dt:dt:durationInterval));
intervalShort = zeros(size(dt:dt:durationIntervalLong));
intervalLong = zeros(size(dt:dt:durationIntervalShort));
f0 = logspace(log10(440), log10(4*440), 25);
melody = [1 3 5 6 8 10 12 13 15 17 18 20 22 24 25];
nrOfHarmonics = 3;
amp = 1/nrOfHarmonics;

% Calculate the regular stimulus
stimulusReg = [];
envelopeToneDamp = exp(-t/tau);
envelopeToneRamp = fliplr(envelopeToneDamp);
for k = 1:length(melody)
    tone = zeros(size(t));
    for i = 1:nrOfHarmonics
        f = i*f0(melody(k));
        tone = tone + amp*sin(2*pi*f*t);
    end
    if mod(k, 2) == 0
        tone = tone.*envelopeToneRamp;
        stimulusReg =  [stimulusReg tone intervalShort];  %#ok<AGROW>
    else
        tone = tone.*envelopeToneDamp;
        stimulusReg =  [stimulusReg tone intervalLong];  %#ok<AGROW>
    end
end

% Calculate the irregular stimulus
stimulusIrreg = [];
envelopeToneDamp = exp(-t/tau);
envelopeToneRamp = fliplr(envelopeToneDamp);
for k = 1:length(melody)
    tone = zeros(size(t));
    for i = 1:nrOfHarmonics
        f = i*f0(melody(k));
        tone = tone + amp*sin(2*pi*f*t);
    end
    if mod(k, 2) == 0
        tone = tone.*envelopeToneRamp;
        stimulusIrreg =  [stimulusIrreg tone interval];  %#ok<AGROW>
    else
        tone = tone.*envelopeToneDamp;
        stimulusIrreg =  [stimulusIrreg tone interval];  %#ok<AGROW>
    end
end

stimulus = [stimulusIrreg interval stimulusReg];

% Save and play the sound
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = [90 90]; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 90; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the sound signal
panel = 1;
axes('Position', pos(panel,:))
dXTick = 0.5; % sec
durationStimulus = length(stimulusReg)*dt; % sec
XTick = 0:0.5:durationStimulus;
tAxis = [-dXTick/4 durationStimulus+dXTick/8];
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
    'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', XTick, 'XTickLabel', XTick, 'YTick', -1:1)
PlotSignal(stimulusReg, sampleFrequency, ...
    tAxis, dXTick, blueGreen, 'time (s)')
for k = 0:length(melody)-1
    plot([2*k*durationTone 2*k*durationTone], [-2 2], 'Color', red)
end
set(gca, 'XTick', 0:0.5:durationStimulus, ...
    'XTickLabel', 0:0.5:durationStimulus, ...
    'Color', lightYellowGreen)

% Plot the sound signal
panel = panel+1;
axes('Position', pos(panel,:))
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
    'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', XTick, 'XTickLabel', XTick, 'YTick', -1:1)
PlotSignal(stimulusIrreg, sampleFrequency, ...
    tAxis, dXTick, blueGreen, '')
for k = 0:length(melody)-1
    plot([2*k*durationTone 2*k*durationTone], [-2 2], 'Color', red)
end
set(gca, 'XTick', 0:0.5:durationStimulus, 'XTickLabel', [], ...
    'Color', lightYellowGreen)


