clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% phoneme boundaries as measured in figure 1-B-6 of Rapp-Holmgren (1971)
phonBound = [ 1.25  2.97  7.23 12.45 13.91
    1.35  3.10  6.73 12.15 13.65
    1.35  3.20  6.27 11.89 13.43
    1.30  3.27  6.13 11.69 13.37
    1.41  3.67  5.88 11.70 13.40
    1.50  3.70  5.80 11.62 13.42
    1.53  3.72  5.68 11.50 13.30];
phonBound = flipud(phonBound);
% Rescale to seconds
phonBound = -0.3 + phonBound*0.7/13.22;
str = [2.97 4.78 5.70 7.23];
st = [3.10 5.06 6.34 6.73];
n = [3.70 5.80];
l = [3.72 5.68];
d = [3.67 5.50 5.88];
t = [3.20 5.29 6.27];
s = [3.27 6.13];
str = -0.3 + str*0.7/13.22;
st = -0.3 + st*0.7/13.22;
n = -0.3 + n*0.7/13.22;
l = -0.3 + l*0.7/13.22;
d = -0.3 + d*0.7/13.22;
t = -0.3 + t*0.7/13.22;
s = -0.3 + s*0.7/13.22;
vowelTxt = sprintf('\x0251');

% Specify the figure parameters
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = 360; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 90; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels

% Calculate the position of the figure on the screen
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Calculate the plot parameters
xTick = -0.3:0.1:0.5;
dXTick = 0.1; % sec
YTick = 1:7; % Hz
YTickLabel = [' l '; ' n '; ' d '; ' s '; ' t '; ...
    'st '; 'str'];
xAxis = [-0.27 0.45];
yAxis = [0.5 7.5];

% Plot the figure
axes('Position', pos)
set(gca, 'LineWidth', 2, 'FontSize', 14, ...
    'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', xTick, 'YTick', YTick, 'YTickLabel', YTickLabel)
plot([0 0], yAxis, 'k')
for k = 1:size(phonBound, 2)
    for j = 1:size(phonBound,1)
        plot([phonBound(j,k) phonBound(j,k)], [j-0.2 j+0.2], 'k')
    end
    plot(phonBound(:,k), 1:size(phonBound,1), 'k.','MarkerSize', 7)
end
for j = 1:size(phonBound, 1)
    text(mean(phonBound(j, 1:2)), j, 'a', 'FontSize', 15, ...
        'FontWeight', 'bold', 'HorizontalAlignment', 'center')
    text(mean(phonBound(j, 3:4)), j, vowelTxt, 'FontSize', 15, ...
        'FontWeight', 'bold', 'HorizontalAlignment', 'center')
    text(mean(phonBound(j, 4:5)), j, 'd', 'FontSize', 15, ...
        'FontWeight', 'bold', 'HorizontalAlignment', 'center')
end
plot(str, 7, 'k.', 'MarkerSize', 6)
text(mean(str(1:2)), 7, 's', 'FontSize', 15, 'FontWeight', 'bold', ...
    'HorizontalAlignment', 'center')
text(mean(str(2:3)), 7, 't', 'FontSize', 15, 'FontWeight', 'bold', ...
    'HorizontalAlignment', 'center')
text(mean(str(3:4)), 7, 'r', 'FontSize', 15, 'FontWeight', 'bold', ...
    'HorizontalAlignment', 'center')
plot(st, 6, 'k.', 'MarkerSize', 6)
text(mean(st(1:2)), 6, 's', 'FontSize', 15, 'FontWeight', 'bold', ...
    'HorizontalAlignment', 'center')
text(mean(st(2:3)), 6, 't', 'FontSize', 15, 'FontWeight', 'bold', ...
    'HorizontalAlignment', 'center')
plot(t, 5, 'k.', 'MarkerSize', 6)
text(mean(t(1:2)), 5, 't', 'FontSize', 15, 'FontWeight', 'bold', ...
    'HorizontalAlignment', 'center')
plot(s, 4, 'k.', 'MarkerSize', 6)
text(mean(s(1:2)), 4, 's', 'FontSize', 15, 'FontWeight', 'bold', ...
    'HorizontalAlignment', 'center')
plot(d, 3, 'k.', 'MarkerSize', 6)
text(mean(d(1:2)), 3, 'd', 'FontSize', 15, 'FontWeight', 'bold', ...
    'HorizontalAlignment', 'center')
plot(n, 2, 'k.', 'MarkerSize', 6)
text(mean(n(1:2)), 2, 'n', 'FontSize', 15, 'FontWeight', 'bold', ...
    'HorizontalAlignment', 'center')
plot(l, 1, 'k.', 'MarkerSize', 6)
text(mean(l(1:2)), 1, 'l', 'FontSize', 15, 'FontWeight', 'bold', ...
    'HorizontalAlignment', 'center')
xlabel('location of phoneme boundaries relative to beat location (sec)', ...
    'FontWeight', 'bold')
ylabel('consonant cluster', 'FontWeight', 'bold')
axis([xAxis yAxis])

    sprintf('mImages/%s.jpg', mfilename);
