clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Calculate the pulse series
sampleFrequency = 22050; % Hz
dt = 1/sampleFrequency;
durationPulses = 3; % sec
durationInterval = 0.2; % sec
tPulses = dt:dt:durationPulses;
tInterval = dt:dt:durationInterval;
interval = zeros(size(tInterval));
pulses = zeros(size(tPulses));
fc = 200; % Hz
T0 = 1000/sampleFrequency;
fm = 3;
df = fc/2;
amp = 0.15;
md = 0.3;
fInst = fc+df*sin(2*pi*fm*tPulses);
sinusoid = amp*sin(2*pi*cumsum(fInst)*dt);
jitter = 0;
for i=2:length(sinusoid)
    if sinusoid(i-1)<0 && sinusoid(i)>=0
        j = i+round(jitter*(0.5*randn-0.5));
        if j>0 && j<=length(tPulses)
            pulses(j) = amp;
        end
    end
end
stim1 = pulses.*(1-md*sin(2*pi*fm*tPulses));
stim2 = pulses; % .*(1+md*sin(2*pi*fm*tPulses));
stimulus = [interval stim2 interval stim1 interval];

% Save and play the stimulus
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = [120 120]; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 90; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the position of the panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% plot the sound signals
panel = 1;
axes('Position', pos(panel,:))
xTick = 0:0.1:tPulses(end);
yTick = -1:0.1:2;
segment = [0.1 0.9];
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
    'Box', 'on', 'Color', lightYellowGreen, ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', xTick, 'YTick', yTick, 'NextPlot', 'add')
plot(tPulses, stim1, 'LineWidth', 2, 'Color', blueGreen)
xlabel('time (s)')
ylabel('signal')
axis([segment -0.1*amp 1.2*(1+md)*amp])

panel = panel+1;
axes('Position', pos(panel,:))
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
    'Box', 'on', 'Color', lightYellowGreen, ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', xTick, 'XTickLabel', [], ......
    'YTick', yTick, 'NextPlot', 'add')
plot(tPulses, stim2, 'LineWidth', 2, 'Color', blueGreen)
ylabel('signal')
axis([segment -0.1*amp 1.1*(1+md)*amp])


