clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

sampleFrequency = 10000; % Hz % Hertz
dt = 1/sampleFrequency;
durationStimulus = 0.05; % sec 
tStim = dt:dt:durationStimulus;
durationZerosOnset = 0.01; % sec
tOnset = dt:dt:durationZerosOnset;
durationZerosOffset = 0.05; % sec
tOffset = dt:dt:durationZerosOffset;
paddingOnset = zeros(size(tOnset));
paddingOffset = zeros(size(tOffset));
duration = ...
    durationZerosOnset + durationStimulus + durationZerosOffset;
a = 0.9;
stimulus = a*ones(size(tStim));
stimulus = [paddingOnset stimulus paddingOffset];
durationStimulus = length(stimulus)*dt; % sec

% Calculate response, based on Westerman and Smith, 1984.
a1 = 500;
tau1 = 0.003; % time constant of rapid adaptation in seconds
a2 = 150;
tau2 = 0.060; % time constant of short-term adaptation in seconds
as = 180;
respOnset = as + a1*exp(-tStim/tau1) + a2*exp(-tStim/tau2);
respOffset = - a1*exp(-tOffset/tau1) - a2*exp(-tOffset/tau2);
resp = [paddingOnset respOnset respOffset];
% Add some low-frequency noise to the response
cutOff = 3000; % Hz
[bLow, aLow] = butter(4, 2*cutOff/sampleFrequency);
spontActivity = 80;
noise = 0.7*spontActivity*randn(size(resp));
resp = resp + filter(bLow, aLow, noise); 
resp = spontActivity+resp;
response = max(0, resp);

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position of figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = [90 240]; % pixels
xLabelHeight = 90; % pixels
yLabelWidth = 90; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the stimulus
panel = 1;
axes('Position', pos(panel, :))
dXTick = 0.01;
xTick = 0:dXTick:2*durationStimulus;
xTickLabel = 1000*(xTick-durationZerosOnset);
yTick = [0 1];
tStim = (1:length(stimulus))*dt;
xRange = [0 tStim(end)];
set(gca, 'FontSize', 14, 'FontWeight', 'bold', ...
    'XTick', xTick, 'XTickLabel', xTickLabel, ...
    'YTick', yTick, 'Color', lightYellowGreen, 'TickDir', 'out', ...
    'Box', 'on', 'LineWidth', 2, 'NextPlot', 'add')
plot(xRange, [0 0], 'LineWidth', 1, 'Color', blueGreen)
plot(tStim, stimulus, 'LineWidth', 2, 'Color', blueGreen)
axis([xRange -0.2 1.2])
xlabel('time (ms)')
ylabel('stimulus')

% Plot the probability of an action potential
panel = panel+1;
axes('Position', pos(panel, :))
set(gca, 'FontSize', 14, 'FontWeight', 'bold', ...
    'XTick', xTick, 'xTickLabel', [], ...
    'Color', lightYellowGreen, 'TickDir', 'out', ...
    'Box', 'on', 'LineWidth', 2, 'NextPlot', 'add')
tStim = (1:length(response))*dt;
plot(xRange, [0 0], 'LineWidth', 1, 'Color', blueGreen)
plot(tStim, response, 'LineWidth', 2, 'Color', blueGreen)
plot(xRange, [spontActivity spontActivity], '--', ...
    'LineWidth', 1, 'Color', darkRed)
r = durationStimulus - durationZerosOffset;
intervalMeanAdapt = [r-0.01 r];
c = [round(intervalMeanAdapt(1)/dt) round(intervalMeanAdapt(2)/dt)];
p = intervalMeanAdapt(1);
meanResp = mean(resp(c(1):c(2)));
arrowWidth = 0.0005;
arrowLength = 100;
plot([0.005 0.060], [max(response) max(response)], '--')
plot([p p], [meanResp max(response)], ...
    'LineWidth', 2, 'Color', darkRed)
plot([p p-arrowWidth], [meanResp meanResp+arrowLength], ...
    'LineWidth', 2, 'Color', darkRed)
plot([p p+arrowWidth], [meanResp meanResp+arrowLength], ...
    'LineWidth', 2, 'Color', darkRed)
plot([p p-arrowWidth], [max(response) max(response)-arrowLength], ...
    'LineWidth', 2, 'Color', darkRed)
plot([p p+arrowWidth], [max(response) max(response)-arrowLength], ...
    'LineWidth', 2, 'Color', darkRed)
text(p-0.0004, mean([meanResp max(response)]), ...
    'decrease due to', ...
    'FontSize', 12, 'FontWeight', 'bold', 'HorizontalAlignment', 'right')
text(p+0.0004, mean([meanResp max(response)]), ...
    'adaptation', ...
    'FontSize', 12, 'FontWeight', 'bold')
axis([xRange -0.2*max(response) 1.1*max(response)])
ylabel('spikes/s')


