clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Calculate the pulse series
sampleFrequency = 22050; % Hz
dt = 1/sampleFrequency;
durationPulses = 0.1; % sec
durationInterval = 0.02; % sec
tPulses = dt:dt:durationPulses;
tInterval = dt:dt:durationInterval;
interval = zeros(size(tInterval));
stimulus = zeros(size(tPulses));
f0 = 200; % Hz
T0 = 1/f0;
p = round((0:T0:durationPulses)*sampleFrequency)+1;
stimulus(p) = 0.9;
stimulus = [interval stimulus interval interval];
t = (1:length(stimulus))*dt;
segment = [0.039 0.069];

% Save and play the stimulus
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the dBA filter
[b_dBA, a_dBA] = Calculate_dBAFilter(sampleFrequency);

% Calculate the center frequencies of the gammatone filterbank
numberOfFilters = 128;
minimumFrequency = 100;
maximumFrequency = sampleFrequency/2;
centerFrequencies = ...
    CalculateCenterFrequencies(numberOfFilters, ...
    minimumFrequency, maximumFrequency);
% Calculate the filter coefficients of the gammatone filter bank
[b, a] = ...
    CalculateGammatoneFilterBank(sampleFrequency, centerFrequencies);

% band-pass filtering
basilarMembrane = zeros(numberOfFilters, length(stimulus));
for k = 1:numberOfFilters
    basilarMembrane(k,:) = filter(b(k,:), a(k,:), stimulus);
end

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = [120 700]; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 90; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the position of the panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);


% Plot the sound signal
panel = 1;
axes('Position', pos(panel,:))
xTick = 0:0.005:t(end);
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
    'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', xTick, 'XTickLabel', 1000*xTick, ...
    'YTick', -1:1, 'YTickLabel', -1:1)
plot(t, stimulus, 'LineWidth', 2, 'Color', blueGreen)
xlabel('time (ms)')
ylabel('signal')
axis([segment -0.4 1.1])

% Plot the basilar membrane response
panel = panel+1;
axes('Position', pos(panel,:))
yticklabel = [50 100 200 500 1000 2000 5000 10000 20000];
ytick = spline(centerFrequencies, 1:numberOfFilters, yticklabel);
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
    'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', xTick, 'XTickLabel', [], ...
    'YTick', ytick, 'YTickLabel', yticklabel/1000)
surface(t, 1:numberOfFilters, basilarMembrane, 'EdgeColor', 'none');
set(gca, 'Color', lightYellowGreen)
ylabel('frequency (kHz)')
caxis([-max(basilarMembrane(:)) max(basilarMembrane(:))])
axis([segment 1 0.9*numberOfFilters])


