clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position of figure in pixels from bottom
panelWidth = 600; % pixels
panelHeight = 600; % pixels
xLabelHeight = 15; % pixels
yLabelWidth = 15; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeight, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeight, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the spiral
axes('Position', pos(1,:))
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
    'Box', 'off', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontWeight', 'bold', 'XTick', [], 'YTick', [])
zMax = Hz2ERB(20000);
dph = 0.001;
ph = 0:dph:6*pi; % three coils
z = zMax*ph/ph(end); % 40 is max nr of ERBs
d = spline([0 0.2 1], [1.6 2.0 0.08], (1:length(ph))/length(ph)); % Width
r = exp(ph/6); % model a logarithmic spiral
x = r.*cos(ph);
y = r.*sin(ph);
% Resample at equidistant points on the spiral
s(2:length(x)) = cumsum(sqrt(diff(x).*diff(x)+diff(y).*diff(y)));
s = zMax*s/s(end);
% Plot the inner spiral
plot(x, y, 'k', 'LineWidth', 2)
% Calculate the outer spiral
[du, dv] = CalculateNormals(x, y);
p = sqrt(du.*du+dv.*dv);
du = du.*d./p;
dv = dv.*d./p;
u = x+du;
v = y+dv;
% Plot the outer spiral
plot(u, v, 'k', 'LineWidth', 2)
text(0.5*x(1)+0.5*u(1), y(1), 'H', ...
    'FontSize', 12, 'FontWeight', 'bold', ...
    'HorizontalAlignment', 'center', ...
    'VerticalAlignment', 'middle', ...
    'Color', red)
text(x(1)+1.2*du(1), y(1)+1.2*dv(1), ...
    sprintf('%4.0f  ', 20), ...
    'HorizontalAlignment', 'right', ...
    'VerticalAlignment', 'top')
oneERB = s(end)/40;
j = 1;
e = 5;
for i = 2:length(s)-1
    % Draw a crossline every 0.1 ERB
    if mod(s(i), 0.1*oneERB) < mod(s(i-1), 0.1*oneERB)
        plot([x(i) u(i)], [y(i) v(i)], 'k')
    end
    % Draw a thicker crossline every ERB
    if mod(s(i), oneERB) < mod(s(i-1), oneERB)
        plot([x(i) u(i)], [y(i) v(i)], 'k', 'LineWidth', 2)
    end
    % Plot frequency for every five ERBs
    pERB = j*e;
    if mod(s(i), pERB*oneERB) < mod(s(i-1), pERB*oneERB)
        u2 = x(i)+1.2*du(i);
        v2 = y(i)+1.2*dv(i);
        if sign(du(i))>=0
            horAlign = 'left';
        else
            horAlign = 'right';
        end
        if sign(dv(i))>=0
            verAlign = 'bottom';
        else
            verAlign = 'top';
        end
        text(u2, v2, sprintf('%4.0f', ERB2Hz(pERB)), ...
            'HorizontalAlignment', horAlign, ...
            'VerticalAlignment', verAlign)
        j = j+1;
    end
end
plot([x(end) u(end)], [y(end) v(end)], 'k')
text(x(end)+1.2*du(end), y(end)+1.2*dv(end), ...
    sprintf('%4.0f', ERB2Hz(z(end))), ...
    'HorizontalAlignment', 'left', 'VerticalAlignment', 'bottom')
text(x(end), y(end)+1.25*dv(end), ...
    'oval window ', 'FontSize', 12, ...
    'HorizontalAlignment', 'right', 'VerticalAlignment', 'middle')
minX = min(x);
maxX = max(x);
minY = min(y);
maxY = max(y);
di = 0.13*(maxX-minX);
axis([minX-di maxX+di minY-di maxY+di], 'off')
text(14, 13, 'width at base: 0.04 mm', 'FontSize', 12)
text(14, 11, 'width at apex: 0.5 mm', 'FontSize', 12)
text(14, 9, 'length: 32 mm', 'FontSize', 12)

