clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Calculate the pulse series
sampleFrequency = 22050; % Hz
dt = 1/sampleFrequency;
durationTone = 0.1; % sec
durationInterval = 0.02; % sec
tTone = dt:dt:durationTone;
tInterval = dt:dt:durationInterval;
interval = zeros(size(tInterval));
fr = [500 5000]; % Hz
fade = 0.005;
tone = zeros(size(tTone));
for k = 1:length(fr)
    tone = tone+sin(2*pi*fr(k)*tTone);
end
tone = (0.9/length(fr))*FadeInOut(tone, sampleFrequency, fade, fade);
stimulus = [interval tone interval];
t = (0:length(stimulus)-1)*dt;
segment = [durationTone/2-0.015 durationTone/2+0.015];

% Save and play the stimulus
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate and apply the dBA filter
[b_dBA, a_dBA] = Calculate_dBAFilter(sampleFrequency);
stimulusDBA = filter(b_dBA, a_dBA, stimulus);

% Calculate the center frequencies of the gammatone filterbank
numberOfFilters = 512;
minimumFrequency = 100;
maximumFrequency = sampleFrequency/2;
centerFrequencies = ...
    CalculateCenterFrequencies(numberOfFilters, ...
    minimumFrequency, maximumFrequency);
% Calculate the filter coefficients of the gammatone filter bank
[b, a] = ...
    CalculateGammatoneFilterBank(sampleFrequency, centerFrequencies);

% band-pass filtering
basilarMembrane = zeros(numberOfFilters, length(stimulusDBA));
for k = 1:numberOfFilters
    basilarMembrane(k,:) = filter(b(k,:), a(k,:), stimulusDBA);
end

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = 300; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 90; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the position of the panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% plot the basilar membrane response
panel = 1;
axes('Position', pos(panel,:))
xTick = 0:0.005:t(end);
yticklabel = [50 100 200 500 1000 2000 5000 10000 20000];
ytick = ...
    spline(centerFrequencies, 1:numberOfFilters, yticklabel);
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
    'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', xTick, 'XTickLabel', 1000*xTick, ...
    'YTick', ytick, 'YTickLabel', yticklabel)
surface(t, 1:numberOfFilters, basilarMembrane, 'EdgeColor', 'none');
set(gca, 'Color', lightYellowGreen)
xlabel('time (ms)')
ylabel('frequency (Hz)')
caxis([-max(basilarMembrane(:)) max(basilarMembrane(:))])
axis([segment 0 0.9*numberOfFilters])


