clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position of figure in pixels from bottom
panelWidth = 400; % pixels
panelHeights = 600; % pixels
xLabelHeight = 15; % pixels
yLabelWidth = 15; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Specify the parameters of the figure
gray = [0.75 0.75 0.75];
r = 0.15; % radius of head
n = 120; % number of points on the circle
xAxis = [-1.2*r 1.2*r];
yAxis = (panelHeights/panelWidth)*xAxis;
lEar = [-r -0.2]; % location of left ear
rEar = [r -0.2]; % location of right ear
lCN = [-0.8*r -0.1]; % location of left cochlear nucleus
rCN = [0.8*r -0.1]; % location of right cochlear nucleus
lSOC = [-0.4*r -0.03]; % location of left cochlear nucleus
rSOC = [0.4*r -0.03]; % location of right cochlear nucleus
lIC = [-0.35*r 0.05]; % location of left cochlear nucleus
rIC = [0.35*r 0.05]; % location of right cochlear nucleus
lMGB = [-0.35*r 0.15]; % location of left cochlear nucleus
rMGB = [0.35*r 0.15]; % location of right cochlear nucleus
lCortex = [-0.5*r 0.3]; % location of left cochlear nucleus
rCortex = [0.5*r 0.3]; % location of right cochlear nucleus
dEar = r/8; % diameter of ear
dCN = r/5; % diameter of cochlear nucleus
dSOC = r/7; % diameter of superior olive complex
dIC = r/5; % diameter of inferior colliculus
dMGB = r/6; % diameter of medial geniculate body
dCortex = r/3; % diameter of cortex

axes('Position', pos(1,:))
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
    'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', [], 'YTick', [])
% Plot the arrows between the auditory centers
arrow = CalcCentArrow(lEar, lCN, 0.15, pi/12, 0.52);
plot(arrow(1,:), arrow(2,:), 'k', 'LineWidth', 2)
arrow = CalcCentArrow(rEar, rCN, 0.15, pi/12, 0.52);
plot(arrow(1,:), arrow(2,:), 'k', 'LineWidth', 2)
arrow = CalcCentArrow(lCN, lSOC, 0.15, pi/12, 0.6);
plot(arrow(1,:), arrow(2,:), 'k', 'LineWidth', 2)
arrow = CalcCentArrow(rCN, rSOC, 0.15, pi/12, 0.6);
plot(arrow(1,:), arrow(2,:), 'k', 'LineWidth', 2)
arrow = CalcCentArrow(lCN, rSOC, 0.1, pi/12, 0.5);
plot(arrow(1,:), arrow(2,:), 'k', 'LineWidth', 2)
arrow = CalcCentArrow(rCN, lSOC, 0.1, pi/12, 0.5);
plot(arrow(1,:), arrow(2,:), 'k', 'LineWidth', 2)
arrow = CalcCentArrow(lSOC, lIC, 0.2, pi/12, 0.55);
plot(arrow(1,:), arrow(2,:), 'k', 'LineWidth', 2)
arrow = CalcCentArrow(rSOC, rIC, 0.2, pi/12, 0.55);
plot(arrow(1,:), arrow(2,:), 'k', 'LineWidth', 2)
arrow = CalcCentArrow(lIC, lMGB, 0.2, pi/12, 0.6);
plot(arrow(1,:), arrow(2,:), 'k', 'LineWidth', 2)
arrow = CalcCentArrow(rIC, rMGB, 0.2, pi/12, 0.6);
plot(arrow(1,:), arrow(2,:), 'k', 'LineWidth', 2)
arrow = CalcCentArrow(lMGB, lCortex, 0.15, pi/12, 0.5);
plot(arrow(1,:), arrow(2,:), 'k', 'LineWidth', 2)
arrow = CalcCentArrow(rMGB, rCortex, 0.15, pi/12, 0.5);
plot(arrow(1,:), arrow(2,:), 'k', 'LineWidth', 2)
% Plot the auditory centers
leftEar = CalcCircle(lEar, dEar, 0, n);
rightEar = CalcCircle(rEar, dEar, 0, n);
patch(leftEar(1,:), leftEar(2,:), gray)
patch(rightEar(1,:), rightEar(2,:), gray)
leftCN = CalcCircle(lCN, dCN, 0, n);
rightCN = CalcCircle(rCN, dCN, 0, n);
patch(leftCN(1,:), leftCN(2,:), gray)
patch(rightCN(1,:), rightCN(2,:), gray)
leftSOC = CalcCircle(lSOC, dSOC, 0, n);
rightSOC = CalcCircle(rSOC, dSOC, 0, n);
patch(leftSOC(1,:), leftSOC(2,:), gray)
patch(rightSOC(1,:), rightSOC(2,:), gray)
leftIC = CalcCircle(lIC, dIC, 0, n);
rightIC = CalcCircle(rIC, dIC, 0, n);
patch(leftIC(1,:), leftIC(2,:), gray)
patch(rightIC(1,:), rightIC(2,:), gray)
leftMGB = CalcCircle(lMGB, dMGB, 0, n);
rightMGB = CalcCircle(rMGB, dMGB, 0, n);
patch(leftMGB(1,:), leftMGB(2,:), gray)
patch(rightMGB(1,:), rightMGB(2,:), gray)
leftCortex = CalcCircle(lCortex, dCortex, 0, n);
rightCortex = CalcCircle(rCortex, dCortex, 0, n);
patch(leftCortex(1,:), leftCortex(2,:), gray)
patch(rightCortex(1,:), rightCortex(2,:), gray)
axis([xAxis yAxis])
% Plot the names of the auditory centers
text(lEar(1), lEar(2), 'ear', 'FontWeight', 'bold', ...
    'HorizontalAlignment', 'center', 'VerticalAlignment', 'middle')
text(rEar(1), rEar(2), 'ear', 'FontWeight', 'bold', ...
    'HorizontalAlignment', 'center', 'VerticalAlignment', 'middle')
text(lCN(1), lCN(2), 'CN', 'FontWeight', 'bold', ...
    'HorizontalAlignment', 'center', 'VerticalAlignment', 'middle')
text(rCN(1), rCN(2), 'CN', 'FontWeight', 'bold', ...
    'HorizontalAlignment', 'center', 'VerticalAlignment', 'middle')
text(lSOC(1), lSOC(2), 'SOC', 'FontWeight', 'bold', ...
    'HorizontalAlignment', 'center', 'VerticalAlignment', 'middle')
text(rSOC(1), rSOC(2), 'SOC', 'FontWeight', 'bold', ...
    'HorizontalAlignment', 'center', 'VerticalAlignment', 'middle')
text(lIC(1), lIC(2), 'IC', 'FontWeight', 'bold', ...
    'HorizontalAlignment', 'center', 'VerticalAlignment', 'middle')
text(rIC(1), rIC(2), 'IC', 'FontWeight', 'bold', ...
    'HorizontalAlignment', 'center', 'VerticalAlignment', 'middle')
text(lMGB(1), lMGB(2), 'MGB', 'FontWeight', 'bold', ...
    'HorizontalAlignment', 'center', 'VerticalAlignment', 'middle')
text(rMGB(1), rMGB(2), 'MGB', 'FontWeight', 'bold', ...
    'HorizontalAlignment', 'center', 'VerticalAlignment', 'middle')
text(lCortex(1), lCortex(2)-0.75*dCortex, 'Cortex', 'FontWeight', 'bold', ...
    'HorizontalAlignment', 'center', 'VerticalAlignment', 'middle')
text(rCortex(1), rCortex(2)-0.75*dCortex, 'Cortex', 'FontWeight', 'bold', ...
    'HorizontalAlignment', 'center', 'VerticalAlignment', 'middle')

