 clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

dB = 0:120;
iRef = 10e-6;
p = iRef*10.^(dB/20);
maxFiringRate = 250;
A0 = 50:-12.5:0; % spontaneous firing rate
A1 = maxFiringRate-A0; % diff. saturation and spontaneous firing rate
A2dB = 30:5:50; % sensitivity of nerve fibre
A2 = iRef*10.^(A2dB/20);
A3dB = 40.0; % onset of basilar membrane nonlinearity
A3 = iRef*10^(A3dB/20);
A4 = 0.2; % exponent of power law in nonlinear region

% Calculate firung rate, based on Yates, 1990, Eqs 8 and 9.
d = zeros(length(A2dB), length(dB));
firingRate = zeros(length(A2dB), length(dB));
r = 1/A4-1;
for k = 1:length(A2dB)
    d(k,:) = (((A3^r*p.^(1/A4))./(A3^r + p.^r))).^A4;
    d2 = d(k,:).*d(k,:);
    firingRate(k,:) = A0(k) + (A1(k)*d2)./(A2(k)*A2(k)+d2);
end

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position of figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = 480; % pixels
xLabelHeight = 75; % pixels
yLabelWidth = 75; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the stimulus
panel = 1;
axes('Position', pos(panel, :))
xTick = 0:20:120;
yTick = 0:100:1000;
set(gca, 'FontSize', 14, 'FontWeight', 'bold', ...
    'Xtick' , xTick, 'YTick', yTick, ...
    'TickDir', 'out', 'Color', lightYellowGreen, ...
    'Box', 'on', 'LineWidth', 2, 'NextPlot', 'add')
for k = 1:length(A2dB)
    plot(dB, firingRate(k,:), 'LineWidth', 2, 'Color', blueGreen)
end
axis([0 120 0 1.1*maxFiringRate])
xlabel('intensity (dB SPL)')
ylabel('firing rate (spikes/s)')
text(20 , 240, 'high-spontaneous', ...
    'FontSize', 12, 'FontWeight', 'bold')
text(27, 230, 'rate fibre', ...
    'FontSize', 12, 'FontWeight', 'bold')
text(72, 70, 'low-spontaneous rate fibre', ...
    'FontSize', 12, 'FontWeight', 'bold')


