clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

lengthOfBasilarMembrane = 35; % mm
dx = 0.01;
z = 0:dx:lengthOfBasilarMembrane;
gamma = 2;
gm1 = gamma-1;
f = 0.5;
maxExcitation = [30 12];
tau = lengthOfBasilarMembrane./[15 30]; % sec
zMax = zeros(size(maxExcitation));
yMax = zeros(size(maxExcitation));
penv = zeros(size(maxExcitation, 2), length(z));
for k = 1:length(maxExcitation)
    p = 0:dx:maxExcitation(k);
    r = (p.^gm1).*exp(-p/tau(k));
    zMax(k) = gm1*tau(k); % location of maximum amplitude
    yMax(k) = (gm1^gm1)*(tau(k)^gm1)*exp(-gm1); % maximum amplitude
    penv(k,:) = [zeros(1, length(z)-length(p)) r]/yMax(k);
end
penv = fliplr(penv);

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position of figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = [180 180]; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 70; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the simulated travelling wave
xTick = 0:5:lengthOfBasilarMembrane;
yTick = -1:0.5:1;
for k = 1:length(maxExcitation)
    axes('Position', pos(k,:))
    if k == 1
        xTickLabel = xTick;
    else
        xTickLabel = [];
    end
    set(gca, 'FontSize', 14, 'FontWeight', 'bold', ...
        'XTick', xTick, 'xTickLabel', xTickLabel, ...
        'YTick', yTick, 'Color', lightYellowGreen, ...
        'Box', 'on', 'LineWidth', 2, 'NextPlot', 'add')
    plot(z, penv(k,:), '--', 'LineWidth', 1, 'Color', red)
    plot(z, -penv(k,:), '--', 'LineWidth', 1, 'Color', red)
    lineWidth = 2;
    if k == 1
        phase = 2*pi*0.08*(0:2);
        dLineWidth = lineWidth/length(phase);
        for j = 1:length(phase)
            plot(z, sin(2*pi*f*z+phase(j)).*penv(k,:), ...
                'Color', blueGreen, 'LineWidth', lineWidth)
            lineWidth = lineWidth-dLineWidth;
        end
    else
        phase = 2*pi*0.24*(0:2);
        dLineWidth = lineWidth/length(phase);
        for j = 1:length(phase)
            plot(z, sin(2*pi*f*z+phase(j)).*penv(k,:), ...
                'Color', blueGreen, 'LineWidth', lineWidth)
            lineWidth = lineWidth-dLineWidth;
        end
    end
    axis([0 z(end) -1.2 1.2])
    if k == 1
        xlabel('distance from oval window (mm)')
        text(14, 0.8, 'low-frequency sinusoid', ...
            'FontSize', 14, 'FontWeight', 'bold')
    else
        text(12, 0.8, 'high-frequency sinusoid', ...
            'FontSize', 14, 'FontWeight', 'bold')
    end
    ylabel('excursion')
end

