clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define and calculate the stimulus
sampleFrequency = 44100; % Hz
dt = 1/sampleFrequency;
attack = [0.005 1];
decay = [0.01 -0.8];
sustain = [0.06 0];
release = [0.025 -0.2];
envelope = cumsum([[0 0]; attack; decay; sustain; release]);
[env, duration] = EnvelopeToEnv(envelope, sampleFrequency); % sec
t = dt:dt:duration;
f0 = 440; % Hz
stimulus = env.*sin(2*pi*f0*t);

% Save and play the stimulus
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position of figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = 240; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 70; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the sound signal
axes('Position', pos)
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
    'Box', 'on', 'Color', lightYellowGreen, 'NextPlot', 'add', ...
    'FontWeight', 'bold', 'TickDir', 'out', 'NextPlot', 'add', ...
    'XTick', -0.02:0.02:2, 'XTickLabel', 1000*(-0.02:0.02:2), ...
    'YTick', -1:1)
xrange = [-0.02 duration+0.02];
yrange = [-1.2 1.2];
plot(t, stimulus, 'LineWidth', 1, 'Color', blueGreen)
plot([0 t], [0 env], 'LineWidth', 2, 'Color', blueGreen)
plot([0 t], [0 -env], 'LineWidth', 2, 'Color', blueGreen)
plot(xrange, [0 0], 'LineWidth', 1, 'Color', blueGreen)
text(0.5*(envelope(2, 1)+envelope(1, 1))-0.001, ...
    0.5*(envelope(2, 2)+envelope(1, 2)), 'attack', ...
    'FontWeight' , 'bold', 'FontSize', 12, ...
    'HorizontalAlignment', 'right', 'VerticalAlignment', 'bottom')
text(0.5*(envelope(3, 1)+envelope(2, 1)), ...
    0.5*(envelope(3, 2)+envelope(2, 2)), 'decay', ...
    'FontWeight' , 'bold', 'FontSize', 12, ...
    'HorizontalAlignment', 'left', 'VerticalAlignment', 'bottom')
text(0.5*(envelope(4, 1)+envelope(3, 1)), ...
    0.5*(envelope(4, 2)+envelope(3, 2)), 'sustain', ...
    'FontWeight' , 'bold', 'FontSize', 12, ...
    'HorizontalAlignment', 'center', 'VerticalAlignment', 'bottom')
text(0.5*(envelope(5, 1)+envelope(4, 1)), ...
    0.5*(envelope(5, 2)+envelope(4, 2)), 'release', ...
    'FontWeight' , 'bold', 'FontSize', 12, ...
    'HorizontalAlignment', 'left', 'VerticalAlignment', 'bottom')
xlabel('time (ms)')
ylabel('amplitude')
axis([xrange yrange])

