% clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define the stimuli
sampleFrequency = 44100; % Hz
dt = 1/sampleFrequency;
amp = 0.48;
durationTone = 0.5; % sec
cf = 500; % Hz
mf = 220;
md = 0.8;
fade = 0.005; % sec

% Calculate the stimulus
f = [cf-mf cf cf+mf];
t = -0.1*durationTone:dt:0.9*durationTone;
s(1,:) = 0.5*amp*md*cos(2*pi*f(1)*t);
s(2,:) = amp*cos(2*pi*f(2)*t);
s(3,:) = 0.5*amp*md*cos(2*pi*f(3)*t);
modulator = amp*(1+md*cos(2*pi*mf*t));
carrier = cos(2*pi*f(2)*t);
stimulus = modulator.*carrier;
stimulus = FadeInOut(stimulus, sampleFrequency, fade, fade);
durationStimulus = length(stimulus)*dt; % sec

% Save and play the stimulus
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the position of the figures on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position of figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = [130 130 130 130]; % pixels;
xLabelHeight = 70; % pixels
yLabelWidth = 70; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the am sound
panel = 1;
axes('Position', pos(panel,:))
dXTick = 0.005; % sec
xTick = -dXTick:dXTick:durationStimulus;
xTickLabel = round(1000*xTick);
tAxis = [-0.5/mf 4.5/mf];
yAxis = amp*[-2.5 2.8];
set(gca, 'LineWidth', 1.5, ...
    'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontSize', 14, 'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', xTick, 'XTickLabel', xTickLabel, 'YTick', -5:5)
plot(t, stimulus, ...
    'Color', blueGreen, 'LineWidth', 1.5);
plot([t(1) t(end)], [0 0], 'Color', blueGreen, 'Linewidth', 0.5)
plot([0 0], yAxis, 'Color', blueGreen, 'Linewidth', 0.5)
plot(t, modulator, '--', 'Color', red, 'LineWidth', 1);
plot(t, -modulator, '--', 'Color', red, 'LineWidth', 1);
xlabel('time (ms)')
ylabel('signal')
axis([tAxis yAxis])
text(dXTick/10, 0.85*yAxis(2), ...
    'sum of the three partials', ...
    'FontSize', 12, 'FontWeight', 'bold')

% Plot the highest partial or the modulator
panel = panel+1;
axes('Position', pos(panel,:))
set(gca, 'LineWidth', 1.5, ...
    'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontSize', 14, 'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', xTick, 'XTickLabel', [], 'YTick', -2:2)
plot(t, s(3,:), 'Color', blueGreen, 'LineWidth', 1.5);
plot([t(1) t(end)], [0 0], 'Color', blueGreen, 'Linewidth', 0.5)
plot([0 0], yAxis, 'Color', blueGreen, 'Linewidth', 0.5)
ylabel('signal')
axis([tAxis yAxis])
text(dXTick/10, 0.85*yAxis(2), ...
    sprintf('higher partial of %3.4g Hz', f(3)), ...
    'FontSize', 12, 'FontWeight', 'bold')

% Plot the central partial, the carrier
panel = panel+1;
axes('Position', pos(panel,:))
set(gca, 'LineWidth', 1.5, ...
    'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontSize', 14, 'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', xTick, 'XTickLabel', [], 'YTick', -2:2)
plot(t, s(2,:), 'Color', blueGreen, 'LineWidth', 1.5);
plot([t(1) t(end)], [0 0], 'Color', blueGreen, 'Linewidth', 0.5)
plot([0 0], yAxis, 'Color', blueGreen, 'Linewidth', 0.5)
ylabel('signal')
axis([tAxis yAxis])
text(dXTick/10, 0.85*yAxis(2), ...
    sprintf('central partial of %3.4g Hz', f(2)), ...
    'FontSize', 12, 'FontWeight', 'bold')

% Plot the lowest partial
panel = panel+1;
axes('Position', pos(panel,:))
set(gca, 'LineWidth', 1.5, ...
    'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontSize', 14, 'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', xTick, 'XTickLabel', [], 'YTick', -2:2)
plot(t, s(1,:), 'Color', blueGreen, 'LineWidth', 1.5);
plot([t(1) t(end)], [0 0], 'Color', blueGreen, 'Linewidth', 0.5)
plot([0 0], yAxis, 'Color', blueGreen, 'Linewidth', 0.5)
ylabel('signal')
axis([tAxis yAxis])
text(dXTick/10, 0.85*yAxis(2), ...
    sprintf('lower partial of %3.4g Hz', f(1)), ...
    'FontSize', 12, 'FontWeight', 'bold')

