clear
close all
InitializePSS()
fprintf('%s\n', mfilename);
rng(1); % set random number generator

% Define the stimuli
sampleFrequency = 44100; % Hz
dt = 1/sampleFrequency;
durationTone = 2; % sec
durationInterval = 0.5; % sec
amp = 0.49;
fade = 0.005; % sec
modFreq = logspace(log10(2.5), log10(10), 5); % Hz
n = length(modFreq);
fc = 1200; % Hz
modDepth = 0.8;

% Calculate and plot the AM tones
period = 1./modFreq;
fprintf('Modulation frequencies: \n')
fprintf('%8.3f', fliplr(modFreq))
fprintf('%s\n', '  Hz')

% Calculate the stimuli
% shift signal to get signal for t<0
t = -0.1*durationTone:dt:0.9*durationTone;
s = zeros(n, length(t));
envelope = zeros(n, length(t));
interval =  zeros(size(dt:dt:durationInterval));
stimulus = [];
for i = n:-1:1 % Start stimulus with highest modulation frequency
    envelope(i,:) = amp*(1+modDepth*cos(2*pi*modFreq(i)*t));
    s(i,:) = envelope(i,:).*cos(2*pi*fc*t);
    s(i,:) = FadeInOut(s(i,:), sampleFrequency, fade, fade);
    stimulus = [stimulus s(i,:) interval]; %#ok<AGROW>
end
stimulus = [stimulus interval interval];

% Calculate the spectra
spc = amp*[0.5*modDepth 1 0.5*modDepth];

% Save and play the stimulus
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = 120*ones(1, n); % pixels
xLabelHeight = 70; % pixels
yLabelWidth = [70 70]; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the signals
for i = 1:n
    axes('Position', pos(i,:))
    % Set zero point of t at t = 3*period(k,i) so that signal is also
    % plotted for t<0.
    tAxis = [-0.125*period(1) 1.875*period(1)];
    yAxis = [-1.2 1.5];
    dXTick = 0.2; % sec
    xTick = -dXTick:dXTick:durationTone;
    xTickLabel = xTick;
    set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
        'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
        'FontWeight', 'bold', 'TickDir', 'out', ...
        'YTick', -1:1)
    if i == 1
        set(gca, 'XTick', xTick, 'XTickLabel', 1000*xTickLabel)
        xlabel('time (ms)', 'FontWeight', 'bold')
    else
        set(gca, 'XTick', xTick, 'XTickLabel', [])
    end
    plot(t, s(i,:), ...
        'Color', blueGreen, 'LineWidth', 1.5);
    plot(tAxis, [0 0], 'Color', blueGreen, 'Linewidth', 0.5)
    plot([0 0], yAxis, 'Color', blueGreen, 'Linewidth', 2)
    if i == 1
        text(period(i), 0.85*yAxis(2), ...
            sprintf('%s', 'period of envelope = '), ...
            'HorizontalAlignment', 'right')
    end
    plot([period(i) period(i)], yAxis, ...
        'Color', blueGreen, 'Linewidth', 2)
    text(period(i), 0.85*yAxis(2), ...
        sprintf(' %4.2f ms', 1000*period(i)), ...
        'HorizontalAlignment', 'left')
    axis([tAxis yAxis])
    ylabel('signal')
end

