clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define the stimulus
sampleFrequency = 10000; % Hz
dt = 1/sampleFrequency;
durationTone = 0.15; % sec
t = dt:dt:durationTone;
durationPadding = 0.1; % sec
durationInterval = 0.05; % sec
interval = zeros(size(dt:dt:durationInterval));
padding = zeros(size(dt:dt:durationPadding));
fade = 0.02; % sec
f0 = 440; % Hz
nrOfHarmonics = 8;
amp = 0.7/nrOfHarmonics;

% Calculate the stimulus
t0 = 0;
nrOfTones = 1;
for k = 1:nrOfHarmonics
    for i = 1:k
        fr = i*f0;
        schemTime(1:2, nrOfTones) = [t0 t0+durationTone]; %#ok<*SAGROW>
        schemFreq(1:2, nrOfTones) = [fr fr];
        nrOfTones = nrOfTones+1;
    end
    t0 = t0+durationTone+durationInterval;
end
envelopeTone = ...
    amp*FadeInOut(ones(size(t)), sampleFrequency, fade, fade);
stimulus = SynthToneSequence(schemTime, schemFreq, sampleFrequency, ...
    envelopeTone);

% Save and play the sound
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position of figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = [70 180 180]; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 70; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Calculate the plot parameters
dXTick = 0.5; % sec
dYTick = 1; % kHz
maxYAxis = 5000; % Hz
fAxis = [-20 maxYAxis+20];
durationStimulus = length(stimulus)*dt; % sec
xTick = 0:dXTick:durationStimulus;
tAxis = [-dXTick/4 durationStimulus+dXTick/4];

% Plot the sound signal
panel = 1;
axes('Position', pos(panel,:))
PlotSignal(stimulus, sampleFrequency, ...
    tAxis, dXTick, blueGreen, 'time (s)')
set(gca, 'XTick', xTick, 'XTickLabel', xTick, 'Color', lightYellowGreen)
text(0.99*tAxis(1)+0.01*tAxis(2), 0.7, ...
    'waveform', 'FontSize', 14, 'FontWeight', 'bold')

% Calculate and plot the spectrogram
panel = panel+1;
axes('Position', pos(panel,:))
nWindow = 256;
nFft = 2048; % Number of samples in fft window
nOverlap = nWindow-32;
[~, f, ts, spcgr] = spectrogram([padding stimulus padding], ...
    nWindow, nOverlap, nFft, sampleFrequency);
ts = ts-durationPadding;
spcgr = 10*log10(abs(spcgr));
[~, iFMax] = min(abs(f-maxYAxis));
PlotSpectrogram(stimulus, sampleFrequency, ...
    f(1:iFMax), ts, spcgr(1:iFMax,:), tAxis, dXTick, fAxis, dYTick, 40, ...
    frameColor)
set(gca, 'Color', lightYellowGreen)
text(0.99*tAxis(1)+0.01*tAxis(2), ...
    fAxis(1)+0.9*(fAxis(2)-fAxis(1)), ...
    'narrow-band spectrogram', 'FontSize', 14, ...
    'FontWeight', 'bold')

% Plot the schematic time-frequency representation
panel = panel+1;
axes('Position', pos(panel,:))
PlotSTFR(stimulus, sampleFrequency, ...
    schemTime, schemFreq, envelopeTone, ...
    tAxis, dXTick, ...
    fAxis, dYTick, amp, blueGreen)
set(gca, 'Color', lightYellowGreen)
text(0.99*tAxis(1)+0.01*tAxis(2), ...
    fAxis(1)+0.9*(fAxis(2)-fAxis(1)), ...
    'schematic time-frequency representation', ...
    'FontSize', 14, 'FontWeight', 'bold')


