clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define the stimulus
sampleFrequency = 44100; % Hz
dt = 1/sampleFrequency;
durationTone = 0.2; % sec 
t = dt:dt:durationTone;
durationInterval = 0; % sec
interval = zeros(size(dt:dt:durationInterval));
fade = 0.02; % sec
f0 = logspace(log10(440), log10(4*440), 25);
melody = 1:25;
nrOfHarmonics = 3;
amp = 1/nrOfHarmonics;
tau = durationTone/5; % sec

% Calculate the stimulus
t0 = 0;
nrOfTones = 1;
envelopeTone = amp*exp(-t/tau);
for k = 1:length(melody)
    for i = 1:nrOfHarmonics
        f = i*f0(melody(k));
        schemTime(1:2, nrOfTones) = [t0 t0+durationTone]; %#ok<SAGROW>
        schemFreq(1:2, nrOfTones) = [f f]; %#ok<SAGROW>
        nrOfTones = nrOfTones+1;
    end
    t0 = t0+durationTone+durationInterval;
end
stimulus = SynthToneSequence(schemTime, schemFreq, sampleFrequency, ...
    envelopeTone);

% Save and play the sound
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = [120 240 240]; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 90; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the sound signal
panel = 1;
axes('Position', pos(panel,:))
dXTick = 1; % sec
dYTick = 1; % kHz
maxYAxis = 5999; % Hz
durationStimulus = length(stimulus)*dt; % sec
tAxis = [-dXTick/4 durationStimulus+dXTick/4];
PlotSignal(stimulus, sampleFrequency, ...
    tAxis, dXTick, blueGreen, 'time (s)')
set(gca, 'XTick', 0:durationStimulus, ...
    'XTickLabel', 0:durationStimulus, ...
    'Color', lightYellowGreen)

% Plot the schematic time-frequency representation
panel = panel+1;
axes('Position', pos(panel,:))
a = 440; % hertz
fAxis = [330 maxYAxis];
lFAxis = log2(fAxis/a);
yTick = -4:log2(sampleFrequency/a);
PlotSTlFR(stimulus, sampleFrequency, ...
    schemTime, schemFreq, envelopeTone, ...
    tAxis, dXTick, fAxis, 0.2*amp, blueGreen)
set(gca, 'YTick', yTick, 'YTickLabel', round(a*2.^yTick/1000,2), ...
    'Color', lightYellowGreen)
ylabel('frequency (kHz)')
text(tAxis(1)/2, lFAxis(1)+0.9*(lFAxis(2)-lFAxis(1)), ...
    'schematic time-frequency representation', ...
    'FontSize', 14, 'FontWeight', 'bold')

% Plot the schematic time vs logfrequency representation
panel = panel+1;
axes('Position', pos(panel,:))
fAxis = [0 maxYAxis];
PlotSTFR(stimulus, sampleFrequency, ...
    schemTime, schemFreq, envelopeTone, ...
    tAxis, dXTick, ...
    fAxis, dYTick, 0.2*amp, blueGreen)
set(gca, 'Color', lightYellowGreen)
text(tAxis(1)/2, fAxis(1)+0.9*(fAxis(2)-fAxis(1)), ...
    'schematic time-frequency representation', ...
    'FontSize', 14, 'FontWeight', 'bold')


