clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define the stimulus
sampleFrequency = 44100; % Hz
dt = 1/sampleFrequency;
durationTone = 0.2; % sec 
t = dt:dt:durationTone;
durationInterval = 0; % sec
interval = zeros(size(dt:dt:durationInterval));
f0 = logspace(log10(440), log10(4*440), 25);
melody = [1 3 5 6 8 10 12 13 15 17 18 20 22 24 25];
nrOfHarmonics = 3;
amp = 1/nrOfHarmonics;
tau = durationTone/5; % sec

% Calculate the stimulus
stimulus = interval;
t0 = durationInterval;
nrOfTones = 1;
envelopeTone = exp(-t/tau);
for k = 1:length(melody)
    tone = zeros(size(t));
    for i = 1:nrOfHarmonics
        f = i*f0(melody(k));
        s = amp*sin(2*pi*f*t);
        tone = tone + s;
        schemTime(1:2, nrOfTones) = [t0 t0+durationTone]; %#ok<SAGROW>
        schemFreq(1:2, nrOfTones) = [f f]; %#ok<SAGROW>
        nrOfTones = nrOfTones+1;
    end
    tone = tone.*envelopeTone;
    stimulus =  [stimulus tone interval];  %#ok<AGROW>
    t0 = t0+durationTone+durationInterval;
end
nrOfTones = nrOfTones-1;

% Save and play the sound
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = [120 240]; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 90; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the sound signal
panel = 1;
axes('Position', pos(panel,:))
dXTick = 1; % sec
durationStimulus = length(stimulus)*dt; % sec
tAxis = [-dXTick/4 durationStimulus+dXTick/4];
PlotSignal(stimulus, sampleFrequency, ...
    tAxis, dXTick, blueGreen, 'time (s)')
set(gca, 'XTick', 0:durationStimulus, ...
    'XTickLabel', 0:durationStimulus, ...
    'Color', lightYellowGreen)

% Plot the schematic time vs logfrequency representation
panel = panel+1;
axes('Position', pos(panel,:))
a = 440;
dYTick = 2; % kHz
maxYAxis = 5999; % Hz
fAxis = [330 maxYAxis];
lFAxis = log2(fAxis/440);
yTick = -4:log2(sampleFrequency/a);
PlotSTlFR(stimulus, sampleFrequency, ...
    schemTime, schemFreq, envelopeTone, ...
    tAxis, dXTick, ...
    fAxis, 0.018, blueGreen)
set(gca, 'YTick', yTick, 'YTickLabel', round(a*2.^yTick/1000,2), ...
    'Color', lightYellowGreen)
ylabel('frequency (kHz)')
text(tAxis(1)/2, lFAxis(1)+0.9*(lFAxis(2)-lFAxis(1)), ...
    'schematic time-frequency representation', ...
    'FontSize', 14, 'FontWeight', 'bold')


