clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define and calculate the stimulus
sampleFrequency = 44100; % Hz
dt = 1/sampleFrequency;
durationTone = 0.45; % sec
tTone = dt:dt:durationTone;
durationInterval = 0.05; % sec
interval = zeros(size(dt:dt:durationInterval));
f0 = 440; % Hz
minAttackTime = 0.001;
maxAttackTime = 0.256;
nrOfTones = 9;
attackTime = ...
    logspace(log10(minAttackTime), log10(maxAttackTime), nrOfTones);
stimulus = interval;
t0 = 0;
for k = 1:length(attackTime)
    attack = [attackTime(k) 1];
    decay = [0.100 -0.8];
    release = [0.020 -0.2];
    sustain = [durationTone-release(1)-attackTime(k)-decay(1) 0];
    envelope = cumsum([[0 0]; attack; decay; sustain; release]);
    envelopeTone = EnvelopeToEnv(envelope, sampleFrequency);
    tTone = dt:dt:envelope(end, 1);
    tone = sin(2*pi*f0*tTone);
    tone = tone.*envelopeTone;
    stimulus =  [stimulus tone interval]; %#ok<*AGROW>
    t0 = t0+durationTone+durationInterval;
end
durationStimulus = length(stimulus)*dt; % sec
t = dt:dt:durationStimulus;

% Save and play the stimulus
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position of figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = 240; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 70; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the signal
axes('Position', pos)
xTick = -0.5:0.5:durationStimulus;
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
    'Box', 'on', 'Color', lightYellowGreen, 'NextPlot', 'add', ...
    'FontWeight', 'bold', 'TickDir', 'out', 'NextPlot', 'add', ...
    'XTick', xTick, 'XTickLabel', xTick, ...
    'YTick', -1:1)
xrange = [-0.02 durationStimulus+0.02];
yrange = [-1.2 1.2];
plot(t, stimulus, 'LineWidth', 1, 'Color', blueGreen)
plot(xrange, [0 0], 'LineWidth', 1, 'Color', blueGreen)
xlabel('time (s)')
ylabel('amplitude')
axis([xrange yrange])

