clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define the stimuli
sampleFrequency = 44100; % Hz
dt = 1/sampleFrequency;
fc = 500; % Hz
fm = 200; % Hz
mi = 2;
durationTone = 0.5; % sec
durationInterval = 0.25; % sec
amp = 0.98;
fade = 0.005; % sec

% Calculate the stimulus
% shift signal to get signal for t<0 for figure
t = -0.1*durationTone:dt:0.9*durationTone;
interval =  zeros(size(dt:dt:durationInterval));
instFreq = fc+mi*fm*cos(2*pi*fm*t);
stimulus = amp*sin(2*pi*cumsum(instFreq)*dt);
stimulus = FadeInOut(stimulus, sampleFrequency, fade, fade);

% Calculate the spectrum
nrOfSidebands = round(2500/min(fm));
spc = zeros(1, 2*nrOfSidebands+1);
for j = -nrOfSidebands:nrOfSidebands
    spc(nrOfSidebands+j+1) = amp*abs(besselj(j, mi));
end

% Save and play the stimulus
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = [120 120 120]; % pixels
xLabelHeight = [70 70 0]; % pixels
yLabelWidth = 100; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Calculate the plot parameters
dXTick = 0.005; % sec
fTick = 0:250:5000;
fTickLabel = fTick;
fAxis = [0 1800];
aAxis = [0 0.80];
tAxis = [-0.25/fm 8/fm];

% Plot the spectrum
panel = 1;
axes('Position', pos(panel,:))
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
    'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'YTick', 0:0.25:1, 'XTick', fTick, 'XTickLabel', fTickLabel)
for j = -nrOfSidebands:nrOfSidebands
    plot([fc+j*fm fc+j*fm], ...
        [0 spc(nrOfSidebands+j+1)], ...
        'Color', blueGreen, 'Linewidth', 2)
end
freqPitch = gcd(fc, fm);
if freqPitch > 50
    for j = 1:2*nrOfSidebands+1
        plot([j*freqPitch j*freqPitch], [0 0.05], ...
            'Color', red, 'LineWidth', 5)
    end
else
    for j = 1:2*nrOfSidebands+1
        plot([j*fm j*fm], [0 0.05], 'Color', red, 'LineWidth', 5)
    end
end
xlabel('frequency (Hz)', 'FontWeight', 'bold', ...
    'Fontsize' , 14)
ylabel('amplitude', 'Fontsize' , 14)
axis([fAxis aAxis])
text(0.8*fAxis(2), 0.85*aAxis(2), ...
    sprintf('f_c = %5.0f Hz', fc), 'FontWeight', 'bold', ...
    'HorizontalAlignment', 'left')
text(0.8*fAxis(2), 0.70*aAxis(2), ...
    sprintf('f_m = %4.0f Hz', fm), 'FontWeight', 'bold', ...
    'HorizontalAlignment', 'left')
text(0.8*fAxis(2), 0.55*aAxis(2), ...
    sprintf('m_i = %3.1f', mi), 'FontWeight', 'bold', ...
    'HorizontalAlignment', 'left')

% Plot the instantaneous frequencies
panel = panel+1;
axes('Position', pos(panel,:))
periodPitch = 1/freqPitch;
periodInstFreq = 1/fm;
xTick = 0:dXTick:durationTone;
xTickLabel = xTick;
yAxis = [0 1200];
yTick = 0:500:5000;
yTickLabel = yTick;
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
    'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', xTick, 'XTickLabel', 1000*xTickLabel, ...
    'YTick', yTick, 'YTickLabel', yTickLabel)
plot(t, instFreq, ...
    'Color', blueGreen, 'LineWidth', 1);
plot(tAxis, [0 0], ...
    'Color', blueGreen, 'Linewidth', 0.5)
plot([0 0], yAxis, ...
    'Color', blueGreen, 'Linewidth', 1)
plot([periodInstFreq periodInstFreq], yAxis, ...
    'Color', blueGreen, 'Linewidth', 1)
text(periodInstFreq, 0.85*yAxis(2), sprintf('%s', '1/f_m = '), ...
    'FontWeight', 'bold', 'HorizontalAlignment', 'right', ...
    'VerticalAlignment', 'baseline')
text(periodInstFreq, 0.85*yAxis(2), sprintf(' %4.2f ms', ...
    1000*periodInstFreq), 'FontWeight', 'bold', ...
    'HorizontalAlignment', 'left', 'VerticalAlignment', 'baseline')
axis([tAxis yAxis])
xlabel('time (ms)', 'FontWeight', 'bold')
ylabel('f_{inst.} (Hz)')

% Plot the signal
panel = panel+1;
axes('Position', pos(panel,:))
yAxis = [-1.5 1.5];
yTick = -2:2;
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
    'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', xTick, 'XTickLabel', [], 'YTick', yTick)
plot(t, stimulus, 'Color', blueGreen, 'LineWidth', 1);
plot(tAxis, [0 0], 'Color', blueGreen, 'Linewidth', 0.5)
plot([0 0], yAxis, ...
    'Color', blueGreen, 'Linewidth', 1)
plot([periodPitch periodPitch], yAxis, ...
    'Color', blueGreen, 'Linewidth', 1)
text(periodPitch, 0.75*yAxis(2), ...
    sprintf('%s', 'pitch period = '), 'FontWeight', 'bold', ...
    'HorizontalAlignment', 'right', 'VerticalAlignment', 'baseline')
text(periodPitch, 0.75*yAxis(2), ...
    sprintf(' %4.2f ms', 1000*periodPitch), 'FontWeight', 'bold', ...
    'HorizontalAlignment', 'left', 'VerticalAlignment', 'baseline')
axis([tAxis yAxis])
ylabel('signal')



