clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define the stimuli
sampleFrequency = 44100; % Hz
dt = 1/sampleFrequency;
durationTone = 4; % sec
durationInterval = 1; % sec
amp = 0.98;
fade = 0.02; % sec
modFreq = logspace(log10(2.5), log10(10), 5); % Hz
n = length(modFreq);
fc = 1200; % Hz
modDepth = 600; % Hz

% Print the modulation frequencies
period = 1./modFreq;
fprintf('Modulation frequencies: \n')
fprintf('%8.2f', fliplr(modFreq))
fprintf('%s\n', '  Hz')

% Calculate the stimuli
% shift signal to get signal for t<0
t = -0.1*durationTone :dt:0.9*durationTone;
s = zeros(n, length(t));
instFreq = zeros(n, length(t));
interval =  zeros(size(dt:dt:durationInterval));
stimulus = [];
mi = zeros(1,n);
for i = n:-1:1 % Start stimulus with highest modulation frequency
    mi(i) = modDepth/modFreq(i);
    instFreq(i,:) = fc+mi(i)*modFreq(i)*cos(2*pi*modFreq(i)*t);
    s(i,:) = amp*cos(2*pi*cumsum(instFreq(i,:))*dt);
    s(i,:) = FadeInOut(s(i,:), sampleFrequency, fade, fade);
    stimulus = [stimulus s(i,:) interval]; %#ok<AGROW>
end
stimulus = [stimulus interval interval];
for i = n:-1:1 % Start stimulus with highest modulation frequency
    tone = amp*sin(2*pi*modFreq(i)*t);
    tone = FadeInOut(tone, sampleFrequency, fade, fade);
    stimulus = [stimulus tone interval]; %#ok<AGROW>
end

% Save and play the stimulus
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, 0.5*stimulus, sampleFrequency)
sound(0.5*stimulus, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = 120*ones(1, n); % pixels
xLabelHeight = 70; % pixels
yLabelWidth = [70 70]; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the signals
for i = 1:n
    axes('Position', pos(i,:))
    tAxis = [-0.125*period(1) 2.5*period(1)];
    dXTick = 0.2; % sec
    xTick = -dXTick:dXTick:durationTone;
    xTickLabel = xTick;
    yAxis = [0 2500];
    yTick = 0:1000:5000;
    yTickLabel = yTick/1000;
    set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
        'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
        'FontWeight', 'bold', 'TickDir', 'out', ...
        'YTick', yTick, 'YTickLabel', yTickLabel)
    if i == 1
        set(gca, 'XTick', xTick, 'XTickLabel', xTickLabel)
        xlabel('time (s)', 'FontWeight', 'bold')
    else
        set(gca, 'XTick', xTick, 'XTickLabel', [])
    end
    plot(t, instFreq(i,:), ...
        'Color', blueGreen, 'LineWidth', 1);
    plot(tAxis, [0 0], ...
        'Color', blueGreen, 'Linewidth', 0.5)
    plot([0 0], yAxis, ...
        'Color', blueGreen, 'Linewidth', 2)
    if i == 1
        text(period(i), 0.85*yAxis(2), ...
            sprintf('%s', 'period of modulation = '), ...
            'HorizontalAlignment', 'right', 'FontWeight', 'bold')
    end
    plot([period(i) period(i)], yAxis, ...
        'Color', blueGreen, 'Linewidth', 2)
    text(period(i), 0.85*yAxis(2), ...
        sprintf(' %4.3f s', period(i)), ...
        'HorizontalAlignment', 'left', 'FontWeight', 'bold')
    text(0.98*tAxis(2), 0.85*yAxis(2), ...
        sprintf('m_i = %4.0f; f_m = %6.2f Hz', ...
        mi(i), modFreq(i)), ...
        'HorizontalAlignment', 'right', 'FontWeight', 'bold')
    axis([tAxis yAxis])
    ylabel('f_{inst} (kHz)')
    
end

