clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Calculate the frequencies of the notes
F = 110*2^(8/12);
nrOfOctaves = 3;
f = logspace(log10(F), log10(F*(2^nrOfOctaves)), 12*nrOfOctaves+1);

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position of figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = 240; % pixels
xLabelHeight = 15; % pixels
yLabelWidth = 15; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Specify the dimensions of the keys in pixels
whiteKeyLength = 150;
blackKeyLength = 105;
nrOfWhiteKeys = 7*nrOfOctaves+1;

% Plot the keyboard
axes('Position', pos)
set(gca, 'LineWidth', 2, ...
    'XTick', [], 'XTickLabel', [], 'YTick', [], 'YTickLabel', [], ...
    'NextPlot', 'add', 'Box', 'off')
wwh = 1;
wbl = 0.7;
wh = 1:7;
t = ['F'; 'G'; 'A'; 'B'; 'C'; 'D'; 'E'];
bl = [1.4 2.5 3.6 5.4 6.6];
axis([0 nrOfWhiteKeys -0.2 1], 'off')
y0 = 1;
yb = y0-(blackKeyLength/whiteKeyLength)*y0;
dx = 0.1;
dy = dx/7;
lw = [y0 yb yb yb y0 yb yb y0];
for i=1:nrOfOctaves
    for j=1:length(wh)
        x = (length(wh)*(i-1)+[j-0.5 j-0.5 j-0.5+dx ...
            j+0.5-dx j+0.5 j+0.5])*wwh;        
        y = [lw(j) dy 0 0 dy lw(j+1)];
        plot(x, y, 'k')
        text((length(wh)*(i-1)+j)*wwh, 0.05, t(j), ...
            'HorizontalAlignment', 'center')
        k = 12*(i-1)+j;
        switch j
           case 2
               k = k+1;
           case 3
               k = k+2;
           case 4
               k = k+3;
           case 5
               k = k+3;
           case 6
               k = k+4;
           case 7
               k = k+5;
        end
        if f(k)<1000
            text((length(wh)*(i-1)+j)*wwh, -0.05, ...
                sprintf('%5.1f', (f(k))), ...
                'FontSize', 7, ...
                'HorizontalAlignment', 'center')
        else
            text((length(wh)*(i-1)+j)*wwh, -0.05, ...
                sprintf('%5.0f', (f(k))), ...
                'FontSize', 7, ...
                'HorizontalAlignment', 'center')
        end
    end
    for j=1:length(bl)
        x = (length(wh)*(i-1)+[bl(j)-0.4 bl(j)-0.4 bl(j)-0.4+dx ...
            bl(j)+0.4-dx bl(j)+0.4 bl(j)+0.4 bl(j)-0.4])*wwh;
        y = [y0 yb+dy yb yb yb+dy y0 y0];
        fill(x, y, [0.3 0.3 0.3])
        plot(x, y, 'k')
        k = 12*(i-1)+j;
        switch j
           case 1
               k = k+1;
           case 2
               k = k+2;
           case 3
               k = k+3;
           case 4
               k = k+5;
           case 5
               k = k+6;
        end
        if f(k)<1000
            text((length(wh)*(i-1)+bl(j))*wwh, 1.03, ...
                sprintf('%5.1f', (f(k))), ...
                'FontSize', 7, 'HorizontalAlignment', 'center')
        else
            text((length(wh)*(i-1)+bl(j))*wwh, 1.03, ...
                sprintf('%5.0f', (f(k))), ...
                'FontSize', 7, 'HorizontalAlignment', 'center')
        end
    end
end
text(7*nrOfOctaves+0.7, -0.05, 'Hz', 'FontSize', 7)
text(7*nrOfOctaves+0.7, 1.03, 'Hz', 'FontSize', 7)
plot([0.5 nrOfWhiteKeys-0.5], -0.13*[1 1], 'k')
xTxt = [2 7 14 19.5];
for oct = 0:3
    plot((4.5+7*oct)*[1 1], [-0.17 -0.09], 'k')
    text(xTxt(oct+1), -0.18, sprintf('octave %d', oct+3))
end

