clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define the stimulus
sampleFrequency = 20000; % Hz
dt = 1/sampleFrequency;
durationTone = 0.20; % sec 
t = dt:dt:durationTone;
durationInterval = 0.05; % sec
interval = zeros(size(dt:dt:durationInterval));
fade = 0.02; % sec
nrOfOctaves = 3;
f0 = 440; % Hz
f = logspace(log10(f0), log10((2^nrOfOctaves)*f0), ...
    12*nrOfOctaves+1);
f = [f 0];
melody = [1 1 5 8 1 1 5 8 1 length(f) 8 length(f)];
nrOfHarmonics = 3;
amp = 1/nrOfHarmonics;
tau = durationTone/3; % sec

% Calculate the stimulus
t0 = 0;
nrOfTones = 1;
for k = 1:length(melody)
    for i = 1:nrOfHarmonics
        fr = i*f(melody(k));
        schemTime(1:2, nrOfTones) = [t0 t0+durationTone]; %#ok<SAGROW>
        schemFreq(1:2, nrOfTones) = [fr fr]; %#ok<SAGROW>
        nrOfTones = nrOfTones+1;
    end
    t0 = t0+durationTone+durationInterval;
end
envelopeTone = amp*exp(-t/tau);
stimulus = SynthToneSequence(schemTime, schemFreq, sampleFrequency, ...
    envelopeTone);

% Save and play the sound
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = [120 240]; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 90; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the sound signal
panel = 1;
axes('Position', pos(panel,:))
dXTick = 1; % sec
dYTick = 2; % kHz
durationStimulus = length(stimulus)*dt; % sec
tAxis = [-dXTick/4 durationStimulus+dXTick/4];
PlotSignal(stimulus, sampleFrequency, ...
    tAxis, dXTick, blueGreen, 'time (s)')
set(gca, 'XTick', 0:durationStimulus, ...
    'XTickLabel', 0:durationStimulus, ...
    'Color', lightYellowGreen, 'NextPlot', 'add')

% Plot the schematic time-logfrequency representation
panel = panel+1;
axes('Position', pos(panel,:))
fAxis = f0*[0.7 7];
PlotSTlFR(stimulus, sampleFrequency, ...
    schemTime, schemFreq, envelopeTone, ...
    tAxis, dXTick, ...
    fAxis, 0.1*amp, blueGreen)
set(gca, 'Color', lightYellowGreen)
% Plot the rectangle containing the fundamental frequencies and
% two other parallelograms
t1 = -0.3*durationTone;
t2 = durationStimulus+0.3*durationTone;
f1 = log2(f(1)/f0)-0.16;
f2 = log2(f(8)/f0)+0.16;
plot([t1 t2 t2 t1 t1], [f1 f1 f2 f2 f1], 'Linewidth', 2, ...
    'Color', red)
t1 = -0.1*durationTone;
t2 = 8*(durationTone+durationInterval)+0.3*durationTone;
f11 = log2(f(13)/f0)-0.40;
f12 = log2(f(28)/f0)-0.40;
f21 = log2(f(28)/f0)+0.20;
f22 = log2(f(13)/f0)+0.20;
plot([t1 t2 t2 t1 t1], [f11 f12 f21 f22 f11], ...
    ':', 'Linewidth', 1.2, 'Color', red)
t1 = -0.1*durationTone;
t2 = 9*(durationTone+durationInterval)+0.3*durationTone;
f11 = log2(f(1)/f0)-0.45;
f12 = log2(f(22)/f0)-0.40;
f21 = log2(f(22)/f0)+0.35;
f22 = log2(f(1)/f0)+0.30;
plot([t1 t2 t2 t1 t1], [f11 f12 f21 f22 f11], ...
    ':', 'Linewidth', 1.2, 'Color', red)


