clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define and synthesize the stimulus
sampleFrequency = 10000; % Hz
dt = 1/sampleFrequency;
durationTone = 0.24; % sec
t = dt:dt:durationTone;
durationInterval = 0.01; % sec
durationPadding = 0.05; % sec
interval = zeros(size(dt:dt:durationInterval));
padding = zeros(size(dt:dt:durationPadding));
fade = 0.02; % sec
amp = 0.5;
t0 = 0;
noise = amp*randn(size(t));
centreFrequency = ...
    440*2.^([0 2 4 5 7 9 11 12 14 16 17 19 21 23 24]/12);
bandWidth = 1;
stimulus = [];
for f = centreFrequency
    c = 2*f/sampleFrequency;
    w1 = c*2^(-bandWidth/2);
    w2 = c*2^(bandWidth/2);
    [b, a ] = butter(4, [w1 w2]);
    s = filter(b, a, noise);
    s = FadeInOut(s, sampleFrequency, fade, fade);
    stimulus =  [stimulus s interval]; %#ok<AGROW>
end

% Save and play the sound segment
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = [80 180]; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 70; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Calculate the plot parameters
dXTick = 0.5; % sec
dYTick = 1; % kHz
maxYAxis = 5000; % Hz
durationStimulus = length(stimulus)*dt; % sec
xTick = -dXTick:dXTick:durationStimulus;
tAxis = [-0.2*dXTick durationStimulus+0.2*dXTick];
fAxis = [-20 maxYAxis+20];

% Plot the signal
panel = 1;
axes('Position', pos(panel,:))
PlotSignal(stimulus, sampleFrequency, ...
    tAxis, dXTick, blueGreen, 'time (s)')
set(gca, 'XTick', xTick, 'XTickLabel', xTick, ...
    'Color', lightYellowGreen)
text(0.99*tAxis(1)+0.01*tAxis(2), 0.7, ...
    'waveform', 'FontSize', 14, 'FontWeight', 'bold')

% Plot the spectrogram
panel = panel+1;
axes('Position', pos(panel,:))
nFft = 1024; % Number of samples in fft window
nWindow = 256;
nOverlap = nWindow-16;
[~, f, ts, p] = spectrogram([padding stimulus padding], ...
    nWindow, nOverlap, nFft, sampleFrequency);
p = 10*log10(abs(p));
ts = ts-durationPadding;
PlotSpectrogram(stimulus, sampleFrequency, ...
    f, ts, p, tAxis, dXTick, fAxis, dYTick, 40, frameColor)
set(gca, 'Color', lightYellowGreen)
text(0.99*tAxis(1)+0.01*tAxis(2), fAxis(1)+0.9*(fAxis(2)-fAxis(1)), ...
    'spectrogram', 'FontSize', 14, 'FontWeight', 'bold')


