clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define and calculate the stimuli
sampleFrequency = 44100; % Hz
dt = 1/sampleFrequency;
durationTone = 0.4; % sec
t = dt:dt:durationTone;
interval =  zeros(size(t));
amp = [0.60 0.76];
f0 = [660 440]; % Hz
s(1,:) = amp(1)*cos(2*pi*f0(1)*t);
s(2,:) = amp(2)*sin(2*pi*f0(2)*t);
stimulus = [s(2,:) interval s(1,:)];

% Save and play the stimumus
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = [180 180]; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 70; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Calculate the plot parameters
dXTick = 0.003; % sec
tAxis = [-dXTick/1.5 3.5*dXTick];
durationStimulus = size(stimulus, 2)*dt; % sec
xTick = 0:dXTick:durationStimulus;

% Plot the two sinewaves
for p = 1:length(panelHeights)
    axes('Position', pos(p,:))
    set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
        'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
        'FontWeight', 'bold', 'TickDir', 'out', ...
        'YTick', -1:1)
    if p == 1
        set(gca, 'XTick', xTick, 'XTickLabel', 1000*xTick)
        xlabel('time (ms)', 'FontWeight', 'bold')
    else
        set(gca, 'XTick', xTick, 'XTickLabel', [])
    end
    plot(t, s(p,:), 'Color', blueGreen, 'LineWidth', 1.5);
    axis([tAxis -1.1 1.1])
    plot([-0.1 length(stimulus)/sampleFrequency+0.1], [0 0], ...
        'Color', blueGreen, 'Linewidth', 0.5)
    plot([0 0], [-1.1 1.1], 'Color', blueGreen, 'Linewidth', 0.5)
    plot([-0.1 0.5/f0(p)], [amp(p) amp(p)], ...
        'Color', red, 'Linewidth', 0.5)
    ylabel('signal')
    str = sprintf('ampl.: %4.2f', amp(p));
    text(tAxis(1)+0.0001, amp(p), str, 'Color' , red, ...
        'FontSize', 14, 'HorizontalAlignment', 'left', ...
        'VerticalAlignment', 'bottom')
    str = sprintf('freq.: %3.0f Hz', f0(p));
    text(dXTick/5, 0.94, str, ...
        'FontSize', 12, 'FontWeight', 'bold')
end


