clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define the stimulus
sampleFrequency = 10000; % Hz
dt = 1/sampleFrequency;
durationTone = 0.10; % sec 
t = dt:dt:durationTone;
durationInterval = 0; % sec
durationPadding = 0.05; % sec
durationDelay = 0.5; % sec
interval = zeros(size(dt:dt:durationInterval));
padding = zeros(size(dt:dt:durationPadding));
delay = zeros(size(dt:dt:durationDelay));
tau = durationTone/4; % sec
f0 = 440; % Hz
amp = 0.7;

% Calculate the stimulus
envelopeTone = exp(-(t-dt)/tau); % Start at t = 0;
tone = amp*sin(2*pi*f0*(t-dt));
stimulus = tone.*envelopeTone;

% Save and play the sound
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
% Zeros added at start to ensure that the onset is perceived as abrupt
% when played by audioplayer
delayStim = [delay stimulus]; 
audiowrite(wavFileName, delayStim, sampleFrequency)
sound(delayStim, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = [120 240 240]; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 70; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Calculate the plot parameters
durationStimulus = length(stimulus)*dt; % sec
dXTick = 0.025; % sec
dYTick = 0.5; % kHz
maxYAxis = 1800; % Hz
fAxis = [0 maxYAxis];
tAxis = [-0.8*dXTick durationStimulus+0.8*dXTick];

% Plot the waveform
panel = 1;
axes('Position', pos(panel,:))
PlotSignal(stimulus, sampleFrequency, ...
    tAxis, dXTick, blueGreen, 'time (ms)')
set(gca, 'Color', lightYellowGreen)

% Calculate and plot the narrow-band spectrogram
panel = panel+1;
axes('Position', pos(panel,:))
nFft = 2048; % Number of samples in fft window
nWindow = 512; 
nOverlap = round(nWindow-nWindow/64);
[~, f, ts, spgr] = spectrogram([padding stimulus padding], ...
    nWindow, nOverlap, nFft, sampleFrequency);
spgr = 10*log10(abs(spgr));
ts = ts-durationPadding;
PlotSpectrogram(stimulus, sampleFrequency, ...
    f, ts, spgr, tAxis, dXTick, fAxis, dYTick, 40, ...
    frameColor)
set(gca, 'Color', lightYellowGreen)
text(tAxis(1)+0.01, 0.9*(fAxis(2)-fAxis(1)), ...
    'narrow-band spectrogram', ...
    'FontSize', 14, 'FontWeight', 'bold')

% Calculate and plot the wide-band spectrogram
panel = panel+1;
axes('Position', pos(panel,:))
nWindow = 64;
nOverlap = round(nWindow-nWindow/16);
[~, f, ts, spgr] = spectrogram([padding stimulus padding], ...
    nWindow, nOverlap, nFft, sampleFrequency);
spgr = 10*log10(abs(spgr));
ts = ts-durationPadding;
PlotSpectrogram(stimulus, sampleFrequency, ...
    f, ts, spgr, tAxis, dXTick, fAxis, dYTick, 40, ...
    frameColor)
set(gca, 'Color', lightYellowGreen)
text(tAxis(1)+0.01, 0.9*(fAxis(2)-fAxis(1)), ...
    'wide-band spectrogram', ...
    'FontSize', 14, 'FontWeight', 'bold')


