clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define the stimuli
sampleFrequency = 10000; % Hz
dt = 1/sampleFrequency;
f0 = 440;
durationTone = 0.1; % sec
t = dt:dt:durationTone;
durationInterval = 0.4; % sec
interval = zeros(1, length(dt:dt:durationInterval));
phase = [-pi/2 -pi/6 0 pi/6 pi/2];
amp = 0.99;

% Synthesize the stimulus
stimulus = interval;
s = zeros(length(phase), length(t));
for k = 1:length(phase)
    s(k,:) = amp*sin(2*pi*f0*(t-dt)+phase(k));
    stimulus = [stimulus interval s(k,:)]; %#ok<AGROW>
end

% Save and play the stimulus
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, amp*stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 720; % pixels
panelHeight = 90*ones(size(phase)); % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 70; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeight, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeight, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Calculate the plot parameters
dXTick = 0.025;
XTick = 0:dXTick:durationTone;
tAxis = [-0.2*dXTick durationTone+0.2*dXTick];
yAxis = [-1.3 1.3];
% Plot the signals
for k = 1:length(phase)
    axes('Position', pos(length(phase)+1-k,:))
    set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
        'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
        'FontWeight', 'bold', 'TickDir', 'out', ...
        'XTick', XTick, 'XTickLabel', 1000*XTick, 'YTick', -1:1)
    if k < length(phase)
        set(gca, 'XTicklabel', '')
    end
    plot(t, s(k,:), 'Color', blueGreen, 'LineWidth', 1.5);
    plot(tAxis, [0 0], 'Color', blueGreen, 'Linewidth', 1.5)
    axis([tAxis yAxis])
    if k == length(phase)
        xlabel('time (ms)', 'FontWeight', 'bold')
    end
    ylabel('signal')
end



