clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define the stimulus
sampleFrequency = 40000; % Hz
dt = 1/sampleFrequency;
durationPulseTrain = 0.2; % sec
% Calculate pulse train, its harmonics, and its partial sums
% Calculate sound for t<0 for plotting
t = (dt:dt:durationPulseTrain)-0.1*durationPulseTrain;
durationInterval = 0.02; % sec
interval = zeros(size(dt:dt:durationInterval));
f0 = 500; % Hz
nrOfHarmonics = 5;
fade = 0.02; % sec
% Synthesize the pulse series
pulses = zeros(size(t));
k = 1;
while k/f0<durationPulseTrain
    pulses(floor(k/f0*sampleFrequency)) = 1;
    k = k+1;
end
% Synthesize the sum of cosines
stimulus = [];
cosines = zeros(nrOfHarmonics+1, length(t));
sumCosines = zeros(1, length(t));
for k = 1:nrOfHarmonics
    cosines(k,:) = (1/nrOfHarmonics)*cos(2*pi*k*f0*t);
    cosines(k,:) = ...
        FadeInOut(cosines(k,:), sampleFrequency, fade, fade);
    sumCosines = ...
        sumCosines+cosines(k,:);
    stimulus = ...
        [stimulus interval sumCosines interval]; %#ok<*AGROW>
end
stimulus = [stimulus interval zeros(size(t)) interval];
stimulus = [stimulus interval pulses interval];

% Save and play the stimulus
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, 0.5*stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position of figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = 180; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 70; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the cosines
panel = 1;
axes('Position', pos(panel,:))
dXTick = 0.002; % sec
plotSegmentDuration = 4/f0; % sec
xAxis = [-0.3/f0 plotSegmentDuration+0.3/f0];
yAxis = [-0.5 1.2];
xTick = 0:dXTick:durationPulseTrain;
xTickLabel = 1000*xTick;
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
    'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', xTick, 'XTickLabel', xTickLabel, ...
    'YTick', -1:1)
for k = 1:nrOfHarmonics
    plot(t, cosines(k,:), 'Color', blueGreen)
end
plot(t, sumCosines, 'Color', blueGreen, 'LineWidth', 2)
plot(t, pulses, 'Color', red, 'LineWidth', 2)
plot([0 0], yAxis, 'Color', blueGreen, 'LineWidth', 1.5)
plot(xAxis, [0 0], 'Color', blueGreen, 'LineWidth', 1.5)
xlabel('time (ms)')
ylabel('signal')
axis([xAxis yAxis])

