clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define the sound signal
sampleFrequency = 10000; % Hz
dt = 1/sampleFrequency;
f = 440; % Hz
durationTone = 0.5; % sec
durationInterval = 0.015; % sec
t0 = 0.37+(0:4)*0.01;
fade = 0.02; % sec
amp = 0.5;

% Calculate the tone
interval = zeros(size(dt:dt:durationInterval));
stimulus = interval;
t = dt:dt:durationTone;
tone = amp*sin(2*pi*f*t);
tone = FadeInOut(tone, sampleFrequency, fade, fade);
stimulus =  [stimulus tone interval]; %#ok<*AGROW>

% Save and play the stimulus
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate and plot the windows for various window lengths
nWindow = 64; % a short analysis window
nFft = 2048; % Number of samples in fft window
h = hamming(nWindow)';
segment = zeros(length(t0), nFft);
for j = 1:length(t0)
    i = round(t0(j)*sampleFrequency);
    segment(j,1:length(h)) = ...
        stimulus(i-nWindow/2+1:i+nWindow/2).*h;
end

% Calculate the power spectra of the segments
spc = zeros(length(t0), nFft/2);
for j = 1:size(segment, 1)
    segment(j,(nWindow+1):nFft) = 0;
    s = abs(fft(segment(j,:))*(64/nWindow));
    spc(j,:) = 20*log10(s(1:nFft/2));
end

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = [120 240 120]; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 70; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
figWidth = yLabelWidth+panelWidth+xMargin;
figHeight = 2*xLabelHeight+sum(panelHeights+yMargin);
set(gcf, 'Position', [figX0 figY0 figWidth figHeight], ...
    'Color', frameColor, 'InvertHardCopy', 'off')
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the sound signal and the analysis windows
panel = 1;
axes('Position', pos(panel,:))
dXTick = 0.03; % sec
dYTick = 0.5; % kHz
tAxis = [t0(1)-dXTick t0(end)+dXTick];
yAxis = [-1.5 1.5];
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
    'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', 0:dXTick:durationTone, ...
    'XTickLabel', 1000*(0:dXTick:durationTone), ...
    'YTick', -1:1)
plot((1:length(stimulus))/sampleFrequency, stimulus, ...
    'Color', blueGreen, 'LineWidth', 1.5);
plot(tAxis, [0 0], ...
    'Color', blueGreen, 'Linewidth', 0.5)
for j = 1:length(t0)
    i = round(t0(j)*sampleFrequency);
    plot((i-nWindow/2+1:i+nWindow/2)*dt, h, ...
        'Color', darkRed, 'LineWidth', 0.5);
    text(t0(j), 1.25, num2str(j), 'FontSize', 8, ...
        'Color', darkRed, 'HorizontalAlignment', 'center')
end
text(0.98*tAxis(1)+0.02*tAxis(2), 1.2, 'five analysis windows', ...
    'FontSize', 10, 'FontWeight', 'bold', 'Color', darkRed)
text(0.98*tAxis(1)+0.02*tAxis(2), 0.8, 'signal', ...
    'FontSize', 10, 'FontWeight', 'bold', 'Color', blueGreen)
xlabel('time ms', 'FontWeight', 'bold')
ylabel('signal')
axis([tAxis yAxis])

% Plot the windowed sound signal
panel = panel+1;
axes('Position', pos(panel,:))
if nWindow > 128
    horAlign = 'center';
else
    horAlign = 'right';
end
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
    'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', 0:dXTick:durationTone, 'XTickLabel', [], ...
    'YTick', -1:1, 'YTickLabel', [])
for j = 1:length(t0)
    i = round(t0(j)*sampleFrequency);
    level = (j-ceil(length(t0)/2))*0.54;
    plot((i-nWindow/2+1:i+nWindow/2)*dt, ...
        level+0.5*segment(j, 1:nWindow), ...
        'Color', blueGreen, 'LineWidth', 1.5);
    plot((i-nWindow/2+1:i+nWindow/2)*dt, ...
        level+zeros(size(segment(j, 1:nWindow))), ...
        'Color', blueGreen, 'LineWidth', 0.5);
    text((i-nWindow/2)*dt, level+0.05, ...
        ['segment ' num2str(j)], ...
        'HorizontalAlignment', horAlign, ...
        'VerticalAlignment', 'bottom', ...
        'FontSize', 8, 'Color', darkRed)
end
axis([tAxis yAxis])
ylabel('signal')
text(0.98*tAxis(1)+0.02*tAxis(2), 1.35, ...
    'five windowed signals', ...
    'FontSize', 10, 'FontWeight', 'bold', 'Color', blueGreen)

% Plot the power spectra
panel = panel+1;
pos(panel, 3) = pos(panel, 3)/(length(t0)+0.3);
pos(panel, 2) = pos(panel, 2)+xLabelHeight/figHeight;
xTick = 0:1000:sampleFrequency/2;
for j = 1:size(segment, 1)
    axes('Position', pos(panel,:))
    set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
        'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
        'FontWeight', 'bold', 'TickDir', 'out', ...
        'XTick', xTick, 'XTickLabel', xTick/1000, ...
        'YTick', -120:30:120, ...
        'TickLength', [0.020 0.025])
    if j == 1
        ylabel('power (dB)')
    else
        set(gca, 'YTickLabel', [])
    end
    plot((1:length(spc(j,:)))/(nFft*dt), spc(j,:), ...
        'Color', blueGreen)
    xlabel('freq. (kHz)')
    if j == 1
        text(200, 29, 'power spectrum', ...
            'FontSize', 10, 'FontWeight', 'bold', ...
            'Color', blueGreen)
        text(2800, 19, [' of segment ' num2str(j)], ...
            'FontSize', 8, 'Color', darkRed, ...
            'HorizontalAlignment', 'right')
    else
        text(2800, 29, [' of segment ' num2str(j)], ...
            'FontSize', 8, 'Color', darkRed, ...
            'HorizontalAlignment', 'right')
    end
    axis([0 2900 -40 35])
    pos(panel, 1) = pos(panel, 1) + ...
        panelWidth/figWidth/length(t0);
end

