clear
close all
InitializePSS()
fprintf('%s\n', mfilename);
rng(3) % set random number generator

% Calculate the sawtooth wave and the square wave, their harmonics,
% and their partial sums
sampleFrequency = 44100; % Hz
dt = 1/sampleFrequency;
durationTone = 0.2; % sec 
amp = 0.5;

% Calculate sound for t<0 for plotting
t = (dt:dt:durationTone)-0.1*durationTone;
durationInterval = 0.02; % sec
interval = zeros(size(dt:dt:durationInterval));
f0 = 500; % Hz
nrOfHarmonics = 5;
fade = 0.02; % sec
% Synthesize the pulse series and its derivative
squareWave = square(2*pi*f0*t+pi/2);
sawtoothWave = -sawtooth(2*pi*f0*t+pi, 0);
% Synthesize the sum of cosines
stimulus = [];
cosines = zeros(nrOfHarmonics+1, length(t));
sumCosines = zeros(1, length(t));
for k = 1:nrOfHarmonics
    cosines(k,:) = ...
        (4/pi)*((-1)^(k-1)/(2*k-1))*cos(2*pi*(2*k-1)*f0*t + ...
        2*pi*rand);
    cosines(k,:) = ...
        FadeInOut(cosines(k,:), sampleFrequency, fade, fade);
    sumCosines = ...
        sumCosines+cosines(k,:);
    stimulus = ...
        [stimulus interval sumCosines interval]; %#ok<*AGROW>
end
stimulus = [stimulus interval zeros(size(t)) interval];
stimulus = [stimulus interval squareWave interval];
stimulus = [stimulus interval zeros(size(t)) interval];
% Synthesize the sum of sines
sines = zeros(nrOfHarmonics+1, length(t));
sumSines = zeros(1, length(t));
for k = 1:nrOfHarmonics
    sines(k,:) = (-1)^(k-1)*(2/(pi*k))*sin(2*pi*k*f0*t + ...
        2*pi*rand);
    sines(k,:) = ...
        FadeInOut(sines(k,:), sampleFrequency, fade, fade);
    sumSines = ...
        sumSines+sines(k,:);
    stimulus = ...
        [stimulus interval sumSines interval];
end
stimulus = [stimulus interval zeros(size(t)) interval];
stimulus = [stimulus interval sawtoothWave interval];
stimulus = [stimulus interval zeros(size(t)) interval];

% Save and play the stimulus
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, amp*stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position of figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = [180 180]; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 70; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the sawtooth
panel = 1;
axes('Position', pos(panel,:))
dXTick = 0.002; % sec
plotSegmentDuration = 4/f0; % sec
xAxis = [-0.3/f0 plotSegmentDuration+0.3/f0];
yAxis = [-2 2];
xTick = 0:dXTick:durationTone;
xTickLabel = 1000*xTick;
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
    'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', xTick, 'XTickLabel', xTickLabel, ...
    'YTick', -1:1)
axis([xAxis yAxis])
xlabel('time (ms)')
ylabel('signal')
for k = 1:nrOfHarmonics
    plot(t, cosines(k,:), 'Color', blueGreen)
end
plot(t, sumCosines, 'Color', blueGreen, 'LineWidth', 2)
plot(t, squareWave, '--', 'Color', red, 'LineWidth', 2)
plot([0 0], yAxis, ...
    'Color', blueGreen, 'LineWidth', 1.5)

% Plot the square wave
panel = panel+1;
axes('Position', pos(panel,:))
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
    'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', 0:dXTick:0.2, 'XTickLabel', [], ...
    'YTick', -1:1)
axis([xAxis yAxis])
ylabel('signal')
for k = 1:nrOfHarmonics
    plot(t, sines(k,:), 'Color', blueGreen)
end
plot(t, sumSines, 'Color', blueGreen, 'LineWidth', 2)
plot(t, sawtoothWave, '--', 'Color', red, 'LineWidth', 2)
plot([0 0], yAxis, 'Color', blueGreen, 'LineWidth', 1.5)

