clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define and calculate the stimuli
sampleFrequency = 44100; % Hz
dt = 1/sampleFrequency;
durationTone = 0.5; % sec
t = dt:dt:durationTone;
interval =  zeros(size(t));
f0 = 20; % Hz
nrOfHarmonics = 50;
amp = 0.9/nrOfHarmonics;
s = zeros(4, length(t));
for k = 1:nrOfHarmonics
    s(1,:) = s(1,:) + amp*sin(2*pi*k*f0*t);
    s(2,:) = s(2,:) + amp*cos(2*pi*k*f0*t);
    s(3,:) = s(3,:) + amp*cos(2*pi*k*f0*t+pi*k*k/nrOfHarmonics);
    s(4,:) = s(4,:) + amp*sin(2*pi*k*f0*t-pi*k*k/nrOfHarmonics);
end
iPeriod = (length(t)+length(interval));
stimulus = zeros(1, 4*iPeriod);
i = 1;
for j = 1:4
    s(j,:) = FadeInOut(s(j,:), sampleFrequency, 0.02, 0.02);
    stimulus(i:i+size(s,2)-1) = stimulus(i:i+size(s,2)-1) + s(j,:);
    i = i+iPeriod;
end

% Save and play the stimumus
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = [150 150 150 150]; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 70; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Calculate the plot parameters
dXTick = 0.05; % sec
tAxis = [0.10 0.10+5/f0];
yAxis = [-1.1 1.1];
durationStimulus = size(stimulus, 2)*dt; % sec
xTick = 0:dXTick:durationStimulus;

% Plot the two sinewaves
nrOfPanels = length(panelHeights);
for p = 1:nrOfPanels
    axes('Position', pos(nrOfPanels+1-p,:))
    set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
        'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
        'FontWeight', 'bold', 'TickDir', 'out', ...
        'YTick', -1:1)
    if p == nrOfPanels
        set(gca, 'XTick', xTick, 'XTickLabel', 1000*xTick)
        xlabel('time (ms)', 'FontWeight', 'bold')
    else
        set(gca, 'XTick', xTick, 'XTickLabel', [])
    end
    plot(t, s(p,:), ...
        'Color', blueGreen, 'LineWidth', 1.5);
    plot([0 durationStimulus], [0 0], ...
        'Color', blueGreen, 'Linewidth', 0.5)
    switch p
        case 1
            text(0.105, 0.8, 'sine phase', ...
                'FontWeight', 'bold')
        case 2
            text(0.105, 0.8, 'cosine phase', ...
                'FontWeight', 'bold')
        case 3
            text(0.105, 0.8, 'positive Schroeder phase', ...
                'FontWeight', 'bold')
        case 4
            text(0.105, 0.8, 'negative Schroeder phase', ...
                'FontWeight', 'bold')
    end
    ylabel('signal')
    axis([tAxis yAxis])
end


