clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Read the speech signal
[speech, sampleFrequency] = audioread('allLines.wav');
stimulus = 0.9*speech';
dt = 1/sampleFrequency;
durationStimulus = length(stimulus)*dt; % sec
t = (0:length(stimulus))*dt;
t0 = 0.3471+(0:4)*0.0036;
tInterval =  [t0(1)-0.03 t0(end)+0.03];
ti = round(tInterval(1)/dt):round(tInterval(end)/dt);
stimulusInterval = stimulus(ti);

% Save and play the sound segment
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = [120 240]; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 70; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the speech signal
panel = 1;
axes('Position', pos(panel,:))
tAxis = [t(1) t(end)];
maxYAxis = sampleFrequency/2; % Hz
fAxis = [0 maxYAxis];
dXTick = 0.25; % sec
dYTick = 1; % kHz
PlotSignal(stimulus, sampleFrequency, ...
    tAxis, dXTick, blueGreen, 'time (s)')
set(gca, 'XTick', 0:0.25:durationStimulus, ...
    'XTickLabel', 0:0.25:durationStimulus, ...
    'Color', lightYellowGreen)
plot([t0(1) t0(1)], [-1.5 1.5], 'Color', darkRed)
plot([t0(end) t0(end)], [-1.5 1.5], 'Color', darkRed)
% Indicate the unvoiced segments
unvoicedSegment = [0.55 0.67; 1.49 1.53; 1.84 2.09]; % sec.
mus = mean(transpose(unvoicedSegment));
for j = 1:size(unvoicedSegment, 1)
    plot(unvoicedSegment(j,:), [0.8 0.8], ...
        'LineWidth', 2, 'Color', darkRed)
    plot([unvoicedSegment(j,1) unvoicedSegment(j,1)], [0.75 0.85], ...
        'LineWidth', 2, 'Color', darkRed)
    plot([unvoicedSegment(j,2) unvoicedSegment(j,2)], [0.75 0.85], ...
        'LineWidth', 2, 'Color', darkRed)
    text(mus(j), 0.6, 'uv', 'HorizontalAlign', 'center');
end
%Indicate the syllables
syllables = ...
    ['All  '; 'lines'; 'from '; 'Lon -'; 'don  '; 'are  '; ...
    'en  -'; 'gaged'];
onsets = [0.13 0.335 0.70 0.90 1.10 1.25 1.40 1.60];
for syll = 1:length(syllables)
    text(onsets(syll), -0.8, syllables(syll,:), ...
        'FontAngle', 'italic', ...
        'FontSize', 10, 'FontWeight', 'bold')
end

% Calculate and plot the spectrogram
panel = panel+1;
axes('Position', pos(panel,:))
nFft = 2048; % Number of samples in fft window
nWindow = 512;
% Calculate the spectrogram
nOverlap = nWindow-32;
[~, f, ts, spgr] = spectrogram(stimulus, ...
    nWindow, nOverlap, nFft, sampleFrequency);
spgr = 10*log10(abs(spgr));
PlotSpectrogram(speech, sampleFrequency, ...
    f, ts, spgr, tAxis, dXTick, fAxis, dYTick, 60, ...
    lightYellowGreen)
plot([t0(1) t0(1)], fAxis, 'Color', darkRed)
plot([t0(end) t0(end)], fAxis, 'Color', darkRed)
text(t(end)-0.05, 0.9*(fAxis(2)-fAxis(1)), ...
    'narrow-band spectrogram', ...
    'FontSize', 14, 'FontWeight', 'bold', ...
    'HorizontalAlignment', 'right')

