clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define the stimuli
sampleFrequency = 44100; % Hz
dt = 1/sampleFrequency;
amp = 0.48;
fade = 0.01; % sec
cf = 500;
df = 40;

% Calculate the stimulus
modFreq = df/2;
f1 = cf-modFreq;
f2 = cf+modFreq;
duration = 2; % sec
nrOfModPeriods = duration*modFreq;
t = -1/modFreq:dt:(nrOfModPeriods-1)/modFreq;
sinusoid1 = amp*cos(2*pi*f1*t);
sinusoid2 = amp*cos(2*pi*f2*t);
modulator = 2*amp*cos(2*pi*modFreq*t);
carrier = cos(2*pi*((f1+f2)/2)*t);
stimulus = modulator.*carrier;
stimulus = FadeInOut(stimulus, sampleFrequency, fade, fade);
durationStimulus = length(stimulus)*dt; % sec

% Save and play the stimulus
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the position of the figures on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position of figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = [130 130 130]; % pixels;
xLabelHeight = 70; % pixels
yLabelWidth = 70; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the stimulus
panel = 1;
axes('Position', pos(panel,:))
dXTick = 0.5/(f2-f1); % sec
xTick = -dXTick:dXTick:durationStimulus;
xTickLabel = round(1000*xTick,2);
tAxis = [-0.5/modFreq 2.5/modFreq];
yAxis = amp*[-2.5 2.8];
set(gca, 'LineWidth', 1.5, ...
    'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontSize', 14, 'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', xTick, 'XTickLabel', xTickLabel, 'YTick', -5:5, ...
    'XTickLabelRotation', 0)
plot(t, stimulus, 'Color', blueGreen, 'LineWidth', 1.5);
plot([t(1) t(end)], [0 0], 'Color', blueGreen, 'Linewidth', 0.5)
plot([0 0], yAxis, 'Color', blueGreen, 'Linewidth', 0.5)
plot(t, abs(modulator), '--', 'Color', red, 'LineWidth', 1);
plot(t, -abs(modulator), '--', 'Color', red, 'LineWidth', 1);
xlabel('time (ms)')
ylabel('signal')
axis([tAxis yAxis])
text(dXTick/10, 0.85*yAxis(2), ...
    sprintf('sum of a %3.4g-Hz and a %3.4g-Hz sinusoid', f1, f2), ...
    'FontSize', 12, 'FontWeight', 'bold')

% Plot the sinusoid with the higher frequency
panel = panel+1;
axes('Position', pos(panel,:))
set(gca, 'LineWidth', 1.5, ...
    'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontSize', 14, 'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', -dXTick:dXTick:durationStimulus, ...
    'XTickLabel', [], 'YTick', -2:2)
plot(t, sinusoid2, 'Color', blueGreen, 'LineWidth', 1.5);
plot([t(1) t(end)], [0 0], 'Color', blueGreen, 'Linewidth', 0.5)
plot([0 0], yAxis, 'Color', blueGreen, 'Linewidth', 0.5)
ylabel('signal')
axis([tAxis yAxis])
text(dXTick/10, 0.85*yAxis(2), ...
    sprintf('a %3.4g-Hz sinusoid', f2), ...
    'FontSize', 12, 'FontWeight', 'bold')

% Plot the sinusoid with the lower frequency
panel = panel+1;
axes('Position', pos(panel,:))
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
    'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', -dXTick:dXTick:durationStimulus, ...
    'XTickLabel', [], 'YTick', -2:2)
plot(t, sinusoid1, 'Color', blueGreen, 'LineWidth', 1.5);
plot([t(1) t(end)], [0 0], 'Color', blueGreen, 'Linewidth', 0.5)
plot([0 0], yAxis, 'Color', blueGreen, 'Linewidth', 0.5)
ylabel('signal')
axis([tAxis yAxis])
text(dXTick/10, 0.85*yAxis(2), ...
    sprintf('a %3.4g-Hz sinusoid', f1), ...
    'FontSize', 12, 'FontWeight', 'bold')

