clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define the stimuli
sampleFrequency = 44100; % Hz
dt = 1/sampleFrequency;
durationTone = 10; % sec
durationInterval = 2; % sec
amp = 0.49;
fade = 0.01; % sec
df = logspace(log10(0.3), log10(0.5), 5); % Hz
n = length(df);
fc = 1200; % Hz

% Print the difference frequencies
fLow = fc-df/2;
fHgh = fc+df/2;
periodEnv = 1./(fHgh-fLow);
fprintf('Difference frequencies: \n')
fprintf('%8.2f', fliplr(round(df, 2)))
fprintf('%s\n', '  Hz')
    
% Calculate the stimuli
t = -0.1*durationTone:dt:0.9*durationTone;
s = zeros(n, length(t));
interval =  zeros(size(dt:dt:durationInterval));
stimulus = [];
for i = n:-1:1 % Start stimulus with highest modulation frequency
    s(i,:) = amp*(cos(2*pi*fHgh(i)*t)-cos(2*pi*fLow(i)*t));
    s(i,:) = FadeInOut(s(i,:), sampleFrequency, fade, fade);
    stimulus = [stimulus s(i,:) interval]; %#ok<AGROW>
end

% Save and play the stimulus
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = 120*ones(1, n); % pixels
xLabelHeight = 70; % pixels
yLabelWidth = [70 70]; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the signals
dXTick = 1; % sec
tAxis = [-0.125*periodEnv(1) 2.875*periodEnv(1)]/2;
yAxis = [-1.2 1.5];
xTick = -dXTick:dXTick:durationTone;
xTickLabel = xTick;
for i = 1:n
    axes('Position', pos(i,:))
    set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
        'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
        'FontWeight', 'bold', 'TickDir', 'out', ...
        'YTick', -1:1)
    if i == 1
        set(gca, 'XTick', xTick, 'XTickLabel', xTickLabel)
        xlabel('time (s)', 'FontWeight', 'bold')
    else
        set(gca, 'XTick', xTick, 'XTickLabel', [])
    end
    plot(t, s(i,:), 'Color', blueGreen, 'LineWidth', 1.5);
    plot(tAxis, [0 0], 'Color', blueGreen, 'Linewidth', 0.5)
    plot([0 0], yAxis, 'Color', blueGreen, 'Linewidth', 2)
    plot([periodEnv(i) periodEnv(i)], yAxis, ...
        'Color', blueGreen, 'Linewidth', 2)
    if i == 1
        text(periodEnv(i), 0.85*yAxis(2), ...
            sprintf('%s', 'period of envelope = '), ...
            'HorizontalAlignment', 'right')
    end
    text(periodEnv(i), 0.85*yAxis(2), ...
        sprintf(' %4.3f s', periodEnv(i)), ...
        'HorizontalAlignment', 'left')
    axis([tAxis yAxis])
    ylabel('signal')
end

