clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Read the speech signal and define the segment
[speech, sampleFrequency] =  audioread('allLines.wav');
speech = 0.9*speech';
dt = 1/sampleFrequency;
speechDuration = length(speech)*dt;
pauseDuration = 0.2; % sec
t0 = 0.3471+(0:4)*0.0036;
padding = 0.060; % sec
fade = 0.01; % sec
tSegment =  [t0(1)-padding t0(end)+padding];
ti = round(tSegment(1)/dt):round(tSegment(end)/dt);
stimulusSegment = FadeInOut(speech(ti), sampleFrequency, fade, fade);
stimulus = ...
    [speech zeros(size(dt:dt:pauseDuration)) stimulusSegment];
durationStimulus = length(stimulus)*dt; % sec
t = (0:length(stimulus))*dt;

% Save and play the sound segment
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = [120 120]; % pixels
xLabelHeight = [70  70]; % pixels
yLabelWidth = 60; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the complete utterance
panel = 1;
axes('Position', pos(panel,:))
dXTick = 0.01; % sec
tAxis = [0.8*tSegment(1)+0.2*tSegment(2) 0.2*tSegment(1)+0.8*tSegment(2)];
PlotSignal(stimulus, sampleFrequency, tAxis, dXTick, blueGreen, 'time (s)')
set(gca, 'Color', lightYellowGreen)
axis([tAxis -0.7 1.5])
xlabel('time (ms)', 'FontWeight', 'bold')
ylabel('signal')
text(0.99*tAxis(1)+0.01*tAxis(2), 1.2, 'voiced speech segment', ...
    'FontSize', 10, 'FontWeight', 'bold')

% Plot the speech segment
panel = panel+1;
axes('Position', pos(panel,:))
dXTick = 0.25; % sec
tAxis = [0 speechDuration];
PlotSignal(stimulus, sampleFrequency, ...
    tAxis, dXTick, blueGreen, 'time (s)')
plot([t0(1) t0(1)], [-1.5 1.5], 'Color', darkRed)
plot([t0(end) t0(end)], [-1.5 1.5], 'Color', darkRed)
axis([tAxis -1.5 1.5])
set(gca, 'XTick', 0:dXTick:durationStimulus, ...
    'XTickLabel', 0:dXTick:durationStimulus, ...
    'Color', lightYellowGreen)
syllables = ...
    ['All  '; 'lines'; 'from '; 'Lon -'; 'don  '; 'are  '; 'en  -'; 'gaged'];
onsets = [0.13 0.335 0.70 0.90 1.10 1.25 1.40 1.60];
for syll = 1:length(syllables)
    text(onsets(syll), -0.8, syllables(syll,:), 'FontAngle', 'italic', ...
        'FontSize', 10, 'FontWeight', 'bold')
end
text(0.99*tAxis(1)+0.01*tAxis(2), 1.2, 'speech utterance', ...
    'FontSize', 10, 'FontWeight', 'bold')

