clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define the stimulus
sampleFrequency = 10000; % Hz
dt = 1/sampleFrequency;
durationBurst = 0.2; % sec
cutoffFrequency = 1000;
fade = 0.02; % sec
amp = 0.4;

% Synthesize the stimulus
durationInterval = 0.02; % sec
durationPadding = 0.05; % sec
interval = zeros(size(dt:dt:durationInterval));
padding = zeros(size(dt:dt:durationPadding));
t = dt:dt:durationBurst;
s = amp*randn(size(t));
w = 2*cutoffFrequency/sampleFrequency;
[b, a] = butter(4, w);
s = filter(b, a, s);
s = FadeInOut(s, sampleFrequency, fade, fade);
stimulus =  [s interval];
if max(abs(stimulus)) > 1
    stimulus = stimulus/max(abs(stimulus));
    fprintf('Noise scaled by a factor: %4.2f\n', max(abs(stimulus)));
end

% Save and play the sound segment
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = [80 180]; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 70; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Calculate the plot parameters
dXTick = 0.05; % sec
dYTick = 1; % kHz
maxYAxis = 5000; % Hz
durationStimulus = length(stimulus)*dt; % sec
xTick = -dXTick:dXTick:durationStimulus;
tAxis = [-1.2*dXTick durationStimulus+0.8*dXTick];
fAxis = [-20 maxYAxis+20];

% Plot the signal
panel = 1;
axes('Position', pos(panel,:))
PlotSignal(stimulus, sampleFrequency, ...
    tAxis, dXTick, blueGreen, 'time (ms)')
set(gca, 'XTick', xTick, 'XTickLabel', 1000*xTick, ...
    'Color', lightYellowGreen)
text(0.99*tAxis(1)+0.01*tAxis(2), 0.7, ...
    'waveform', 'FontSize', 14, 'FontWeight', 'bold')

% Calculate and plot the narrow-band spectrogram
panel = panel+1;
axes('Position', pos(panel,:))
nFft = 2048; % Number of samples in fft window
nWindow = 64; 
nOverlap = nWindow-4;
[~, f, ts, spcgr] = spectrogram([padding stimulus padding], ...
    nWindow, nOverlap, nFft, sampleFrequency);
ts = ts-durationPadding;
spcgr = 10*log10(abs(spcgr));
PlotSpectrogram(stimulus, sampleFrequency, ...
    f, ts, spcgr, tAxis, dXTick, fAxis, dYTick, 40, ...
    frameColor)
set(gca, 'XTick', xTick, 'XTickLabel', [], ...
    'Color', lightYellowGreen)
plot([tAxis(1) tAxis(2) tAxis(2) tAxis(1) tAxis(1)], ...
    [fAxis(1) fAxis(1) fAxis(2) fAxis(2) fAxis(1)], ...
    'LineWidth', 2, 'Color', 'k')
text(0.99*tAxis(1)+0.01*tAxis(2), fAxis(1)+0.9*(fAxis(2)-fAxis(1)), ...
    'spectrogram', 'FontSize', 14, 'FontWeight', 'bold')


