clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define the stimulus
sampleFrequency = 10000; % Hz
dt = 1/sampleFrequency;
durationBurst = 0.40; % sec
durationInterval = 0.10; % sec
fade = 0.02; % sec
amp = 0.25;

% Synthesize the stimulus
durationPadding = 0.10; % sec
interval = zeros(size(dt:dt:durationInterval));
padding = zeros(size(dt:dt:durationPadding));
t = dt:dt:durationBurst;
s1 = amp*randn(size(t));
s1 = FadeInOut(s1, sampleFrequency, fade, fade);
s2 = amp*randn(size(t));
s2 = FadeInOut(s2, sampleFrequency, fade, fade);
stimulus =  [padding s1 interval s2 interval];
if max(abs(stimulus)) > 1
    stimulus = stimulus/max(abs(stimulus));
    fprintf('Noise scaled by a factor: %4.2f\n', max(abs(stimulus)));
end

% Save and play the stimulus
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position of figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = [80 180 180]; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 70; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Calculate the plot parameters
dXTick = 0.1; % sec
dYTick = 1; % kHz
maxYAxis = 5000; % Hz
durationStimulus = length(stimulus)*dt; % sec
xTick = -dXTick:dXTick:durationStimulus;
tAxis = [-0.1*dXTick durationStimulus+0.1*dXTick];
fAxis = [-20 maxYAxis+20];

% Plot the sound signal
panel = 1;
axes('Position', pos(panel,:))
PlotSignal(stimulus, sampleFrequency, ...
    tAxis, dXTick, blueGreen, 'time (ms)')
set(gca, 'XTick', xTick, 'XTickLabel', 1000*xTick, ...
    'Color', lightYellowGreen)
text(0.99*tAxis(1)+0.01*tAxis(2), 0.7, ...
    'waveform', 'FontSize', 14, 'FontWeight', 'bold')

% Calculate and plot the narrow-band spectrogram
panel = panel+1;
axes('Position', pos(panel,:))
nFft = 2048; % Number of samples in fft window
nWindow = 512;
nOverlap = nWindow-32;
[~, fNarrow, tsNarrow, spcgrNarrow] = spectrogram(stimulus, ...
    nWindow, nOverlap, nFft, sampleFrequency);
spcgrNarrow = 10*log10(abs(spcgrNarrow));
PlotSpectrogram(stimulus, sampleFrequency, ...
    fNarrow, tsNarrow, spcgrNarrow, tAxis, dXTick, fAxis, dYTick, ...
    30, lightYellowGreen)
set(gca, 'Color', lightYellowGreen)
text(0.99*tAxis(1)+0.01*tAxis(2), ...
    fAxis(1)+0.9*(fAxis(2)-fAxis(1)), ...
    'narrow-band spectrogram', 'FontSize', 14, 'FontWeight', 'bold')

% Calculate and plot the wide-band spectrogram
panel = panel+1;
axes('Position', pos(panel,:))
dBRange = 30;
nWindow = 16;
nOverlap = nWindow-4;
[~, fWide, tsWide, spcgrWide] = spectrogram(stimulus, ...
    nWindow, nOverlap, nFft, sampleFrequency);
spcgrWide = 10*log10(abs(spcgrWide));
PlotSpectrogram(stimulus, sampleFrequency, ...
    fWide, tsWide, spcgrWide, tAxis, dXTick, fAxis, dYTick, ...
    dBRange, lightYellowGreen)
set(gca, 'Color', lightYellowGreen)
text(0.99*tAxis(1)+0.01*tAxis(2), ...
    fAxis(1)+0.9*(fAxis(2)-fAxis(1)), ...
    'wide-band spectrogram', 'FontSize', 14, 'FontWeight', 'bold')

