clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Calculate the temporal window
A = 1.9;
j = 0.49;
tw = 0.0061;
s = 400;
sampleFrequency = 10000; % Hz
dt = 1/sampleFrequency;
endT = 0.02;
t = dt:dt:endT;
ti1 = find(t<tw-pi/(2*s));
ti2 = find(t>=tw-pi/(2*s) & t<tw+pi/(2*s));
ti3 = find(t>=tw+pi/(2*s));
wd(ti1) = 1;
wd(ti2) = 0.5-0.5*sin(s*(t(ti2)-tw));
wd(ti3) = 0;
wi = 1-wd;

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = 240; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 90; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the position of the panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the temporal window
axes('Position', pos)
dXTick = 0.0025;
xTick = 0:dXTick:endT;
set(gca, 'Box', 'on', 'LineWidth', 2, ...
    'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'XTick', xTick, 'XTickLabel', round(1000*xTick, 1), ...
    'YTick', 0:0.25:1, ...
    'FontSize', 14, 'Fontweight', 'bold')
plot(t, wd, 'LineWidth', 2, 'Color', blueGreen)
plot(t, wi, '--', 'LineWidth', 1, 'Color', blueGreen)
plot([tw tw], [-0.1 1.1], 'Color', blueGreen)
plot([t(1) t(end)], [0 0], 'Color', blueGreen)
xlabel('time (ms)', 'FontWeight', 'bold', 'FontSize', 18)
ylabel('weight', 'FontWeight', 'bold', 'FontSize', 18)
text(tw-0.0006, 0.1, '{\it t_w} = 6.1 ms', ...
    'FontSize', 12, 'FontWeight', 'bold')
text(0.0031, 0.8, 'direct', 'FontSize', 12, 'FontWeight', 'bold')
text(0.0080, 0.8, 'indirect', 'FontSize', 12, 'FontWeight', 'bold')
axis([0 endT -0.1 1.1])

