clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define and calculate the stimuli
sampleFrequency = 44100; % Hz
dt = 1/sampleFrequency;
durationStim = 1.0; % sec
t = dt:dt:durationStim;
ampTone = 0.9;
sdNoise = 0.3;
f0 = 880; % Hz
fade = 0.01;
delay = 0.01;
tEnvLeft = [0 fade fade+fade durationStim-fade durationStim];
tEnvRight = [0 delay delay+fade durationStim-fade durationStim];
aEnvLeft = [0 ampTone 0 0 0];
aEnvRight = [0 0 ampTone 0 0];
for k = 1:length(tEnvLeft)-1
    a0 = (aEnvLeft(k+1)-aEnvLeft(k))/(tEnvLeft(k+1)-tEnvLeft(k));
    a1 = aEnvLeft(k)-a0*tEnvLeft(k);
    i1 = floor(tEnvLeft(k)/dt)+1;
    i2 = floor(tEnvLeft(k+1)/dt);
    envLeft(i1:i2) = a0*t(i1:i2)+a1;
end
for k = 1:length(tEnvRight)-1
    a0 = (aEnvRight(k+1)-aEnvRight(k))/(tEnvRight(k+1)-tEnvRight(k));
    a1 = aEnvRight(k)-a0*tEnvRight(k);
    i1 = floor(tEnvRight(k)/dt)+1;
    i2 = floor(tEnvRight(k+1)/dt);
    envRight(i1:i2) = a0*t(i1:i2)+a1;
end
tone = sin(2*pi*f0*t);
noise = sdNoise*randn(size(t)); % Franssen effect does not work with noise
stimulusLeft = [envLeft.*tone envLeft.*noise];
stimulusRight = [envRight.*tone envRight.*noise];
stimulus = [stimulusLeft' stimulusRight'];

% Save and play the stimumus
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = [90 90]; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 70; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Calculate the plot parameters
dXTick = 0.25; % sec
tAxis = [-dXTick/2 2*durationStim+dXTick/2];
yAxis = [-1.1 1.1];
durationStimulus = size(stimulus, 1)*dt; % sec
xTick = 0:dXTick:durationStimulus;

% Plot the left-hand noise sound
axes('Position', pos(2,:))
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
    'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', xTick, 'XTickLabel', [], 'YTick', -1:1)
plot([t t+durationStim], stimulusLeft, ...
    'Color', blueGreen, 'LineWidth', 1.5);
plot([tAxis(1) tAxis(2)], [0 0], 'Color', blueGreen, 'LineWidth', 1);
plot([0 0], yAxis, 'Color', blueGreen, 'LineWidth', 1)
plot([durationStim durationStim], yAxis, ...
    'Color', blueGreen, 'LineWidth', 1)
axis([tAxis -1.1 1.1])
ylabel('left')

% Plot the right-hand noise sound
axes('Position', pos(1,:))
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
    'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', xTick, 'XTickLabel', xTick, 'YTick', -1:1)
plot([t t+durationStim], stimulusRight, ...
    'Color', blueGreen, 'LineWidth', 1.5);
plot([tAxis(1) tAxis(2)], [0 0], 'Color', blueGreen, 'LineWidth', 1);
plot([0 0], yAxis, 'Color', blueGreen, 'LineWidth', 1)
plot([durationStim durationStim], yAxis, ...
    'Color', blueGreen, 'LineWidth', 1)
axis([tAxis -1.1 1.1])
xlabel('time (s)', 'FontWeight', 'bold')
ylabel('right')


