clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Calculate the power law for a number of distances
% Values for k and a are based on Zahoric (2002a).
k = 1.32;
a = 0.39;
actDist = logspace(log10(0.1), log10(200), 8);
horizon = 15; % auditory horizon set at 15 m
asymptote = k*horizon^a;
percDist = min(k*actDist.^a, asymptote);
logPercDist = log10(percDist);
% low pass filter to get a gradual transition from power law to asymptote
h = [1 2 1]/4;
logPercDist = ...
    [logPercDist(1) conv(logPercDist, h, 'valid') logPercDist(end)];
actualDistInterp = logspace(log10(0.1), log10(200), 400);
logActualDistInterp = log10(actualDistInterp);
logActualDist = log10(actDist);
logPercDistInterp = ...
    spline(logActualDist, logPercDist, logActualDistInterp);
percDistInterp = 10.^(logPercDistInterp);
% Data estimated from Strybel and Perrott (1984) Figure 1
varStrybelPer = [0.49 1.52 3.04 6.09 12.19 24.38 48.76];
weberFraction = [0.19 0.11 0.09 0.06 0.06 0.06 0.06];
logWeberFraction = log10(weberFraction);
weberInterp = interp1(varStrybelPer, weberFraction, actualDistInterp, ...
    'linear', 'extrap');
dUpp = percDistInterp.*(1+0.5*weberInterp);
dLow = percDistInterp./(1+0.5*weberInterp);
logDUpp = log10(dUpp);
logDLow = log10(dLow);
var = 2; % based on Zahorik (2002b)
varUpp = percDistInterp*(1+0.5*var);
varLow = percDistInterp/(1+0.5*var);
logVarUpp = log10(varUpp);
logVarLow = log10(varLow);

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 480; % pixels
panelHeights = 300; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 70; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the position of the panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the functions
axes('Position', pos)
dTick = [0.1 0.2 0.5 1 2 5 10 20 50 100 200];
logDTick = log10(dTick);
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
        'Box', 'on', 'Color', lightYellowGreen, 'NextPlot', 'add', ...
        'FontWeight', 'bold', 'TickDir', 'out', ...
        'Xtick', logDTick, 'XtickLabel', dTick, ...
        'Ytick', logDTick, 'YtickLabel', dTick)
plot(logActualDistInterp, log10(percDistInterp), ...
    'LineWidth', 2, 'Color', blueGreen)
plot(logActualDistInterp, logDUpp, 'Color', blueGreen)
plot(logActualDistInterp, logDLow, 'Color', blueGreen)
plot(logActualDistInterp, logDUpp, 'Color', blueGreen)
plot(logActualDistInterp, logDLow, 'Color', blueGreen)

dDots = 0.015;
for k = 1:8:length(logActualDistInterp)
    nDots = 0.5*(logVarUpp(k)-logVarLow(k))/dDots;
    xx = linspace(logActualDistInterp(k), logActualDistInterp(k), nDots);
    yy = linspace(logVarLow(k), logVarUpp(k), nDots);
    plot(xx, yy, '.', 'MarkerSize', 3, 'MarkerEdgeColor', 'k')
end
dDots = 0.005;
for k = 1:3:length(logActualDistInterp)
    nDots = (logDUpp(k)-logDLow(k))/dDots;
    xx = linspace(logActualDistInterp(k), logActualDistInterp(k), nDots);
    yy = linspace(logDLow(k), logDUpp(k), nDots);
    plot(xx, yy, '.', 'MarkerSize', 3, 'MarkerEdgeColor', 'k')
end
plot(logActualDist, logActualDist, '--', ...
    'LineWidth', 1, 'Color', blueGreen)
axis([log10(0.2/1.2) log10(120) ...
    log10(0.44) log10(1.5*asymptote)])
xlabel('actual distance (m)', 'FontSize', 14)
ylabel('perceived distance (m)', 'FontSize', 14)

