clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position of figure in pixels from bottom
panelWidth = [400 400]; % pixels
panelHeights = 400; % pixels
xLabelHeight = 15; % pixels
yLabelWidth = 15; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Specify the parameters of the figure
r = 0.3; % radius of head
n = 100; % number of points on the circle
th = pi/5; % azimuth in radians
d = 4; % maximum length of drawn lines
c = [-0.3 -0.3]; % center of head
le = [c(1)-r c(2)]; % location of left ear
re = [c(1)+r c(2)]; % location of right ear

% Plot the left panel
panel = 1;
axes('Position', pos(panel,:))
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
    'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', [], 'YTick', [])
plot(c(1), c(2), 'k.', 'MarkerSize', 12)
leftEar = CalcCircle(le, r/4, 0, n);
rightEar = CalcCircle(re, r/4, 0, n);
patch(leftEar(1,:), leftEar(2,:), [0.7 0.7 0.7])
patch(rightEar(1,:), rightEar(2,:), [0.7 0.7 0.7])
s = [re(1)-2*r*cos(th)*cos(th) re(2)+2*r*sin(th)*cos(th)];
plot(s(1), s(2), 'k.', 'MarkerSize', 12) % Mark the center of the head
% Plot the various distances
plot([re(1) s(1)], [re(2) s(2)], 'k', 'LineWidth', 0.5)
plot([le(1) s(1)], [le(2) s(2)], 'Color', red, 'LineWidth', 2)
% Plot the asymptotes of the hyperbola
% plot([c(1) c(1)+d*sin(th)*sin(th)], [c(2) c(2)+d*sin(th)*cos(th)], ...
%     '--k', 'LineWidth', 0.5)
% plot([c(1) c(1)+d*sin(th)*sin(th)], [c(2) c(2)-d*sin(th)*cos(th)], ...
%     '--k', 'LineWidth', 0.5)
plot([le(1) re(1)], [le(2) re(2)],  'k', 'LineWidth', 0.5)
plot([c(1) c(1)], [c(2) c(2)+d],  'k', 'LineWidth', 0.5)
% Plot the arrows and the lines from the source
pArr = [1.1 0.7];
arrow = CalcArrow(...
    [re(1)+pArr(1)*sin(th) re(2)+pArr(1)*cos(th)], ...
    [re(1)+pArr(2)*sin(th) re(2)+pArr(2)*cos(th)], 0.2, pi/9);
plot(arrow(1,:), arrow(2,:), 'k', 'LineWidth', 0.5)
arrow = CalcArrow(...
    [s(1)+pArr(1)*sin(th) s(2)+pArr(1)*cos(th)], ...
    [s(1)+pArr(2)*sin(th) s(2)+pArr(2)*cos(th)], 0.2, pi/9);
plot(arrow(1,:), arrow(2,:), 'k', 'LineWidth', 0.5)
plot([s(1) s(1)+d*sin(th)], [s(2) s(2)+d*cos(th)], ...
    'k', 'LineWidth', 0.5)
plot([re(1) re(1)+d*sin(th)], [re(2) re(2)+d*cos(th)], ...
    'k', 'LineWidth', 0.5)
% Plot the axis between the ears
plot([le(1) re(1)], [le(2) re(2)],  'k', 'LineWidth', 0.5)
text(c(1)+0.03, c(2)+0.52, '\theta', ...
    'FontSize', 15, 'HorizontalAlignment', 'center')
text(c(1)-0.15, c(2)-0.03, '{\it r}', ...
    'FontSize', 15, 'HorizontalAlignment', 'center')
mk = mean([le; s]);
text(mk(1)-0.125, mk(2)+0.125, '2{\it r} \rm{sin}(\theta)', ...
    'FontSize', 15, 'HorizontalAlignment', 'center')
% Plot the arrows from 2*r*sin(th)
arrow = CalcArrow([mk(1)-0.1 mk(2)+0.06], ...
    [mk(1) mk(2)], 0.3, pi/9);
plot(arrow(1,:), arrow(2,:), 'k', 'LineWidth', 0.5)
% Plot the hyperbola
a = r*cos(th);
b = r*sin(th);
t = -5:0.01:5;
x = b*cosh(t)+c(1);
y = a*sinh(t)+c(2);
plot(x, y, 'LineWidth', 1.5, 'Color', blueGreen)
axis([-0.9 0.9 -0.9 0.9])

% Plot the right panel
panel = panel+1;
axes('Position', pos(panel,:))
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
    'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', [], 'YTick', [])
% Calculate and plot the head, the ears, and the nose
head = CalcCircle(c, r, 0, n);
leftEar = CalcCircle(le, r/4, 0, n);
rightEar = CalcCircle(re, r/4, 0, n);
nose = CalcCircle([c(1) c(2)+r], r/3, pi/2, 3);
plot(head(1,:), head(2,:), 'k', 'LineWidth', 2)
patch(leftEar(1,:), leftEar(2,:), [0.7 0.7 0.7])
patch(rightEar(1,:), rightEar(2,:), [0.7 0.7 0.7])
patch(nose(1,:), nose(2,:), [0.7 0.7 0.7])
patch(head(1,:), head(2,:), [0.7 0.7 0.7])
plot(c(1), c(2), 'k.', 'MarkerSize', 12)
s = [c(1)-r*cos(th) c(2)+r*sin(th)];
p = [s(1)+r*sin(th)*sin(th) s(2)+r*sin(th)*cos(th)];
plot(s(1), s(2), 'k.', 'MarkerSize', 12)
plot(p(1), p(2), 'k.', 'MarkerSize', 12)
plot([s(1) s(1)+d*sin(th)], [s(2) s(2)+d*cos(th)], ...
    'k', 'LineWidth', 0.5)
plot([c(1) c(1)+r*sin(th)*sin(th)], [c(2) c(2)+r*sin(th)*cos(th)], ...
    'k', 'LineWidth', 0.5)
pArr = [1.1 0.7];
arrow = CalcArrow(...
    [re(1)+pArr(1)*sin(th) re(2)+pArr(1)*cos(th)], ...
    [re(1)+pArr(2)*sin(th) re(2)+pArr(2)*cos(th)], 0.2, pi/9);
plot(arrow(1,:), arrow(2,:), 'k', 'LineWidth', 0.5)
arrow = CalcArrow(...
    [p(1)+pArr(1)*sin(th) p(2)+pArr(1)*cos(th)], ...
    [p(1)+pArr(2)*sin(th) p(2)+pArr(2)*cos(th)], 0.2, pi/9);
plot(arrow(1,:), arrow(2,:), 'k', 'LineWidth', 0.5)
plot([re(1) re(1)+d*sin(th)], [re(2) re(2)+d*cos(th)], ...
    'k', 'LineWidth', 0.5)
plot([c(1) s(1)], [c(2) s(2)], 'k', 'LineWidth', 0.5)
plot([le(1) re(1)], [le(2) re(2)],  'k', 'LineWidth', 0.5)
plot([re(1) p(1)], [re(2) p(2)],  'k', 'LineWidth', 0.5)
% Plot the line segments of r*th and r*sin(th) in red
plot([s(1) s(1)+r*sin(th)*sin(th)], [s(2) s(2)+r*sin(th)*cos(th)], ...
    'LineWidth', 2, 'Color', red)
k = [round((pi-th)/(2*pi)*n)+2 round(n/2)+1];
for j = k(1):k(2)
    plot([head(1,j-1) head(1,j)], [head(2,j-1) head(2,j)], ...
        'LineWidth', 2, 'Color', red)
end
% Calculate and plot the arrows to the line segments at hand
text(c(1)-0.15, c(2)-0.03, '{\it r}', ...
    'FontSize', 15, 'HorizontalAlignment', 'center')
text(re(1)-0.14, re(2)+0.05, '\theta', ...
    'FontSize', 15, 'HorizontalAlignment', 'center')
mk = round(mean(k));
text(head(1,mk)-0.125, head(2,mk)+0.125, '{\it r} \theta', ...
    'FontSize', 15, 'HorizontalAlignment', 'center')
arrow = CalcArrow([head(1,mk)-0.1 head(2,mk)+0.06], ...
    [head(1,mk-2) head(2,mk-2)], 0.3, pi/9);
plot(arrow(1,:), arrow(2,:), 'k', 'LineWidth', 0.5)
mk(1) = 0.67*s(1)+0.33*(s(1)+r*sin(th)*sin(th));
mk(2) = 0.67*s(2)+0.33*(s(2)+r*sin(th)*cos(th));
text(mk(1)-0.125, mk(2)+0.125, '{\it r} \rm{sin}(\theta)', ...
    'FontSize', 15, 'HorizontalAlignment', 'center')
arrow = CalcArrow([mk(1)-0.1 mk(2)+0.06], ...
    [mk(1) mk(2)], 0.3, pi/9);
plot(arrow(1,:), arrow(2,:), 'k', 'LineWidth', 0.5)
axis([-0.9 0.9 -0.9 0.9])

