clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% This script reproduces the equal loudness contours calculated
% according to Moore, Glasberg, & Baer (1997), p. 232, Fig. 13.

% Calculate the loudness functions from z_min to z_max
I_ref = 1.0e-12;
z_min = Hz2ERB(50);
z_max = Hz2ERB(20000);
dz = 0.1;
z = z_min:dz:z_max;
I_dB = -10:120;
f_ref = 1000; % Hz
loudness = zeros(size(I_dB));
for k = 1:length(I_dB)
    I = I_ref*10.^(I_dB(k)/10);
    [~, specificLoudness] = ...
        CalcLoudnessFunctions(f_ref, I, z, 1, 1);
    loudness(k) = sum(specificLoudness)*dz;
end

% Interpolate the loundess for loudness levels 0:10:120
cL = 0:10:120;
loudnessLevels = interp1(I_dB, loudness, cL);
f = logspace(log10(20), log10(15000), 100);
elc = zeros(length(0:10:120), length(f));
for i = 1:length(f)
    loudness = zeros(size(I_dB));
    for k = 1:length(I_dB)
        I = I_ref*10.^(I_dB(k)/10);
        [~, specificLoudness] = ...
            CalcLoudnessFunctions(f(i), I, z, 1, 1);
        loudness(k) = sum(specificLoudness)*dz;
    end
    elc(:, i) = interp1(loudness, I_dB, loudnessLevels);
end

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 600; % pixels
panelHeights = 500; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 70; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the equal-loudness contours
axes('Position', pos)
xTick = [20 50 100 200 500 1000 2000 5000 10000 20000];
set(gca, 'Box', 'on', 'LineWidth', 2, ...
    'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'XTick', log10(xTick), 'XTickLabel', xTick/1000, ...
    'YTick', -20:20:120, ...
    'FontSize', 14, 'Fontweight', 'bold', 'TickDir', 'out')
for j = 1:size(elc, 1)
    plot(log10(f), elc(j, :), ...
        'LineWidth', 2,  'Color', blueGreen)
    text(log10(1000), cL(j), ...
        sprintf('%3.0f', cL(j)), 'FontSize', 12, ...
        'Fontweight', 'bold')
end
xlabel('frequency (kHz)', 'FontSize', 14, 'Fontweight', 'bold')
ylabel('level (dB)', 'FontSize', 14, 'Fontweight', 'bold')
axis([log10(20) log10(20000) -20 125])


