clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Calculate the loudness of the tones
I_ref = 1.0e-12;
f = 1000; % Hz
z_min = 3;
z_max = Hz2ERB(20000);
dz = 0.1;
z = z_min:dz:z_max;
I_dB = 0:120;
loudness = zeros(size(I_dB));
for k = 1:length(I_dB)
    I = I_ref*10.^(I_dB(k)/10);
    [~, specificLoudness] = ...
        CalcLoudnessFunctions(f, I, z, 1, 1);
    loudness(k) = sum(specificLoudness)*dz;
end

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = 400; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 90; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the loudness of the tones as a function of their intensity
axes('Position', pos)
xTick = 0:20:120;
yTick = -3:3;
xAxis = [I_dB(1) I_dB(end)];
yAxis = [-3 3]; % log sone
set(gca, 'Box', 'on', 'LineWidth', 2, ...
    'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'XTick', xTick, 'XTickLabel', xTick, ...
    'YTick', yTick, 'YTickLabel', 10.^yTick, ...
    'FontSize', 14, 'Fontweight', 'bold')
plot(I_dB, log10(loudness), 'LineWidth' , 2, 'Color', blueGreen)
plot(I_dB, log10(2.^((I_dB-40)/10)), '--', 'Color', blueGreen);
plot([0 40 40],[0 0 -3], 'Color', blueGreen)
xlabel('intensity level (dB)')
ylabel('estimated loudness (sone)')
axis([xAxis yAxis])


