clear
clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Calculate the stimulus
sampleFrequency = 44100; % Hz
dt = 1/sampleFrequency;
% I_ref is the intensity in W/m2 corresponding to 0 db SIL
I_ref = 1.0e-12; 
% Calculate the envelope of the series of tones
I_dB_min = 50; % minimum of ramp at start in dB
I_dB_max = 60; % maximum of ramp at thee end in dB
toneDuration = 0.2;
toneInterval = 0.2;
f = 1000; % Hz % frequency of tone in Hz
tTone = dt:dt:toneDuration;
tInterval = dt:dt:toneInterval;
fade = 0.02; % sec
toneEnvelope = FadeInOut(ones(size(tTone)), ...
    sampleFrequency, fade, fade);
interval = zeros(size(tInterval));
nrOfTones = 20;
I_tones = interval;
for k = 1:nrOfTones
    I_tones = ...
        [I_tones toneEnvelope interval]; %#ok<AGROW>
end
I_tones = I_ref*I_tones*(10^6);
duration = dt*length(I_tones); % sec

% Calculate the envelope of the ramp
% turning points tp of envelope in time
t_turningPoints = [0 0.1 0.9 1]*duration;
% intensity of envelope Ip_dB in dB at time tp
I_turningPoints_dB = [I_dB_min I_dB_min I_dB_max I_dB_max];
t = dt:dt:duration;
I_ramp_dB = zeros(size(I_tones));
ti1 = 1;
for k = 2:length(t_turningPoints)
    ti2 = floor(t_turningPoints(k)/dt);
    dI_dB = I_turningPoints_dB(k)-I_turningPoints_dB(k-1);
    ds = t_turningPoints(k)-t_turningPoints(k-1);
    for i = ti1:ti2
        I_ramp_dB(i) = ...
            (dI_dB/ds)*(t(i)-t_turningPoints(k-1)) + ...
            I_turningPoints_dB(k-1);
    end
    I_ramp(ti1:ti2) = I_ref*10.^(I_ramp_dB(ti1:ti2)/10);
    ti1 = ti2+1;
end
while length(I_ramp) < length(I_tones)
    I_ramp(end+1) = I_tones(end); %#ok<*SAGROW>
end
I_stimulus = max(I_tones, I_ramp);
% Calculate the pure tone and multiply it with the envelope
stimulus = sqrt(I_stimulus/max(I_stimulus)).*sin(2*pi*f*t);
stimulus = FadeInOut(stimulus, sampleFrequency, fade, fade);

wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, 0.2*stimulus, sampleFrequency)
sound(0.2*stimulus, sampleFrequency)

% Calculate the partial loudness of the tones relative 
% to the ramp for every frame duration, i.e., every 0.01 second
frameDuration = 0.01; % sec
samplesInFrame = 0.01*sampleFrequency;
dz = 0.1;
z = 1.8:dz:39;
nrOfFrames =  floor(duration/frameDuration);
partialLoudness_tones = zeros(1, nrOfFrames);
partialLoudness_ramp = zeros(1, nrOfFrames);
loudness_ramp = zeros(1, nrOfFrames);
loudness_tones = zeros(1, nrOfFrames);
I_t = zeros(1, nrOfFrames);
I_n = zeros(1, nrOfFrames);
I_s = zeros(1, nrOfFrames);
frameTimes = zeros(1, nrOfFrames);
i = 1;
for k = 1:nrOfFrames
    I_t(k) = I_stimulus(i);
    I_n(k) = I_ramp(i);
    I_s(k) = I_stimulus(i)-I_ramp(i);
    [~, specificLoudness] = ...
        CalcLoudnessFunctions(f, ...
        I_t(k), z, 1, 1);
    loudness(k) = sum(specificLoudness)*dz;
    [~, specificLoudness] = ...
        CalcLoudnessFunctions(f, ...
        I_n(k), z, 1, 1);
    loudness_ramp(k) = sum(specificLoudness)*dz;
    [~, specificLoudness] = ...
        CalcLoudnessFunctions(f, ...
        I_s(k), z, 1, 1);
    loudness_tones(k) = sum(specificLoudness)*dz;
    [~, ~, partialSpecificLoudness] = ...
        CalcPartialLoudnessFunctions(f, ...
        I_n(k), I_t(k), z, 1, 1);
    partialLoudness_tones(k) = sum(partialSpecificLoudness)*dz;
    [~, ~, partialSpecificLoudness] = ...
        CalcPartialLoudnessFunctions(f, ...
        I_s(k), I_t(k), z, 1, 1);
    partialLoudness_ramp(k) = sum(partialSpecificLoudness)*dz;
    i = i+samplesInFrame;
    frameTimes(k) = (k-1)*frameDuration;
end

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = [100 120 100 120 100 120]; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 70; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the estimated loudness and partial loudness of the ramp
panel = 1;
axes('Position', pos(panel,:))
yt = -2:2-eps; % Y ticks in dB
set(gca, 'Box', 'on', 'LineWidth', 2, ...
    'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'TickDir', 'out', ...
    'XTick', 0:2:duration, 'XtickLabel', 0:2:duration, ...
    'YTick', yt, 'YtickLabel', 10.^yt, ...
    'FontSize', 12, 'Fontweight', 'bold')
log10pL = log10(partialLoudness_ramp);
plot(frameTimes, max(-3, log10pL), ...
    'LineWidth', 0.5, 'Color', blueGreen)
plot(frameTimes, log10(loudness_ramp), ...
    'LineWidth', 2, 'Color', red)
axis([0 duration -2 1.8]);
xlabel('time (s)')
ylabel('sone')
text(0.05, 1.3, 'f. estimated loudness of ramp', ...
    'FontSize', 12, 'Fontweight', 'bold', 'Color', red)
text(4.05, 1.3, 'estimated partial loudness of ramp', ...
    'FontSize', 10, 'Color', blueGreen)

% Plot the intensity of the ramp
panel = panel+1;
axes('Position', pos(panel,:))
yt = 0:5:100; % Y ticks in dB
set(gca, 'Box', 'on', 'LineWidth', 2, ...
    'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'TickDir', 'out', ...
    'XTick', 0:2:duration, 'XtickLabel', [], ...
    'YTick', yt, 'YtickLabel', yt, ...
    'FontSize', 12, 'Fontweight', 'bold')
plot(t, 10*log10(I_ramp/I_ref), ...
    'LineWidth', 2, 'Color', blueGreen)
axis([0 duration I_dB_min-2.2 I_dB_max+5]);
ylabel('dB')
text(0.05, 63, 'e. intensity of ramp', ...
    'FontSize', 12, 'Fontweight', 'bold', 'Color', blueGreen)

% Plot the estimated loudness and partial loudness of the tones
panel = panel+1;
axes('Position', pos(panel,:))
yt = -2:2-eps; % Y ticks in dB
set(gca, 'Box', 'on', 'LineWidth', 2, ...
    'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'TickDir', 'out', ...
    'XTick', 0:2:duration, 'XtickLabel', [], ...
    'YTick', yt, 'YtickLabel', 10.^yt, ...
    'FontSize', 12, 'Fontweight', 'bold')
plot(frameTimes, max(-3, log10(partialLoudness_tones)), ...
    'LineWidth', 2, 'Color', red)
plot(frameTimes, max(-3, log10(loudness_tones)), ...
    'LineWidth', 0.5, 'Color', blueGreen)
axis([0 duration -2 1.8]);
ylabel('sone')
text(0.05, 1.3, 'd. estimated loudness of tones', ...
    'FontSize', 10, 'Color', blueGreen)
text(4.05, 1.3, ...
    'estimated partial loudness of tones', ...
    'FontSize', 12, 'Fontweight', 'bold', 'Color', red)

% Plot the intensity of the tones
panel = panel+1;
axes('Position', pos(panel,:))
yt = 0:5:100; % Y ticks in dB
set(gca, 'Box', 'on', 'LineWidth', 2, ...
    'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'TickDir', 'out', ...
    'XTick', 0:2:duration, 'XtickLabel', [], ...
    'YTick', yt, 'YtickLabel', yt, ...
    'FontSize', 12, 'Fontweight', 'bold')
plot(t, 10*log10((I_stimulus-I_ramp)/I_ref), ...
    'LineWidth', 2, 'Color', blueGreen)
axis([0 duration I_dB_min-2.2 I_dB_max+5]);
ylabel('dB')
text(0.05, 63, 'c. intensity of tones', ...
    'FontSize', 12, 'Fontweight', 'bold', 'Color', blueGreen)

% Plot the  loudness of the stimulus
panel = panel+1;
axes('Position', pos(panel,:))
yt = -2:2-eps; % Y ticks in dB
set(gca, 'Box', 'on', 'LineWidth', 2, ...
    'NextPlot', 'add', 'Color', lightYellowGreen, 'TickDir', 'out', ...
    'XTick', 0:2:duration, 'XtickLabel', [], ...
    'YTick', yt, 'YtickLabel', 10.^yt, ...
    'FontSize', 12, 'Fontweight', 'bold')
plot(frameTimes, max(-3, log10(loudness)), ...
    'LineWidth', 0.5, 'Color', blueGreen)
axis([0 duration -2 1.8]);
ylabel('sone')
text(0.05, 1.3, 'b. estimated loudness', ...
    'FontSize', 10, 'Color', blueGreen)

% Plot the  intensity of the stimulus
panel = panel+1;
axes('Position', pos(panel,:))
yt = 0:5:100; % Y ticks in dB
set(gca, 'Box', 'on', 'LineWidth', 2, ...
    'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'TickDir', 'out', ...
    'XTick', 0:2:duration, 'XtickLabel', [], ...
    'YTick', yt, 'YtickLabel', yt, ...
    'FontSize', 12, 'Fontweight', 'bold')
plot(t, 10*log10(I_stimulus/I_ref), ...
    'LineWidth', 2, 'Color', blueGreen)
axis([0 duration I_dB_min-2.2 I_dB_max+5]);
ylabel('dB')
text(0.05, 63, 'a. intensity of stimulus', ...
    'FontSize', 12, 'Fontweight', 'bold', 'Color', blueGreen)


