clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define and synthesize the stimulus
sampleFrequency = 10000; % Hz
dt = 1/sampleFrequency;
durationNoise = 0.20; % sec
t = dt:dt:durationNoise;
durationInterval = 0.05; % sec
durationPause = 2; % sec
durationPadding = 0.05; % sec
interval = zeros(size(dt:dt:durationInterval));
pause = zeros(size(dt:dt:durationPause));
padding = zeros(size(dt:dt:durationPadding));
fade = 0.02; % sec
steps = [0.5 1 3 6]; % dB
n = 25; % Nr of noise bursts. Must be odd.
d = [ones(1, (n-1)/2) -ones(1, (n-1)/2)];
stimulus = zeros(length(steps), length(d)*(length(t)+length(interval)));
amplitude = zeros(size(d));
amplitude(1) = 0.05;
% Calculate the bandpassfilter
centreFrequency = 1760;
bandWidth = 2;
c = 2*centreFrequency/sampleFrequency;
w1 = c*2^(-bandWidth/2);
w2 = c*2^(bandWidth/2);
[b, a] = butter(4, [w1 w2]);
for k = 1:length(steps)
    nrDB = 10.^(steps(k)/20);
    d = d(randperm(length(d)));
    for i = 1:n-1
        amplitude(i+1) = nrDB.^d(i)*amplitude(i);
    end
    stim = [];
    for amp = amplitude
        noise = randn(size(t));
        noise = filter(b, a, noise);
        noise = FadeInOut(noise, sampleFrequency, fade, fade);
        stim =  [stim amp*noise interval]; %#ok<AGROW>
    end
    stimulus(k, 1:1+length(stim)-1) = stim;
    stimulus(k, 1+length(stim):1+length(stim)+length(pause)-1) = pause;
end
% Save and play the sound segment
s = stimulus';
s = s(:);
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, s, sampleFrequency)
sound(s, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = ones(size(steps))*120; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 70; % pixelsPlotSpectrogram
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the spectrograms
dXTick = 1; % sec
dYTick = 1; % kHz
maxYAxis = 5000; % Hz
durationStimulus = length(stim)*dt; % sec
xTick = -dXTick:dXTick:durationStimulus;
tAxis = [-0.2*dXTick durationStimulus+0.2*dXTick];
fAxis = [-20 maxYAxis+20];
for st = 1:length(steps)
    axes('Position', pos(st,:))
    nFft = 1024;
    nWindow = 512;
    nOverlap = nWindow-16;
    k = length(steps)-st+1;
    [~, f, ts, p] = spectrogram([padding stimulus(k,:) padding], ...
        nWindow, nOverlap, nFft, sampleFrequency);
    p = 10*log10(abs(p));
    ts = ts-durationPadding;
    PlotSpectrogram(stim, sampleFrequency, ...
        f, ts, p, tAxis, dXTick, fAxis, dYTick, 40, ...
        frameColor)
    set(gca, 'Color', lightYellowGreen)
    text(0.99*tAxis(1)+0.01*tAxis(2), fAxis(1)+0.9*(fAxis(2)-fAxis(1)), ...
        sprintf('%10.1g dB', steps(k)), 'FontSize', 14, 'FontWeight', 'bold')
    if st == 1
        set(gca, 'XTick', xTick, 'XTickLabel', xTick)
        xlabel('time (s)')
    else
        set(gca, 'XTick', xTick, 'XTickLabel', [])
    end
    ylabel('freq. (kHz)')
end


