clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% This script reproduces the equal loudness contours calculated 
% with EqualLoudnessContours_ISO226.

cL = 0:10:90;
[elc(1,:), freq] = EqualLoudnessContours_ISO226(cL(1));
for k = 2:length(cL)
    elc(k,:) = EqualLoudnessContours_ISO226(cL(k));
end
% Interpolate the equal loudness contours
f = logspace(log10(20), log10(12500), 97);
elcInt = zeros(length(cL), length(f));
for k = 1:length(cL)
    elcInt(k,:) = spline(freq, elc(k,:), f);
end

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 600; % pixels
panelHeights = 500; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 80; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the equal-loudness contours
axes('Position', pos)
xTick = [20 50 100 200 500 1000 2000 5000 10000 20000];
set(gca, 'Box', 'on', 'LineWidth', 2, ...
    'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'XTick', log10(xTick), 'XTickLabel', xTick/1000, ...
    'YTick', -20:20:120, ...
    'FontSize', 14, 'Fontweight', 'bold', 'TickDir', 'out')
for j = 1:size(elc, 1)
    plot(log10(f), elcInt(j, :), ...
        'LineWidth', 2,  'Color', blueGreen)
    text(log10(1000), cL(j), ...
        sprintf('%3.0f', cL(j)), 'FontSize', 12, ...
        'Fontweight', 'bold', 'HorizontalAlignment', 'center')
end
xlabel('frequency (kHz)', 'FontSize', 14, 'Fontweight', 'bold')
ylabel('level (dB)', 'FontSize', 14, 'Fontweight', 'bold')
axis([log10(20) log10(15000) -20 125])


