% % copyright statement
% % overview

% PSS/mScripts/loudness_KFiltering.m

clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Calculate the dBA filter coefficients
sampleFrequency = 48000; % Hz
a1 = [1 -1.69065929318241 0.73248077421585];
b1 = [1.53512485958697 -2.69169618940638 1.19839281085285];
a2 = [1 -1.99004745483398 0.9900722503662];
b2 = [1 -2 1];
aK = conv(a1, a2);
bK = conv(b1,b2);

n = 512;
fMin = 10;
fMax = sampleFrequency/2;
freq = logspace(log10(fMin), log10(fMax), n);
spc1 = freqz(b1, a1, 2*pi*freq/sampleFrequency);
spc2 = freqz(b2, a2, 2*pi*freq/sampleFrequency);
spc = freqz(bK, aK, 2*pi*freq/sampleFrequency);

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = [150 150 150]; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 90; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the position of the panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Define the plot parameters
xTick = [10 20 50 100 200 500 1000 2000 5000 10000 20000];
yTick = -100:10:0;

% Plot the transfer function
panel = 1;
axes('Position', pos(panel,:))
set(gca, 'Box', 'on', 'LineWidth', 2, ...
    'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'XTick', log10(xTick), 'XTickLabel', xTick/1000, ...
    'YTick', yTick, 'YTickLabel', yTick, ...
    'FontSize', 14, 'Fontweight', 'bold')
plot(log10(freq), 20*log10(abs(spc)), '.', ...
    'LineWidth', 2, 'Color', blueGreen);
plot([log10(fMin) log10(fMax)], [0 0], 'k')
xlabel('frequency (kHz)');
ylabel('transfer (dB)');
text(log10(12), 5, 'K-filter', 'FontSize', 14, 'Fontweight', 'bold')
axis([log10(10) log10(fMax) -30 10]);

panel = panel+1;
axes('Position', pos(panel,:))
set(gca, 'Box', 'on', 'LineWidth', 2, ...
    'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'XTick', log10(xTick), 'XTickLabel', [], ...
    'YTick', yTick, 'YTickLabel', yTick, ...
    'FontSize', 14, 'Fontweight', 'bold')
plot(log10(freq), 20*log10(abs(spc2)), '-', ...
    'LineWidth', 2, 'Color', blueGreen);
plot([log10(fMin) log10(fMax)], [0 0], 'k')
ylabel('transfer (dB)');
text(log10(12), 5, 'second filter', 'FontSize', 14, 'Fontweight', 'bold')
axis([log10(10) log10(fMax) -30 10]);

panel = panel+1;
axes('Position', pos(panel,:))
set(gca, 'Box', 'on', 'LineWidth', 2, ...
    'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'XTick', log10(xTick), 'XTickLabel', [], ...
    'YTick', yTick, 'YTickLabel', yTick, ...
    'FontSize', 14, 'Fontweight', 'bold')
plot(log10(freq), 20*log10(abs(spc1)), ...
    'LineWidth', 2, 'Color', blueGreen);
plot([log10(fMin) log10(fMax)], [0 0], 'k')
ylabel('transfer (dB)');
text(log10(12), 5, 'first filter', 'FontSize', 14, 'Fontweight', 'bold')
axis([log10(10) log10(fMax) -30 10]);
