clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% The data have been taken from Figure 20 of Fletcher (1940)
% "Auditory patterns" Reviews of Modern Physics 12.1: 47-55.

% Calculate the transfer function
I_dBSampled = 0:10:100; % dB SPL
loudnessFletcher = [0.001 0.019 0.11 0.4 1 2.2 4.5 10 20 45 100]; % sone
logLoudnessSampled = log10(loudnessFletcher);
I_dB = 0:100;
logLoudness = spline(I_dBSampled, logLoudnessSampled, I_dB);
loudness = 10.^logLoudness; % sone
loudnessStevens = 2.^((I_dB-40)/10); % Stevens' Lawe

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = 400; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 90; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the loudness function
xTick = 0:20:120;
yTick = -3:3;
xAxis = [I_dB(1) I_dB(end)];
yAxis = [-3 3]; % log sone
set(gca, 'Box', 'on', 'LineWidth', 2, ...
    'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'XTick', xTick, 'XTickLabel', xTick, ...
    'YTick', yTick, 'YTickLabel', 10.^yTick, ...
    'FontSize', 14, 'Fontweight', 'bold')
plot(I_dB, log10(loudness), 'LineWidth' , 2, 'Color', blueGreen)
plot(I_dB, log10(loudnessStevens), '--', 'Color', blueGreen);
plot([I_dB(1) 40 40],[0 0 -3], 'Color', blueGreen)
xlabel('intensity level (dB)')
ylabel('loudness (sone)')
axis([xAxis yAxis])
