clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Synthesize the bandpass noise and the exponentially
% frequency-modulated tone
sampleFrequency = 44100; % Hz
dt = 1/sampleFrequency;
% Synthesize the frequency-modulated tone
fMin = 50;
fMax = 20000;
duration = 20; % sec
amp = 0.1;
t = dt:dt:duration;
tau = duration/(log(fMax)-log(fMin)); % sec
phi = 2 * pi * tau * fMin * (exp(t/tau)-1);
tone = amp * sin(phi);
% Synthesize the bandpass noise
noise = 1.8*randn(1, length(tone));
bandWidth = 1/3; % bandwidth in octaves
f_m = 1000;
cutOff_low = f_m*2^(-bandWidth/2);
cutOff_high = f_m*2^(bandWidth/2);
w1 = cutOff_low/(sampleFrequency/2);
w2 = cutOff_high/(sampleFrequency/2);
[b, a] = butter(2, [w1 w2]);
filteredNoise = filter(b, a, noise);
% Add tones and filtered noise
stimulus = tone+filteredNoise;
stimulus = FadeInOut(stimulus, sampleFrequency, 0.02, 0.02);
maxAbs = max(abs(stimulus));
if maxAbs>1
    stimulus = stimulus/maxAbs;
    fprintf('\nTo avoid clipping stimulus scaled by a factor %5.3f.\n', ...
        maxAbs)
end

% Save and play the stiumulus
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the partial loudness functions
I_ref = 1.0e-12;
I_s_dB = 60;
f_s = logspace(log10(fMin), log10(fMax), 500);
I_m_dB = [-20 60];
dz = 0.1;
z = 1.8:dz:39;
partialLoudness = zeros(length(I_m_dB), length(f_s));
for j = 1:length(I_m_dB)
    for i = 1:length(f_s)
        f = [f_s(i) f_m];
        I_s = [I_ref*10^(I_s_dB/10) zeros(size(f_m))];
        I_m = [zeros(size(f_s(i))) I_ref*10^(I_m_dB(j)/10)*ones(size(f_m))];
        I_t = I_s+I_m;
        [~, ~, partialSpecificLoudness] = ...
            CalcPartialLoudnessFunctions(f, I_m, I_t, z, 1, 1);
        partialLoudness(j, i) = sum(partialSpecificLoudness)*dz;
    end
end

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = 300; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 70; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the partial loudness of the frequency-modulated tone
axes('Position', pos)
xt = [20 50 100 200 500 1000 2000 5000 10000 20000];
yt = [0.2 0.5 1 1.5 2 3 4 6 8];
set(gca, 'Box', 'on', 'LineWidth', 2, ...
    'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'XTick', log10(xt), 'XtickLabel', xt/1000, ...
    'YTick', log10(yt), 'YtickLabel', yt, ...
    'FontSize', 14, 'Fontweight', 'bold')
plot(log10(f_s), log10(partialLoudness(1,:)), ':', ...
    'LineWidth', 2, 'Color', red)
plot(log10(f_s), log10(partialLoudness(2,:)), ...
    'LineWidth', 2, 'Color', blueGreen)
xlabel('frequency (kHz)')
ylabel('partial loudness (sone)')
axis([log10(fMin) log10(fMax) log10(0.5) log10(9)])


