clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

d =[0.200   94    92   103    99    97    90
    0.200   79    76    83    83    84    81
    0.200   67    66    63    62    68    63
    0.200   57    57    43    40    48    45
    0.200   46    46    23    21    25    25
    0.200   20    20     4     4    -2    -2
    
    0.100   94    88   103    96   104    91
    0.100   79    73    83    77    86    77
    0.100   67    61    63    58    70    63
    0.100   57    53    46    40    52    45
    0.100   46    44    29    24    29    25
    0.100   20    20     4     4     1    -2
    
    0.040   98    77   105    90   105    93
    0.040   89    72    85    69    90    78
    0.040   77    66    65    52    74    61
    0.040   67    55    50    37    58    42
    0.040   57    51    33    24    35    23
    0.040   20    20    11     4     5    -2
    
    0.010   98    74    98    69    89    69
    0.010   89    69    76    50    78    56
    0.010   77    62    60    34    65    44
    0.010   67    55    38    19    45    30
    0.010   57    48    18    4     14    -2
    0.010   20    20    18    4     14    -2
    
    0.005  108    77    98    65    97    65
    0.005   93    69    80    55    81    51
    0.005   81    65    69    38    70    40
    0.005   69    54    50    26    53    27
    0.005   20    20    18     4    10    -2];

durations = [d(1,1) d(7,1) d(13,1) d(19,1) d(25,1)]; % sec
n = [6 6 6 6 5];
freq = [125 1000 5650];
L_level = zeros(length(durations), length(freq));
level = 70;
for k = 1:length(durations)
    for f = 1:length(freq)
        i = 6*k-5;
        j = 2*f;
        L_level(k, f) = ...
            interp1(d(i:(i+n(k)-2), j), ...
            d(i:(i+n(k)-2), j+1), level);
        % The next plots reproduce Figure 7 from Fletcher
        % and Munson,(1937), p. 588
        % subplot(5, 3, 3*(k-1)+f)
        % hold 'on'
        % plot(d(i:(i+n(k)-1), j), d(i:(i+n(k)-1), j+1))
        % plot(d(i:(i+n(k)-1), j), d(i:(i+n(k)-1), j+1), '.')
        % plot([0 100], [0 100], 'k')
        % axis([0 100 0 100], 'square')
        % set(gca, 'FontSize', 6, ...
        %   'XTick', 0:25:100, 'YTick', 0:25:100)
    end
end

% Calculate the 1000-Hz tones of decreasing durations
sampleFrequency = 44100; % Hz
dt = 1/sampleFrequency;
interOnsetInterval = 1.2; % second
amp = 0.9;
stimulus = [];
f0 = 1000; % Hz
% Start with a 1000-ms tone
durationsDemo = [1 durations]; % sec
for k = 1:length(durationsDemo)
    t = dt:dt:durationsDemo(k);
    tone = amp * sin(2*pi*f0*t);
    tone = FadeInOut(tone, sampleFrequency, 0.002, 0.002);
    int = interOnsetInterval-durationsDemo(k);
    stimulus = ...
        [stimulus tone zeros(size(dt:dt:int))]; %#ok<AGROW>
end

% Play the 1000-Hz tones of decreasing durations
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, 0.2*stimulus, sampleFrequency)
sound(stimulus, sampleFrequency);

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position of figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = [240 240]; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 70; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% The next plot reproduces Figure 4 of Munson (1947), p. 588.
panel = 1;
axes('Position', pos(panel,:))
set(gca, 'LineWidth', 2, 'FontSize', 14, 'NextPlot', 'add', ...
    'Box', 'on', 'Color', lightYellowGreen, ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', 0:0.05:0.2, 'YTick', 0:2:8)
N_level = 2.^((L_level-40)/10);
plot(durations, N_level(:,1), '-o', ...
    'LineWidth', 1, 'Color', blueGreen)
plot(durations, N_level(:,2), '-o', ...
    'LineWidth', 2, 'Color', blueGreen)
plot(durations, N_level(:,3), ':o', ...
    'LineWidth', 1, 'Color', blueGreen)
text(0.215, 2^((level-40)/10), 'x', ...
    'FontSize', 18, 'Color', blueGreen)
axis([0 0.22 0 8.5])
xlabel('tone duration (sec)')
ylabel('loudness (sone)')

% The next plot reproduces Figure 3 of Munson (1947), p. 588.
panel = panel+1;
axes('Position', pos(panel,:))
set(gca, 'LineWidth', 2, 'FontSize', 14, 'NextPlot', 'add', ...
    'Box', 'on', 'Color', lightYellowGreen, ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', 0:0.05:0.2, 'XTickLabel', [], ...
    'YTick', 0:10:100)
plot(durations, L_level(:,1), '-o', ...
    'LineWidth', 1, 'Color', blueGreen)
plot(durations, L_level(:,2), '-o', ...
    'LineWidth', 2, 'Color', blueGreen)
plot(durations, L_level(:,3), ':o', ...
    'LineWidth', 1, 'Color', blueGreen)
text(0.215, level, 'x', ...
    'FontSize', 18, 'Color', blueGreen)
axis([0 0.22 25 75])
ylabel('loudness level (dB)')

