clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Specify the tone and the noise
fTone = 1000;
fMin = 500;
fMax = 2000;
I_n_dB = 0:15:60;
I_s_dB = 60;
nrOfPartials = 257;
f = logspace(log10(fMin), log10(fMax), nrOfPartials);
soundDuration = 0.9;
durationInterval = 0.5;

% Calculate the stimulus
sampleFrequency = 22050; % Hz
dt = 1/sampleFrequency;
tNoise = dt:dt:soundDuration;
tInterval = dt:dt:durationInterval;
noise = zeros(size(tNoise));
amplitude = 5/length(f);
for j = 1:length(f)
    noise = ...
        noise + amplitude*sin(2*pi*f(j)*tNoise+2*pi*rand);
end
tone = amplitude*sin(2*pi*fTone*tNoise);
interval = zeros(size(tInterval));
amplitude = 10.^(I_n_dB/20)/10^3;
stimulus = [];
for k = 1:length(I_n_dB)
    noiseAndTone = tone+amplitude(k)*noise;
    noiseAndTone = FadeInOut(noiseAndTone, sampleFrequency, 0.02, 0.02);
    stimulus = [stimulus interval noiseAndTone]; %#ok<AGROW>
end

% Save and play the stimulus
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the specific loudness of the noise, the specific
% loudness of the signal and the noise, and the partial 
% specific loudness of the tone. 
I_ref = 1.0e-12;
dz = 0.1;
z = 1.8:dz:39;
[~, ifMax] = find(abs(f-fTone) == min(abs(f-fTone)));
I_s = zeros(size(f));
I_s(ifMax) = I_ref*10^(I_s_dB/10);
specificLoudnessNoise = zeros(length(z), length(I_n_dB));
specificLoudnessSignalAndNoise = zeros(length(z), length(I_n_dB));
partialSpecificLoudness = zeros(length(z), length(I_n_dB));
for k = 1:length(I_n_dB)
    I_n = I_ref*10^(I_n_dB(k)/10)*ones(size(f));
    I_t = I_s+I_n;
    [specificLoudnessNoise(:,k), ...
        specificLoudnessSignalAndNoise(:,k), ...
        partialSpecificLoudness(:,k)] = ...
        CalcPartialLoudnessFunctions(f, I_n, I_t, z, 1, 1);
end

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidths = [180 180 180]; % pixels
panelHeights = [90 90 90 90 90 10]; % pixels
xLabelHeight = 70; % pixels
yLabelWidths = [70 0 60]; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidths, panelHeights, ...
    xLabelHeight, yLabelWidths, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidths, panelHeights, yLabelWidths, xLabelHeight, ...
    xMargin, yMargin);

% Define the plot parameters
rangeXAxis = [0 38];
rangeYAxis = [-0.3 4.2];
xTick = 0:10:40;
yTick = 0:2:4;
panel = 0;
for k = 1:length(I_n_dB)
    % Plot the loudness of the noise
    panel = panel+1;
    axes('Position', pos(panel,:))
    set(gca, 'Box', 'on', 'LineWidth', 2, 'NextPlot', 'add', ...
        'TickLength', [0.02 0.0250], ...
        'XTick', xTick, 'XTickLabel', '', ...
        'YTick', yTick, 'TickDir', 'out', ...
        'FontSize', 14, 'Fontweight', 'bold', ...
        'Color', lightYellowGreen)
    j = length(I_n_dB)-k+1;
    plot(z, specificLoudnessSignalAndNoise(:,j), ...
        'LineWidth', 2, 'Color', blueGreen)
    plot(rangeXAxis, [0 0], 'LineWidth', 1, 'Color', blueGreen)
    axis([rangeXAxis rangeYAxis])
    text(0.05*rangeXAxis(2), 0.85*rangeYAxis(2), ...
        sprintf('%5.2f sone', sum(specificLoudnessSignalAndNoise(:,j))*dz), ...
        'FontSize', 12, 'Fontweight', 'bold')
    if k == length(I_n_dB)-floor(length(I_n_dB)/2)
        ylabel('specific loudness (sone/ERB)')
    end
    if k == 1
        xlabel('Cam')
        set(gca, 'XTick', 0:10:40, 'XTickLabel', 0:10:40)
    end
end
panel = panel+1;
axes('Position', pos(panel,:))
axis 'off'
text(0.5,0.2, 'signal and noise', 'FontSize', 14, 'Fontweight', 'bold', ...
    'HorizontalAlignment', 'center')

% Plot the loudness of the noise and the tone
for k = 1:length(I_n_dB)
    panel = panel+1;
    axes('Position', pos(panel,:))
    set(gca, 'Box', 'on', 'LineWidth', 2, 'NextPlot', 'add', ...
        'TickLength', [0.02 0.0250], ...
        'XTick', xTick, 'XTickLabel', '', ...
        'YTick', yTick, 'YTickLabel', [], 'TickDir', 'out', ...
        'FontSize', 14, 'Fontweight', 'bold', ...
        'Color', lightYellowGreen)
    j = length(I_n_dB)-k+1;
    plot(z, specificLoudnessNoise(:,j), ...
        'LineWidth', 2, 'Color', blueGreen)
    plot(rangeXAxis, [0 0], 'LineWidth', 1, 'Color', blueGreen)
    axis([rangeXAxis rangeYAxis])
    text(0.05*rangeXAxis(2), 0.85*rangeYAxis(2), ...
        sprintf('%5.2f sone', sum(specificLoudnessNoise(:,j))*dz), ...
        'FontSize', 12, 'Fontweight', 'bold')
    if k == 1
        xlabel('Cam')
        set(gca, 'XTick', 0:10:40, 'XTickLabel', 0:10:40)
    end
end
panel = panel+1;
axes('Position', pos(panel,:))
axis 'off'
text(0.5,0.2, 'noise', 'FontSize', 14, 'Fontweight', 'bold', ...
    'HorizontalAlignment', 'center')

% Plot the partial loudness of the tone
for k = 1:length(I_n_dB)
    panel = panel+1;
    axes('Position', pos(panel,:))
    set(gca, 'Box', 'on', 'LineWidth', 2, 'NextPlot', 'add', ...
        'TickLength', [0.02 0.0250], ...
        'XTick', xTick, 'XTickLabel', '', ...
        'YTick', yTick, 'TickDir', 'out', ...
        'FontSize', 14, 'Fontweight', 'bold', ...
        'Color', lightYellowGreen)
    j = length(I_n_dB)-k+1;
    plot(z, partialSpecificLoudness(:,j), ...
        'LineWidth', 2, 'Color', blueGreen)
    plot(rangeXAxis, [0 0], 'LineWidth', 1, 'Color', blueGreen)
    axis([rangeXAxis rangeYAxis])
    text(0.05*rangeXAxis(2), 0.85*rangeYAxis(2), ...
        sprintf('%5.2f sone', sum(partialSpecificLoudness(:,j))*dz), ...
        'FontSize', 12, 'Fontweight', 'bold')
    if k == length(I_n_dB)-floor(length(I_n_dB)/2)
        ylabel('partial specific loudness (sone/ERB)')
    end
    if k == 1
        xlabel('Cam')
        set(gca, 'XTick', 0:10:40, 'XTickLabel', 0:10:40)
    end
end
panel = panel+1;
axes('Position', pos(panel,:))
axis 'off'
text(0.5,0.2, 'signal', 'FontSize', 14, 'Fontweight', 'bold', ...
    'HorizontalAlignment', 'center')

