clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Specify the tone and the noise
fTone = 1000;
fmin = 500;
fmax = 2000;
f = logspace(log10(fmin), log10(fmax), 65);
I_n_dB = 0:10:70;

% Calculate the various loudness functions
I_ref = 1.0e-12;
I_s_dB = 0:120;
dz = 0.1;
z = 1.8:dz:39;
partialLoudness = zeros(length(I_s_dB), length(f));
for k = 1:length(I_n_dB)
    [~, j] = find(abs(f-fTone) == min(abs(f-fTone)));
    I_n = I_ref*10^(I_n_dB(k)/10)*ones(size(f));
    for i = 1:length(I_s_dB)
        I_s = zeros(size(f));
        I_s(j) = I_ref*10^(I_s_dB(i)/10);
        I_t = I_s+I_n;
        [specificLoudnessNoise, ...
            specificLoudnessSignalAndNoise, ...
            partialSpecificLoudness] = ...
            CalcPartialLoudnessFunctions(f, I_n, I_t, z, 1, 1);
        partialLoudness(k, i) = sum(partialSpecificLoudness)*dz;
    end
end

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 45; % vertical position figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = 400; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 90; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the partial loudness
axes('Position', pos)
set(gca, 'Box', 'on', 'LineWidth', 2, ...
    'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'XTick', 0:10:120, 'XTickLabel', 0:10:120, ...
    'YTick', -2:2, 'YTickLabel', 10.^(-2:2), ...
    'FontSize', 14, 'Fontweight', 'bold')
for k = 1:length(I_n_dB)
    plot(I_s_dB, log10(partialLoudness(k,:)), ...
        'LineWidth' , 2, 'Color', blueGreen)
    r = abs(partialLoudness(k,:)-0.05);
    [~, j] = find(r == min(r));
    text(I_s_dB(j), -1.3, sprintf('%2.0f', I_n_dB(k)), ...
        'FontSize', 14, 'Fontweight', 'bold', ...
        'horizontalAlignment', 'center')
end
text(I_s_dB(j)+5, -1.3, 'dB', ...
    'FontSize', 12, 'Fontweight', 'bold', ...
    'horizontalAlignment', 'center')
xlabel('intensity of tone (dB)')
ylabel('partial loudness of tone (sone)')
axis([0 I_s_dB(end) -2 3])

