clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Specify the stimuli
I_ref = 1.0e-12;
zMin = Hz2ERB(50);
zMax = Hz2ERB(20000);
dz = 0.01;
z = zMin:dz:zMax;
I_dB = 50;
cntrFreq = 1000; % Hertz
df = [0 20 400 1000]; % Hertz

% Synthesize the stimulus
sampleFrequency = 44100; % Hz
dt = 1/sampleFrequency;
durationNoise = 1; % sec
durationInterval = 0.1; % sec
tNoise = dt:dt:durationNoise;
tInterval = dt:dt:durationInterval;
interval = zeros(size(tInterval));
fade = 0.02; % sec
amp = 1;
bandWidth = 1/6; % octave
stimulus = interval;
for k = 1:length(df)
    stim = zeros(size(tNoise));
    noiseWideBand = amp*randn(size(tNoise));
    fcLow = 2*(cntrFreq-0.5*df(k))/sampleFrequency;
    w1 = fcLow*2^(-bandWidth/2);
    w2 = fcLow*2^(bandWidth/2);
    [b, a] = butter(4, [w1 w2]);
    s = filter(b, a, noiseWideBand);
    stim = stim + s;
    noiseWideBand = amp*randn(size(tNoise));
    fcHgh =  2*(cntrFreq+0.5*df(k))/sampleFrequency;
    w1 = fcHgh*2^(-bandWidth/2);
    w2 = fcHgh*2^(bandWidth/2);
    [b, a] = butter(4, [w1 w2]);
    s = filter(b, a, noiseWideBand);
    stim = stim + s;
    stim = FadeInOut(stim, sampleFrequency, fade, fade);
    stimulus = [stimulus stim interval]; %#ok<AGROW>
end

% Save and play the sound
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the specific-loudness contours
specificLoudness = zeros(length(df), length(z));
loudness = zeros(length(df));
I = I_ref*10.^(I_dB/10);
f = zeros(length(df), 2);
for k = 1:length(df)
    f(k,:) = [cntrFreq-0.5*df(k) cntrFreq+0.5*df(k)];
    [~, specificLoudness(k,:)] = ...
        CalcLoudnessFunctions(f(k,:), I, z, 1, 1);
    loudness(k) = dz*sum(specificLoudness(k,:));
end

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = 120*ones(size(df)); % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 70; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the specific-loudness contours
zRange = [zMin 36];
rangeYAxis = [0 1.45]; % dB
for k = 1:length(df)
    axes('Position', pos(k,:))
    p = length(df)-k+1;
    plot(z, specificLoudness(p,:), 'Color', blueGreen, 'LineWidth', 2)
    axis([zRange rangeYAxis])
    set(gca, 'Box', 'on', 'LineWidth', 2, ...
        'NextPlot', 'add', 'Color', lightYellowGreen, ...
        'YTick', 0:0.5:2, 'YTickLabel', 0:0.5:2, ...
        'FontSize', 14, 'Fontweight', 'bold')
    if k == 1
        set(gca, 'XTick', 5:5:40, 'XTickLabel', 5:5:40)
        xlabel('Cam')
    else
        set(gca, 'XTick', 5:5:40, 'XTickLabel', [])
    end
    ylabel('spec. loudness', 'FontSize', 12, 'Fontweight', 'bold')
    txt = [sprintf('%4d ', f(p, 1:end-1)) sprintf(' and %4d %s ', ...
        f(p, end), 'Hz')];
    text(zRange(1)+1, 1.25, txt, 'FontSize', 12, 'Fontweight', 'bold')
    txt = sprintf('%5.2f sone', loudness(p));
    text(zRange(end)-5, 1.25, txt, 'FontSize', 12, 'Fontweight', 'bold')
end

