clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define the stimulus
sampleFrequency = 44100; % Hz
dt = 1/sampleFrequency;
durationTone = 0.3; % sec
t = dt:dt:durationTone;
durationInterval = 0.1; % sec
interval = zeros(size(dt:dt:durationInterval));
fade = 0.02; % sec
f0 = [200 250];
nrOfHarmonics = 2;
lowestHarmonic = [9 7];
amp = 1/nrOfHarmonics;

% Calculate the schematic time-frequency representation
t0 = 0;
nrOfTones = 1;
nrOfVirtualTones = 1;
for k = 1:length(f0)
    for i = lowestHarmonic(k):lowestHarmonic(k)+nrOfHarmonics-1
        f = i*f0(k);
        schemTime(1:2, nrOfTones) = ...
            [t0 t0+durationTone]; %#ok<*SAGROW>
        schemFreq(1:2, nrOfTones) = [f f];
        schemTimeVirtual(1:2, nrOfVirtualTones) = ...
            [t0 t0+durationTone]; %#ok<*SAGROW>
        schemFreqVirtual(1:2, nrOfVirtualTones) = [f0(k) f0(k)];
        nrOfTones = nrOfTones+1;
        nrOfVirtualTones = nrOfVirtualTones+1;
    end
    t0 = t0+durationTone+durationInterval;
end
envelopeTone = ...
    amp*FadeInOut(ones(size(t)), sampleFrequency, fade, fade);
stimulus = SynthToneSequence(schemTime, schemFreq, sampleFrequency, ...
    envelopeTone);

% Save and play the stimulus
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position of figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = 400; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 80; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the schematic time frequency representation
axes('Position', pos)
dXTick = 0.2; % sec
dYTick = 500; % kHz
maxYAxis = 2200; % Hz
durationStimulus = length(stimulus)*dt; % sec
xAxis = [-dXTick/3 durationStimulus+dXTick/3];
yAxis = [0 maxYAxis];
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
    'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'YTick', 0:dYTick:maxYAxis, ...
    'YTickLabel', (0:dYTick:maxYAxis)/1000)
PlotSTFR(stimulus, sampleFrequency, ...
    schemTime, schemFreq, envelopeTone, ...
    xAxis, dXTick, ...
    yAxis, dYTick, 0.02*amp, blueGreen)
set(gca, 'XTick', 0:dXTick:durationStimulus, ...
    'XTickLabel', 0:dXTick:durationStimulus, ...
    'Color', lightYellowGreen)
t0 = 0;
for k = 1:length(f0)
    plot([t0 t0+durationTone], [f0(k) f0(k)], '--', 'Color', red)
    t0 = t0+durationTone+durationInterval;
end
x = mean([durationTone durationTone+durationInterval]);
y = mean([lowestHarmonic(1)*f0(1) lowestHarmonic(2)*f0(2)]);
text(x, y, 'analytic', 'HorizontalAlignment', 'center', ...
    'FontWeight', 'bold', 'FontSize', 12)
y = mean(f0);
text(x, y, 'synthetic', 'HorizontalAlignment', 'center', ...
    'FontWeight', 'bold', 'FontSize', 12)
xlabel('time (s)', 'FontWeight', 'bold')
ylabel('frequency (kHz)')
axis([xAxis yAxis])


