clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define the stimulus
sampleFrequency = 44100; % Hz
dt = 1/sampleFrequency;
f1 = 2000;
f2 = 20;
durationInterval = 5; % sec
toneDuration = durationInterval*log2(f1/f2);
t = dt:dt:toneDuration;
fade = 0.2; % sec
hWin = hann(length(t));
nrOfRepetitions = 10;
samplesInInterval = floor(durationInterval*sampleFrequency);
amp = 1/nrOfRepetitions;

% Calculate the stimulus
a = -(1/toneDuration)*log2(f2/f1);
f_inst = f1*2.^(-a*t);
phi = 2*pi*cumsum(f_inst)*dt;
tone = amp*hWin'.*sin(phi);
tone(length(tone)+1:nrOfRepetitions*samplesInInterval) = 0;
stimulus = tone;
for k = 2:nrOfRepetitions
    tone = circshift(tone, [0, samplesInInterval]);
    stimulus = stimulus+tone;
end
stimulus = FadeInOut(stimulus, sampleFrequency, fade, fade);

% Save and play the sound
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Specify the figure parameters
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = 180; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 90; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels

% Calculate the position of the figure on the screen
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the schematic time-logfrequency representation
panel = 1;
axes('Position', pos(panel,:))
dXTick = 10; % sec
a = 400;
yTick = -4:2:log2(sampleFrequency/a);
durationStimulus = length(stimulus)*dt; % sec
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
    'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', 0:dXTick:durationStimulus, ...
    'YTick', yTick, 'YTickLabel', (a*2.^yTick))
tAxis = ...
    [-dXTick/4 durationStimulus+dXTick/4];
lfAxis = log2([f2 f1]/a)+[-1 1];
t0 = 0;
sc = 0.15;
for k = 1:nrOfRepetitions
    tt = t0+t;
    r = find(tt>durationStimulus);
    tt(r) = tt(r)-durationStimulus;
    for i = 1:5000:length(hWin)
        plot([tt(i) tt(i)], ...
            [log2(f_inst(i)/a)-sc*hWin(i) log2(f_inst(i)/a)+sc*hWin(i)], ...
            'LineWidth', 2, 'Color', (1-hWin(i))*[1 1 1])
    end
    t0 = t0+durationInterval;
end
axis([tAxis lfAxis])
xlabel('time (s)', 'FontWeight', 'bold')
ylabel('frequency (Hz)', 'FontWeight', 'bold')


