clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define the stimulus
sampleFrequency = 44100; % Hz
dt = 1/sampleFrequency;
f1 = 20;
f2 = 18000;
durationTone = 0.15; % sec
tTOne = dt:dt:durationTone;
durationInterval = 0.05; % sec
interval = zeros(size(dt:dt:durationInterval));
fade = 0.02; % sec
amp = 0.1;
a = 440;
nrOfOctaves = 4;
f0 = logspace(log10(a), log10(nrOfOctaves*a), nrOfOctaves*12+1);

% Calculate the schematic time-frequency representation
t0 = 0;
nrOfTones = 1;
for k = 1:length(f0)
    i1 = ceil(log2(f1/f0(k)));
    i2 = floor(log2(f2/f0(k)));
    for i = i1:i2
        f = f0(k)*2^i;
        schemTime(1:2, nrOfTones) = ...
            [t0 t0+durationTone]; %#ok<*SAGROW>
        schemFreq(1:2, nrOfTones) = [f f];
        nrOfTones = nrOfTones+1;
    end
    t0 = t0+durationTone+durationInterval;
end
envelopeTone = ...
    amp*FadeInOut(ones(size(tTOne)), sampleFrequency, fade, fade);
% Calculate the tone sequence
stimulus = SynthToneSequence(schemTime, schemFreq, sampleFrequency, ...
        envelopeTone);

% Save and play the stimulus
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position of figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = 180; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 90; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the schematic time frequency representation
axes('Position', pos)
dXTick = 1; % sec
yTick = -4:2:4;
durationStimulus = length(stimulus)*dt; % sec
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
    'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', 0:dXTick:durationStimulus, ...
    'YTick', yTick, 'YTickLabel', a*2.^yTick)
tAxis = [-dXTick/4 durationStimulus+dXTick/4];
fAxis = [f1 f2];
schemFreq = log2(schemFreq/a);
lfAxis = log2(fAxis/a)+[-1 1];
widthAmpl = 0.01;
schemEnv = widthAmpl*(lfAxis(2)-lfAxis(1))*envelopeTone;
for m = 1:size(schemTime, 2)
    tt = [schemTime(1, m) schemTime(2, m)];
    plot(tt, [schemFreq(1,m) schemFreq(1,m)], ...
        'Color', [0 0 0], 'LineWidth', 2)
end
xlabel('time (s)', 'FontWeight', 'bold')
ylabel('frequency (Hz)')
axis([tAxis lfAxis])


