clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define and synthesize the stimulus
sampleFrequency = 10000; % Hz
dt = 1/sampleFrequency;
durationTone = 0.25; % sec
t = dt:dt:durationTone;
durationInterval = 0.05; % sec
durationSilence = 0.5; % sec
nrOfIterations = 10;
bandWidth = 1/6;
fade = 0.02; % sec
amp = 0.1/sqrt(nrOfIterations);
nrOfOctaves = 3;
f = logspace(log10(220), log10((2^nrOfOctaves)*220), ...
    12*nrOfOctaves+1);
melody = [1 3 5 6 8 10 12 13];
interval = zeros(size(dt:dt:durationInterval));
silence = zeros(size(dt:dt:durationSilence));
stimulus = [];
for k = 1:length(melody)
    f0 = f(melody(k));
    delay = round(sampleFrequency/f0);
    noise = amp*randn(size(t));
    s = noise;
    for j = 1:nrOfIterations
        s = s+circshift(noise, [0, j*delay]);
    end
    s = FadeInOut(s, sampleFrequency, fade, fade);
    stimulus =  [stimulus s interval]; %#ok<AGROW>
end

% Save and play the sound segment
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = [80 180]; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 70; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the signel and the spectrogram
dXTick = 0.5; % sec
dYTick = 1; % kHz
maxYAxis = 5000; % Hz
durationStimulus = length(stimulus)*dt; % sec
xTick = -dXTick:dXTick:durationStimulus;
tAxis = [-0.2*dXTick durationStimulus+0.2*dXTick];
fAxis = [-20 maxYAxis+20];

% Plot the signal
panel = 1;
axes('Position', pos(panel,:))
PlotSignal(stimulus, sampleFrequency, ...
    tAxis, dXTick, blueGreen, 'time (s)')
set(gca, 'XTick', xTick, 'XTickLabel', xTick, ...
    'Color', lightYellowGreen)
text(0.99*tAxis(1)+0.01*tAxis(2), 0.7, ...
    'waveform', 'FontSize', 14, 'FontWeight', 'bold')

% Plot the spectrogram
panel = panel+1;
axes('Position', pos(panel,:))
nFft = 1024; % Number of samples in fft window
nWindow = 256; 
nOverlap = nWindow-16;
[~, f, ts, p] = spectrogram([silence stimulus silence], ...
    nWindow, nOverlap, nFft, sampleFrequency);
p = 10*log10(abs(p));
ts = ts-durationSilence;
PlotSpectrogram(stimulus, sampleFrequency, ...
    f, ts, p, tAxis, dXTick, fAxis, dYTick, 40, ...
    frameColor)
set(gca, 'Color', lightYellowGreen)
text(0.99*tAxis(1)+0.01*tAxis(2), fAxis(1)+0.9*(fAxis(2)-fAxis(1)), ...
    '', 'FontSize', 14, 'FontWeight', 'bold')


