clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Calculate the helix
n = 120;
nrOfOctaves = 3;
phi = linspace(0, 2*pi*nrOfOctaves, nrOfOctaves*n);
x = zeros(1, nrOfOctaves*n);
y = zeros(1, nrOfOctaves*n);
for k = 1:nrOfOctaves*n
    x(k) = cos(phi(k));
    y(k) = sin(phi(k));
end
z = linspace(0, nrOfOctaves, nrOfOctaves*n);

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position of figure in pixels from bottom
panelWidth = 600; % pixels
panelHeights = 600; % pixels
xLabelHeight = 15; % pixels
yLabelWidth = 15; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot
panel = 1;
axes('Position', pos(panel,:))
set(gca, 'LineWidth', 0.01, 'FontSize', 14, ...
    'NextPlot', 'add', 'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', [], 'YTick', [], 'ZTick', [])
plot(x, y, 'LineWidth', 2, 'Color', blueGreen)
plot3(x, y, z, 'LineWidth', 2, 'Color', blueGreen)
view(7, 24)
axis([-1.5 1.5 -1.5 1.5 0 nrOfOctaves], 'off')
notes = [' C '; 'C^#'; ' D '; 'D^#'; ...
    ' E '; ' F '; 'F^#'; ' G '; 'G^#'; ' A '; 'A^#'; ' B '];
nN = size(notes, 1);
x = cos(2*pi*((0:nrOfOctaves*nN)/nN));
y = sin(2*pi*((0:nrOfOctaves*nN)/nN));
for h = 1:nN
    plot([0.95*x(h) 1.05*x(h)], [0.95*y(h) 1.05*y(h)], ...
        'LineWidth', 2, 'Color', blueGreen)
    text(x(h), y(h), 0, ...
        notes(h,:), 'FontSize', 18, 'FontWeight', 'bold', ...
        'Color', 0.3+0.3*[y(h) y(h) y(h)], ...
        'HorizontalAlignment', 'center', 'VerticalAlignment', 'bottom')
end
for h = 1:nrOfOctaves*nN+1
    plot3([0.95*x(h) 1.05*x(h)], [0.95*y(h) 1.05*y(h)], ... 
        [(h-1)/nN (h-1)/nN], 'LineWidth', 2, 'Color', blueGreen)
    text(x(h), y(h), (h-1)/nN, notes(mod(h-1, 12)+1,:), ...
        'FontSize', 18, 'FontWeight', 'bold', ...
        'Color', 0.3+0.3*[y(h) y(h) y(h)], ...
        'HorizontalAlignment', 'center', 'VerticalAlignment', 'bottom')
end

