clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = 400; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 70; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the position of the panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Specify the stimulus
sampleFrequency = 44100; % Hz
dt = 1/sampleFrequency;
durationInterval = 0.2; % sec
interval = zeros(size(dt:dt:durationInterval));
f0 = 440; % Hz
f = logspace(log10(f0), log10(2*f0), 13);
melody = [1 3 5 6 8 10 12 13];
delay = 1./f(melody);
durationTone = 0.03; % sec
tTone = dt:dt:durationTone;
fade = 0.01; % sec
a = 0.9;

% Calculate the stimulus
% Synthesize scale of pulse pairs
pulses = zeros(1, length(interval)*(length(melody)+1));
t = (1:length(pulses))*dt;
t0 = zeros(1, length(melody));
t0(1) = durationInterval;
for k = 1:length(melody)
    p1 = sampleFrequency*(t0(k)-0.5*delay(k));
    p2 = sampleFrequency*(t0(k)+0.5*delay(k));
    pulses(round(p1)+1) = a;
    pulses(round(p1)+2) = a;
    pulses(round(p1)+3) = a;
    pulses(round(p2)+1) = a;
    pulses(round(p2)+2) = a;
    pulses(round(p2)+3) = a;
    t0(k+1) = t0(k)+durationInterval;
end
durationStimulus = length(pulses)*dt; % sec
% Synthesize scale of tones
tones = zeros(1, length(interval)*(length(melody)+1));
t0 = zeros(1, length(melody));
t0(1) = durationInterval;
for k = 1:length(melody)
    tone = 0.25*a*sin(2*pi*f(melody(k))*tTone);
    tone = FadeInOut(tone, sampleFrequency, fade, fade);
    p = round(sampleFrequency*t0(k));
    tones(p+1:p+length(tone)) = tone;
    t0(k+1) = t0(k)+durationInterval;
end
stimulus = [pulses interval interval tones];

% Save and play the stimulus
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Plot the signal
axes('Position', pos)
dXTick = 0.2; % sec
dYTick = 1; % kHz
tAxis = [-dXTick/8 durationStimulus+dXTick/8];
yAxis = [-0.2 1.1];
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
    'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', 0:dXTick:durationStimulus, ...
    'XTickLabel', 0:dXTick:durationStimulus, ...
    'YTick', -1:1)
tp = 0.008; % sec
lambda = 20; % scale factor
st = 0.02; % determines slope of slanted lines
sy = 0.25; % determines height of slanted lines
for k = 1:length(melody)
    t1 = t0(k)-0.5*tp;
    t2 = t0(k)+0.5*tp;
    s1 = round(sampleFrequency*t1)+1;
    s2 = round(sampleFrequency*t2)+1;
    plot(t0(k)+lambda*(t(s1:s2)-t0(k)), pulses(s1:s2), ...
        'Color', blueGreen, 'LineWidth', 2);
    tBegin = t0(k)+lambda*(t(s1)-t0(k));
    tEnd = t0(k)+lambda*(t(s2)-t0(k));
    plot([tBegin-st tBegin+st], [sy -sy]*yAxis(1), ...
        'Color', blueGreen)
    plot([tEnd-st tEnd+st], [sy -sy]*yAxis(1), ...
        'Color', blueGreen)
    text(t0(k), -0.1, sprintf('%1.0f ms', 1000*tp), ...
        'HorizontalAlignment', 'center')
    text(t0(k)+lambda*(t(s1)-t0(k)), -0.1, '<', ...
        'HorizontalAlignment', 'left')
    text(t0(k)+lambda*(t(s2)-t0(k)), -0.1, '>', ...
        'HorizontalAlignment', 'right')
end
plot(tAxis, [0 0], 'Color', blueGreen)
axis([tAxis yAxis])
xlabel('time (s)', 'FontWeight', 'bold')
ylabel('signal value')


