clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Read the speech signal
[speech, sampleFrequency] = audioread('pleaseTurn.wav');
stimulus = 0.9*speech';
dt = 1/sampleFrequency;
durationStimulus = length(stimulus)*dt; % sec
t = (1:length(stimulus))*dt;

% Save and play the sound
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = [120 240 240]; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 70; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the signal
panel = 1;
axes('Position', pos(panel,:))
dXTick = 0.25; % sec
dYTick = 1; % kHz
tAxis = [t(1) t(end)];
set(gca, 'XTick', 0:dXTick:durationStimulus, ...
    'XTickLabel', 0:dXTick:durationStimulus)
PlotSignal(stimulus, sampleFrequency, ...
    tAxis, dXTick, blueGreen, 'time (ms)')
set(gca, 'Color', lightYellowGreen)
% Indicate the unvoiced segments
unvoicedSegment = [0.04 0.10; 0.23 0.37; 1.09 1.24; 1.50 1.66]; % sec.
mus = mean(transpose(unvoicedSegment));
for j = 1:size(unvoicedSegment, 1)
    plot(unvoicedSegment(j,:), [0.8 0.8], ...
        'LineWidth', 2, 'Color', darkRed)
    plot([unvoicedSegment(j,1) unvoicedSegment(j,1)], [0.75 0.85], ...
        'LineWidth', 2, 'Color', darkRed)
    plot([unvoicedSegment(j,2) unvoicedSegment(j,2)], [0.75 0.85], ...
        'LineWidth', 2, 'Color', darkRed)
    text(mus(j), 0.6, 'uv', 'HorizontalAlign', 'center');
end
syllables = ...
    ['Please '; 'turn   '; 'on     '; 'your   '; 're    -'; ...
    'cor   -'; 'der    '];
onsets = [0.1 0.41 0.68 0.85 1.03 1.27 1.41];
for syll = 1:length(syllables)
    text(onsets(syll), -0.8, syllables(syll,:), ...
        'FontAngle', 'italic', ...
        'FontSize', 10, 'FontWeight', 'bold', 'Color', blueGreen)
end

% Plot the wide-band spectrogram
panel = panel+1;
axes('Position', pos(panel,:))
maxYAxis = sampleFrequency/2; % Hz
fAxis = [0 maxYAxis];
% Calculate the wide-band spectrogram
nWindow = 64;
nFft = 2048; % Number of samples in fft window
nOverlap = round((3/4)*nWindow);
[~, fWideband, tsWideband, widebandSpectrogram] = ...
    spectrogram(stimulus, ...
    nWindow, nOverlap, nFft, sampleFrequency);
widebandSpectrogram = 10*log10(abs(widebandSpectrogram));
PlotSpectrogram(stimulus, sampleFrequency, ...
    fWideband, tsWideband, widebandSpectrogram, ...
    tAxis, dXTick, fAxis, dYTick, 60, lightYellowGreen)
set(gca, 'Color', lightYellowGreen)
text(t(end)-0.05, 0.9*(fAxis(2)-fAxis(1)), ...
    'wide-band spectrogram', ...
    'FontSize', 14, 'FontWeight', 'bold', ...
    'HorizontalAlignment', 'right')

% Plot the narrow-band spectrogram
panel = panel+1;
axes('Position', pos(panel,:))
% Calculate the narrow-band spectrogram
nWindow = 512;
nOverlap = round((7/8)*nWindow);
[~, fNarrowband, tsNarrowband, narrowbandSpectrogram] = ...
    spectrogram(stimulus, ...
    nWindow, nOverlap, nFft, sampleFrequency);
narrowbandSpectrogram = 10*log10(abs(narrowbandSpectrogram));
PlotSpectrogram(stimulus, sampleFrequency, ...
    fNarrowband, tsNarrowband, narrowbandSpectrogram, ...
    tAxis, dXTick, fAxis, dYTick, 60, lightYellowGreen)
set(gca, 'Color', lightYellowGreen)
text(t(end)-0.05, 0.9*(fAxis(2)-fAxis(1)), ...
    'narrow-band spectrogram', ...
    'FontSize', 14, 'FontWeight', 'bold', ...
    'HorizontalAlignment', 'right')


