clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Read the speech signal
[speech1, ~] = audioread('pleaseTurn.wav');
[speech2, sampleFrequency] = audioread('pleaseInsert.wav');
speech = zeros(max([length(speech1) length(speech2)]), 1);
speech(1:length(speech1)) = 0.6*speech1;
speech(1:length(speech2)) = ...
    speech(1:length(speech2))+0.4*speech2;
stimulus = speech';
dt = 1/sampleFrequency;
durationStimulus = length(stimulus)*dt; % sec
t = (1:length(stimulus))*dt;
segment = [0.11 0.21];
t1 = round(sampleFrequency*segment(1));
t2 = round(sampleFrequency*segment(2));
stimulusSegment = speech(t1:t2);

% Save and play the sound
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulusSegment, sampleFrequency)
sound(stimulusSegment, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = [120 240 240]; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 70; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the signal
panel = 1;
axes('Position', pos(panel,:))
dXTick = 0.025; % sec
dYTick = 1; % kHz
tAxis = segment;
set(gca, 'XTick', 0:dXTick:durationStimulus, ...
    'XTickLabel', 0:dXTick:durationStimulus)
PlotSignal(stimulus, sampleFrequency, ...
    tAxis, dXTick, blueGreen, 'time (ms)')
set(gca, 'Color', lightYellowGreen)

% Plot the wide-band spectrogram
panel = panel+1;
axes('Position', pos(panel,:))
maxYAxis = sampleFrequency/2; % Hz
fAxis = [0 maxYAxis];
% Calculate the wide-band spectrogram
nFft = 512; % Number of samples in fft window
nWindow = 64;
nOverlap = nWindow-(1/16)*nWindow;
[~, fWideband, tsWideband, widebandSpectrogram] = ...
    spectrogram(stimulus, ...
    nWindow, nOverlap, nFft, sampleFrequency);
widebandSpectrogram = 10*log10(abs(widebandSpectrogram));
PlotSpectrogram(stimulus, sampleFrequency, ...
    fWideband, tsWideband, widebandSpectrogram, ...
    tAxis, dXTick, fAxis, dYTick, 60, lightYellowGreen)
set(gca, 'Color', lightYellowGreen)
text(tAxis(2)-0.005, 0.9*(fAxis(2)-fAxis(1)), ...
    'wide-band spectrogram', ...
    'FontSize', 14, 'FontWeight', 'bold', ...
    'HorizontalAlignment', 'right')

% Plot the narrow-band spectrogram
panel = panel+1;
axes('Position', pos(panel,:))
% Calculate the narrow-band spectrogram
nWindow = 512;
nOverlap = nWindow-(1/64)*nWindow;
[~, fNarrowband, tsNarrowband, narrowbandSpectrogram] = ...
    spectrogram(stimulus, ...
    nWindow, nOverlap, nFft, sampleFrequency);
narrowbandSpectrogram = 10*log10(abs(narrowbandSpectrogram));
PlotSpectrogram(stimulus, sampleFrequency, ...
    fNarrowband, tsNarrowband, narrowbandSpectrogram, ...
    tAxis, dXTick, fAxis, dYTick, 60, lightYellowGreen)
set(gca, 'Color', lightYellowGreen)
text(tAxis(2)-0.005, 0.9*(fAxis(2)-fAxis(1)), ...
    'narrow-band spectrogram', ...
    'FontSize', 14, 'FontWeight', 'bold', ...
    'HorizontalAlignment', 'right')


