clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define the stimulus
sampleFrequency = 44100; % Hz
dt = 1/sampleFrequency;
durationTone = 0.15; % sec
t = dt:dt:durationTone;
durationPadding = 0.1; % sec
durationInterval = 0.05; % sec
interval = zeros(size(dt:dt:durationInterval));
padding = zeros(size(dt:dt:durationPadding));
fade = 0.02; % sec
f0 = 330; % Hz
nrOfHarmonics = 12;
nrOfCancelledHarmonics = 8;
amp = 1/nrOfHarmonics;

% Calculate the schematic time-frequency representation
t0 = 0;
nrOfTones = 1;
nrOfVirtualTones = 1;
for k = 1:nrOfCancelledHarmonics
    for i = k:nrOfHarmonics
        f = i*f0;
        schemTime(1:2, nrOfTones) = ...
            [t0 t0+durationTone]; %#ok<*SAGROW>
        schemFreq(1:2, nrOfTones) = [f f];
        schemTimeVirtual(1:2, nrOfVirtualTones) = ...
            [t0 t0+durationTone]; %#ok<*SAGROW>
        schemFreqVirtual(1:2, nrOfVirtualTones) = [f0 f0];
        nrOfTones = nrOfTones+1;
        nrOfVirtualTones = nrOfVirtualTones+1;
    end
    t0 = t0+durationTone+durationInterval;
end
envelopeTone = ...
    amp*FadeInOut(ones(size(t)), sampleFrequency, fade, fade);
stimulus = SynthToneSequence(schemTime, schemFreq, sampleFrequency, ...
    envelopeTone);

% Save and play the stimulus
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position of figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = 180; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 70; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the schematic time frequency representation
axes('Position', pos)
dXTick = 0.5; % sec
dYTick = 2; % kHz
maxYAxis = 5000; % Hz
durationStimulus = length(stimulus)*dt; % sec
xAxis = ...
    [-dXTick/4 durationStimulus+dXTick/4];
yAxis = [0 maxYAxis];
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
    'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', 0:dXTick:durationStimulus, ...
    'YTick', 0:1000:maxYAxis, ...
    'YTickLabel', (0:1000:maxYAxis)/1000)
for m = 1:size(schemTime, 2)
    plot([schemTime(1, m) schemTime(2, m)], ...
        [schemFreq(1,m) schemFreq(1,m)], ...
        'LineWidth', 3, 'Color', blueGreen)
end
% Plot the virtual pitches
t0 = 0;
for k = 1:nrOfCancelledHarmonics
    plot([t0 t0+durationTone], [f0 f0], '--', 'Color', red)
    t0 = t0+durationTone+durationInterval;
end
xlabel('time (s)', 'FontWeight', 'bold')
ylabel('frequency (kHz)')
axis([xAxis yAxis])


