clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define the stimulus
sampleFrequency = 20000; % Hz
dt = 1/sampleFrequency;
durationTone = 0.18; % sec
t = dt:dt:durationTone;
durationInterval = 0.02; % sec
interval = zeros(size(dt:dt:durationInterval));
fade = 0.02; % sec
f0 = 330; % Hz
freq = logspace(log10(f0), log10(4*f0), 25);
melody = [1 3 5 6 8 10 12 13 12 10 8 6 5 3 1];
lowestHarmonicRank = [8:-1:2 1:8];
nrOfHarmonics = 3;
amp = 0.1/nrOfHarmonics;

% Calculate the schematic time-frequency representation
t0 = 0;
nrOfTones = 1;
for j = 1:length(melody)
    for i = lowestHarmonicRank(j):lowestHarmonicRank(j)+nrOfHarmonics-1
        fr = i*freq(melody(j));
        schemTime(1:2, nrOfTones) = ...
            [t0 t0+durationTone]; %#ok<*SAGROW>
        schemFreq(1:2, nrOfTones) = [fr fr];
        nrOfTones = nrOfTones+1;
    end
    t0 = t0+durationTone+durationInterval;
end
% Calculate the stimulus 
envelopeTone = ...
    amp*FadeInOut(ones(size(t)), sampleFrequency, fade, fade);
stimulus = SynthToneSequence(schemTime, schemFreq, sampleFrequency, ...
    envelopeTone);

% Save and play the sound
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Specify the figure parameters
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = 180; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 90; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
% Calculate the position of the figure on the screen
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the schematic time-logfrequency representation
panel = 1;
axes('Position', pos(panel,:))
dXTick = 0.5; % sec
maxYAxis = 5000; % Hz
minYAxis = 180; % Hz
durationStimulus = length(stimulus)*dt; % sec
tAxis = ...
    [-dXTick/4 durationStimulus+dXTick/4];
fAxis = [minYAxis maxYAxis];
PlotSTlFR(stimulus, sampleFrequency, ...
    schemTime, schemFreq, envelopeTone, ...
    tAxis, dXTick, ...
    fAxis, 7*amp, blueGreen)
set(gca, 'XTick', 0:dXTick:durationStimulus, ...
    'XTickLabel', 0:dXTick:durationStimulus, ...
    'Color', lightYellowGreen)
% Plot the virtual pitches
t0 = 0;
for j = 1:length(melody)
    lf = log2(freq(melody(j))/440);
    plot([t0 t0+durationTone], [lf lf], '--', 'Color', red)
    t0 = t0+durationTone+durationInterval;
end
xlabel('time (s)', 'FontWeight', 'bold')

