clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define the stimulus
sampleFrequency = 20000; % Hz
dt = 1/sampleFrequency;
durationTone = 0.20; % sec
t = dt:dt:durationTone;
durationInterval = 0.05; % sec
interval = zeros(size(dt:dt:durationInterval));
intervalMelody = zeros(size(dt:dt:6*durationTone));
a = 440;
f = logspace(log10(a), log10(2*a), 13);
f = [f 0];
melody = [1 3 5 6 8 10 12 13 12 10 8 6 5 3 1];
nrOfHarmonics = 6;
amp = 1/nrOfHarmonics;
tau = durationTone/4; % sec

% Specify the figure parameters
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = [150 150]; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 100; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels

% Calculate the stimuli and the draw the figures
lowestPartialFrequency = [3000 4500];
panel = 0;
stimulus = [];
for k = 1:length(lowestPartialFrequency)
    % Calculate the stimulus and the schematic
    % time-frequency representation
    t0 = 0;
    nrOfTones = 1;
    for j = 1:length(melody)
        f0 = f(melody(j));
        if f0>0
            lowestHarmonicRank = ceil(lowestPartialFrequency(k)/f0);
            for i = lowestHarmonicRank:lowestHarmonicRank+nrOfHarmonics-1
                fr = i*f0;
                schemTime(1:2, nrOfTones) = ...
                    [t0 t0+durationTone]; %#ok<*SAGROW>
                schemFreq(1:2, nrOfTones) = [fr fr];
                nrOfTones = nrOfTones+1;
            end
        end
        t0 = t0+durationTone+durationInterval;
    end
    envelopeTone = amp*exp(-t/tau);
    s = SynthToneSequence(schemTime, schemFreq, sampleFrequency, ...
        envelopeTone);
    stimulus = [stimulus s intervalMelody]; %#ok<AGROW>
    
    % Calculate the position of the figure on the screen
    [figWidth, figHeight] = SetGcf(figX0, figY0, ...
        panelWidth, panelHeights, ...
        xLabelHeight, yLabelWidth, xMargin, yMargin, ...
        frameColor);
    % Calculate the positions of panels within the figure
    pos = CalculatePanelPositions(figWidth, figHeight, ...
        panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
        xMargin, yMargin);
    
    % Plot the schematic time-logfrequency representation
    panel = panel+1;
    axes('Position', pos(panel,:))
    dXTick = 1; % sec
    maxYAxis = 20000; % Hz
    durationStimulus = length(s)*dt; % sec
    tAxis = ...
        [-dXTick/4 durationStimulus+dXTick/4];
    fAxis = [280 maxYAxis];
    PlotSTlFR(s, sampleFrequency, ...
        schemTime, schemFreq, envelopeTone, ...
        tAxis, dXTick, ...
        fAxis, 0.2*amp, blueGreen)
    set(gca, 'XTick', 0:dXTick:durationStimulus, ...
        'XTickLabel', 0:dXTick:durationStimulus, ...
        'Color', lightYellowGreen)
    t0 = 0;
    for j = 1:length(melody)
        lf = log2(f(melody(j))/440);
        plot([t0 t0+durationTone], [lf lf], ...
            '--', 'Color', red)
        t0 = t0+durationTone+durationInterval;
    end
    r = log2(lowestPartialFrequency(k)/440);
    plot(tAxis, [r r], ':', 'Color', blueGreen)
    if panel == 1
        set(gca, 'XTick', 0:dXTick:durationStimulus, ...
            'XTickLabel', 0:dXTick:durationStimulus)
        xlabel('time (s)', 'FontWeight', 'bold')
    else
        set(gca, 'XTick', 0:dXTick:durationStimulus, ...
            'XTickLabel', [])
    end
end

% Save and play the sound
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

