clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define the stimulus
sampleFrequency = 44100; % Hz
dt = 1/sampleFrequency;
tau = 0.002; % sec
durationTone = 4*tau; % sec
t = dt:dt:durationTone;
freq = 440;
nrOfPartials = 8;
ratioBetweenPartials = 1.2;
amp = 1/nrOfPartials;
nrOfImpacts = 24;
restCoeff = 0.9; % restitution coefficient
restCoeff2 = restCoeff*restCoeff;
firstInterval = 0.2;

% Calculate the impact sound
envelopeTone = exp(-t/tau);
tone = zeros(size(t));
for j = 1:nrOfPartials
    f = ratioBetweenPartials^(j-1)*freq;
    tone = tone + amp*cos(2*pi*f*t);
end
tone = tone.*envelopeTone;
stimulus = tone;

% Calculate the moments of the impacts
tImp = zeros(1, nrOfImpacts);
aImp = zeros(1, nrOfImpacts);
interval = firstInterval;
tImp(1) = firstInterval;
aImp(1) = 1;
stimulus(1:length(tone)) = aImp(1)*tone;
for k = 2:nrOfImpacts
    aImp(k) = restCoeff2*aImp(k-1);
    i1 = round(tImp(k-1)/dt);
    stimulus(i1+1:i1+length(tone)) = aImp(k)*tone;
    interval = restCoeff*interval;
    tImp(k) = tImp(k-1)+interval;
end

% Save and play the sound
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = 120; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 90; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the oscillogram
panel = 1;
axes('Position', pos(panel,:))
dXTick = 0.2; % sec
durationStimulus = length(stimulus)*dt; % sec
tAxis = [-0.9*dXTick durationStimulus];
PlotSignal(stimulus, sampleFrequency, ...
    tAxis, dXTick, blueGreen, '')
set(gca, 'Color', lightYellowGreen)
xlabel('time (s)')
axis([tAxis -0.5 1.3])


