clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define the stimulus
sampleFrequency = 44100; % Hz
dt = 1/sampleFrequency;
durationTone = 0.2; % sec
t = dt:dt:durationTone;
durationInterval = 0.05; % sec
interval = zeros(size(dt:dt:durationInterval));
fade = 0.02; % sec
f0 = 220; % Hz
nrOfTones = 7;
nrOfHarmonics = 5;
amp = 0.8/nrOfHarmonics;
maxHarm = nrOfTones+nrOfHarmonics-1;

% Calculate the stimulus
a = zeros(nrOfTones, maxHarm);
for k = 1:nrOfTones
    for j = 1:nrOfHarmonics
        a(k,k+j-1) = 1;
    end
end
centroid = zeros(1, nrOfTones);
for k = 1:nrOfTones
    centroid(k) = f0*sum((1:maxHarm).*a(k,:))/sum(a(k,:));
end
envelopeTone = FadeInOut(amp*ones(size(t)), sampleFrequency, fade, fade);
stimulus = [];
for k = 1:nrOfTones
    tone = zeros(size(t));
    for i = 1:maxHarm
        s = a(k,i)*sin(2*pi*i*f0*t);
        tone = tone + s;
    end
    tone = tone.*envelopeTone;
    stimulus =  [stimulus tone interval];  %#ok<AGROW>
end

% Save and play the sound
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the excitation pattern of seven tones
I_ref = 1.0e-12;
freq = f0*(1:maxHarm);
dz = 0.01;
z = 2:dz:Hz2ERB(3*freq(end));
I = I_ref*10.^(6*a);
specLoudness = zeros(nrOfHarmonics, length(z));
loudness = zeros(1, nrOfHarmonics);
centroid = zeros(1, nrOfHarmonics);
for k = 1:nrOfTones
    [~, specLoudness(k,:)] = ...
        CalcLoudnessFunctions(freq, I(k,:), z, 1, 1);
    loudness(k) = dz*sum(specLoudness(k,:));
    centroid(k) = sum(z.*specLoudness(k,:))/sum(specLoudness(k,:));
end

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = 300; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 90; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot specific loudness distributions
panel = 1;
axes('Position', pos(panel,:))
rangeXAxis = [3 25];
rangeYAxis = [0 1.3*max(specLoudness(:))]; % dB
set(gca, 'Box', 'on', 'LineWidth', 2, ...
    'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'XTick', 5:5:40, 'YTick', 0:0.5:5, ...
    'FontSize', 14, 'Fontweight', 'bold')
for k = nrOfTones:-1:1
    rr = k/(nrOfTones+1);
    co = (1-rr)*blueGreen+rr*[1 1 1];
    plot(z, specLoudness(k,:), 'Color', co, 'LineWidth', 2)
    plot(centroid(k), 1.8, 'o', 'Color', co, 'LineWidth', 2)
    text(centroid(k), 2.0, sprintf('%1.2f', ERB2Hz(centroid(k))/1000), ...
        'FontSize', 8, 'HorizontalAlignment', 'center')
    text(centroid(k), 2.15, sprintf('%2.1f', centroid(k)), ...
        'FontSize', 8, 'HorizontalAlignment', 'center')
end
plot([0 z(end)], [0 0], 'Color', [0 0 0], 'LineWidth', 2)
text(centroid(1)-0.5, 2.15, 'centroid at ', ...
    'FontSize', 8, 'HorizontalAlignment', 'right')
text(centroid(nrOfTones)+0.7, 2.15, 'Cam', ...
    'FontSize', 8, 'HorizontalAlignment', 'left')
text(centroid(nrOfTones)+0.7, 2, 'kHz', ...
    'FontSize', 8, 'HorizontalAlignment', 'left')

axis([rangeXAxis rangeYAxis])
xlabel('Cam')
ylabel('specific loudness (sone/ERB)')

    sprintf('mImages/%s.jpg', mfilename);

