clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define the stimulus
sampleFrequency = 44100; % Hz
dt = 1/sampleFrequency;
durationTone = 0.2; % sec
t = dt:dt:durationTone;
durationInterval = 0.05; % sec
interval = zeros(size(dt:dt:durationInterval));
fade = 0.02; % sec
f0 = 220; % Hz
tilt = -30:10:30; % tilt in dB
nrOfHarmonics = 6;
amp = 1/nrOfHarmonics;

% Calculate the stimulus
harmonics = 1:nrOfHarmonics;
I_dB = zeros(length(tilt), nrOfHarmonics);
for k = 1:length(tilt)
    I_dB(k,:) = ...
        ((harmonics)-(nrOfHarmonics+1)/2)/(nrOfHarmonics-1)*tilt(k);
end
a = amp*10.^(I_dB/20);
envelopeTone = FadeInOut(amp*ones(size(t)), sampleFrequency, fade, fade);
stimulus = [];
for k = 1:length(tilt)
    tone = zeros(size(t));
    for i = harmonics
        s = a(k,i)*sin(2*pi*i*f0*t);
        tone = tone + s;
    end
    tone = tone.*envelopeTone;
    stimulus =  [stimulus tone interval];  %#ok<AGROW>
end

% Save and play the sound
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the excitation pattern of seven tones
I_ref = 1.0e-12;
freq = f0*(1:nrOfHarmonics);
I_dB = 50+I_dB;
dz = 0.01;
z = 2:dz:Hz2ERB(3*freq(end));
I = I_ref*10.^(I_dB/10);
specLoudness = zeros(nrOfHarmonics, length(z));
loudness = zeros(1, nrOfHarmonics);
centroid = zeros(1, nrOfHarmonics);
for k = 1:length(tilt)
    [~, specLoudness(k,:)] = ...
        CalcLoudnessFunctions(freq, I(k,:), z, 1, 1);
    loudness(k) = dz*sum(specLoudness(k,:));
    centroid(k) = sum(z.*specLoudness(k,:))/sum(specLoudness(k,:));
end

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = 300; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 90; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot specific loudness distributions
panel = 1;
axes('Position', pos(panel,:))
rangeXAxis = [3 25];
rangeYAxis = [0 1.3*max(specLoudness(:))]; % dB
set(gca, 'Box', 'on', 'LineWidth', 2, ...
    'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'XTick', 5:5:40, 'YTick', 0:0.5:5, ...
    'FontSize', 14, 'Fontweight', 'bold')
for k = length(tilt):-1:1
    r = k/(length(tilt)+1);
    c = (1-r)*blueGreen+r*[1 1 1];
    plot(z, specLoudness(k,:), 'Color', c, 'LineWidth', 2)
    plot(centroid(k), 1.8, 'o', 'Color', c, 'LineWidth', 2)
    text(centroid(k), 2.0, sprintf('%1.2f', ERB2Hz(centroid(k))/1000), ...
        'FontSize', 8, 'HorizontalAlignment', 'center')
    text(centroid(k), 2.15, sprintf('%2.1f', centroid(k)), ...
        'FontSize', 8, 'HorizontalAlignment', 'center')
end
plot([0 z(end)], [0 0], 'Color', [0 0 0], 'LineWidth', 2)
text(centroid(1)-0.5, 2.15, 'centroid at ', ...
    'FontSize', 8, 'HorizontalAlignment', 'right')
text(centroid(length(tilt))+0.7, 2.15, 'Cam', ...
    'FontSize', 8, 'HorizontalAlignment', 'left')
text(centroid(length(tilt))+0.7, 2, 'kHz', ...
    'FontSize', 8, 'HorizontalAlignment', 'left')
axis([rangeXAxis rangeYAxis])
xlabel('Cam')
ylabel('specific loudness (sone/ERB)')

    sprintf('mImages/%s.jpg', mfilename);

