clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define the stimulus
sampleFrequency = 44100; % Hz
dt = 1/sampleFrequency;
durationTone = 0.2; % sec
t = dt:dt:durationTone;
durationInterval = 0.05; % sec
interval = zeros(size(dt:dt:durationInterval));
fade = 0.02; % sec
f0 = 220; % Hz
tilt = -30:10:30; % tilt in dB
nrOfHarmonics = 6;
amp = 1/nrOfHarmonics;

% Calculate the stimulus
I_dB = zeros(length(tilt), nrOfHarmonics);
for k = 1:length(tilt)
    I_dB(k,:) = ...
        ((1:nrOfHarmonics)-(nrOfHarmonics+1)/2)/(nrOfHarmonics-1)*tilt(k);
end
a = amp*10.^(I_dB/20);
% calculate centroid
centroid = zeros(1, length(tilt));
for k = 1:length(tilt)
    centroid(k) = sum((1:nrOfHarmonics).*a(k,:))/sum(a(k,:));
end
envelopeTone = FadeInOut(amp*ones(size(t)), sampleFrequency, fade, fade);
stimulus = [];
for k = 1:length(tilt)
    tone = zeros(size(t));
    for i = 1:nrOfHarmonics
        s = a(k,i)*sin(2*pi*i*f0*t);
        tone = tone + s;
    end
    tone = tone.*envelopeTone;
    stimulus =  [stimulus tone interval];  %#ok<AGROW>
end

% Save and play the sound
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = 180; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 90; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the sound signal
axes('Position', pos(1,:))
dXTick = 1;
dYTick = 5;
hold 'on'
for k = 1:length(tilt)
    plot(1:nrOfHarmonics, I_dB(k,:), ':', 'LineWidth', 0.5, 'Color', 'k')
    plot(1:nrOfHarmonics, I_dB(k,:), '.', 'MarkerSize', 15, 'Color', 'k')
    plot(centroid(k), tilt(1)/2-2, '*', 'MarkerSize', 6, 'Color', 'k')
    text(centroid(k)-0.12, tilt(1)/2-2, sprintf('%d', k))
    text(0.85, I_dB(k,1), sprintf('%d', k))
    text(centroid(k), tilt(1)/2-6, sprintf('%1.2f', centroid(k)*f0/1000), ...
        'HorizontalAlignment', 'center')
end
text(centroid(1)-0.2, tilt(1)/2-6, 'spectral centroid: ', ...
    'HorizontalAlignment', 'right')
text(centroid(k)+0.2, tilt(1)/2-6, 'kHz')
set(gca, 'LineWidth', 2, 'FontSize', 14, ...
    'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', 0:nrOfHarmonics+1, ...
    'XTickLabel', (0:nrOfHarmonics+1)*f0/1000, ...
    'YTick', tilt(1):15:tilt(end))
axis([0.5 nrOfHarmonics+0.5 tilt(1)/2-10 tilt(end)/2+5])
xlabel('frequency of harmonic (kHz)')
ylabel('amplitude (dB)')

    sprintf('mImages/%s.jpg', mfilename);

