clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define the stimulus
sampleFrequency = 44100; % Hz
dt = 1/sampleFrequency;
durationInterval = 0.5; % sec
tau = 0.08; % sec
durationTone = 4*tau; % sec
t = dt:dt:durationTone;
interval = zeros(size(dt:dt:(durationInterval-durationTone)));
freqLow = 110;
nrOfOctaves = 7;
freq = freqLow*2.^(0:nrOfOctaves-1);
nrOfPartials = 3;
ratioBetweenPartials = 1.2;
amp = 1/nrOfPartials;

% Calculate the stimulus
t0 = 0;
nrOfTones = 1;
for k = 1:length(freq)
    for i = 1:nrOfPartials
        f = ratioBetweenPartials^(i-1)*freq(k);
        schemTime(1:2, nrOfTones) = [t0 t0+durationTone]; %#ok<SAGROW>
        schemFreq(1:2, nrOfTones) = [f f]; %#ok<SAGROW>
        nrOfTones = nrOfTones+1;
    end
    t0 = t0+durationInterval;
end
envelopeTone = amp*exp(-t/tau);
stimulus = SynthToneSequence(schemTime, schemFreq, sampleFrequency, ...
    envelopeTone);

% Save and play the sound

wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = 360; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 90; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the schemetic time vs log-frequency representation
durationStimulus = length(stimulus)*dt; % sec
dXTick = 1; % sec
XTick = 0:dXTick:durationStimulus;
maxYAxis = sampleFrequency/2; % Hz
tAxis = [-dXTick/4 durationStimulus+dXTick/4];
fAxis = [80 maxYAxis];
lFAxis = log2(fAxis/440);
PlotSTlFR(stimulus, sampleFrequency, ...
    schemTime, schemFreq, envelopeTone, ...
    tAxis, dXTick, ...
    fAxis, 0.1*amp, blueGreen)
set(gca, 'XTick', XTick, 'XTickLabel', XTick, ...
    'Color', lightYellowGreen);
xlabel('time (s)')
text(tAxis(1)/2, lFAxis(1)+0.9*(lFAxis(2)-lFAxis(1)), ...
    'schematic time vs log-frequency representation', ...
    'FontSize', 14, 'FontWeight', 'bold')


