clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Synthesize the stimulus
sampleFrequency = 44100; % Hz
dt = 1/sampleFrequency;
duration = 20; % sec
t = 0:dt:duration;
fade = 0.02; % sec
amp = 0.8;
fc = 1000; % Hz
fmBegin = 2; % Hz
fmEnd = 800; % Hz
fmInst = fmBegin*10.^((t/duration)*log10(fmEnd/fmBegin));
phi = 2*pi*cumsum(fmInst)*dt;
chi = 2*pi*fc*t;
stimulus = 0.5*(1+amp*cos(phi)).*sin(chi);
% stimulus = 0.5*(sin(phi+chi)-sin(phi-chi));
% Calculate instantaneous frequencies of low tone and high tone
fInstLow = diff(-(phi-chi))/(2*pi*dt);
fInstHigh = diff(phi+chi)/(2*pi*dt);
% Prevent audible clicks at onset and offset
stimulus = FadeInOut(stimulus, sampleFrequency, fade, fade);

% Save and play the sound
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the roughness curve
meas = 1:1000:length(t)-1;
fLow = fInstLow(meas);
fHigh = fInstHigh(meas);
% The following data points are estimated from Figure 3 
% of Daniel & Weber (1997)
frMeas = 20:10:160;
roughnessMeas = (1/19.7)* ...
    [4.5  8.5 12.4 16.5 19.0 19.7 19.1 17.3 15.3 12.7 11.2  9.8 ...
    8.8  7.7  6.7];
% Calculate the moments at which the carrier frequency is 
% frMeas, i.e., 20:10:160 Hz.
tMeas = interp1(fmInst, 1:length(t), frMeas, 'nearest');
 
% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position of figure in pixels from bottom
panelWidth = 450; % pixels
panelHeights = 150; % pixels
xLabelHeight = 80; % pixels
yLabelWidth = 80; % pixels
xMargin = 90; % pixels
yMargin = 90; % pixels
% Set the current figure handle and return the width and 
% height of the figure. 
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the figure
axes('Position', pos(1,:))
yTick = [50 100 200 500 1000 2000 5000 10000];
logFTick = log10(yTick);
xTick = [2 5 10 20 50 100 200 500 1000];
xTickLabel = log10(xTick); % Diff. freq. is twice the mod. freq.
logYTick = log10(xTick);
xAxis = [log10(fmBegin) log10(fmEnd)];
yAxis = [log10(150) log10(2500)];
set(gca, 'LineWidth', 2, 'FontSize', 14, ...
    'Box', 'off', 'Color', lightYellowGreen, 'NextPlot', 'add', ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'YAxisLocation', 'right', ...
    'Ytick', logFTick, 'YtickLabel', yTick/1000, ...
    'Xtick', log10(xTick), 'XTickLabel', xTick)
plot(log10(fmInst(2:end)), log10(fInstLow), 'Color', red)
plot(log10(fmInst(2:end)), log10(fInstHigh), 'Color', red)
plot([log10(fmBegin) log10(fmEnd)], [log10(fc) log10(fc)], ...
    'Color', red, 'LineWidth', 2)
xlabel('modulation frequency ({\itf}_c) (Hz)')
ylabel('frequency (kHz)', ...
    'Rotation', 270, 'Position', [3.3127 2.7500 -1.0000])
axis([xAxis yAxis])

axes('Position', pos(1,:))
xAxis = [0 duration];
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
    'Box', 'off', 'Color', 'none', 'NextPlot', 'add', ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'XAxisLocation', 'top', 'Ytick', 0:0.2:1, 'Xtick', 0:4:duration)
plot (t(tMeas), roughnessMeas, 'LineWidth', 2, 'Color', blueGreen)
xlabel('time (s)')
ylabel('roughness (asper)')
axis([xAxis 0 1.2])


