clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Synthesize the stimulus
sampleFrequency = 44100; % Hz
dt = 1/sampleFrequency;
duration = 20; % sec
t = dt:dt:duration-dt;
fade = 0.02; % sec
amp = 0.8;
fc = 1000; % Hz
fmBegin = 800; % Hz
fmEnd = 2; % Hz
fmInst = fmBegin*10.^((t/duration)*log10(fmEnd/fmBegin));
phi = 2*pi*cumsum(fmInst)*dt;
chi = 2*pi*fc*t;
stimulus = amp*cos(phi).*sin(chi);
% stimulus = 0.5*(sin(phi+chi)-sin(phi-chi));
% Calculate instantaneous frequencies of low tone and high tone
fInstLow = diff(-(phi-chi))/(2*pi*dt);
fInstHigh = diff(phi+chi)/(2*pi*dt);
% Prevent audible clicks at onset and offset
stimulus = FadeInOut(stimulus, sampleFrequency, fade, fade);

% Save and play the sound
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the lower and the higher roughness boundary
% Based on Fig. 4 of Terhardt (1968a). 
% Lower boundary passes through (200, 10) and (4000, 15) Hz;
% (NB: difference frequency is twice the modulation frequency!
% Upper boundary approximated by arctangent. 
freqRef = [200 4000];
boundaryLowRef = [10 15];
logFreqRef = log10(freqRef);
logBoundaryLowRef = log10(boundaryLowRef);
d = det([logFreqRef; 1 1]);
a = det([logBoundaryLowRef; 1 1])/d;
b = det([logFreqRef; logBoundaryLowRef])/d;
f = logspace(log10(100), log10(10000), 100);
boundaryLow = a*log10(f)+b;
boundaryHigh = log10(75)+0.24*(2/pi)*atan(3*(log10(f/fc)));

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position of figure in pixels from bottom
panelWidth = 450; % pixels
panelHeights = 300; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 70; % pixels
xMargin = 20; % pixels
yMargin = 20; % pixels
% Set the current figure handle and return the width and 
% height of the figure. 
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);

% Plot the figure
fTick = [50 100 200 500 1000 2000 5000 10000];
logFTick = log10(fTick);
fbTick = [2 5 10 20 50 100 200 500];
fbTickLabel = 2*fbTick; % Difference frequency is twice the mod. freq.
logFbTick = log10(fbTick);
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
    'Box', 'on', 'Color', lightYellowGreen, 'NextPlot', 'add', ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'Xtick', logFTick, 'XtickLabel', fTick/1000, ...
    'Ytick', logFbTick, 'YtickLabel', fbTickLabel)
for k = 1:length(f)
    plot([log10(f(k)) log10(f(k))], ...
    [boundaryLow(k) boundaryHigh(k)], ...
    ':', 'LineWidth', 1.5, 'Color', blueGreen)
end
plot(log10(fInstLow), log10(fmInst(2:end)), 'Color', red)
plot(log10(fInstHigh), log10(fmInst(2:end)), 'Color', red)
plot(log10([fc fc]), [log10(fmEnd) log10(fmBegin)], ':', 'Color', red)
text(log10(1000), log10(5), 'beats', ...
    'FontSize', 18, 'HorizontalAlignment', 'center')
text(log10(1000), log10(32), 'roughness', ...
    'FontSize', 24, 'HorizontalAlignment', 'center')
text(log10(1000), log10(270), 'two tones', ...
    'FontSize', 18, 'HorizontalAlignment', 'center')
xlabel('carrier frequency ({\itf}_c) (kHz)')
ylabel('difference frequency ({\itf}_2-{\itf}_1) (Hz)')
axis([log10(f(1)) log10(f(end)) log10(fmEnd) log10(fmBegin)])


