clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define and calculate the stimuli
sampleFrequency = 44100; % Hz
dt = 1/sampleFrequency;
toneDuration = 0.5;
t = dt:dt:toneDuration;
durationInterval = 0.2;
interval =  zeros(size(dt:dt:durationInterval));
amp = 0.9;
fc = 1000; % Hz
fm = 40;
md = 0.8;
fade = 0.02; % sec
env(1,:) = amp*0.5*(1+md*sawtooth(2*pi*fm*t, 0.1));
env(2,:) = amp*0.5*(1+md*sawtooth(2*pi*fm*t, 0.9));
env(1,:) = FadeInOut(env(1,:), sampleFrequency, fade, fade);
env(2,:) = FadeInOut(env(2,:), sampleFrequency, fade, fade);
s(1,:) = env(1,:).*cos(2*pi*fc*t);
s(2,:) = env(2,:).*cos(2*pi*fc*t);
stimulus = [s(2,:) interval s(1,:)];

% Save and play the stimumus
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = [180 180]; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 70; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the two sounds
panel = 1;
axes('Position', pos(panel,:))
dXTick = 0.02;
xTick = 0:dXTick:toneDuration; % sec
xAxis = [0.20 0.32];
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
    'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'YTick', -1:1, 'XTick', xTick)
plot(t, s(panel,:), ...
    'Color', blueGreen, 'LineWidth', 1.5);
plot(t, env(panel,:), '--', t, -env(panel,:), ...
    '--', 'Color', red, 'LineWidth', 1);
plot([-0.1 length(stimulus)/sampleFrequency+0.1], [0 0], ...
    'Color', blueGreen, 'Linewidth', 0.5)
xlabel('time (s)', 'FontWeight', 'bold')
ylabel('signal')
axis([xAxis -1.1 1.1])

panel = panel+1;
axes('Position', pos(panel,:))
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
    'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'YTick', -1:1, 'XTick', xTick, 'XTickLabel', [])
plot(t, s(panel,:), ...
    'Color', blueGreen, 'LineWidth', 1.5);
plot(t, env(panel,:), '--', t, -env(panel,:), ...
    '--', 'Color', red, 'LineWidth', 1);
plot([-0.1 length(stimulus)/sampleFrequency+0.1], [0 0], ...
    'Color', blueGreen, 'Linewidth', 0.5)
ylabel('signal')
axis([xAxis -1.1 1.1])


