clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define the stimulus
sampleFrequency = 10000; % Hz
dt = 1/sampleFrequency;
duration = 0.3; % sec
t = dt:dt:duration;
silenceDuration = 0.1;
silence = zeros(size(dt:dt:silenceDuration));
ampl = 0.9;
f0 = 600; % Hz
% Formant frequencies and bandwidths.
% Data from Table II of (Peterson & Barney, 1952, p. 183).
formantFrequencies = [...
    270 2290 3010 3500 4500 % /i/
    390 1990 2550 3500 4500 % /I/
    530 1840 2480 3500 4500 % /\x025B/
    660 1720 2410 3500 4500 % /\x00E6/
    730 1090 2440 3500 4500 % /\x0251/
    570  840 2410 3500 4500 % /\x0254/
    440 1020 2240 3500 4500 % /\x028A/
    300  870 2240 3500 4500 % /u/
    640 1190 2390 3500 4500 % /\x028C/
    490 1350 2240 3500 4500]; % /\x025C/
nVowels = size(formantFrequencies, 1);
permFormantFrequencies = formantFrequencies(randperm(nVowels),:);
formantBandwidths = [60 90 120 180 240];
preEmph = -0.8;
% Synthesize pulse series
pulses = zeros(1, length(t));
pulses(1:round(sampleFrequency/f0):length(t)) = 1;

% Calculate formant filter and filter source
f = linspace(0, sampleFrequency/2, 1000);
dw = 2*pi*dt;
stimulus = silence;
nSpc = 1000;
spc = zeros(size(permFormantFrequencies, 1), nSpc);
for k = 1: size(permFormantFrequencies, 1)
    a = [1 preEmph];
    b = 1;
    for j = 1:size(permFormantFrequencies, 2)
        p = exp(-formantBandwidths(j)*dw);
        q = cos(permFormantFrequencies(k, j)*dw);
        a = conv(a, [1 -2*p*q p*p]);
        b = conv(1-2*p*q+p*p, b);
    end
    vowel = filter(b, a, pulses);
    vowel = ampl*vowel/max(abs(vowel));
    vowel = FadeInOut(vowel, sampleFrequency, 0.02, 0.02);
    stimulus = [stimulus vowel silence]; %#ok<AGROW>
    spc(k,:) = abs(freqz(b, a, f, sampleFrequency));
    spc(k,:) = 20*log10(spc(k,:))+30;
end

% Save and play the sound
wavFileName = ...
    sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the position of the figure on the screen
% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = [120 120]; % pixels
xLabelHeight = 45; % pixels
yLabelWidth = 45; % pixels
xMargin = 0; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

dXTick = 1000;
xTick = 0:dXTick:sampleFrequency/2-1;
yTick = 0:20:100;
panel = 2;
for k = 1:nVowels/2
    % Calculate the position of the figure on the screen
    p = pos(panel,:);
    p(3) = pos(panel, 3)/(size(permFormantFrequencies, 1)/2)-0.015;
    p(1) = pos(panel, 1)+(k-1)*(p(3)+0.015);
    axes('Position', p)
    set(gca, 'LineWidth', 1.5, 'FontSize', 9, ...
        'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
        'FontWeight', 'bold', ...
        'TickDir', 'out', 'TickLength', [0.03 0.025], ...
        'XTick', xTick, 'XTickLabel', [], 'YTick', yTick)
    if k == 1
        set(gca, 'YTickLabel', (-30:20:30)+30)
        ylabel('power (dB)')
    else
        set(gca, 'YTickLabel', [])
    end
    plot(f, spc(k,:), ':', 'Color', darkRed, 'LineWidth', 2)
    for j = 1:round(nSpc*f0*2/sampleFrequency):nSpc
        plot([j j]*sampleFrequency/2/nSpc, [-40 spc(k, j)], ...
            'Color', blueGreen, 'LineWidth', 1)
    end
    axis([0 sampleFrequency/2 -5 70])
end
panel = panel-1;
for k = (nVowels/2+1):nVowels
    % Calculate the position of the figure on the screen
    p = pos(panel,:);
    p(3) = pos(panel, 3)/(size(permFormantFrequencies, 1)/2)-0.015;
    p(1) = pos(panel, 1)+(k-nVowels/2-1)*(p(3)+0.015);
    axes('Position', p)
    set(gca, 'LineWidth', 1.5, 'FontSize', 9, ...
        'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
        'FontWeight', 'bold', ...
        'TickDir', 'out', 'TickLength', [0.03 0.025], ...
        'XTick', xTick, 'XTickLabel', xTick/1000, ...
        'YTick', yTick)
    if k == nVowels/2+1
        set(gca, 'YTickLabel', yTick)
        ylabel('power (dB)')
    else
        set(gca, 'YTickLabel', [])
    end
    plot(f, spc(k,:), ':', 'Color', darkRed, 'LineWidth', 2)
    for j = 1:round(nSpc*f0*2/sampleFrequency):nSpc
        plot([j j]*sampleFrequency/2/nSpc, [-40 spc(k, j)], ...
            'Color', blueGreen, 'LineWidth', 1)
    end
    axis([0 sampleFrequency/2 -5 70])
    xlabel('freq. (kHz)')
end

    sprintf('mImages/%s.jpg', mfilename);


