clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Formant frequencies
% Data from Table II of (Peterson & Barney, 1952, p. 183).
formantFrequencies = [...
    270 2290 3010 3500 4500 % /i/
    390 1990 2550 3500 4500 % /I/
    530 1840 2480 3500 4500 % /\x025B/
    660 1720 2410 3500 4500 % /\x00E6/
    730 1090 2440 3500 4500 % /\x0251/
    570  840 2410 3500 4500 % /\x0254/
    440 1020 2240 3500 4500 % /\x028A/
    300  870 2240 3500 4500 % /u/
    640 1190 2390 3500 4500 % /\x028C/
    490 1350 2240 3500 4500 % /\x025C/
    990 1450 2550 3500 4500]; % /a/, from Pols et al. (1969), p. 464
nVowels = size(formantFrequencies, 1);
txt1 = sprintf('/i/ /\x026A/ /\x025B/ /\x00E6/ /\x0251/ /\x0254/');
txt2 = sprintf(' /\x028A/ /u/ /\x028C/ /\x025C/ /a/');
vowelTxt = strcat(txt1, txt2);

% Figure parameters
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 360; % pixels
panelHeights = 360; % pixels
xLabelHeight = 90; % pixels
yLabelWidth = 90; % pixels
xMargin = 25; % pixels
yMargin = 25; % pixels

% Calculate the position of the figure on the screen
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);
axes('Position', pos)
xT = [200 300 400 600 800 1200 1600 2400];
xTick = log10(xT);
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
    'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', xTick, 'XTickLabel', xT, ...
    'YTick', xTick, 'YTickLabel', xT)
for k = 1: nVowels
    text(log10(formantFrequencies(k, 1)), ...
        log10(formantFrequencies(k, 2)), ...
        vowelTxt((1:3)+(k-1)*4), 'FontSize', 18, ...
        'HorizontalAlignment', 'left', ...
        'VerticalAlignment', 'middle')
end
xlabel('F1 (Hz)')
ylabel('F2 (Hz)')
axis(log10([200 1500 600 3000]))

    sprintf('mImages/%s.jpg', mfilename);


