clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Table for the Bark scale (Zwicker, 1961)
bark = [ 0     0
         1   100
         2   200
         3   300
         4   400
         5   510
         6   630
         7   770
         8   920
         9  1080
        10  1270
        11  1480
        12  1720
        13  2000
        14  2320
        15  2700
        16  3150
        17  3700
        18  4400
        19  5300
        20  6400
        21  7700
        22  9500
        23 12000
        24 15500];

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position of figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = 360; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 70; % pixels
xMargin = 15; % pixels
yMargin = 20; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

minFrequency = 20;
maxFrequency = 20000;
f = logspace(log10(minFrequency), log10(maxFrequency), 100);

% Calculates the Bark scale (Traunmüller, 1990)
z = 26.81*f./(1960+f) - 0.53;

% Calculates the ERB-rate scale (Glasberg & Moore, 1990)
e = Hz2ERB(f);

for i = 1:length(f)
    if z(i)<2.0
        z(i) = z(i) + 0.15*(2.0-z(i));
    end
    if z(i)>20.1
        z(i) = z(i) + 0.22*(z(i)-20.1);
    end
end

% Plot the graphs
axes('Position', pos)
xTick = log10([20 50 100 200 500 1000 2000 5000 10000 20000]);
set(gca, 'Box', 'on', 'NextPlot', 'add', 'LineWidth', 2, ...
    'FontSize', 14, 'Fontweight', 'bold', 'NextPlot', 'add', ...
    'TickDir', 'out', 'Color', lightYellowGreen, ...
    'XTick', xTick, 'XTickLabel', (10.^xTick)/1000)
plot(log10(f), z, ':', 'LineWidth', 2, 'Color', darkRed)
plot(log10(bark(:,2)), bark(:,1), '+', ...
    'LineWidth', 2, 'Color', red)
plot(log10(f), e, '-', 'LineWidth', 2, 'Color', blueGreen)
axis([log10(minFrequency) log10(maxFrequency) 0 40])
xlabel('frequency (kHz)', 'FontSize', 14, 'Fontweight', 'bold')
ylabel('nr of auditory filter', ...
    'FontSize', 14, 'Fontweight', 'bold')
legend('Bark (equation by Traunmüller, 1990)', ...
    'Bark (table from Zwicker, 1961)', ...
    'Cam (equation by Glasberg & Moore, 1990)', ...
    'Location', 'northwest')

