clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = [180 180]; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 70; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Calculate the excitation pattern of seven-tone complex
I_ref = 1.0e-12;
f0 = 400; % Hz
nrOfHarmonics = 7;
f7Harmonics = f0*(1:nrOfHarmonics);
I_dB = 45;
fr = 50:3*f7Harmonics(end);
z = Hz2ERB(fr);
I = I_ref*10.^(I_dB/10);
excPattern7Harmonics = zeros(nrOfHarmonics+1, length(z));
for k = 1:nrOfHarmonics
    [excPattern7Harmonics(k,:), ~] = ...
        CalcLoudnessFunctions(f7Harmonics(k), I, z, 1, 1);
end
[excPattern7Harmonics(nrOfHarmonics+1,:), ~] = ...
    CalcLoudnessFunctions(f7Harmonics, I, z, 1, 1);

% Calculate the excitation pattern of two-tone complex
nrOfHarmonics = 2;
f2Harmonics = f0*(1:nrOfHarmonics);
excPattern2Harmonics = zeros(nrOfHarmonics+1, length(z));
for k = 1:nrOfHarmonics
    [excPattern2Harmonics(k,:), ~] = ...
        CalcLoudnessFunctions(f2Harmonics(k), I, z, 1, 1);
end
[excPattern2Harmonics(nrOfHarmonics+1,:), ~] = ...
    CalcLoudnessFunctions(f2Harmonics, I, z, 1, 1);

% Calculate excitation pattern of two-tone complex
panel = 1;
axes('Position', pos(panel,:))
rangeYAxis = [I_dB+10-90 I_dB+20]; % dB
set(gca, 'Box', 'on', 'LineWidth', 2, ...
    'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'XTick', 5:5:40, 'YTick', -25:25:100, ...
    'FontSize', 14, 'Fontweight', 'bold')
for k = 1:size(excPattern7Harmonics-1, 1)
    plot(z, excPattern7Harmonics(k,:), 'Color', blueGreen, 'LineWidth', 0.5)
end
plot(z, excPattern7Harmonics(k,:), 'Color', blueGreen, 'LineWidth', 2)
axis([0 Hz2ERB(fr(end)) rangeYAxis])
xlabel('Cam')
ylabel('excitation (dB)')
txt = [sprintf('%6d, ', f7Harmonics(1:end-1)) sprintf(' and %4d %s ', f7Harmonics(end), 'Hz')];
text(0.5, 55, txt, 'FontSize', 12, 'Fontweight', 'bold')

% Calculate excitation pattern of two-tone complex
panel = panel+1;
axes('Position', pos(panel,:))
set(gca, 'Box', 'on', 'LineWidth', 2, ...
    'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'XTick', 5:5:40, 'XTickLabel', [], ...
    'YTick', -25:25:100, 'YTickLabel', -25:25:100, ...
    'FontSize', 14, 'Fontweight', 'bold')
for k = 1:size(excPattern2Harmonics-1, 1)
    plot(z, excPattern2Harmonics(k,:), 'Color', blueGreen, 'LineWidth', 0.5)
end
plot(z, excPattern2Harmonics(k,:), 'Color', blueGreen, 'LineWidth', 2)
axis([0 Hz2ERB(fr(end)) rangeYAxis])
ylabel('excitation (dB)')
txt = [sprintf('%6d ', f2Harmonics(1:end-1)) sprintf(' and %4d %s ', f7Harmonics(end), 'Hz')];
text(0.5, 55, txt, 'FontSize', 12, 'Fontweight', 'bold')


