clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Calculate the excitation pattern
I_ref = 1.0e-12;
f = 1500; % Hz
I_dB = 51;
fc = logspace(log10((2/3)*f), log10((3/2)*f), 7); % Hz

fr = 50:3*f;
z = Hz2ERB(fr);
I = I_ref*10.^(I_dB/10);
[excitationPattern, ~] = CalcLoudnessFunctions(f, I, z, 1, 1);

% Calculate the rounded exponentials
logTr = zeros(length(fc), length(fr));
for k = 1:length(fc)
    w = RoundedExponential(fr, fc(k), I_dB); 
    logTr(k,:) = 10*log10(w')+I_dB;
end

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = [240 240]; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 70; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the excitation pattern
panel = 1;
rangeXAxis = [5 Hz2ERB(fr(end))];
rangeYAxis = [I_dB+10-90 I_dB+10]; % dB
xTick = 5:5:40;
yTick = -25:25:100;
axes('Position', pos(panel,:))
set(gca, 'Box', 'on', 'LineWidth', 2, ...
    'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'XTick', xTick, 'YTick', yTick, ...
    'FontSize', 14, 'Fontweight', 'bold', 'TickDir', 'out')
plot(z, excitationPattern, 'Color', blueGreen, 'LineWidth', 2)
for k = 1:length(fc)
    l = find(round(fr) == round(fc(k)));
    plot([Hz2ERB(fc(k)) Hz2ERB(fc(k))], [rangeYAxis(1) excitationPattern(l)], ...
        'Color', blueGreen, 'LineWidth', 2)
    plot(Hz2ERB(fc(k)), excitationPattern(l), 'o', 'Color', blueGreen)
    text(Hz2ERB(fc(k))+0.3, excitationPattern(l), ...
        sprintf('%d Hz', round(fc(k))), 'FontSize', 6)
end
xlabel('Cam')
ylabel('excitation (dB)')
axis([rangeXAxis rangeYAxis])

% Plot the roex filters
panel = panel+1;
axes('Position', pos(panel,:))
set(gca, 'Box', 'on', 'LineWidth', 2, ...
    'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'XTick', xTick, 'XTickLabel', [], 'YTick', yTick, ...
    'FontSize', 14, 'Fontweight', 'bold', 'TickDir', 'out')
for k = 1:length(fc)
    plot(z, logTr, 'Color', blueGreen)
    exc = logTr(k, fr == f);
    plot(Hz2ERB(f), exc, 'o', 'Color', blueGreen)
    text(Hz2ERB(f)+0.2, exc, ...
        sprintf('%d Hz', round(fc(k))), 'FontSize', 6)
end
plot(Hz2ERB([f f]), [rangeYAxis(1) I_dB], 'Color', blueGreen, 'LineWidth', 2)
ylabel('transfer (dB)')
axis([rangeXAxis rangeYAxis])


