% % copyright statement 
clear
close all
InitializePSS()

% Calculate the excitation patterns
I_ref = 1.0e-12;
f = 1500;
zMin = 3;
zMax = Hz2ERB(20000);
dz = 0.1;
z = zMin:dz:zMax;
I_dB = 20:10:90;
excitationPattern = zeros(length(I_dB), length(z));
for k = 1:length(I_dB)
    I = I_ref*10.^(I_dB(k)/10);
    [excitationPattern(k,:), ~] = ...
        CalcLoudnessFunctions(f, I, z, 1, 1);
end

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = 240; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 70; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the excitation patterns
axes('Position', pos)
zMin = 3;
zMax = Hz2ERB(20000);
dz = 0.1;
z = zMin:dz:zMax;
rangeYAxis = [0 100]; % dB
rangeXAxis = [11 zMax];
set(gca, 'Box', 'on', 'LineWidth', 2, ...
    'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'XTick', 5:5:40, 'YTick', -20:20:100, ...
    'FontSize', 14, 'Fontweight', 'bold')
for k = 1:length(I_dB)
    plot(z, excitationPattern(k,:), 'Color', blueGreen, 'LineWidth', 2)
    text(12, I_dB(k), sprintf('%5.2f dB', I_dB(k)))
end
xlabel('Cam')
ylabel('excitation (dB)')
axis([rangeXAxis rangeYAxis])



