clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = [270 270]; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 70; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Calculate the excitation pattern of seven-tone complex
I_ref = 1.0e-12;
f0 = 400; % Hz
nrOfHarmonics = 7;
f7Harmonics = f0*(1:nrOfHarmonics);
I_dB = 45;
fr = 50:3*f7Harmonics(end);
dz = 0.01;
z = 5:dz:Hz2ERB(fr(end));
I = I_ref*10.^(I_dB/10);
[~, specLoudness7Harmonics] = ...
    CalcLoudnessFunctions(f7Harmonics, I, z, 1, 1);
loudness7 = dz*sum(specLoudness7Harmonics);

% Calculate the excitation pattern of two-tone complex
nrOfHarmonics = 2;
f2Harmonics = f0*(1:nrOfHarmonics);
[~, specLoudness2Harmonics] = ...
    CalcLoudnessFunctions(f2Harmonics, I, z, 1, 1);
loudness2 = dz*sum(specLoudness2Harmonics);

% Plot specific loudness distribution of seven-tone complex
panel = 1;
axes('Position', pos(panel,:))
rangeYAxis = [0 1]; % dB
set(gca, 'Box', 'on', 'LineWidth', 2, ...
    'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'XTick', 5:5:40, 'YTick', 0:0.2:1, ...
    'FontSize', 14, 'Fontweight', 'bold')
plot(z, specLoudness7Harmonics, 'Color', blueGreen, 'LineWidth', 2)
axis([0 Hz2ERB(fr(end)) rangeYAxis])
xlabel('Cam')
ylabel('spec. loudness (sone/ERB)')
txt = [sprintf('%6d, ', f7Harmonics(1:end-1)) sprintf(' and %4d %s ', ...
    f7Harmonics(end), 'Hz')];
text(1, 0.9, txt, 'FontSize', 12, 'Fontweight', 'bold')
txt = sprintf('%5.2f sone', loudness7);
text(27, 0.9, txt, 'FontSize', 12, 'Fontweight', 'bold')

% Plot specific loudness distribution of two-tone complex
panel = panel+1;
axes('Position', pos(panel,:))
set(gca, 'Box', 'on', 'LineWidth', 2, ...
    'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'XTick', 5:5:40, 'XTickLabel', [], ...
    'YTick', 0:0.2:1, 'YTickLabel', 0:0.2:1, ...
    'FontSize', 14, 'Fontweight', 'bold')
plot(z, specLoudness2Harmonics, 'Color', blueGreen, 'LineWidth', 2)
axis([0 Hz2ERB(fr(end)) rangeYAxis])
ylabel('spec. loudness (sone/ERB)')
txt = [sprintf('%6d, ', f2Harmonics(1:end-1)) sprintf(' and %4d %s ', ...
    f2Harmonics(end), 'Hz')];
text(1, 0.9, txt, 'FontSize', 12, 'Fontweight', 'bold')
txt = sprintf('%5.2f sone', loudness2);
text(27, 0.9, txt, 'FontSize', 12, 'Fontweight', 'bold')


