clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define the stimulus
sampleFrequency = 10000; % Hz
dt = 1/sampleFrequency;
durationBurst = 0.2; % sec
centreFrequency = 1500; % Hz
fade = 0.01; % sec
nrOfNoiseBurstsPairs = 10;
bandWidthStandard = 0.2;
bandWidth = ...
    bandWidthStandard*2.^((0:nrOfNoiseBurstsPairs-1)/3); % octaves
durationIntervalNoise = 0.1; % sec
durationIntervalBetweenPairs = 0.4; % sec
intervalNoise = zeros(size(dt:dt:durationIntervalNoise));
intervalBetweenPairs = ...
    zeros(size(dt:dt:durationIntervalBetweenPairs));
ampNoise = 0.7;

% Synthesize the stimulus
noise = ampNoise*randn(size(dt:dt:durationBurst));
c = 2*centreFrequency/sampleFrequency;
w = [c*2^(-bandWidth(1)/2) c*2^(bandWidth(1)/2)];
[b, a] = butter(6, w);
standardBurst = filter(b, a, noise);
standardBurst = FadeInOut(standardBurst, sampleFrequency, fade, fade);
standardBurstRms = rms(standardBurst)*dt;
stimulus = intervalNoise;
for k = 1:length(bandWidth)
    w = [c*2^(-bandWidth(k)/2) c*2^(bandWidth(k)/2)];
    [b, a] = butter(6, w);
    burst = filter(b, a, noise);
    burst = FadeInOut(burst, sampleFrequency, fade, fade);
    burstRms = rms(burst)*dt;
    burst = standardBurstRms/burstRms*burst;
    stimulus = [stimulus ...
        standardBurst intervalNoise ...
        burst intervalBetweenPairs]; %#ok<AGROW>
end
mas = max(abs(stimulus));
if mas > 1
    stimulus = stimulus/mas;
    warning('Noise scaled by a factor: %4.2f\n', mas);
end

% Calculate the spectrograms
nFft = 2048; % Number of samples in fft window
nWindow = 512;
nOverlap = nWindow-64;
[~, fMid, tsMid, spcgrMid] = spectrogram(stimulus, ...
    nWindow, nOverlap, nFft, sampleFrequency);
spcgrMid = 10*log10(abs(spcgrMid));

% Save and play the sound segment
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position of figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = 180; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 70; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Calculate the plot parameters
dXTick = 2; % sec
dYTick = 1; % kHz
maxYAxis = 3000; % Hz
durationStimulus = length(stimulus)*dt; % sec
xTick = -dXTick:dXTick:durationStimulus;
tAxis = [-0.1*dXTick durationStimulus+0.1*dXTick];
fAxis = [-20 maxYAxis+20];

% Plot the spectrogram
dBRange = 30;
panel = 1;
axes('Position', pos(panel,:))
PlotSpectrogram(stimulus, sampleFrequency, ...
    fMid, tsMid, spcgrMid, tAxis, dXTick, fAxis, dYTick, ...
    dBRange, lightYellowGreen)
set(gca, 'XTick', xTick, 'XTickLabel', xTick)
text(0.99*tAxis(1)+0.01*tAxis(2), ...
    0.1*fAxis(1)+0.9*(fAxis(2)-fAxis(1)), ...
    'spectrogram', 'FontSize', 14, 'FontWeight', 'bold')
xlabel('time (s)')

