clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define the gammatones
sampleFrequency = 44100; % Hz
dt = 1/sampleFrequency;
toneDuration = 0.03; % sec
f = 500; % Hz
gamma = 4;

% Calculate the stimulus
t = dt:dt:toneDuration;
gammatones = zeros(length(gamma), length(t));
gammachirps = zeros(length(gamma), length(t));
penv = zeros(length(gamma), length(t));
c = 2;
for g = 1:length(gamma)
    gm1 = gamma(g)-1;
    tau = toneDuration/(gamma(g)*4); % sec
    % tmax = gm1*tau;
    ymax = (gm1^gm1)*(tau^gm1)*exp(-gm1);
    penv(g,:) = (t.^gm1).*exp(-t/tau)./ymax;
    gt = penv(g,:).*sin(2*pi*f*t);
    gc = penv(g,:).*sin(2*pi*f*t+c*log(t));
    durationStimulus = length(gt)*dt; % sec
    gammatones(g,:) = gt;
    gammachirps(g,:) = gc;
end

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position of figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = 120*ones(size(gamma)); % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 70; % pixels
xMargin = 20; % pixels
yMargin = 20; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Plot the gammatones
dXTick = 0.005;
tAxis = [-0.8*dXTick durationStimulus+0.8*dXTick];
xTicks = -dXTick:dXTick:durationStimulus;
for g = 1:length(gamma)
    durationStimulus = length(gt)*dt; % sec
    axes('Position', pos(g,:))
    set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
        'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
        'FontWeight', 'bold', 'TickDir', 'out', ...
        'XTick', xTicks)
    if g == 1
        set(gca, 'XTickLabel', 1000*xTicks, 'YTick', -1:1)
        plot([0 0], [-penv(1) penv(1)], 'Color', red)
        xlabel('time (ms)', 'FontWeight', 'bold', 'FontSize', 14)
    else
        set(gca, 'XTickLabel', [], 'YTick', -1:1)
    end
    plot(t, penv(g,:), '--', 'Color', red, 'LineWidth', 1)
    plot(t, -penv(g,:), '--', 'Color', red, 'LineWidth', 1)
    plot(t, gammachirps(g,:), 'LineWidth', 2, 'Color', blueGreen)
    plot(t, gammatones(g,:), ':', 'LineWidth', 1, 'Color', blueGreen)
    plot(tAxis, [0 0], 'LineWidth', 2, 'Color', blueGreen)
    axis([tAxis -1.2 1.2])
    txt = '$ \boldmath \gamma $';
    text(-0.6*dXTick, 0.6, sprintf('%s = %d', txt, gamma(g)), ...
        'FontSize', 12, 'Interpreter', 'latex')
    ylabel('signal value', 'FontWeight', 'bold', 'FontSize', 14)
end


