clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Calculate the pulse series
sampleFrequency = 22050; % Hz
dt = 1/sampleFrequency;
durationPulses = 0.1; % sec
durationInterval = 0.02; % sec
tPulses = dt:dt:durationPulses;
tInterval = dt:dt:durationInterval;
interval = zeros(size(tInterval));
stimulus = zeros(size(tPulses));
f0 = 200; % Hz
T0 = 1/f0;
p = round((0:T0:durationPulses-dt)*sampleFrequency)+1;
stimulus(p) = 0.9;
stimulus = [interval stimulus interval interval];
t = (1:length(stimulus))*dt;
segment = [0.029 0.059];

% Save and play the stimulus
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the dBA filter
[b_dBA, a_dBA] = Calculate_dBAFilter(sampleFrequency);
stimulusDBA = filter(b_dBA, a_dBA, stimulus);

% Calculate the center frequencies of the gammatone filterbank
numberOfFilters = 128;
minimumFrequency = 100;
maximumFrequency = sampleFrequency/2;
centerFrequencies = ...
    CalculateCenterFrequencies(numberOfFilters, ...
    minimumFrequency, maximumFrequency);
% Calculate the filter coefficients of the gammatone filter bank
[b, a] = ...
    CalculateGammatoneFilterBank(sampleFrequency, centerFrequencies);

% Band-pass filtering
basilarMembrane = zeros(numberOfFilters, length(stimulusDBA));
for k = 1:numberOfFilters
    basilarMembrane(k,:) = filter(b(k,:), a(k,:), stimulusDBA);
end

% half-wave rectification and compression
cochleogram = (basilarMembrane+abs(basilarMembrane))/2;
cochleogram = cochleogram.^(1/3);

% low-pass filtering
cutoffFrequency = 3000; % Hz
[b, a] = butter(4, 2*cutoffFrequency/sampleFrequency);
for k = 1:numberOfFilters
    cochleogram(k,:) = filter(b, a, cochleogram(k,:));
end

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = [300 300 120]; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 90; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the position of the panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Calculate plot parameters
xTick = 0:0.005:t(end);
yticklabel = [50 100 200 500 1000 2000 5000 10000 20000];
ytick = ...
    spline(centerFrequencies, 1:numberOfFilters, yticklabel);

% plot the cochleogram
panel = 1;
axes('Position', pos(panel,:))
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
    'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', xTick, 'XTickLabel', 1000*xTick, ...
    'YTick', ytick, 'YTickLabel', yticklabel/1000)
surface(t, 1:numberOfFilters, cochleogram, 'EdgeColor', 'none');
plot([t(1) t(end) t(end) t(1)], [1 1  numberOfFilters numberOfFilters], ...
    'k', 'LineWidth', 1.5)
xlabel('time (ms)')
ylabel('frequency (kHz)')
caxis([0 max(cochleogram(:))])
axis([segment 0 0.95*numberOfFilters])

% plot some filter outputs
panel = panel+1;
axes('Position', pos(panel,:))
filterFrequencyLabels = [200 400 600 1000 1500 2000 3000 5000];
filterFrequencies = ...
    spline(centerFrequencies, 1:numberOfFilters, filterFrequencyLabels);    
shift = round(filterFrequencies);
set(gca, 'LineWidth', 1.5, 'FontSize', 12, ...
    'Box', 'on', 'NextPlot', 'add', 'Color', lightYellowGreen, ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', xTick, 'XTickLabel', [], ...
    'YTick', shift, 'YTickLabel', filterFrequencyLabels/1000)
for k = 1:length(filterFrequencies)
    plot(t, shift(k)+25*cochleogram(shift(k),:), ...
        'LineWidth', 1.5, 'Color', blueGreen)
end
ylabel('frequency (kHz)', 'FontSize', 14)
axis([segment 0 0.95*numberOfFilters])

% plot the sound signal
panel = panel+1;
axes('Position', pos(panel,:))
plot(t, stimulus, 'LineWidth', 2, 'Color', blueGreen)
ylabel('signal')
axis([segment -0.4 1.1])
set(gca, 'LineWidth', 1.5, 'FontSize', 14, ...
    'Box', 'on', 'Color', lightYellowGreen, ...
    'FontWeight', 'bold', 'TickDir', 'out', ...
    'XTick', xTick, 'XTickLabel', [], ...
    'YTick', -1:1, 'YTickLabel', -1:1)


