clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Define the stimulus
sampleFrequency = 10000; % Hz
dt = 1/sampleFrequency;
nrOfTones = 10;
durationIntervalTone = 0.1; % sec
centreFrequency = 1200; % Hz
fade = 0.01; % sec
ampTone = 0.10;
nrOfNoiseBursts = 8;
bandWidth = 1./2.^(0:nrOfNoiseBursts-1); % octaves
durationIntervalNoise = 0.2; % sec
intervalNoise = zeros(size(dt:dt:durationIntervalNoise));
ampNoise = 0.15;

% Synthesize the stimulus
% Synthesize the staircase
intervalTone = zeros(size(dt:dt:durationIntervalTone));
durationTone = 0.3; % sec
tTone = dt:dt:durationTone;
amp = ampTone*sqrt(2).^(-(nrOfTones-1:-1:0));
tone = sin(2*pi*centreFrequency*tTone);
tone = FadeInOut(tone, sampleFrequency, fade, fade);
staircase = repmat(intervalTone, 1, 5);
for k = 1:nrOfTones
    staircase = [staircase intervalTone amp(k)*tone]; %#ok<AGROW>
end
staircase = [staircase repmat(intervalTone, 1, 5)];
% Synthesize the noise and add the staircase
noise = ampNoise*randn(size(staircase));
noise = FadeInOut(noise, sampleFrequency, fade, fade);
c = 2*centreFrequency/sampleFrequency;
stimulus = intervalNoise;
for k = 1:length(bandWidth)
    w = [c*2^(-bandWidth(k)/2) c*2^(bandWidth(k)/2)];
    [b, a] = butter(4, w, 'stop');
    burst = filter(b, a, noise);
    stimulus =  ...
        [stimulus burst+staircase intervalNoise]; %#ok<AGROW>
end
mas = max(abs(stimulus));
if mas > 1
    stimulus = stimulus/mas;
    warning('Noise scaled by a factor: %4.2f\n', mas);
end

% Calculate the spectrograms
nFft = 2048; % Number of samples in fft window
nWindow = 512;
nOverlap = nWindow-16;
[~, fMid, tsMid, spcgrMid] = spectrogram(stimulus, ...
    nWindow, nOverlap, nFft, sampleFrequency);
spcgrMid = 10*log10(abs(spcgrMid));

% Save and play the sound segment
wavFileName = sprintf('wavFiles/%s.wav', mfilename);
audiowrite(wavFileName, stimulus, sampleFrequency)
sound(stimulus, sampleFrequency)

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position of figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = 180; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 70; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

% Calculate the plot parameters
dXTick = 5; % sec
dYTick = 1; % kHz
maxYAxis = 3000; % Hz
durationStimulus = length(stimulus)*dt; % sec
xTick = -dXTick:dXTick:durationStimulus;
tAxis = [-0.1*dXTick durationStimulus+0.1*dXTick];
fAxis = [-20 maxYAxis+20];

% Plot the spectrogram
dBRange = 30;
axes('Position', pos(1,:))
PlotSpectrogram(stimulus, sampleFrequency, ...
    fMid, tsMid, spcgrMid, tAxis, dXTick, fAxis, dYTick, ...
    dBRange, lightYellowGreen)
set(gca, 'XTick', xTick, 'XTickLabel', xTick)
text(0.99*tAxis(1)+0.01*tAxis(2), ...
    0.1*fAxis(1)+0.9*(fAxis(2)-fAxis(1)), ...
    'spectrogram', 'FontSize', 14, 'FontWeight', 'bold')
xlabel('time (s)')

