clear
close all
InitializePSS()
fprintf('%s\n', mfilename);

% Calculate the position of the figure on the screen
figX0 = 270; % horizontal position of figure in pixels from left
figY0 = 120; % vertical position of figure in pixels from bottom
panelWidth = 720; % pixels
panelHeights = 450; % pixels
xLabelHeight = 70; % pixels
yLabelWidth = 70; % pixels
xMargin = 15; % pixels
yMargin = 15; % pixels
% Set the current figure handle and return the width and 
% height of the figure. 
[figWidth, figHeight] = SetGcf(figX0, figY0, ...
    panelWidth, panelHeights, ...
    xLabelHeight, yLabelWidth, xMargin, yMargin, ...
    frameColor);
% Calculate the positions of panels within the figure
pos = CalculatePanelPositions(figWidth, figHeight, ...
    panelWidth, panelHeights, yLabelWidth, xLabelHeight, ...
    xMargin, yMargin);

nrOfChannels = 9;
ncp1 = nrOfChannels+1;
axes('Position', [0 0.05 1 0.9])
axis('off')
hold 'on'
axis([0 1 0 1])
set(gca, 'XTick', [], 'YTick', [])
boxHeight = 0.8/nrOfChannels;

% Outer and middle ear
xx = -1:0.1:1;
yy = 0.33*(xx.^3-3*xx.^2-xx+3);
sensitivity = [xx; fliplr(yy)];
x0 = 0.03;
boxXPos =  [0.05 0.19 0.21 0.33 0.45 0.57 0.69 0.81];
boxWidth = [0.12 0.12 0.09 0.09 0.09 0.09 0.09 0.12];
box = 1;
rectangle('Position', ...
    [boxXPos(box) 0.5-0.5*boxHeight boxWidth(box) 2*boxHeight], ...
    'LineWidth', 2)
plot(boxXPos(box)+0.5*boxWidth(box)+0.4*boxWidth(box)*sensitivity(1,:), ...
    0.5-0.3*boxHeight+1.6*boxHeight*sensitivity(2,:), ...
            'LineWidth', 2, 'Color', blueGreen)
plot([x0 boxXPos(box)], [0.5+0.5*boxHeight 0.5+0.5*boxHeight], 'k')
plot([boxXPos(box)+boxWidth(1) boxXPos(box+1)], ...
    [0.5+0.5*boxHeight 0.5+0.5*boxHeight], 'k')
plot([boxXPos(2) boxXPos(2)], ...
    [nrOfChannels/ncp1 1/ncp1]+0.5*boxHeight, 'k')
text(boxXPos(box)+0.5*boxWidth(box), 0.3/ncp1, 'dBA filter', ...
    'FontWeight', 'bold', 'HorizontalAlignment', 'center')

% Auditory filter bank
dx = 0.1;
xpar = -1:dx:1;
ypar = 1-xpar.*xpar;
parabola = [xpar; ypar];
box = 3;
for nc = nrOfChannels:-1:1
    if nc>4 || nc==1
        boxYPos = nc/ncp1;
        boxPos = [boxXPos(box) boxYPos boxWidth(box) boxHeight];
        rectangle('Position', boxPos, 'LineWidth', 2)
        plot(boxXPos(box)+0.9*boxWidth(box)*(ncp1-nc)/nrOfChannels+0.06*boxWidth(box)*parabola(1,:), ...
            boxYPos+0.12*boxHeight+0.7*boxHeight*parabola(2,:), ...
            'LineWidth', 2, 'Color', blueGreen)
        plot([boxXPos(box-1) boxXPos(box)], [boxYPos+0.5*boxHeight boxYPos+0.5*boxHeight], 'k')
    else
        boxYPos = nc/ncp1;
        boxPos = [boxXPos(box) boxYPos boxWidth(box) boxHeight];
        plot(boxXPos(box)+0.5*boxWidth(box),...
            boxYPos+0.5*boxHeight, '.k', 'MarkerSize', 15)
    end
end
text(boxXPos(box)+0.5*boxWidth(box+1), 0.3/ncp1, 'BPF', ...
    'FontWeight', 'bold', 'HorizontalAlignment', 'center')

% Automatic gain control and half-wave rectification
dx = 0.1;
xpar = -1.0:dx:1;
ypar = zeros(size(xpar));
i = 1;
x = xpar(1);
while x<=xpar(end)
   if x > -0.3
       ypar(i) = 0.8*(xpar(i)+0.3)^(1/3);
   end
   x = x+dx;
   i = i+1;
end
rectifier = [xpar; ypar];
box = box+1;
for nc = nrOfChannels:-1:1
    if nc>4 || nc==1
        boxYPos = nc/ncp1;
        boxPos = [boxXPos(box) boxYPos boxWidth(box) boxHeight];
        rectangle('Position', boxPos, 'LineWidth', 2)
        plot(boxXPos(box) + 0.5*boxWidth(box) + 0.3*boxWidth(box)*rectifier(1,:), ...
            boxYPos + 0.2*boxHeight+0.7*boxHeight*rectifier(2,:), ...
            'LineWidth', 2, 'Color', blueGreen)
        plot([boxXPos(box-1)+boxWidth(box) boxXPos(box)], [boxYPos+0.5*boxHeight boxYPos+0.5*boxHeight], 'k')
    else
        boxYPos = nc/ncp1;
        boxPos = [boxXPos(4) boxYPos boxWidth(box) boxHeight];
        plot(boxXPos(4)+0.5*boxWidth(box),...
            boxYPos+0.5*boxHeight, '.k', 'MarkerSize', 15)
    end
end
text(boxXPos(box)+0.5*boxWidth(box-1), 0.3/ncp1, 'AGC and HWR', ...
    'FontWeight', 'bold', 'HorizontalAlignment', 'center')

% Low-pass filtering
dx = 0.1;
xpar = -1.0:dx:1.2;
lpfpar = zeros(size(xpar));
i = 1;
x = xpar(1);
while x<=xpar(end)
    if x>0.2
        lpfpar(i) = 1-(x-0.2)*(x-0.2);
    else
        lpfpar(i) = 1;
    end
    x = x+dx;
    i = i+1;
end
lpf = [xpar; lpfpar];
box = box+1;
for nc = nrOfChannels:-1:1
    if nc>4 || nc==1
        boxYPos = nc/ncp1;
        boxPos = [boxXPos(box) boxYPos boxWidth(box) boxHeight];
        rectangle('Position', boxPos, 'LineWidth', 2)
        plot(boxXPos(box) + 0.5*boxWidth(box) + 0.3*boxWidth(box)*lpf(1,:), ...
            boxYPos + 0.2*boxHeight+0.6*boxHeight*lpf(2,:), ...
            'LineWidth', 2, 'Color', blueGreen)
        plot([boxXPos(box-1)+boxWidth(box) boxXPos(box)], [boxYPos+0.5*boxHeight boxYPos+0.5*boxHeight], 'k')
        plot([boxXPos(box)+boxWidth(box) boxXPos(box+1)], [boxYPos+0.5*boxHeight boxYPos+0.5*boxHeight], 'k')
    else
        boxYPos = nc/ncp1;
        boxPos = [boxXPos(box) boxYPos boxWidth(box) boxHeight];
        plot(boxXPos(box)+0.5*boxWidth(box),...
            boxYPos+0.5*boxHeight, '.k', 'MarkerSize', 15)
    end
end
text(boxXPos(box)+0.5*boxWidth(box-1), 0.3/ncp1, 'LPF', ...
    'FontWeight', 'bold', 'HorizontalAlignment', 'center')

% Spike generation
dx = 0.1;
xpar = -1.0:dx:1.2;
i = 1;
x = xpar(1);
while x<=xpar(end)
    if x>0.2
        sgpar(i) = 1; %#ok<SAGROW>
    else
        sgpar(i) = 0; %#ok<SAGROW>
    end
    x = x+dx;
    i = i+1;
end
sg = [xpar; sgpar];
box = box+1;
for nc = nrOfChannels:-1:1
    if nc>4 || nc==1
        boxYPos = nc/ncp1;
        boxPos = [boxXPos(box) boxYPos boxWidth(box) boxHeight];
        rectangle('Position', boxPos, 'LineWidth', 2)
        plot(boxXPos(box)+0.5*boxWidth(box)+0.3*boxWidth(box)*sg(1,:), ...
            boxYPos+0.2*boxHeight+0.6*boxHeight*sg(2,:), ...
            'LineWidth', 2, 'Color', blueGreen)
        plot([boxXPos(box-1)+boxWidth(box) boxXPos(box)], [boxYPos+0.5*boxHeight boxYPos+0.5*boxHeight], 'k')
        plot([boxXPos(box)+boxWidth(box) boxXPos(box+1)], [boxYPos+0.5*boxHeight boxYPos+0.5*boxHeight], 'k')
    else
        boxYPos = nc/ncp1;
        boxPos = [boxXPos(box) boxYPos boxWidth(box) boxHeight];
        plot(boxXPos(box)+0.5*boxWidth(box),...
            boxYPos+0.5*boxHeight, '.k', 'MarkerSize', 15)
    end
end
text(boxXPos(box)+0.5*boxWidth(box-1), 0.3/ncp1, 'SG', ...
    'FontWeight', 'bold', 'HorizontalAlignment', 'center')

% Autocorrelation
dx = 0.1;
xpar = -1.0:dx:1.2;
i = 6;
x = xpar(6);
acpar = zeros(size(xpar));
while x<=xpar(end)
    acpar(i) = 1;
    x = x+6*dx;
    i = i+6;
end
sg = [xpar; acpar];
box = box+1;
for nc = nrOfChannels:-1:1
    if nc>4 || nc==1
        boxYPos = nc/ncp1;
        boxPos = [boxXPos(box) boxYPos boxWidth(box) boxHeight];
        rectangle('Position', boxPos, 'LineWidth', 2)
        plot(boxXPos(box)+0.5*boxWidth(box)+0.3*boxWidth(box)*sg(1,:), ...
            boxYPos+0.2*boxHeight+0.6*boxHeight*sg(2,:), ...
            'LineWidth', 2, 'Color', blueGreen)
        plot([boxXPos(box)+boxWidth(box) boxXPos(box+1)], ...
            [boxYPos+0.5*boxHeight boxYPos+0.5*boxHeight], 'k')
    else
        boxYPos = nc/ncp1;
        boxPos = [boxXPos(box) boxYPos boxWidth(box) boxHeight];
        plot(boxXPos(box)+0.5*boxWidth(box),...
            boxYPos+0.5*boxHeight, '.k', 'MarkerSize', 15)
    end
end
text(boxXPos(box)+0.5*boxWidth(box-1), 0.3/ncp1, 'AC', ...
    'FontWeight', 'bold', 'HorizontalAlignment', 'center')

% Summary autocorrelation
box = box+1;
boxYPos = (1+0.65*nrOfChannels)/ncp1;
text(boxXPos(box)+0.5*boxWidth(box), boxYPos, 'pitch', ...
    'FontWeight', 'bold', 'HorizontalAlignment', 'center')
boxYPos = (1+0.35*nrOfChannels)/ncp1;
text(boxXPos(box)+0.5*boxWidth(box), boxYPos, 'estimation', ...
    'FontWeight', 'bold', 'HorizontalAlignment', 'center')
rectangle('Position', ...
    [boxXPos(box) 1/ncp1 boxWidth(box) (nrOfChannels-1)/ncp1+boxHeight], ...
    'LineWidth', 2)

text(boxXPos(box)+0.5*boxWidth(box), 0.3/ncp1, 'SAC', ...
    'FontWeight', 'bold', 'HorizontalAlignment', 'center')

